@@ -78,13 +78,13 @@ void AP_UnixDialog_GenericInput::runModal(XAP_Frame * pFrame)
 GtkWidget * AP_UnixDialog_GenericInput::_constructWindow(void)
 {
 	GtkWidget* window;
-	//const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 	
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_GenericInput.xml";
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_GenericInput.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_GenericInput-2.ui");
+#endif
 	
 	// Update our member variables with the important widgets that 
 	// might need to be queried or altered later
@@ -93,7 +93,7 @@ GtkWidget * AP_UnixDialog_GenericInput::_constructWindow(void)
 	m_wInput = GTK_WIDGET(gtk_builder_get_object(builder, "edInput"));
 
 	// set the dialog title
-	abiDialogSetTitle(window, getTitle().utf8_str());
+	abiDialogSetTitle(window, "%s", getTitle().utf8_str());
 	
 	// set the question
 	gtk_label_set_text(GTK_LABEL(GTK_WIDGET(gtk_builder_get_object(builder, "lbQuestion"))), getQuestion().utf8_str());
