@@ -94,6 +94,9 @@
 #ifdef ABICOLLAB_HANDLER_SIPSIMPLE
 #include <backends/sipsimple/unix/SIPSimpleUnixAccountHandler.h>
 #endif
+#ifdef ABICOLLAB_HANDLER_FAKE
+#include <backends/fake/xp/FakeAccountHandler.h>
+#endif
 
 // event includes
 #include <account/xp/Event.h>
@@ -286,6 +289,10 @@ bool AbiCollabSessionManager::registerAccountHandlers()
 #endif
 #ifdef ABICOLLAB_HANDLER_SIPSIMPLE
 	m_regAccountHandlers[SIPSimpleAccountHandler::getStaticStorageType()] = SIPSimpleAccountHandlerConstructor;
+#endif
+#ifdef ABICOLLAB_HANDLER_FAKE
+	AccountHandler *pFakeHandler = new FakeAccountHandler("FakeAbiCollabBackend", NULL);
+	addAccount(pFakeHandler);
 #endif
 	return true;
 }
@@ -308,6 +315,7 @@ void AbiCollabSessionManager::unregisterSniffers(void)
 		IE_ImpSniffer* pSniffer = m_vImpSniffers[i];
 		UT_continue_if_fail(pSniffer);
 		IE_Imp::unregisterImporter(pSniffer);
+		delete pSniffer;
 	}
 	m_vImpSniffers.clear();
 }
@@ -359,7 +367,9 @@ void AbiCollabSessionManager::loadProfile()
 						// TODO: check if this node is really an AccountHandler node
 
 						// find the account handler belonging to this type
-						UT_UTF8String handlerType = reinterpret_cast<char *>(xmlGetProp(accountNode, reinterpret_cast<const xmlChar*>("type"))); 
+						xmlChar* prop = xmlGetProp(accountNode, BAD_CAST "type");
+						UT_UTF8String handlerType = reinterpret_cast<char *>(prop); 
+						xmlFree(prop);
 						std::map<UT_UTF8String, AccountHandlerConstructor>::iterator handler_iter = m_regAccountHandlers.find(handlerType);
 						if (handler_iter == m_regAccountHandlers.end())
 						    continue; // could happen for example when the sugar backend is found in the profile, which does not have a registered account handler belowing to it for now
@@ -1563,7 +1573,7 @@ bool AbiCollabSessionManager::_nullUpdate()
 		}
 	}
 	Sleep(10);
-#elif defined(TOOLKIT_GTK)
+#elif defined(TOOLKIT_GTK_ALL)
 		for (UT_sint32 i = 0; (i < 10) && gtk_events_pending(); i++)
 			gtk_main_iteration ();
 		usleep(1000*10);
