@@ -45,6 +45,7 @@
 #include "ut_string.h"
 #include "ev_UnixToolbar.h"
 #include "xap_Types.h"
+#include "xap_Gtk2Compat.h"
 #include "xap_UnixApp.h"
 #include "xap_UnixFrameImpl.h"
 #include "ev_Toolbar_Actions.h"
@@ -62,6 +63,7 @@
 #include "xap_UnixFontPreview.h"
 #include "xap_FontPreview.h"
 #include "ut_string_class.h"
+#include "pt_PieceTable.h"
 #include "ap_Toolbar_Id.h"
 #include "ap_UnixStockIcons.h"
 #include "ev_UnixFontCombo.h"
@@ -76,6 +78,12 @@
 
 #define PROP_HANDLER_ID "handler-id"
 
+#ifndef UINT_RGBA_R
+#	define UINT_RGBA_R GO_COLOR_UINT_R
+#	define UINT_RGBA_G GO_COLOR_UINT_G
+#	define UINT_RGBA_B GO_COLOR_UINT_B
+#endif
+
 class _wd;
 
 static void s_proxy_activated(GtkAction * action, _wd * wd);
@@ -541,6 +549,7 @@ public:									// we create...
  	 */
 	static void s_combo_apply_changes(GtkComboBox * combo, _wd * wd)
 	{
+		const char *text;
 		// TODO Rob: move this into ev_UnixFontCombo
 		gchar *buffer = NULL;
 		GtkTreeModel *model = gtk_combo_box_get_model (combo);
@@ -573,7 +582,12 @@ public:									// we create...
 			}
 		}
 
-		UT_UCS4String ucsText(buffer);
+		if (wd->m_id == AP_TOOLBAR_ID_FMT_STYLE)
+			text = pt_PieceTable::s_getUnlocalisedStyleName(buffer);
+		else
+			text = buffer;
+
+		UT_UCS4String ucsText(text);
 		wd->m_pUnixToolbar->toolbarEvent(wd, ucsText.ucs4_str(), ucsText.length());
 		g_free (buffer);
 	}
@@ -598,9 +612,9 @@ s_fore_color_changed (GOComboColor 	* /*cc*/,
 	UT_return_if_fail (wd);
 
 	str = UT_UTF8String_sprintf ("%02x%02x%02x", 
-								 GO_COLOR_UINT_R (color),
-								 GO_COLOR_UINT_G (color),
-								 GO_COLOR_UINT_B (color));
+								 UINT_RGBA_R (color),
+								 UINT_RGBA_G (color),
+								 UINT_RGBA_B (color));
 	wd->m_pUnixToolbar->toolbarEvent(wd, str.ucs4_str().ucs4_str(), str.size());
 }
 
@@ -620,9 +634,9 @@ s_back_color_changed (GOComboColor 	* /*cc*/,
 		str = "transparent";
 	} else {
 		str = UT_UTF8String_sprintf ("%02x%02x%02x", 
-								 GO_COLOR_UINT_R (color),
-								 GO_COLOR_UINT_G (color),
-								 GO_COLOR_UINT_B (color));
+								 UINT_RGBA_R (color),
+								 UINT_RGBA_G (color),
+								 UINT_RGBA_B (color));
 	}
 
 	wd->m_pUnixToolbar->toolbarEvent(wd, str.ucs4_str().ucs4_str(), str.size());
@@ -860,7 +874,6 @@ bool EV_UnixToolbar::synthesize(void)
 
 	//m_wHSizeGroup = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 	m_wVSizeGroup = gtk_size_group_new(GTK_SIZE_GROUP_VERTICAL);
-	g_object_ref(m_wVSizeGroup);
 
 	for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 	{
@@ -904,7 +917,7 @@ bool EV_UnixToolbar::synthesize(void)
 					GtkWidget * abi_table = abi_table_new();
 					const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
                     std::string sTable;
-					pSS->getValueUTF8(XAP_STRING_ID_TB_Table,sTable);
+					pSS->getValueUTF8(XAP_STRING_ID_TB_Rows_x_Cols_Table,sTable);
                     std::string sCancel;
 					pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel,sCancel);
 
@@ -1063,6 +1076,12 @@ bool EV_UnixToolbar::synthesize(void)
 					else {
 						for (gint m=0; m < items; m++) {
 							const char * sz = v->getNthItem(m);
+							UT_UTF8String sLoc;
+							if (wd->m_id == AP_TOOLBAR_ID_FMT_STYLE)
+							{
+								pt_PieceTable::s_getLocalisedStyleName(sz, sLoc);
+								sz = sLoc.utf8_str();
+							}
 							gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), sz);
 						}
 					}
@@ -1093,12 +1112,16 @@ bool EV_UnixToolbar::synthesize(void)
 				UT_ASSERT (g_ascii_strcasecmp(pLabel->getIconName(),"NoIcon") != 0);
 
 			    if (pAction->getItemType() == EV_TBIT_ColorFore) {
+					const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
+                    std::string sClear;
+					pSS->getValueUTF8(XAP_STRING_ID_TB_ClearForeground,sClear);
+
 					action_name = "dlgColorPickerFore";
 					stock_id = ABIWORD_COLOR_FORE;
 					pixbuf = gtk_widget_render_icon (m_wToolbar, ABIWORD_COLOR_FORE, 
 													 GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 					cg = go_color_group_fetch ("fore_color_group", m_wToolbar);
-					combo = go_combo_color_new (pixbuf, pLabel->getToolbarLabel(), 0, cg);
+					combo = go_combo_color_new (pixbuf, sClear.c_str(), 0, cg);
 
 				    wd->m_widget = combo;
 				    g_signal_connect (G_OBJECT (combo), "color-changed",
@@ -1352,6 +1375,9 @@ bool EV_UnixToolbar::refreshToolbar(AV_View * pView, AV_ChangeMask mask)
 					}
 					else if (wd->m_id == AP_TOOLBAR_ID_FMT_STYLE) {
 #define BUILTIN_INDEX "builtin-index"
+						UT_UTF8String sLoc;
+						pt_PieceTable::s_getLocalisedStyleName(szState, sLoc);
+						szState = sLoc.utf8_str();
 						gint idx = GPOINTER_TO_INT(g_object_steal_data(G_OBJECT(combo), BUILTIN_INDEX));
 						if (idx > 0) {
 							gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(combo), idx);
@@ -1527,21 +1553,40 @@ bool EV_UnixToolbar::repopulateStyles(void)
 // Now make a new one.
 //
 	gint items = v->getItemCount();
-	if (ABI_IS_FONT_COMBO (combo)) {
-		const gchar **fonts = g_new0 (const gchar *, items + 1);
-		for (gint m=0; m < items; m++) {
-			fonts[m] = v->getNthItem(m);
-		}						
-		abi_font_combo_set_fonts (ABI_FONT_COMBO (combo), fonts);
-		g_free (fonts); fonts = NULL;
+
+	GtkTreeIter iter;
+	GtkListStore *list = gtk_list_store_new(1, G_TYPE_STRING);
+
+	for (gint m=0; m < items; m++) {
+		UT_UTF8String sLoc;
+		const char * sz = v->getNthItem(m);
+
+		pt_PieceTable::s_getLocalisedStyleName(sz, sLoc);
+		sz = sLoc.utf8_str();
+		gtk_list_store_append(list, &iter);
+		gtk_list_store_set(list, &iter, 0, sz, -1);
 	}
-	else {
-		for (gint m=0; m < items; m++) {
-			const char * sz = v->getNthItem(m);
-			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), sz);
-		}
+
+	GtkTreeSortable *sort;
+	sort = GTK_TREE_SORTABLE(list);
+	gtk_tree_sortable_set_sort_column_id(sort, 0, GTK_SORT_ASCENDING);
+
+	gboolean itering = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list), &iter);
+
+	while (itering)
+	{
+		gchar *entry;
+
+		gtk_tree_model_get(GTK_TREE_MODEL(list), &iter, 0, &entry, -1);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), entry);
+
+		g_free(entry);
+
+		itering = gtk_tree_model_iter_next(GTK_TREE_MODEL(list), &iter);
 	}
 
+	g_object_unref(G_OBJECT(list));    
+
 	wd->m_blockSignal = wasBlocked;
 
 //
