@@ -95,16 +95,6 @@ GR_UnixCairoGraphics::GR_UnixCairoGraphics(GdkWindow * win, bool double_buffered
 
 GR_UnixCairoGraphics::~GR_UnixCairoGraphics()
 {
-	UT_VECTOR_SPARSEPURGEALL( UT_Rect*, m_vSaveRect);
-
-	// purge saved pixbufs (SPARSE)
-	for (UT_sint32 i = 0; i < m_vSaveRectBuf.size (); i++)
-	{
-		GdkPixbuf * pix = m_vSaveRectBuf.getNthItem(i);
-		if(pix) {
-			g_object_unref (G_OBJECT (pix));
-		}
-	}
 	if (m_Widget) {
 		g_signal_handler_disconnect (m_Widget, m_Signal);
 		g_signal_handler_disconnect (m_Widget, m_DestroySignal);
@@ -123,6 +113,16 @@ GR_Graphics *   GR_UnixCairoGraphics::graphicsAllocator(GR_AllocInfo& info)
 	return new GR_UnixCairoGraphics(AI.m_win, AI.m_double_buffered);
 }
 
+inline UT_RGBColor _convertGdkColor(const GdkColor &c)
+{
+	UT_RGBColor color;
+	color.m_red = c.red >> 8;
+	color.m_grn = c.green >> 8;
+	color.m_blu = c.blue >> 8;
+	return color;
+}
+
+#if GTK_CHECK_VERSION(3,0,0)
 inline UT_RGBColor _convertGdkRGBA(const GdkRGBA &c)
 {
 	UT_RGBColor color;
@@ -131,6 +131,7 @@ inline UT_RGBColor _convertGdkRGBA(const GdkRGBA &c)
 	color.m_blu = c.blue * 255;
 	return color;
 }
+#endif
 
 void GR_UnixCairoGraphics::widget_size_allocate(GtkWidget* /*widget*/, GtkAllocation* /*allocation*/, GR_UnixCairoGraphics* me)
 {
@@ -154,57 +155,84 @@ void GR_UnixCairoGraphics::initWidget(GtkWidget* widget)
 	m_DestroySignal = g_signal_connect(G_OBJECT(widget), "destroy", G_CALLBACK(widget_destroy), this);
 }
 
-void GR_UnixCairoGraphics::init3dColors(GtkStyleContext * pCtxt)
+#if GTK_CHECK_VERSION(3,0,0)
+#define COLOR_MIX 0.67   //COLOR_MIX should be between 0 and 1
+#define SQUARE(A) (A)*(A)
+void GR_UnixCairoGraphics::init3dColors(GtkWidget* w)
 {
-	GdkRGBA rgba, rgba_;
-	gtk_style_context_get_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba);
-	m_3dColors[CLR3D_Foreground] = _convertGdkRGBA(rgba);
-	gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_PRELIGHT, &rgba);
-	m_3dColors[CLR3D_Highlight]  = _convertGdkRGBA(rgba);
-	gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba);
-	m_3dColors[CLR3D_Background] = _convertGdkRGBA(rgba);
+	GtkStyleContext* pCtxt = gtk_widget_get_style_context(w);
+	GdkRGBA rgba1, rgba2, rgba_;
+	bool bUseThemeColors = true;
+
+	gtk_style_context_get_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba1);
+	gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba2);
+	if ((SQUARE(rgba1.red-rgba2.red) + SQUARE(rgba1.green-rgba2.green) + SQUARE(rgba1.blue - rgba2.blue)) < 0.01)
+	{
+		// There is very little contrast between the bg and fg colors
+		// Use default values (black for fg and white for bg)
+		// This happens for unknown reasons with some themes
+		UT_DEBUGMSG(("No contrast between the theme foreground and background colors! Use black and white instead.\n"));
+		bUseThemeColors = false;
+		rgba1.red = 0.;
+		rgba1.green = 0.;
+		rgba1.blue = 0.;
+		rgba2.red = 1.;
+		rgba2.green = 1.;
+		rgba2.blue = 1.;
+	} 
+	m_3dColors[CLR3D_Foreground] = _convertGdkRGBA(rgba1);
+	m_3dColors[CLR3D_Background] = _convertGdkRGBA(rgba2);
 	rgba_.alpha = 1.;   // we don't really care, abiword does not use transparency
-	rgba_.red = rgba.red + .1;
-	double f, rf = 1. + .1 / rgba.red;
-	if (rf > 1. / rgba.red)
-		rf = 1. / rgba.red;
-	f = 1. + .1 / rgba.green;
-	if (f < rf)
-		rf = f;
-	f = 1. + .1 / rgba.blue;
-	if (f < rf)
-		rf = f;
-	rgba_.red = rgba.red * rf;
-	rgba_.green = rgba.green* rf;
-	rgba_.blue = rgba.blue * rf;
+	rgba_.red = rgba1.red*COLOR_MIX + rgba2.red*(1.-COLOR_MIX);
+	rgba_.green = rgba1.green*COLOR_MIX + rgba2.green*(1.-COLOR_MIX);
+	rgba_.blue = rgba1.blue*COLOR_MIX + rgba2.blue*(1.-COLOR_MIX);
 	m_3dColors[CLR3D_BevelUp]    = _convertGdkRGBA(rgba_);
-	rf = 1. - .1 / rgba.red;
-	f = 1. - .1 / rgba.green;
-	if (f > rf)
-		rf = f;
-	f = 1. - .1 / rgba.blue;
-	if (f > rf)
-		rf = f;
-	if (rf < .5)
-		rf = .5;
-	rgba_.red = rgba.red * rf;
-	rgba_.green = rgba.green* rf;
-	rgba_.blue = rgba.blue * rf;
+	rgba_.red = rgba1.red*(1.-COLOR_MIX) + rgba2.red*COLOR_MIX;
+	rgba_.green = rgba1.green*(1.-COLOR_MIX) + rgba2.green*COLOR_MIX;
+	rgba_.blue = rgba1.blue*(1.-COLOR_MIX) + rgba2.blue*COLOR_MIX;
 	m_3dColors[CLR3D_BevelDown]  = _convertGdkRGBA(rgba_);
+	if (bUseThemeColors)
+	{
+		gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_PRELIGHT, &rgba2);
+	}
+	m_3dColors[CLR3D_Highlight]  = _convertGdkRGBA(rgba2);
 	m_bHave3DColors = true;
 }
+#undef COLOR_MIX
+#undef SQUARE
+#else
+void GR_UnixCairoGraphics::init3dColors(GtkWidget* w)
+{
+	init3dColors(w->style);
+}
+void GR_UnixCairoGraphics::init3dColors(GtkStyle* pStyle)
+{
+	m_3dColors[CLR3D_Foreground] = _convertGdkColor(pStyle->text[GTK_STATE_NORMAL]);
+	m_3dColors[CLR3D_Background] = _convertGdkColor(pStyle->bg[GTK_STATE_NORMAL]);
+	m_3dColors[CLR3D_BevelUp]    = _convertGdkColor(pStyle->light[GTK_STATE_NORMAL]);
+	m_3dColors[CLR3D_BevelDown]  = _convertGdkColor(pStyle->dark[GTK_STATE_NORMAL]);
+	m_3dColors[CLR3D_Highlight]  = _convertGdkColor(pStyle->bg[GTK_STATE_PRELIGHT]);
+
+ 	m_bHave3DColors = true;
+}
+#endif
 
 GR_Font * GR_UnixCairoGraphics::getGUIFont(void)
 {
 	if (!m_pPFontGUI)
 	{
 		// get the font resource
+#if GTK_CHECK_VERSION(3,0,0)
 		GtkStyleContext *tempCtxt = gtk_style_context_new();
 		GtkWidgetPath *path = gtk_widget_path_new();
 		gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
 		gtk_style_context_set_path(tempCtxt, path);
 		gtk_widget_path_free(path);
 		const char *guiFontName = pango_font_description_get_family(gtk_style_context_get_font(tempCtxt, GTK_STATE_FLAG_NORMAL));
+#else
+		GtkStyle *tempStyle = gtk_style_new();
+		const char *guiFontName = pango_font_description_get_family(tempStyle->font_desc);
+#endif
 		if (!guiFontName)
 			guiFontName = "'Times New Roman'";
 
@@ -221,7 +249,11 @@ GR_Font * GR_UnixCairoGraphics::getGUIFont(void)
 		
 		m_pPFontGUI = new GR_PangoFont(guiFontName, 11.0, this, s.utf8_str(), true);
 
+#if GTK_CHECK_VERSION(3,0,0)
 		g_object_unref(G_OBJECT(tempCtxt));
+#else
+		g_object_unref(G_OBJECT(tempStyle));
+#endif
 		
 		UT_ASSERT(m_pPFontGUI);
 	}
@@ -351,7 +383,11 @@ void GR_UnixCairoGraphics::setCursor(GR_Graphics::Cursor c)
 	xxx_UT_DEBUGMSG(("cursor set to %d  gdk %d \n",c,cursor_number));
 	GdkCursor * cursor = gdk_cursor_new(cursor_number);
 	gdk_window_set_cursor(m_pWin, cursor);
+#if GTK_CHECK_VERSION(3,0,0)
+	g_object_unref(cursor);
+#else
 	gdk_cursor_unref(cursor);
+#endif
 }
 
 
@@ -405,7 +441,18 @@ void GR_UnixCairoGraphics::scroll(UT_sint32 x_dest, UT_sint32 y_dest,
 						  UT_sint32 x_src, UT_sint32 y_src,
 						  G_GNUC_UNUSED UT_sint32 width, G_GNUC_UNUSED UT_sint32 height)
 {
+#if !GTK_CHECK_VERSION(3,0,0)
+	GdkGC *gc;
+
+	disableAllCarets();
+	gc = gdk_gc_new(_getWindow());
+   	gdk_draw_drawable(_getWindow(), gc, _getWindow(), tdu(x_src), tdu(y_src),
+					  tdu(x_dest), tdu(y_dest), tdu(width), tdu(height));
+	g_object_unref(G_OBJECT(gc)), gc = NULL;
+	enableAllCarets();
+#else
 	scroll(x_src - x_dest, y_src - y_dest);
+#endif
 }
 
 void GR_UnixCairoGraphics::_resetClip(void)
@@ -415,54 +462,6 @@ void GR_UnixCairoGraphics::_resetClip(void)
 	xxx_UT_DEBUGMSG(("Reset clip in gtk cairo \n"));
 }
 
-void GR_UnixCairoGraphics::saveRectangle(UT_Rect & r, UT_uint32 iIndx)
-{
-	UT_Rect* oldR = NULL;	
-	cairo_save(m_cr);
-	cairo_reset_clip(m_cr);
-	m_vSaveRect.setNthItem(iIndx, new UT_Rect(r),&oldR);
-	if(oldR) {
-		delete oldR;
-	}
-
-	GdkPixbuf * oldC = NULL;
-	UT_sint32 idx = _tduX(r.left);
-	UT_sint32 idy = _tduY(r.top);
-	UT_sint32 idw = _tduR(r.width);
-	UT_sint32 idh = _tduR(r.height);
-	cairo_surface_flush ( cairo_get_target(m_cr));
-
-	GdkPixbuf * pix = gdk_pixbuf_get_from_window(_getWindow(),
-	                                             idx, idy,
-	                                             idw, idh);
-	m_vSaveRectBuf.setNthItem(iIndx, pix, &oldC);
-
-	if(oldC)
-		g_object_unref (G_OBJECT (oldC));
-	cairo_restore(m_cr);
-}	
-
-void GR_UnixCairoGraphics::restoreRectangle(UT_uint32 iIndx)
-{
-	cairo_save(m_cr);
-	cairo_reset_clip(m_cr);
-	cairo_identity_matrix(m_cr);
-	UT_Rect * r = m_vSaveRect.getNthItem(iIndx);
-	GdkPixbuf *p = m_vSaveRectBuf.getNthItem(iIndx);
-	UT_sint32 idx = _tduX(r->left);
-	UT_sint32 idy = _tduY(r->top);
-	UT_sint32 idw = _tduR(r->width);
-	UT_sint32 idh = _tduR(r->height);
-	cairo_surface_flush ( cairo_get_target(m_cr));
-
-	if (p && r) {
-		gdk_cairo_set_source_pixbuf(m_cr, p, idx, idy);
-		cairo_rectangle(m_cr, idx, idy, idw, idh);
-		cairo_fill(m_cr);
-	}
-	cairo_restore(m_cr);
-}
-
 /*!
  * Take a screenshot of the graphics and convert it to an image.
  */
@@ -474,10 +473,18 @@ GR_Image * GR_UnixCairoGraphics::genImageFromRectangle(const UT_Rect &rec)
 	UT_sint32 idh = _tduR(rec.height);
 	UT_return_val_if_fail (idw > 0 && idh > 0 && idx >= 0, NULL);
 	cairo_surface_flush ( cairo_get_target(m_cr));
+#if !GTK_CHECK_VERSION(3,0,0)
+	GdkColormap* cmp = gdk_colormap_get_system();
+	GdkPixbuf * pix = gdk_pixbuf_get_from_drawable(NULL,
+												   _getWindow(),
+												   cmp,
+												   idx, idy, 0, 0,
+												   idw, idh);
+#else
 	GdkPixbuf * pix = gdk_pixbuf_get_from_window(getWindow(),
 	                                             idx, idy,
 	                                             idw, idh);
-
+#endif
 	UT_return_val_if_fail(pix, NULL);
 
 	GR_UnixImage * pImg = new GR_UnixImage("ScreenShot");
