@@ -71,7 +71,7 @@ bool GR_EmbedView::getSnapShots(void)
   UT_UTF8String sName = "snapshot-png-";
   sName += m_sDataID;
   bool bFound = false;
-  void * pHandle = NULL;
+  PD_DataItemHandle pHandle = NULL;
   const UT_ByteBuf * pPNG = NULL;
   const UT_ByteBuf * pSVG = NULL;
   bFound = m_pDoc->getDataItemDataByName(sName.utf8_str(),&pPNG,NULL,&pHandle);
@@ -493,6 +493,10 @@ void GR_EmbedManager::setRun (UT_sint32 /*uid*/, fp_Run * /*run*/)
 {
 }
 
-void GR_EmbedManager:: updateData(UT_sint32 /*uid*/, UT_sint32 /*api*/)
+void GR_EmbedManager::updateData(UT_sint32 /*uid*/, UT_sint32 /*api*/)
+{
+}
+
+void GR_EmbedManager::setFont(UT_sint32 /*uid*/, const GR_Font * /*pFont*/)
 {
 }
