@@ -28,13 +28,16 @@
 
 TFTEST_MAIN("UT_LocaleTransactor")
 {
-/* TODO Rob: this fails with ubuntu
 	char msg[128];
-	setlocale(LC_ALL, "fr_FR");
-	
+	if (setlocale(LC_ALL, "fr_FR") == NULL)
+	{
+		printf("Test skipped, fr_FR locale is unknown on this system\n");
+		return;
+	}
+
 	sprintf(msg, "%f", 1.0f);
 	TFPASS(strstr(msg, "1,0") == msg);
-	
+
 	TFPASS(strcmp(setlocale(LC_NUMERIC, NULL), "fr_FR") == 0);
 
 	{
@@ -47,5 +50,4 @@ TFTEST_MAIN("UT_LocaleTransactor")
 	TFPASS(strcmp(setlocale(LC_NUMERIC, NULL), "fr_FR") == 0);
 	sprintf(msg, "%f", 1.0f);
 	TFPASS(strstr(msg, "1,0") == msg);
-*/
 }
