@@ -41,25 +41,29 @@ static UT_LangRecord s_Table[] =
 	//language code, localised language name, numerical id, text
 	//direction
 	{"-none-",		NULL, XAP_STRING_ID_LANG_0,     UTLANG_LTR},
+	{"ach",  		NULL, XAP_STRING_ID_LANG_ACH,   UTLANG_LTR},
 	{"af-ZA",		NULL, XAP_STRING_ID_LANG_AF_ZA, UTLANG_LTR},
 	{"ak-GH",		NULL, XAP_STRING_ID_LANG_AK_GH, UTLANG_LTR},
 	{"am-ET",		NULL, XAP_STRING_ID_LANG_AM_ET, UTLANG_LTR},
-	{"ar",			NULL, XAP_STRING_ID_LANG_AR, UTLANG_RTL},
+	{"ar",			NULL, XAP_STRING_ID_LANG_AR,    UTLANG_RTL},
 	{"ar-EG",		NULL, XAP_STRING_ID_LANG_AR_EG, UTLANG_RTL},
 	{"ar-SA",		NULL, XAP_STRING_ID_LANG_AR_SA, UTLANG_RTL},
 	{"as-IN",		NULL, XAP_STRING_ID_LANG_AS_IN, UTLANG_LTR},
-	{"ast-ES",		NULL, XAP_STRING_ID_LANG_AST_ES, UTLANG_LTR},
-	{"aym-BO",		NULL, XAP_STRING_ID_LANG_AYM_BO, UTLANG_LTR},
-	{"ayc-BO",		NULL, XAP_STRING_ID_LANG_AYC_BO, UTLANG_LTR},
-	{"ayr",			NULL, XAP_STRING_ID_LANG_AYR, UTLANG_LTR},
+	{"ast-ES",		NULL, XAP_STRING_ID_LANG_AST_ES,UTLANG_LTR},
+	{"aym-BO",		NULL, XAP_STRING_ID_LANG_AYM_BO,UTLANG_LTR},
+	{"ayc-BO",		NULL, XAP_STRING_ID_LANG_AYC_BO,UTLANG_LTR},
+	{"ayr",			NULL, XAP_STRING_ID_LANG_AYR,   UTLANG_LTR},
 	{"be-BY",		NULL, XAP_STRING_ID_LANG_BE_BY, UTLANG_LTR},
-	{"be@latin",		NULL, XAP_STRING_ID_LANG_BE_LATIN, UTLANG_LTR}, 
+	{"be@latin",		NULL, XAP_STRING_ID_LANG_BE_LATIN, UTLANG_LTR},
 	{"bg-BG",		NULL, XAP_STRING_ID_LANG_BG_BG, UTLANG_LTR},
-	{"bn-IN",       NULL, XAP_STRING_ID_LANG_BN_IN, UTLANG_LTR}, // Bengali -- is it LTR?
-	{"br-FR",		NULL, XAP_STRING_ID_LANG_BR_FR, UTLANG_LTR},		
-	{"ca-ES",		NULL, XAP_STRING_ID_LANG_CA_ES, UTLANG_LTR},	
-	{"co-FR",		NULL, XAP_STRING_ID_LANG_CO_FR, UTLANG_LTR},	
-	{"cop-EG",		NULL, XAP_STRING_ID_LANG_COP_EG, UTLANG_LTR},	
+	{"bm",   		NULL, XAP_STRING_ID_LANG_BM,    UTLANG_LTR},
+	{"bn-IN",       	NULL, XAP_STRING_ID_LANG_BN_IN, UTLANG_LTR},
+	{"br-FR",		NULL, XAP_STRING_ID_LANG_BR_FR, UTLANG_LTR},
+	{"bs-BA",		NULL, XAP_STRING_ID_LANG_BS_BA, UTLANG_LTR},
+	{"ca-ES",		NULL, XAP_STRING_ID_LANG_CA_ES, UTLANG_LTR},
+	{"cgg",  		NULL, XAP_STRING_ID_LANG_CGG,   UTLANG_LTR},
+	{"co-FR",		NULL, XAP_STRING_ID_LANG_CO_FR, UTLANG_LTR},
+	{"cop-EG",		NULL, XAP_STRING_ID_LANG_COP_EG,UTLANG_LTR},
 	{"cs-CZ",		NULL, XAP_STRING_ID_LANG_CS_CZ, UTLANG_LTR},
 	{"cy-GB",		NULL, XAP_STRING_ID_LANG_CY_GB, UTLANG_LTR},
 	{"da-DK",		NULL, XAP_STRING_ID_LANG_DA_DK, UTLANG_LTR},
@@ -77,82 +81,94 @@ static UT_LangRecord s_Table[] =
 	{"eo",			NULL, XAP_STRING_ID_LANG_EO,    UTLANG_LTR},
 	{"es-ES",		NULL, XAP_STRING_ID_LANG_ES_ES, UTLANG_LTR},
 	{"es-MX",		NULL, XAP_STRING_ID_LANG_ES_MX, UTLANG_LTR},
-	{"et",			NULL, XAP_STRING_ID_LANG_ET,    UTLANG_LTR},		// Hipi: Why not et-EE?
-	{"eu-ES",		NULL, XAP_STRING_ID_LANG_EU_ES, UTLANG_LTR},	// Hipi: What about eu-FR?
+	{"et",			NULL, XAP_STRING_ID_LANG_ET,    UTLANG_LTR},
+	{"eu-ES",		NULL, XAP_STRING_ID_LANG_EU_ES, UTLANG_LTR},
+	{"fa-AF",		NULL, XAP_STRING_ID_LANG_FA_AF, UTLANG_RTL},
 	{"fa-IR",		NULL, XAP_STRING_ID_LANG_FA_IR, UTLANG_RTL},
 	{"fi-FI",		NULL, XAP_STRING_ID_LANG_FI_FI, UTLANG_LTR},
+	{"fil-PH",		NULL, XAP_STRING_ID_LANG_FIL_PH, UTLANG_LTR},
 	{"fr-BE",		NULL, XAP_STRING_ID_LANG_FR_BE, UTLANG_LTR},
 	{"fr-CA",		NULL, XAP_STRING_ID_LANG_FR_CA, UTLANG_LTR},
 	{"fr-CH",		NULL, XAP_STRING_ID_LANG_FR_CH, UTLANG_LTR},
 	{"fr-FR",		NULL, XAP_STRING_ID_LANG_FR_FR, UTLANG_LTR},
-	{"fy-NL",		NULL, XAP_STRING_ID_LANG_FY_NL, UTLANG_LTR},	
+	{"fy-NL",		NULL, XAP_STRING_ID_LANG_FY_NL, UTLANG_LTR},
+	{"ff",			NULL, XAP_STRING_ID_LANG_FF,    UTLANG_LTR},
 	{"ga-IE",		NULL, XAP_STRING_ID_LANG_GA_IE, UTLANG_LTR},
-	{"gl",			NULL, XAP_STRING_ID_LANG_GL, UTLANG_LTR},
-	{"ha-NE",		NULL, XAP_STRING_ID_LANG_HA_NE, UTLANG_LTR},    // is this correct or just duplicate of the line below?
+	{"gl",			NULL, XAP_STRING_ID_LANG_GL,    UTLANG_LTR},
+	{"ha-NE",		NULL, XAP_STRING_ID_LANG_HA_NE, UTLANG_LTR},
 	{"ha-NG",		NULL, XAP_STRING_ID_LANG_HA_NG, UTLANG_LTR},
-	{"haw-US",      NULL, XAP_STRING_ID_LANG_HAW_US,UTLANG_LTR},
-	{"he-IL",		NULL, XAP_STRING_ID_LANG_HE_IL, UTLANG_RTL},	// was iw-IL - why?
+	{"haw-US",      	NULL, XAP_STRING_ID_LANG_HAW_US,UTLANG_LTR},
+	{"he-IL",		NULL, XAP_STRING_ID_LANG_HE_IL, UTLANG_RTL},
 	{"hi-IN",		NULL, XAP_STRING_ID_LANG_HI_IN, UTLANG_LTR},
-	{"hr-HR",		NULL, XAP_STRING_ID_LANG_HR_HR,    UTLANG_LTR},
+	{"hr-HR",		NULL, XAP_STRING_ID_LANG_HR_HR, UTLANG_LTR},
 	{"hu-HU",		NULL, XAP_STRING_ID_LANG_HU_HU, UTLANG_LTR},
-	{"hy-AM",		NULL, XAP_STRING_ID_LANG_HY_AM, UTLANG_LTR},	// Win2K shows "hy-am"
+	{"hy-AM",		NULL, XAP_STRING_ID_LANG_HY_AM, UTLANG_LTR},
 	{"ia",			NULL, XAP_STRING_ID_LANG_IA,    UTLANG_LTR},
 	{"id-ID",		NULL, XAP_STRING_ID_LANG_ID_ID, UTLANG_LTR},
 	{"is-IS",		NULL, XAP_STRING_ID_LANG_IS_IS, UTLANG_LTR},
 	{"it-IT",		NULL, XAP_STRING_ID_LANG_IT_IT, UTLANG_LTR},
 	{"iu-CA",		NULL, XAP_STRING_ID_LANG_IU_CA, UTLANG_LTR},
 	{"ja-JP",		NULL, XAP_STRING_ID_LANG_JA_JP, UTLANG_VERTICAL},	// TODO also UTLANG_LTR
+	{"jbo", 		NULL, XAP_STRING_ID_LANG_JBO,   UTLANG_LTR},
 	{"ka-GE",		NULL, XAP_STRING_ID_LANG_KA_GE, UTLANG_LTR},
-	{"kn-IN",       NULL, XAP_STRING_ID_LANG_KN_IN, UTLANG_LTR},     // is Kannada LTR?
-	{"ko-KR",		NULL, XAP_STRING_ID_LANG_KO_KR, UTLANG_VERTICAL},	// TODO also UTLANG_LTR, Hipi: What about ko-KP?
-	{"ko",			NULL, XAP_STRING_ID_LANG_KO, UTLANG_LTR},
-	{"ku",			NULL, XAP_STRING_ID_LANG_KU, UTLANG_LTR},	
-	{"kw-GB",		NULL, XAP_STRING_ID_LANG_KW_GB, UTLANG_LTR},	
-	{"la-IT",		NULL, XAP_STRING_ID_LANG_LA_IT, UTLANG_LTR},	// Hipi: Should be just "la"
-	{"lo-LA",       NULL, XAP_STRING_ID_LANG_LO_LA, UTLANG_LTR},
+	{"kk-KZ",		NULL, XAP_STRING_ID_LANG_KK_KZ, UTLANG_LTR},
+	{"km-KH",		NULL, XAP_STRING_ID_LANG_KM_KH, UTLANG_LTR},
+	{"kn-IN",       	NULL, XAP_STRING_ID_LANG_KN_IN, UTLANG_LTR},
+	{"ko-KR",		NULL, XAP_STRING_ID_LANG_KO_KR, UTLANG_VERTICAL},	// TODO also UTLANG_LTR
+	{"ko",			NULL, XAP_STRING_ID_LANG_KO,    UTLANG_LTR},
+	{"ku",			NULL, XAP_STRING_ID_LANG_KU,    UTLANG_LTR},
+	{"kw-GB",		NULL, XAP_STRING_ID_LANG_KW_GB, UTLANG_LTR},
+	{"la-IT",		NULL, XAP_STRING_ID_LANG_LA_IT, UTLANG_LTR},
+	{"lg",  		NULL, XAP_STRING_ID_LANG_LG,    UTLANG_LTR},
+	{"lo-LA",		NULL, XAP_STRING_ID_LANG_LO_LA, UTLANG_LTR},
 	{"lt-LT",		NULL, XAP_STRING_ID_LANG_LT_LT, UTLANG_LTR},
 	{"lv-LV",		NULL, XAP_STRING_ID_LANG_LV_LV, UTLANG_LTR},
+	{"mg-MG",		NULL, XAP_STRING_ID_LANG_MG_MG, UTLANG_LTR},
 	{"mh-MH",		NULL, XAP_STRING_ID_LANG_MH_MH, UTLANG_LTR},
 	{"mh-NR",		NULL, XAP_STRING_ID_LANG_MH_NR, UTLANG_LTR},
-	{"mi-NZ",       NULL, XAP_STRING_ID_LANG_MI_NZ, UTLANG_LTR},
-	{"mk",			NULL, XAP_STRING_ID_LANG_MK,    UTLANG_LTR},		// Hipi: Why not mk-MK?
-    {"mn-MN",       NULL, XAP_STRING_ID_LANG_MN_MN, UTLANG_LTR},
-    {"mnk-SN",       NULL, XAP_STRING_ID_LANG_MNK_SN, UTLANG_LTR},
-    {"mr-IN",       NULL, XAP_STRING_ID_LANG_MR_IN, UTLANG_LTR},
-    {"ms-MY",       NULL, XAP_STRING_ID_LANG_MS_MY, UTLANG_LTR},
+	{"mi-NZ",		NULL, XAP_STRING_ID_LANG_MI_NZ, UTLANG_LTR},
+	{"mk",			NULL, XAP_STRING_ID_LANG_MK,    UTLANG_LTR},
+	{"mn-MN",		NULL, XAP_STRING_ID_LANG_MN_MN, UTLANG_LTR},
+	{"mnk-SN",		NULL, XAP_STRING_ID_LANG_MNK_SN,UTLANG_LTR},
+	{"mr-IN",		NULL, XAP_STRING_ID_LANG_MR_IN, UTLANG_LTR},
+	{"ms-MY",		NULL, XAP_STRING_ID_LANG_MS_MY, UTLANG_LTR},
 	{"nb-NO",		NULL, XAP_STRING_ID_LANG_NB_NO, UTLANG_LTR},
 	{"ne-NP",		NULL, XAP_STRING_ID_LANG_NE_NP, UTLANG_LTR},
 	{"nl-BE",		NULL, XAP_STRING_ID_LANG_NL_BE, UTLANG_LTR},
 	{"nl-NL",		NULL, XAP_STRING_ID_LANG_NL_NL, UTLANG_LTR},
-	{"nn-NO",		NULL, XAP_STRING_ID_LANG_NN_NO, UTLANG_LTR},	
-    {"oc-FR",		NULL, XAP_STRING_ID_LANG_OC_FR, UTLANG_LTR},
-    {"pa-IN",       NULL, XAP_STRING_ID_LANG_PA_IN, UTLANG_LTR}, // is this LTR?
-    {"pa-PK",       NULL, XAP_STRING_ID_LANG_PA_PK, UTLANG_RTL},
+	{"nn-NO",		NULL, XAP_STRING_ID_LANG_NN_NO, UTLANG_LTR},
+	{"oc-FR",		NULL, XAP_STRING_ID_LANG_OC_FR, UTLANG_LTR},
+	{"pa-IN",		NULL, XAP_STRING_ID_LANG_PA_IN, UTLANG_LTR},
+	{"pa-PK",		NULL, XAP_STRING_ID_LANG_PA_PK, UTLANG_RTL},
 	{"pl-PL",		NULL, XAP_STRING_ID_LANG_PL_PL, UTLANG_LTR},
-	{"ps",			NULL, XAP_STRING_ID_LANG_PS, UTLANG_RTL},
+	{"ps",			NULL, XAP_STRING_ID_LANG_PS,    UTLANG_RTL},
 	{"pt-BR",		NULL, XAP_STRING_ID_LANG_PT_BR, UTLANG_LTR},
 	{"pt-PT",		NULL, XAP_STRING_ID_LANG_PT_PT, UTLANG_LTR},
 	{"qu-BO",		NULL, XAP_STRING_ID_LANG_QU_BO, UTLANG_LTR},
 	{"quh-BO",		NULL, XAP_STRING_ID_LANG_QUH_BO,UTLANG_LTR},
 	{"qul-BO",		NULL, XAP_STRING_ID_LANG_QUL_BO,UTLANG_LTR},
+	{"quz",  		NULL, XAP_STRING_ID_LANG_QUZ,   UTLANG_LTR},
 	{"ro-RO",		NULL, XAP_STRING_ID_LANG_RO_RO, UTLANG_LTR},
-	{"ru-RU",		NULL, XAP_STRING_ID_LANG_RU_RU, UTLANG_LTR},	
-	{"sc-IT",		NULL, XAP_STRING_ID_LANG_SC_IT, UTLANG_LTR},	
+	{"ru-RU",		NULL, XAP_STRING_ID_LANG_RU_RU, UTLANG_LTR},
+	{"ru@petr1708",		NULL, XAP_STRING_ID_LANG_RU_PETR1708, UTLANG_LTR},
+	{"sc-IT",		NULL, XAP_STRING_ID_LANG_SC_IT, UTLANG_LTR},
 	{"sk-SK",		NULL, XAP_STRING_ID_LANG_SK_SK, UTLANG_LTR},
 	{"sl-SI",		NULL, XAP_STRING_ID_LANG_SL_SI, UTLANG_LTR},
+	{"son", 		NULL, XAP_STRING_ID_LANG_SON,   UTLANG_LTR},
 	{"sq-AL",		NULL, XAP_STRING_ID_LANG_SQ_AL, UTLANG_LTR},
-	{"sr",			NULL, XAP_STRING_ID_LANG_SR,    UTLANG_LTR},		// Why not sr-YU?
-    {"sv-SE",		NULL, XAP_STRING_ID_LANG_SV_SE, UTLANG_LTR},
-    {"sw",          NULL, XAP_STRING_ID_LANG_SW,    UTLANG_LTR},
-    {"syr",         NULL, XAP_STRING_ID_LANG_SYR,   UTLANG_RTL}, 
-    {"ta-IN",       NULL, XAP_STRING_ID_LANG_TA_IN, UTLANG_LTR}, // is this LTR?
-    {"te-IN",       NULL, XAP_STRING_ID_LANG_TE_IN, UTLANG_LTR}, // is this LTR?
-    {"th-TH",		NULL, XAP_STRING_ID_LANG_TH_TH, UTLANG_LTR},
-    {"tl-PH",       NULL, XAP_STRING_ID_LANG_TL_PH, UTLANG_LTR},
+	{"sr",			NULL, XAP_STRING_ID_LANG_SR,    UTLANG_LTR},
+	{"sr@latin",		NULL, XAP_STRING_ID_LANG_SR_LATIN, UTLANG_LTR},
+	{"sv-SE",		NULL, XAP_STRING_ID_LANG_SV_SE, UTLANG_LTR},
+	{"sw",  		NULL, XAP_STRING_ID_LANG_SW,    UTLANG_LTR},
+	{"syr",  		NULL, XAP_STRING_ID_LANG_SYR,   UTLANG_RTL},
+	{"ta-IN",		NULL, XAP_STRING_ID_LANG_TA_IN, UTLANG_LTR},
+	{"te-IN",		NULL, XAP_STRING_ID_LANG_TE_IN, UTLANG_LTR},
+	{"th-TH",		NULL, XAP_STRING_ID_LANG_TH_TH, UTLANG_LTR},
+	{"tl-PH",		NULL, XAP_STRING_ID_LANG_TL_PH, UTLANG_LTR},
 	{"tr-TR",		NULL, XAP_STRING_ID_LANG_TR_TR, UTLANG_LTR},		// UTLANG_RTL for Ottoman Turkish
 	{"uk-UA",		NULL, XAP_STRING_ID_LANG_UK_UA, UTLANG_LTR},
 	{"ur-PK",		NULL, XAP_STRING_ID_LANG_UR_PK, UTLANG_RTL},
-	{"ur",			NULL, XAP_STRING_ID_LANG_UR, UTLANG_RTL},
+	{"ur",			NULL, XAP_STRING_ID_LANG_UR,    UTLANG_RTL},
 	{"uz-UZ",		NULL, XAP_STRING_ID_LANG_UZ_UZ, UTLANG_RTL},
 	{"vi-VN",		NULL, XAP_STRING_ID_LANG_VI_VN, UTLANG_LTR},
 	{"wo-SN",		NULL, XAP_STRING_ID_LANG_WO_SN, UTLANG_LTR},
@@ -161,6 +177,7 @@ static UT_LangRecord s_Table[] =
 	{"zh-HK",		NULL, XAP_STRING_ID_LANG_ZH_HK, UTLANG_VERTICAL},	// TODO also UTLANG_LTR
 	{"zh-SG",		NULL, XAP_STRING_ID_LANG_ZH_SG, UTLANG_VERTICAL},	// TODO also UTLANG_LTR
 	{"zh-TW",		NULL, XAP_STRING_ID_LANG_ZH_TW, UTLANG_VERTICAL},	// TODO also UTLANG_LTR
+	{"zu",  		NULL, XAP_STRING_ID_LANG_ZU,    UTLANG_LTR},
 };
 
 /*!
