@@ -3,20 +3,20 @@
 /* AbiSource Application Framework
  * Copyright (C) 2004 AbiSource, Inc.
  * Copyright (C) 2004 Francis James Franklin <fjf@alinameridon.com>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -114,7 +114,7 @@ private:
 - (void)dealloc;
 - (void)windowDidLoad;
 - (void)toggleVisibility:(id)sender;
-- (BOOL)validateMenuItem:(id <NSMenuItem>)menuItem;
+- (BOOL)validateMenuItem:(NSMenuItem *)menuItem;
 - (void)setPreviewString:(NSString *)previewString;
 @end
 
@@ -193,7 +193,7 @@ private:
 - (void)windowWillClose:(NSNotification *)aNotification;
 
 - (void)toggleVisibility:(id)sender;
-- (BOOL)validateMenuItem:(id <NSMenuItem>)menuItem;
+- (BOOL)validateMenuItem:(NSMenuItem *)menuItem;
 
 + (void)setPreviewText:(id)previewText;
 - (void)setPreviewString:(NSString *)previewString;
