@@ -309,8 +309,6 @@ bool XAP_UnixClipboard::_getDataFromServer(T_AllowGet tFrom, const char** format
 	GtkClipboard * clipboard = gtkClipboardForTarget (tFrom);
 #if DEBUG
 	gtk_clipboard_request_targets(clipboard,( GtkClipboardTargetsReceivedFunc) allTargets, this);
-#else
-	gtk_clipboard_request_targets(clipboard, NULL, NULL);
 #endif
 	UT_GenericVector<GdkAtom> atoms ;
 	for(int atomCounter = 0; formatList[atomCounter]; atomCounter++)
@@ -326,7 +324,7 @@ bool XAP_UnixClipboard::_getDataFromServer(T_AllowGet tFrom, const char** format
 		UT_DEBUGMSG(("Looking for %s on clipbaord \n",formatList[i]));
 		if(selection)
 		{
-			if (gtk_selection_data_get_target(selection) && (gtk_selection_data_get_length(selection) > 0))
+			if (gtk_selection_data_get_data(selection) && (gtk_selection_data_get_length(selection) > 0))
 			{
 			  if(!rval)
 			    {
