@@ -208,7 +208,11 @@ static void s_select_row_size(GtkTreeSelection * /* widget */, XAP_UnixDialog_Fo
 }
 
 static gboolean s_drawing_area_draw(GtkWidget * w,
+#if GTK_CHECK_VERSION(3,0,0)
 								  cairo_t * /* pExposeEvent */)
+#else
+								  GdkEventExpose * /* pExposeEvent */)
+#endif
 {
 	XAP_UnixDialog_FontChooser * dlg = 
 		(XAP_UnixDialog_FontChooser *)g_object_get_data(G_OBJECT(w), "user-data");
@@ -490,6 +494,10 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindow(void)
 	UT_UTF8String s;
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_FontTitle,s);
 	windowFontSelection = abiDialogNew ( "font dialog", TRUE, s.utf8_str() ) ;
+	gtk_window_set_position(GTK_WINDOW(windowFontSelection), GTK_WIN_POS_CENTER_ON_PARENT);
+#if !GTK_CHECK_VERSION(3,0,0)
+	gtk_dialog_set_has_separator(GTK_DIALOG(windowFontSelection), FALSE);
+#endif
 
 	vboxOuter = gtk_dialog_get_content_area(GTK_DIALOG(windowFontSelection));
 
@@ -514,9 +522,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	GtkWidget *listFonts;
 	GtkWidget *labelSize;
 	GtkWidget *frameEffects;
-	GtkWidget *vboxEffectRows;
-	GtkWidget *hboxDecorations;
-	GtkWidget *hboxAdvDecorations;
+	GtkWidget *tblEffectRows;
 	GtkWidget *checkbuttonStrikeout;
 	GtkWidget *checkbuttonUnderline;
 	GtkWidget *checkbuttonOverline;
@@ -592,7 +598,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	g_object_set_data_full (G_OBJECT (window1), "labelFont", labelFont,
 							  reinterpret_cast<GDestroyNotify>(g_object_unref));
 	gtk_widget_show (labelFont);
-	gtk_box_pack_start (GTK_BOX (vbox1), labelFont, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox1), labelFont, FALSE, FALSE, 6);
 
 	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_set_name (scrolledwindow1, "scrolledwindow1");
@@ -630,7 +636,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	g_object_set_data_full (G_OBJECT (window1), "labelStyle", labelStyle,
 							  reinterpret_cast<GDestroyNotify>(g_object_unref));
 	gtk_widget_show (labelStyle);
-	gtk_box_pack_start (GTK_BOX (vbox2), labelStyle, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), labelStyle, FALSE, FALSE, 6);
 
 	scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_set_name (scrolledwindow2, "scrolledwindow2");
@@ -668,7 +674,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	g_object_set_data_full (G_OBJECT (window1), "labelSize", labelSize,
 							  reinterpret_cast<GDestroyNotify>(g_object_unref));
 	gtk_widget_show (labelSize);
-	gtk_box_pack_start (GTK_BOX (vbox3), labelSize, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox3), labelSize, FALSE, FALSE, 6);
 
 	scrolledwindow3 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_set_name (scrolledwindow3, "scrolledwindow3");
@@ -703,57 +709,61 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 	frameEffects = gtk_frame_new (s.utf8_str());
 	gtk_frame_set_shadow_type(GTK_FRAME(frameEffects), GTK_SHADOW_NONE);
 	gtk_widget_show (frameEffects);
-	gtk_box_pack_start(GTK_BOX (vboxmisc), frameEffects, 0,0, 2);
+	gtk_box_pack_start(GTK_BOX (vboxmisc), frameEffects, 0,0, 6);
 
-	vboxEffectRows = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-	gtk_widget_show (vboxEffectRows);
-	gtk_container_add (GTK_CONTAINER (frameEffects), vboxEffectRows);
-
-	hboxDecorations = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_widget_show (hboxDecorations);
-	gtk_box_pack_start (GTK_BOX (vboxEffectRows), hboxDecorations, FALSE, FALSE, 0);
+	tblEffectRows = gtk_table_new(2, 4, FALSE);
+	gtk_widget_show (tblEffectRows);
+	gtk_container_add (GTK_CONTAINER (frameEffects), tblEffectRows);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_StrikeoutCheck,s);
 	checkbuttonStrikeout = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonStrikeout), 5);
 	gtk_widget_show (checkbuttonStrikeout);
-	gtk_box_pack_start (GTK_BOX (hboxDecorations), checkbuttonStrikeout, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonStrikeout, 0, 1, 0, 1,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_UnderlineCheck,s);
 	checkbuttonUnderline = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonUnderline), 5);
 	gtk_widget_show (checkbuttonUnderline);
-	gtk_box_pack_start (GTK_BOX (hboxDecorations), checkbuttonUnderline, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonUnderline, 1, 2, 0, 1,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_OverlineCheck,s);
 	checkbuttonOverline = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonOverline), 5);
 	gtk_widget_show (checkbuttonOverline);
-	gtk_box_pack_start (GTK_BOX (hboxDecorations), checkbuttonOverline, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonOverline, 2, 3, 0, 1,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_HiddenCheck,s);
 	checkbuttonHidden = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonHidden), 5);
 	gtk_widget_show (checkbuttonHidden);
-	gtk_box_pack_start (GTK_BOX (hboxDecorations), checkbuttonHidden, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonHidden, 3, 4, 0, 1,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	/* subscript/superscript */
 
-	hboxAdvDecorations = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_widget_show (hboxAdvDecorations);
-	gtk_box_pack_start (GTK_BOX (vboxEffectRows), hboxAdvDecorations, FALSE, FALSE, 0);
-
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_SubScript,s);
 	checkbuttonSubscript = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonSubscript), 5);
 	gtk_widget_show (checkbuttonSubscript);
-	gtk_box_pack_start (GTK_BOX (hboxAdvDecorations), checkbuttonSubscript, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonSubscript, 0, 1, 1, 2,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_SuperScript,s);
 	checkbuttonSuperscript = gtk_check_button_new_with_label (s.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (checkbuttonSuperscript), 5);
 	gtk_widget_show (checkbuttonSuperscript);
-	gtk_box_pack_start (GTK_BOX (hboxAdvDecorations), checkbuttonSuperscript, TRUE, TRUE, 0);
+	gtk_table_attach(GTK_TABLE(tblEffectRows), checkbuttonSuperscript, 1, 2, 1, 2,
+					  static_cast<GtkAttachOptions>(GTK_FILL),
+					  static_cast<GtkAttachOptions>(GTK_FILL), 0, 0);
 
 	/* Notebook page for ForeGround Color Selector */
 
@@ -772,6 +782,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
     gtk_notebook_append_page(GTK_NOTEBOOK(notebookMain), hbox1,labelTabColor);
 
 	colorSelector = gtk_color_selection_new ();
+	gtk_container_set_border_width(GTK_CONTAINER(colorSelector), 6);
 	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(colorSelector), FALSE);
 	gtk_widget_show (colorSelector);
 	gtk_box_pack_start (GTK_BOX (hbox1), colorSelector, TRUE, TRUE, 0);
@@ -792,6 +803,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
     gtk_notebook_append_page(GTK_NOTEBOOK(notebookMain), vboxBG,labelTabBGColor);
 
 	colorBGSelector = gtk_color_selection_new ();
+	gtk_container_set_border_width(GTK_CONTAINER(colorBGSelector), 6);
 	gtk_color_selection_set_has_opacity_control(GTK_COLOR_SELECTION(colorBGSelector), FALSE);
 	gtk_widget_show (colorBGSelector);
 	gtk_box_pack_start (GTK_BOX (vboxBG), colorBGSelector, TRUE, TRUE, 0);
@@ -801,6 +813,7 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 //
 	pSS->getValueUTF8(XAP_STRING_ID_DLG_UFS_TransparencyCheck,s);
 	GtkWidget * checkbuttonTrans = gtk_check_button_new_with_label (s.utf8_str());
+	gtk_container_set_border_width(GTK_CONTAINER(checkbuttonTrans), 6);
 	gtk_widget_show (checkbuttonTrans);
 	gtk_box_pack_start (GTK_BOX (vboxBG), checkbuttonTrans, TRUE, TRUE, 0);
 
@@ -817,8 +830,13 @@ GtkWidget * XAP_UnixDialog_FontChooser::constructWindowContents(GtkWidget *paren
 
 	entryArea = createDrawingArea ();
 	gtk_widget_set_events(entryArea, GDK_EXPOSURE_MASK);
+#if GTK_CHECK_VERSION(3,0,0)
 	g_signal_connect(G_OBJECT(entryArea), "draw",
 					   G_CALLBACK(s_drawing_area_draw), NULL);
+#else
+	g_signal_connect(G_OBJECT(entryArea), "expose_event",
+					   G_CALLBACK(s_drawing_area_draw), NULL);
+#endif
 	gtk_widget_set_size_request (entryArea, -1, PREVIEW_BOX_HEIGHT_PIXELS);
 	gtk_widget_show (entryArea);
 	gtk_container_add (GTK_CONTAINER (frame4), entryArea);
