@@ -112,12 +112,12 @@ GtkWidget * XAP_UnixDialog_History::_constructWindow(void)
 {
     const XAP_StringSet * pSS = m_pApp->getStringSet();
 	
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/xap_UnixDlg_History.xml";
-	
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("xap_UnixDlg_History.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("xap_UnixDlg_History-2.ui");
+#endif
 
 	// Update our member variables with the important widgets that 
 	// might need to be queried or altered later
@@ -165,12 +165,14 @@ void XAP_UnixDialog_History::_fillHistoryTree(void)
     for (i = 0; i < getListItemCount(); i++)
 	{
 		// Add a new row to the model
+		gchar *itime = g_locale_to_utf8(getListValue(i,1), -1, NULL, NULL, NULL);
 		gtk_tree_store_append (model, &iter,NULL);
 		gtk_tree_store_set (model, &iter, 0, getListValue(i,0), 
-							1,getListValue(i,1) ,
+							1,itime ,
 							2,getListValue(i,2) ,
 							3,getListItemId(i) ,
 							-1);
+    g_free(itime);
 	}
     m_wTreeView = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 
@@ -206,20 +208,20 @@ void XAP_UnixDialog_History::_populateWindowData(GtkBuilder* builder)
 {
     const XAP_StringSet * pSS = m_pApp->getStringSet();
 	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbDocumentDetails")), pSS, XAP_STRING_ID_DLG_History_DocumentDetails);
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbDocumentName")), getHeaderLabel(0));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbDocNameVal")), getHeaderValue(0));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbVersion")), getHeaderLabel(1));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbVersionVal")), getHeaderValue(1));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbCreated")), getHeaderLabel(2));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbCreatedVal")), getHeaderValue(2));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbSaved")), getHeaderLabel(3));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbSavedVal")), getHeaderValue(3));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbEditTime")), getHeaderLabel(4));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbEditTimeVal")), getHeaderValue(4));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbIdentifier")), getHeaderLabel(5));
-	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbIdentifierVal")), getHeaderValue(5));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbDocumentName")), getHeaderLabel(0));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbDocNameVal")), getHeaderValue(0));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbVersion")), getHeaderLabel(1));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbVersionVal")), getHeaderValue(1));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbCreated")), getHeaderLabel(2));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbCreatedVal")), getHeaderValue(2));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbSaved")), getHeaderLabel(3));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbSavedVal")), getHeaderValue(3));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbEditTime")), getHeaderLabel(4));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbEditTimeVal")), getHeaderValue(4));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbIdentifier")), getHeaderLabel(5));
+	gtk_label_set_text (GTK_LABEL(gtk_builder_get_object(builder, "lbIdentifierVal")), getHeaderValue(5));
 	setLabelMarkup (GTK_WIDGET(gtk_builder_get_object(builder, "lbVersionHistory")), getListTitle());
-
+	localizeButton(GTK_WIDGET(gtk_builder_get_object(builder, "okbutton1")), pSS, XAP_STRING_ID_DLG_History_Restore);
 }
 
 
