@@ -32,6 +32,7 @@
 #include "ut_assert.h"
 #include "ut_vector.h"
 #include "ut_debugmsg.h"
+#include "xap_Gtk2Compat.h"
 #include "xap_UnixDialogHelper.h"
 #include "xap_UnixDlg_MessageBox.h"
 #include "xap_UnixApp.h"
@@ -77,6 +78,11 @@ void XAP_UnixDialog_MessageBox::runModal(XAP_Frame * pFrame)
 	toplevel = GTK_WINDOW(pUnixFrameImpl->getTopLevelWindow());
 #endif	
 
+	int dflFlags = 
+#if !GTK_CHECK_VERSION(3,0,0)
+	                          GTK_DIALOG_NO_SEPARATOR |
+#endif
+	                          GTK_DIALOG_MODAL;
 	
 	int dflResponse = GTK_RESPONSE_OK;
 
@@ -124,15 +130,18 @@ void XAP_UnixDialog_MessageBox::runModal(XAP_Frame * pFrame)
             char * tmp_str = g_strdup(s.c_str());
 			convertMnemonics(tmp_str);
 			message = gtk_dialog_new_with_buttons("",
-							      toplevel, 
-							      GTK_DIALOG_MODAL,
-							      tmp_str,
-							      GTK_RESPONSE_NO,
-							      GTK_STOCK_CANCEL, 
-							      GTK_RESPONSE_CANCEL, 
-							      GTK_STOCK_SAVE, 
-							      GTK_RESPONSE_YES,
-							      NULL);
+							      toplevel,
+							      static_cast<GtkDialogFlags>(dflFlags),
+							      NULL, NULL);
+			GtkWidget *button_no = gtk_dialog_add_button(GTK_DIALOG(message), tmp_str, GTK_RESPONSE_NO);
+			GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_DELETE, GTK_ICON_SIZE_BUTTON);
+			gtk_button_set_image(GTK_BUTTON(button_no), img);      
+			gtk_dialog_add_buttons(GTK_DIALOG(message), 
+							       GTK_STOCK_CANCEL, 
+							       GTK_RESPONSE_CANCEL, 
+							       GTK_STOCK_SAVE, 
+							       GTK_RESPONSE_YES,
+							       NULL);
 
 			dflResponse = GTK_RESPONSE_YES;
 			FREEP(tmp_str);
@@ -172,7 +181,7 @@ void XAP_UnixDialog_MessageBox::runModal(XAP_Frame * pFrame)
 
 #else
 			message = gtk_message_dialog_new (toplevel, 
-							  GTK_DIALOG_MODAL,
+							  static_cast<GtkDialogFlags>(dflFlags),
 							  GTK_MESSAGE_QUESTION,
 							  GTK_BUTTONS_NONE,
 							  "%s",
