@@ -45,6 +45,7 @@
 #include "ut_files.h"
 #include "ut_misc.h"
 #include "ut_sleep.h"
+#include "xap_Gtk2Compat.h"
 #include "xap_ViewListener.h"
 #include "xap_UnixApp.h"
 #include "xap_UnixFrameImpl.h"
@@ -1200,11 +1201,17 @@ gint XAP_UnixFrameImpl::_fe::delete_event(GtkWidget * w, GdkEvent * /*event*/, g
 	return TRUE;
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
 gint XAP_UnixFrameImpl::_fe::draw(GtkWidget * w, cairo_t * cr)
+#else
+gint XAP_UnixFrameImpl::_fe::expose(GtkWidget * w, GdkEventExpose* pExposeEvent)
+#endif
 {
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(g_object_get_data(G_OBJECT(w), "user_data"));
 	FV_View * pView = static_cast<FV_View *>(pUnixFrameImpl->getFrame()->getCurrentView());
+#if GTK_CHECK_VERSION(3,0,0)
 	GdkEventExpose *pExposeEvent = reinterpret_cast<GdkEventExpose *>(gtk_get_current_event());
+#endif
 /* Jean: commenting out next lines since the zoom update code does draw only
  * part of what needs to be updated. */
 //	if((pUnixFrameImpl->m_bDoZoomUpdate) || (pUnixFrameImpl->m_iZoomUpdateID != 0))
@@ -1215,12 +1222,16 @@ gint XAP_UnixFrameImpl::_fe::draw(GtkWidget * w, cairo_t * cr)
 	{
 		GR_Graphics * pGr = pView->getGraphics ();
 		UT_Rect rClip;
+		if (pGr->getPaintCount () > 0)
+			return TRUE;
 		xxx_UT_DEBUGMSG(("Expose area: x %d y %d width %d  height %d \n",pExposeEvent->area.x,pExposeEvent->area.y,pExposeEvent->area.width,pExposeEvent->area.height));
 		rClip.left = pGr->tlu(pExposeEvent->area.x);
 		rClip.top = pGr->tlu(pExposeEvent->area.y);
 		rClip.width = pGr->tlu(pExposeEvent->area.width)+1;
 		rClip.height = pGr->tlu(pExposeEvent->area.height)+1;
+#if GTK_CHECK_VERSION(3,0,0)
 		static_cast<GR_CairoGraphics *>(pGr)->setCairo(cr);
+#endif
 		pView->draw(&rClip);
 	}
 	return FALSE;
@@ -1440,7 +1451,11 @@ void XAP_UnixFrameImpl::_setCursor(GR_Graphics::Cursor c)
 	if (m_wStatusBar)
 		gdk_window_set_cursor(gtk_widget_get_window(m_wStatusBar), cursor);
 
+#if GTK_CHECK_VERSION(3,0,0)
+	g_object_unref(cursor);
+#else
 	gdk_cursor_unref(cursor);
+#endif
 }
 
 UT_sint32 XAP_UnixFrameImpl::_setInputMode(const char * szName)
@@ -1485,8 +1500,6 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 {
 	// create a top-level window for us.
 
-	bool bResult;
-
 	if(m_iFrameMode == XAP_NormalFrame)
 	{
 		m_wTopLevelWindow = _createInternalWindow ();
@@ -1578,6 +1591,7 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 		m_pUnixMenu = new EV_UnixMenuBar(static_cast<XAP_UnixApp*>(XAP_App::getApp()), getFrame(), m_szMenuLayoutName,
 										 m_szMenuLabelSetName);
 		UT_return_if_fail(m_pUnixMenu);
+		UT_DebugOnly<bool> bResult;
 		bResult = m_pUnixMenu->synthesizeMenuBar();
 		UT_ASSERT(bResult);
 	}
@@ -1945,8 +1959,7 @@ void XAP_UnixFrameImpl::_rebuildMenus(void)
 					 m_szMenuLayoutName,
 					 m_szMenuLabelSetName);
 	UT_return_if_fail(m_pUnixMenu);
-	bool bResult = m_pUnixMenu->rebuildMenuBar();
-	UT_UNUSED(bResult);
+	UT_DebugOnly<bool> bResult = m_pUnixMenu->rebuildMenuBar();
 	UT_ASSERT_HARMLESS(bResult);
 }
 
