@@ -28,6 +28,7 @@
 #include <stdlib.h>
 
 #include <gtk/gtk.h>
+#include "xap_Gtk2Compat.h"
 #include "xap_UnixTableWidget.h"
 #include "ut_debugmsg.h"
 #include "ut_assert.h"
@@ -114,9 +115,9 @@ abi_table_resize(AbiTable* table)
 {
 	guint width;
 	guint height;
-	char* text;	
+	char* text;
 	GtkRequisition size;
-	
+
 	UT_return_if_fail(table);
 
 	if (table->selected_rows == 0 && table->selected_cols == 0)
@@ -129,11 +130,11 @@ abi_table_resize(AbiTable* table)
 		text = g_strdup_printf(prText.utf8_str(), table->selected_rows, table->selected_cols);
 	}
 	cells_to_pixels(table->total_cols, table->total_rows, &width, &height);
-	gtk_widget_size_request(GTK_WIDGET(table->window_label), &size);
-	
+	gtk_widget_get_preferred_size(GTK_WIDGET(table->window_label), &size, NULL);
+
 	gtk_label_set_text(table->window_label, text);
 	gtk_window_resize(table->window, width + 1, height + size.height);
-	
+
 	g_free(text);
 }
 
@@ -196,7 +197,11 @@ abi_table_get_max_size (const AbiTable* abi_table, guint* rows, guint* cols)
 }
 
 static gboolean
+#if GTK_CHECK_VERSION(3,0,0)
 on_drawing_area_event (GtkWidget *area, cairo_t *cr, gpointer user_data)
+#else
+on_drawing_area_event (GtkWidget *area, GdkEventExpose *, gpointer user_data)
+#endif
 {
 	AbiTable* table = static_cast<AbiTable*>(user_data);
 	guint i;
@@ -205,30 +210,91 @@ on_drawing_area_event (GtkWidget *area, cairo_t *cr, gpointer user_data)
 	guint selected_cols = table->selected_cols;
 	guint x;
 	guint y;
-	GtkStyleContext *ctxt;
-	GdkRGBA fg, bgn, bgs;
 	
 	// TODO: use gtk_paint_box, gtk_paint_line
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkStyleContext *ctxt;
+	GdkRGBA fg, bgn, bgs;
 	ctxt = gtk_widget_get_style_context(area);
 	gtk_style_context_get_color(ctxt, GTK_STATE_FLAG_NORMAL, &fg);
 	gtk_style_context_get_background_color(ctxt, GTK_STATE_FLAG_NORMAL, &bgn);
 	gtk_style_context_get_background_color(ctxt, GTK_STATE_FLAG_SELECTED, &bgs);
 	cairo_set_line_width(cr, 1.0);
-	for (i = 0; i < table->total_rows; ++i)
-		for (j = 0; j < table->total_cols; ++j)
-		{
+#else
+	gdk_draw_rectangle (area->window,
+			    area->style->bg_gc[GTK_STATE_NORMAL],
+			    TRUE,
+			    0, 0,
+			    area->allocation.width,
+			    area->allocation.height);
+#endif
+	for (i = 0; i < table->total_rows; ++i) {
+		for (j = 0; j < table->total_cols; ++j) {
 			cells_to_pixels(j, i, &x, &y);
 
+#if GTK_CHECK_VERSION(3,0,0)
 			cairo_rectangle(cr, x, y, cell_width + 1, cell_height + 1);
-			if (i < selected_rows && j < selected_cols)
+			if (i < selected_rows && j < selected_cols) {
 				cairo_set_source_rgba(cr, bgs.red, bgs.green, bgs.blue, bgs.alpha);
-			else
+			}
+			else {
 				cairo_set_source_rgba(cr, bgn.red, bgn.green, bgn.blue, bgn.alpha);
+			}
 			cairo_fill(cr);
 
 			cairo_rectangle(cr, x - .5, y - .5, cell_width + .5, cell_height + .5);
 			cairo_set_source_rgba(cr, fg.red, fg.green, fg.blue, fg.alpha);
 			cairo_stroke(cr);
+#else
+			gdk_draw_rectangle (area->window,
+					    area->style->dark_gc[GTK_STATE_NORMAL],
+					    FALSE,
+					    x - 1, y - 1,
+					    cell_width + 1,
+					    cell_height + 1);
+			if (i < selected_rows && j < selected_cols) {
+				gdk_draw_rectangle (area->window,
+						    table->selected_gc,
+						    TRUE,
+						    x, y,
+						    cell_width,
+						    cell_height);
+			}
+			else {
+				gdk_draw_rectangle (area->window,
+						    area->style->white_gc,
+						    TRUE,
+						    x, y,
+						    cell_width,
+						    cell_height);
+			}
+			/* black border line */
+			gdk_draw_line (area->window,
+				       area->style->black_gc,
+				       area->allocation.width - 1, 0, area->allocation.width - 1, area->allocation.height - 1);
+			gdk_draw_line (area->window,
+				       area->style->black_gc,
+				       area->allocation.width - 1, area->allocation.height - 1, 0, area->allocation.height - 1);
+			
+			/* dark border line */
+			gdk_draw_line (area->window,
+				       area->style->dark_gc[GTK_STATE_NORMAL],
+				       area->allocation.width - 2, 1, area->allocation.width - 2,
+				       area->allocation.height - 2);
+			gdk_draw_line (area->window,
+				       area->style->dark_gc[GTK_STATE_NORMAL],
+				       area->allocation.width - 2, area->allocation.height - 2, 1,
+				       area->allocation.height - 2);
+			
+			/* ligth border line */
+			gdk_draw_line (area->window,
+				       area->style->light_gc[GTK_STATE_NORMAL],
+				       0, 0, area->allocation.width - 3, 0);
+			gdk_draw_line (area->window,
+				       area->style->light_gc[GTK_STATE_NORMAL],
+				       0, 0, 0, area->allocation.height - 2);
+#endif
+		}
 	}
 
 	return TRUE;
@@ -279,7 +345,11 @@ restart_widget (AbiTable *table)
 	table->total_cols = my_max(init_cols + 1, 5);
 	table->total_rows = my_max(init_rows + 1, 6);
 
+#if GTK_CHECK_VERSION(2,24,0)
+	g_signal_emit_by_name(table, "button-release-event");
+#else
 	gtk_button_released(GTK_BUTTON(table));
+#endif
 
 	gtk_widget_hide(GTK_WIDGET(table->window));
 }
@@ -312,8 +382,8 @@ on_button_release_event (GtkWidget *, GdkEventButton *ev, gpointer user_data)
 	if (ev->y < 0.0 && ev->x >= 0.0)
 	{
 		GtkRequisition size;
-		
-		gtk_widget_size_request(GTK_WIDGET(table), &size);
+
+		gtk_widget_get_preferred_size(GTK_WIDGET(table), &size, NULL);
 
 		/* And now, precise and slightly slower test.
 		   I wonder if the double test really matters from a speed pov */
@@ -354,15 +424,15 @@ popup_grab_on_window (GdkWindow *window,
 	GdkEventMask emask = static_cast<GdkEventMask>(GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
 												   GDK_POINTER_MOTION_MASK | GDK_LEAVE_NOTIFY_MASK |
 												   GDK_ENTER_NOTIFY_MASK) ;
-	if ((gdk_pointer_grab (window, FALSE,emask,
+	if ((XAP_gdk_pointer_grab (window, FALSE,emask,
 						   NULL, NULL, activate_time) == 0))
 	{
-		if (gdk_keyboard_grab (window, FALSE,
+		if (XAP_gdk_keyboard_grab (window, FALSE,
 							   activate_time) == 0)
 			return TRUE;
 		else
 		{
-			gdk_pointer_ungrab (activate_time);
+			XAP_gdk_pointer_ungrab (activate_time);
 			return FALSE;
 		}
 	}
@@ -400,6 +470,13 @@ on_pressed(GtkButton* button, gpointer user_data)
 	 */
 	popup_grab_on_window (gtk_widget_get_window(GTK_WIDGET(table->area)),
 			      gtk_get_current_event_time ());
+#if !GTK_CHECK_VERSION(3,0,0)
+	GdkColor selected_color = (GTK_WIDGET (button))->style->base[GTK_STATE_SELECTED];
+
+	/* leak */
+	table->selected_gc = gdk_gc_new(GTK_WIDGET(button)->window);
+	gdk_gc_set_rgb_fg_color(table->selected_gc, &selected_color);
+#endif
 }
 
 gboolean
@@ -575,11 +652,36 @@ void abi_table_set_icon(AbiTable* abi_table,GtkWidget * gtkImageIcon)
 
 /* ------------------- and now the GObject part ---------------------- */
 
+static void
+abi_table_dispose (GObject *instance)
+{
+	AbiTable* self = ABITABLE_WIDGET(instance);
+
+// For some reason I get an alert
+	if(self->label) {
+		g_object_unref(self->label);
+		self->label = NULL;
+	}
+
+	if(self->szTable) {
+		g_free(self->szTable);
+		self->szTable = NULL;
+	}
+	if(self->szCancel) {
+		g_free(self->szCancel);
+		self->szCancel = NULL;
+	}
+
+	G_OBJECT_CLASS (abi_table_parent_class)->dispose (instance);	
+}
+
 static void
 abi_table_class_init (AbiTableClass *klass)
 {
 	GtkWidgetClass *object_class = reinterpret_cast<GtkWidgetClass*>(klass);
 
+	G_OBJECT_CLASS(object_class)->dispose = abi_table_dispose;
+
 	abi_table_parent_class = static_cast<GtkWidgetClass *>(g_type_class_peek (GTK_TYPE_BUTTON));
 	abi_table_signals [SELECTED] =
 		g_signal_new ("selected",
@@ -633,6 +735,7 @@ abi_table_init (AbiTable* table)
 		table->icon = gtk_image_new_from_stock ("abi-table-widget", GTK_ICON_SIZE_LARGE_TOOLBAR);
 		gtk_widget_show(table->icon);
 		gtk_widget_show(table->label);
+		g_object_ref_sink(table->label);
 		//
 		// We actually never want this label in toolbar
 		//		gtk_box_pack_end(GTK_BOX(table->button_box), table->label, FALSE, FALSE, 0);
@@ -645,6 +748,7 @@ abi_table_init (AbiTable* table)
 		UT_DEBUGMSG(("abi-table icon did not load !\n"));
 		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 		table->label = gtk_label_new_with_mnemonic("_Table");
+		g_object_ref_sink(table->label);
 		//		gtk_box_pack_end(GTK_BOX(table->button_box), table->label, FALSE, FALSE, 0);
 	}
 
@@ -652,8 +756,13 @@ abi_table_init (AbiTable* table)
 
 	g_signal_connect(G_OBJECT(table), "pressed",
 			 G_CALLBACK(on_pressed), static_cast<gpointer>(table));
+#if GTK_CHECK_VERSION(3,0,0)
 	g_signal_connect(G_OBJECT(table->area), "draw",
 			 G_CALLBACK(on_drawing_area_event), static_cast<gpointer>(table));
+#else
+	g_signal_connect(G_OBJECT(table->area), "expose_event",
+			 G_CALLBACK(on_drawing_area_event), static_cast<gpointer>(table));
+#endif
 	g_signal_connect(G_OBJECT(table->area), "motion_notify_event",
 			 G_CALLBACK(on_motion_notify_event), static_cast<gpointer>(table));
 	g_signal_connect(G_OBJECT(table->area), "button_release_event",
@@ -711,6 +820,12 @@ abi_table_new (void)
 	return GTK_WIDGET (g_object_new (abi_table_get_type (), NULL));
 }
 
+/**
+ * abi_table_get_label:
+ * @abi_table: #AbiTable
+ *
+ * Returns: (transfer none): the label widget.
+ */
  GtkWidget* abi_table_get_label(AbiTable* abi_table)
 {
 	return abi_table->label;
