@@ -28,6 +28,7 @@
 
 dcl(MSG_ImportingDoc, "Importing Document...")
 dcl(MSG_BuildingDoc,  "Building Document:")
+dcl(MSG_ParagraphsImported,  "Imported Paragraph")
 dcl(MSG_AutoRevision, "Autorevision")
 dcl(MSG_HistoryPartRestore1, "AbiWord cannot fully restore version %d of the document because the version information is incomplete.")
 dcl(MSG_HistoryPartRestore2, "The nearest version that can be restored fully is %d. Would you like to restore this version instead? To partially restore version %d press No.")
@@ -43,6 +44,7 @@ dcl(UntitledDocument,			"Untitled%d")
 dcl(ReadOnly,					"Read-Only")
 
 /*  Styles */
+dcl(STYLE_NONE,			    "None")		//xgettext:msgctxt
 dcl(STYLE_NUMBER_LIST,		"Numbered List")
 dcl(STYLE_PLAIN_TEXT,		"Plain Text")
 dcl(STYLE_NORMAL,			"Normal")
@@ -55,31 +57,36 @@ dcl(STYLE_TOCHEADING1, 		"Contents 1")
 dcl(STYLE_TOCHEADING2, 		"Contents 2")
 dcl(STYLE_TOCHEADING3, 		"Contents 3")
 dcl(STYLE_TOCHEADING4, 		"Contents 4")
-dcl(STYLE_BLOCKTEXT,		"Block Text")          
-dcl(STYLE_LOWERCASELIST,	"Lower Case List")     
-dcl(STYLE_UPPERCASTELIST,	"Upper Case List")     
-dcl(STYLE_LOWERROMANLIST,	"Lower Roman List")    
-dcl(STYLE_UPPERROMANLIST,	"Upper Roman List")    
-dcl(STYLE_BULLETLIST,		"Bullet List")         
-dcl(STYLE_DASHEDLIST,		"Dashed List")         
-dcl(STYLE_SQUARELIST,		"Square List")         
-dcl(STYLE_TRIANGLELIST,		"Triangle List")       
-dcl(STYLE_DIAMONLIST,		"Diamond List")	      
-dcl(STYLE_STARLIST,			"Star List")           
-dcl(STYLE_TICKLIST,			"Tick List")           
-dcl(STYLE_BOXLIST,			"Box List")            
-dcl(STYLE_HANDLIST,			"Hand List")           
-dcl(STYLE_HEARTLIST,		"Heart List")          
-dcl(STYLE_CHAPHEADING,		"Chapter Heading")     
-dcl(STYLE_SECTHEADING,		"Section Heading")     
-dcl(STYLE_ENDREFERENCE,		"Endnote Reference")   
-dcl(STYLE_ENDTEXT,			"Endnote Text")        
-dcl(STYLE_FOOTREFERENCE,	"Footnote Reference")   
-dcl(STYLE_FOOTTEXT,			"Footnote Text")        
-dcl(STYLE_NUMHEAD1,			"Numbered Heading 1")  
-dcl(STYLE_NUMHEAD2,			"Numbered Heading 2")  
-dcl(STYLE_NUMHEAD3,			"Numbered Heading 3")  
-dcl(STYLE_IMPLIES_LIST,		"Implies List")  
+dcl(STYLE_BLOCKTEXT,		"Block Text")
+dcl(STYLE_LOWERCASELIST,	"Lower Case List")
+dcl(STYLE_UPPERCASTELIST,	"Upper Case List")
+dcl(STYLE_LOWERROMANLIST,	"Lower Roman List")
+dcl(STYLE_UPPERROMANLIST,	"Upper Roman List")
+dcl(STYLE_BULLETLIST,		"Bullet List")
+dcl(STYLE_DASHEDLIST,		"Dashed List")
+dcl(STYLE_SQUARELIST,		"Square List")
+dcl(STYLE_TRIANGLELIST,		"Triangle List")
+dcl(STYLE_DIAMONLIST,		"Diamond List")
+dcl(STYLE_STARLIST,			"Star List")
+dcl(STYLE_TICKLIST,			"Tick List")
+dcl(STYLE_BOXLIST,			"Box List")
+dcl(STYLE_HANDLIST,			"Hand List")
+dcl(STYLE_HEARTLIST,		"Heart List")
+dcl(STYLE_ARROWHEADLIST,	"Arrowhead List")
+dcl(STYLE_CHAPHEADING,		"Chapter Heading")
+dcl(STYLE_SECTHEADING,		"Section Heading")
+dcl(STYLE_ENDREFERENCE,		"Endnote Reference")
+dcl(STYLE_ENDTEXT,			"Endnote Text")
+dcl(STYLE_ENDNOTE,			"Endnote")
+dcl(STYLE_FOOTREFERENCE,	"Footnote Reference")
+dcl(STYLE_FOOTTEXT,			"Footnote Text")
+dcl(STYLE_FOOTNOTE,			"Footnote")
+dcl(STYLE_NUMHEAD1,			"Numbered Heading 1")
+dcl(STYLE_NUMHEAD2,			"Numbered Heading 2")
+dcl(STYLE_NUMHEAD3,			"Numbered Heading 3")
+dcl(STYLE_IMPLIES_LIST,		"Implies List")
+dcl(STYLE_DELIM_CHAPTER,	"Chapter")
+dcl(STYLE_DELIM_SECTION,	"Section")
 
 
 /* Common to many dialogs */
@@ -95,7 +102,7 @@ dcl(DLG_Select, 				"Select")
 dcl(DLG_Merge, 				    "Merge")
 dcl(DLG_Show, 				    "Show")
 dcl(DLG_Restore,			    "Restore")
-	
+
 /* Units */
 dcl(DLG_Unit_inch,				"inch")
 dcl(DLG_Unit_cm,				"cm")
@@ -117,7 +124,7 @@ dcl(DLG_MB_No,					"No")
 /* More Windows dialog */
 dcl(DLG_MW_MoreWindows, 		"View Document")
 dcl(DLG_MW_Activate,			"View:")
-dcl(DLG_MW_AvailableDocuments,		"Available Documents")
+dcl(DLG_MW_AvailableDocuments,		"Available Documents:")
 dcl(DLG_MW_ViewButton,			"&View")
 
 /* Remove Toolbar Icon */
@@ -129,11 +136,11 @@ dcl(DLG_UFS_FontLabel,			"Font:")
 dcl(DLG_UFS_StyleLabel, 		"Style:")
 dcl(DLG_UFS_SizeLabel,			"Size:")
 dcl(DLG_UFS_EncodingLabel,		"Encoding:")
-dcl(DLG_UFS_EffectsFrameLabel,	"Effects")
+dcl(DLG_UFS_EffectsFrameLabel,	"Effects:")
 dcl(DLG_UFS_StrikeoutCheck, 	"Strike")
 dcl(DLG_UFS_UnderlineCheck, 	"Underline")
 dcl(DLG_UFS_OverlineCheck,		"Overline")
-dcl(DLG_UFS_HiddenCheck,        "Hidden")	
+dcl(DLG_UFS_HiddenCheck,        "Hidden")
 dcl(DLG_UFS_TransparencyCheck,	"Set no Highlight Color")
 dcl(DLG_UFS_FontTab,			"Font")
 dcl(DLG_UFS_ColorTab,			"Text Color")
@@ -250,7 +257,7 @@ dcl(DLG_PLUGIN_MANAGER_NAME,			"Name:")
 dcl(DLG_PLUGIN_MANAGER_DESC,			"Description:")
 dcl(DLG_PLUGIN_MANAGER_AUTHOR,			"Author:")
 dcl(DLG_PLUGIN_MANAGER_VERSION, 		"Version:")
-dcl(DLG_PLUGIN_MANAGER_DETAILS, 		"Plugin Details:")
+dcl(DLG_PLUGIN_MANAGER_DETAILS, 		"Plugin Details")
 dcl(DLG_PLUGIN_MANAGER_NOT_AVAILABLE, 		"Not available")
 
 /* spellchecker */
@@ -265,15 +272,15 @@ dcl(DLG_PLUGIN_MANAGER_NONE_SELECTED,	"No plugin selected")
 /* Language Dialog */
 dcl(DLG_ULANG_LangTitle,				"Set Language")
 dcl(DLG_ULANG_LangLabel,				"Select Language:")
-dcl(DLG_ULANG_AvailableLanguages,			"Available Languages")
+dcl(DLG_ULANG_AvailableLanguages,			"Available Languages:")
 dcl(DLG_ULANG_SetLangButton,				"&Set Language")
 dcl(DLG_ULANG_DefaultLangLabel,         "Default language: ")
 dcl(DLG_ULANG_DefaultLangChkbox,        "Make default for document")
-	
+
 /* ClipArt Dialog */
 dcl(DLG_CLIPART_Title, "Clip Art")
-dcl(DLG_CLIPART_Loading, "Loading Clip Art")
-dcl(DLG_CLIPART_Error, "Clip Art could not be loaded")
+dcl(DLG_CLIPART_Loading, "Loading Clip Art...")
+dcl(DLG_CLIPART_Error, "Clip Art could not be loaded.")
 
 /* About Dialog */
 dcl(DLG_ABOUT_Title,					"About %s")
@@ -284,7 +291,7 @@ dcl(DLG_ABOUT_URL,                      "For more information: http://www.abisou
 
 /* image size dialog */
 dcl(DLG_Image_Title, "Image Properties")
-dcl(DLG_Image_DescTabLabel, "&Description")
+dcl(DLG_Image_DescTabLabel, "General")
 dcl(DLG_Image_WrapTabLabel, "&Wrapping")
 dcl(DLG_Image_PlacementTabLabel, "&Placement")
 dcl(DLG_Image_Width, "Width:")
@@ -292,10 +299,10 @@ dcl(DLG_Image_Height, "Height:")
 dcl(DLG_Image_Aspect, "Preserve aspect ratio")
 dcl(DLG_Image_LblTitle, "Title:")
 dcl(DLG_Image_LblDescription, "Description:")
-dcl(DLG_Image_ImageSize, "Set Image Size")
-dcl(DLG_Image_ImageDesc, "Set Image Name")
-dcl(DLG_Image_TextWrapping, "Define Text Wrapping")
-dcl(DLG_Image_Placement, "Define Image Placement")
+dcl(DLG_Image_ImageSize, "Image Size")
+dcl(DLG_Image_ImageDesc, "Image Name")
+dcl(DLG_Image_TextWrapping, "Text Wrapping")
+dcl(DLG_Image_Placement, "Image Placement")
 dcl(DLG_Image_InLine, "Image placed in-line (no text wrapping)")
 dcl(DLG_Image_WrappedNone, "Image floats above text")
 dcl(DLG_Image_WrappedRight, "Text wrapped to the Right of the Image")
@@ -311,70 +318,90 @@ dcl(DLG_Image_TightWrap, "Tight text wrapping")
 /* ListDocuments Dialog */
 dcl(DLG_LISTDOCS_Title,					"Opened Documents")
 dcl(DLG_LISTDOCS_Heading1,				"Choose document from the list:")
-	
+
 /*
 For insert Table widget
 */
 dcl(TB_InsertNewTable,                   "Insert New Table")
-dcl(TB_Table,                            "Table")
+dcl(TB_Rows_x_Cols_Table,                "Table")
 dcl(TB_ClearBackground,"Clear Background")
+dcl(TB_ClearForeground,"Clear Foreground")
 
 /*
-	  Language property in different languages; alphabetical except English first.
+	  Language names, arranged alphabetically.
+	
+	  Please add a country (in parentheses) only if there is more than one 
+	  entry for the language (or if it's not the main dialect).
+
+	  A specification in parentheses shall refer to the country code, if   
+	  possible, rather than to geographical or descriptive information.
+
+	  Add other information such as variant information solely by using a 
+	  comma.
+	
 	  Please when translating the first entry, put it also into parenthesis
 	  or, surround it by some other characters, so that it will appear on the top
 	  of the list when sorted alphabetically.
 */
-dcl(LANG_0, 							"(no proofing)")
-dcl(LANG_EN_AU, 							"English (Australia)")
-dcl(LANG_EN_CA, 							"English (Canada)")
-dcl(LANG_EN_GB, 							"English (UK)")
-dcl(LANG_EN_IE, 							"English (Ireland)")
-dcl(LANG_EN_NZ, 							"English (New Zealand)")
-dcl(LANG_EN_ZA, 							"English (South Africa)")
-dcl(LANG_EN_US, 							"English (US)")
+dcl(LANG_0,     							"(no proofing)")
+dcl(LANG_ACH,   							"Acholi")
 dcl(LANG_AF_ZA, 							"Afrikaans")
-dcl(LANG_AK_GH, 							"Akan")	// 
+dcl(LANG_AK_GH, 							"Akan")	//
 dcl(LANG_SQ_AL, 							"Albanian")	// Jordi 19/10/2002
-dcl(LANG_AM_ET, 							"Amharic (Ethiopia)")
+dcl(LANG_AM_ET, 							"Amharic")
 dcl(LANG_AR, 								"Arabic")
 dcl(LANG_AR_EG, 							"Arabic (Egypt)")
 dcl(LANG_AR_SA, 							"Arabic (Saudi Arabia)")
 dcl(LANG_HY_AM, 							"Armenian")
 dcl(LANG_AS_IN, 							"Assamese")
-dcl(LANG_AST_ES, 							"Asturian (Spain)")
-dcl(LANG_AYM_BO, 							"Aymara (La Paz)")
-dcl(LANG_AYC_BO, 							"Aymara (Oruro)")
-dcl(LANG_AYR, 								"Central Aymara")
+dcl(LANG_AST_ES, 							"Asturian")
+dcl(LANG_AYR, 								"Aymara, Central")
+dcl(LANG_AYM_BO, 							"Aymara (Central/Northern Bolivia)")
+dcl(LANG_AYC_BO, 							"Aymara (Southern Bolivia)")
+dcl(LANG_BM,    							"Bamanankan")
 dcl(LANG_EU_ES, 							"Basque")
 dcl(LANG_BE_BY, 							"Belarusian")
 dcl(LANG_BE_LATIN,							"Belarusian, Latin")
 dcl(LANG_BN_IN,                             "Bengali")
+dcl(LANG_NB_NO, 							"Bokmal")
+dcl(LANG_BS_BA, 							"Bosnian")
 dcl(LANG_BR_FR,								"Breton")		// Jordi 19/10/2002
 dcl(LANG_BG_BG, 							"Bulgarian")
 dcl(LANG_CA_ES, 							"Catalan")
-dcl(LANG_KW_GB,								"Cornish")		// Jordi 19/10/2002
-dcl(LANG_CO_FR,								"Corsican")		// Jordi 19/10/2002
-dcl(LANG_HR_HR,								"Croatian")
+dcl(LANG_CGG,   							"Chiga")
 dcl(LANG_ZH_HK, 							"Chinese (Hong Kong)")
 dcl(LANG_ZH_CN, 							"Chinese (PRC)")
 dcl(LANG_ZH_SG, 							"Chinese (Singapore)")
 dcl(LANG_ZH_TW, 							"Chinese (Taiwan)")
 dcl(LANG_COP_EG, 							"Coptic")
+dcl(LANG_KW_GB,								"Cornish")		// Jordi 19/10/2002
+dcl(LANG_CO_FR,								"Corsican")		// Jordi 19/10/2002
+dcl(LANG_HR_HR,								"Croatian")
 dcl(LANG_CS_CZ, 							"Czech")
 dcl(LANG_DA_DK, 							"Danish")
-dcl(LANG_NL_NL, 							"Dutch (Netherlands)")
+dcl(LANG_FA_AF, 							"Dari")
+dcl(LANG_NL_NL, 							"Dutch")
+dcl(LANG_EN_AU, 							"English (Australia)")
+dcl(LANG_EN_CA, 							"English (Canada)")
+dcl(LANG_EN_IE, 							"English (Ireland)")
+dcl(LANG_EN_NZ, 							"English (New Zealand)")
+dcl(LANG_EN_ZA, 							"English (South Africa)")
+dcl(LANG_EN_GB, 							"English (UK)")
+dcl(LANG_EN_US, 							"English (US)")
 dcl(LANG_EO,								"Esperanto")
 dcl(LANG_ET,								"Estonian")		// Hipi: Why not et-EE?
 dcl(LANG_FA_IR, 							"Farsi")
+dcl(LANG_FIL_PH, 							"Filipino")
 dcl(LANG_FI_FI, 							"Finnish")
-dcl(LANG_NL_BE, 							"Flemish (Belgium)")
+dcl(LANG_NL_BE, 							"Flemish")
 dcl(LANG_FR_BE, 							"French (Belgium)")
 dcl(LANG_FR_CA, 							"French (Canada)")
 dcl(LANG_FR_FR, 							"French (France)")
 dcl(LANG_FR_CH, 							"French (Switzerland)")
 dcl(LANG_FY_NL,								"Frisian")	// Jordi 19/10/2002
-dcl(LANG_GL, 								"Galician (Galego)")
+dcl(LANG_FF,								"Fulah")
+dcl(LANG_GL, 								"Galician")
+dcl(LANG_LG, 								"Ganda")
 dcl(LANG_KA_GE, 							"Georgian")
 dcl(LANG_DE_AT, 							"German (Austria)")
 dcl(LANG_DE_DE, 							"German (Germany)")
@@ -388,46 +415,53 @@ dcl(LANG_HI_IN, 							"Hindi")
 dcl(LANG_HU_HU, 							"Hungarian")
 dcl(LANG_IS_IS, 							"Icelandic")
 dcl(LANG_ID_ID,	 							"Indonesian")
-dcl(LANG_IU_CA,                             "Inuktitut")
 dcl(LANG_IA,	 							"Interlingua")
+dcl(LANG_IU_CA,                             "Inuktitut")
 dcl(LANG_GA_IE, 							"Irish")
-dcl(LANG_IT_IT, 							"Italian (Italy)")
+dcl(LANG_IT_IT, 							"Italian")
 dcl(LANG_JA_JP, 							"Japanese")
 dcl(LANG_KN_IN,                             "Kannada")
-dcl(LANG_KO_KR, 							"Korean")
+dcl(LANG_KK_KZ,                             "Kazakh")
+dcl(LANG_KM_KH, 							"Khmer")
 dcl(LANG_KO, 								"Korean")
+dcl(LANG_KO_KR, 							"Korean (South Korea)")
 dcl(LANG_KU, 								"Kurdish")
 dcl(LANG_LO_LA,                             "Lao")
-dcl(LANG_LA_IT, 							"Latin (Renaissance)")	// Is _IT the right thing here?
+dcl(LANG_LA_IT, 							"Latin")	// Is _IT the right thing here?
 dcl(LANG_LV_LV, 							"Latvian")
 dcl(LANG_LT_LT, 							"Lithuanian")
+dcl(LANG_JBO,   							"Lojban")
 dcl(LANG_MK,								"Macedonian")	// Jordi 19/10/2002 Hipi: Why not mk-MK?
+dcl(LANG_MG_MG,                             "Malagasy")
 dcl(LANG_MS_MY,                             "Malay")
+dcl(LANG_MNK_SN,							"Mandinka")
 dcl(LANG_MI_NZ,                             "Maori")
 dcl(LANG_MR_IN,                             "Marathi")
 dcl(LANG_MH_MH, 							"Marshallese (Marshall Islands)")
 dcl(LANG_MH_NR, 							"Marshallese (Nauru)")
 dcl(LANG_MN_MN,                             "Mongolian")
-dcl(LANG_MNK_SN,							"Mandinka (Senegal)")
-dcl(LANG_NB_NO, 							"Norwegian Bokmal")
-dcl(LANG_NE_NP, 							"Nepali (Nepal)")
-dcl(LANG_NN_NO, 							"Norwegian Nynorsk")
+dcl(LANG_NE_NP, 							"Nepali")
+dcl(LANG_NN_NO, 							"Nynorsk")
 dcl(LANG_OC_FR,								"Occitan")		// Jordi 19/10/2002
-dcl(LANG_PL_PL, 							"Polish")
 dcl(LANG_PS,								"Pashto")
+dcl(LANG_PL_PL, 							"Polish")
 dcl(LANG_PT_BR, 							"Portuguese (Brazil)")
 dcl(LANG_PT_PT, 							"Portuguese (Portugal)")
-dcl(LANG_PA_IN,                             "Punjabi (Gurmukhi)")
-dcl(LANG_PA_PK,                             "Punjabi (Shahmukhi)")
+dcl(LANG_PA_IN,                             "Punjabi (India)")
+dcl(LANG_PA_PK,                             "Punjabi (Pakistan)")
 dcl(LANG_QU_BO,                             "Quechua")
-dcl(LANG_QUH_BO,                            "Quechua (3 vowels)")
-dcl(LANG_QUL_BO,                            "Quechua (5 vowels)")
+dcl(LANG_QUZ,                               "Quechua (Cusco)")
+dcl(LANG_QUL_BO,                            "Quechua (Northern Bolivia)")
+dcl(LANG_QUH_BO,                            "Quechua (Southern Bolivia)")
 dcl(LANG_RO_RO, 							"Romanian")
-dcl(LANG_RU_RU, 							"Russian (Russia)")
+dcl(LANG_RU_RU, 							"Russian")
+dcl(LANG_RU_PETR1708,						"Russian, pre-1918")
 dcl(LANG_SC_IT,								"Sardinian")	// Jordi 19/10/2002
 dcl(LANG_SR,								"Serbian")		// Jordi 19/10/2002 Hipi: Why not sr-YU?
+dcl(LANG_SR_LATIN,							"Serbian, Latin")
 dcl(LANG_SK_SK, 							"Slovak")				// or Slovakian?
 dcl(LANG_SL_SI, 							"Slovenian")
+dcl(LANG_SON,   							"Songhay")
 dcl(LANG_ES_MX, 							"Spanish (Mexico)")
 dcl(LANG_ES_ES, 							"Spanish (Spain)")
 dcl(LANG_SW,                                "Swahili")
@@ -439,13 +473,14 @@ dcl(LANG_TE_IN,                             "Telugu")
 dcl(LANG_TH_TH, 							"Thai")
 dcl(LANG_TR_TR, 							"Turkish")
 dcl(LANG_UK_UA, 							"Ukrainian")
-dcl(LANG_UR_PK, 							"Urdu (Pakistan)")
 dcl(LANG_UR, 								"Urdu")
+dcl(LANG_UR_PK, 							"Urdu (Pakistan)")
 dcl(LANG_UZ_UZ, 							"Uzbek")
 dcl(LANG_VI_VN, 							"Vietnamese")
 dcl(LANG_CY_GB, 							"Welsh")
-dcl(LANG_WO_SN, 							"Wolof (Senegal)")
+dcl(LANG_WO_SN, 							"Wolof")
 dcl(LANG_YI,								"Yiddish")
+dcl(LANG_ZU,								"Zulu")
 
 
 /* Encoding Dialog */
@@ -465,7 +500,7 @@ dcl(ENC_WEST_ASCII, 					"US-ASCII")
 /* Western Europe */
 dcl(ENC_WEST_ISO,						"Western European, ISO-8859-1")
 dcl(ENC_WEST_WIN,						"Western European, Windows Code Page 1252")
-dcl(ENC_US_DOS,						"Western European, DOS/Windows Code Page 437")
+dcl(ENC_US_DOS,						"English, DOS/Windows Code Page 437")
 dcl(ENC_MLNG_DOS,						"Western European, DOS/Windows Code Page 850")
 dcl(ENC_WEST_MAC,						"Western European, Macintosh")
 dcl(ENC_WEST_HP,						"Western European, HP")
@@ -536,7 +571,7 @@ dcl(ENC_JAPN_WIN,						"Japanese, Windows Code Page 932")
 /* Korean */
 dcl(ENC_KORE_KSC,						"Korean, KSC_5601") // ISO
 dcl(ENC_KORE_EUC,						"Korean, EUC-KR")
-dcl(ENC_KORE_JOHAB, 					"Korean, Johab")
+dcl(ENC_KORE_JOHAB, 					"Korean, JOHAB")
 dcl(ENC_KORE_WIN,						"Korean, Windows Code Page 949")
 /* Unicode */
 dcl(ENC_UNIC_UTF_7, 					"Unicode UTF-7")
@@ -565,6 +600,8 @@ dcl(DLG_HTMLOPT_ExpDeclareXML,			"Declare as XML (version 1.0)")
 dcl(DLG_HTMLOPT_ExpAllowAWML,			"Allow extra markup in AWML namespace")
 dcl(DLG_HTMLOPT_ExpEmbedCSS,			"Embed (CSS) style sheet")
 dcl(DLG_HTMLOPT_ExpEmbedImages,			"Embed images in URLs (Base64-encoded)")
+dcl(DLG_HTMLOPT_ExpMathMLRenderPNG,		"Render MathML to PNG images (JavaScript will be used if option is not checked)")
+dcl(DLG_HTMLOPT_ExpSplitDocument,		"Split document")
 dcl(DLG_Exit_CloseWithoutSaving,				"Close &Without Saving")
 
 	/* X11 input methods */
@@ -588,7 +625,8 @@ dcl(DLG_History_List_Title, "Version history")
 dcl(DLG_History_Version_Version, "Version")
 dcl(DLG_History_Version_Started, "Created")
 dcl(DLG_History_Version_AutoRevisioned, "Auto-revision")
-	
+dcl(DLG_History_Restore, "Restore")
+
 dcl(DLG_DocComparison_WindowLabel, "Document Comparison")
 dcl(DLG_DocComparison_DocsCompared, "Documents compared")
 dcl(DLG_DocComparison_Results, "Results")
