@@ -119,7 +119,7 @@ fl_DocListener::~fl_DocListener()
 
 /*!
  */
-bool fl_DocListener::populate(PL_StruxFmtHandle sfh,
+bool fl_DocListener::populate(fl_ContainerLayout* sfh,
 							  const PX_ChangeRecord * pcr)
 {
 	UT_ASSERT(m_pLayout);
@@ -262,9 +262,9 @@ bool fl_DocListener::populate(PL_StruxFmtHandle sfh,
 static UT_uint32 countStrux = 0;
 /*!
  */
-bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
+bool fl_DocListener::populateStrux(pf_Frag_Strux* sdh,
 								   const PX_ChangeRecord * pcr,
-								   PL_StruxFmtHandle * psfh)
+								   fl_ContainerLayout* * psfh)
 {
 	UT_ASSERT(m_pLayout);
 
@@ -280,7 +280,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			{
 				xxx_UT_DEBUGMSG(("Null Update in Populate Strux \n"));
 				PT_DocPosition pos = pcrx->getPosition();
-				UT_uint32 percentFilled = 100*pos/m_pLayout->getDocSize();
+				UT_sint32 percentFilled = 100*pos/m_pLayout->getDocSize();
 				if(percentFilled > m_iFilled)
 				{
 				  pFrame->nullUpdate();
@@ -370,7 +370,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 				//
 				UT_DEBUGMSG(("SEVIOR: Doing Populate DocSection in DocListener \n"));
 				fl_DocSectionLayout * pPDSL = m_pLayout->getLastSection();
-				if(pPDSL != NULL)
+				if(pPDSL && !m_pLayout->isLayoutFilling())
 				{
 					pPDSL->format();
 				}
@@ -384,7 +384,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 				
 				m_pLayout->addSection(pSL);
 				
-				*psfh = (PL_StruxFmtHandle)pSL;
+				*psfh = (fl_ContainerLayout*)pSL;
 				
 				m_pCurrentSL = pSL;
 			}
@@ -412,7 +412,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 					//
 					m_pLayout->addHdrFtrSection(pSL);
 					pDocSL->setHdrFtr(hfType, pSL);
-					*psfh = (PL_StruxFmtHandle)pSL;
+					*psfh = (fl_ContainerLayout*)pSL;
 					
 					m_pCurrentSL = pSL;
 				}
@@ -461,7 +461,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 		    UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		  }
 
-		*psfh = (PL_StruxFmtHandle)pSL;
+		*psfh = (fl_ContainerLayout*)pSL;
 		m_pCurrentSL = (fl_SectionLayout*)pSL;
 		break;
 	}
@@ -495,7 +495,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			UT_ASSERT(pCL->getContainerType() == FL_CONTAINER_ANNOTATION);
 		}
 #endif
-		*psfh = (PL_StruxFmtHandle) pCL;
+		*psfh = (fl_ContainerLayout*) pCL;
 		m_pCurrentSL = (fl_SectionLayout *) static_cast<fl_EmbedLayout *>(m_pCurrentSL)->getDocSectionLayout();
 		fl_BlockLayout * pBL = NULL;
 		if(isFoot)
@@ -531,7 +531,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 	    fl_SectionLayout * pSL = NULL;
 		UT_DEBUGMSG(("fl_DocListener::populateStrux for 'SectionTOC'\n"));
 		pSL = (fl_SectionLayout *) m_pCurrentSL->append(sdh, pcr->getIndexAP(),FL_CONTAINER_TOC);
-		*psfh = (PL_StruxFmtHandle)pSL;
+		*psfh = (fl_ContainerLayout*)pSL;
 		m_pCurrentSL = (fl_SectionLayout*)pSL;
 		break;
 	}
@@ -547,7 +547,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 		UT_DEBUGMSG(("fl_DocListener::populateStrux for 'EndTOC'\n"));
 		UT_ASSERT(pCL->getContainerType() == FL_CONTAINER_TOC);
 #endif
-		*psfh = (PL_StruxFmtHandle) pCL;
+		*psfh = (fl_ContainerLayout*) pCL;
 		static_cast<fl_TOCLayout *>(pCL)->setTOCEndIn();
 		m_pCurrentSL = (fl_SectionLayout *) static_cast<fl_TOCLayout *>(m_pCurrentSL)->getDocSectionLayout();
 		break;
@@ -598,7 +598,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 					//
 					m_pLayout->addHdrFtrSection(pSL);
 					pDocSL->setHdrFtr(hfType, pSL);
-					*psfh = (PL_StruxFmtHandle)pSL;
+					*psfh = (fl_ContainerLayout*)pSL;
 					UT_DEBUGMSG(("Sevior: HeaderFooter created %p \n",pSL));
 					
 					m_pCurrentSL = pSL;
@@ -636,7 +636,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 				return false;
 			}
 			fl_CellLayout * pCell = (fl_CellLayout *) pCon;
-			UT_DEBUGMSG(("SEVIOR: Appending block to cell %p \n",pCell));
+			xxx_UT_DEBUGMSG(("SEVIOR: Appending block to cell %p \n",pCell));
 			// Append a new BlockLayout to this cell
 
 			pCL = pCell->append(sdh, pcr->getIndexAP(),FL_CONTAINER_BLOCK);
@@ -690,7 +690,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 #endif
 		}
 
-		*psfh = (PL_StruxFmtHandle)pCL;
+		*psfh = (fl_ContainerLayout*)pCL;
 		if(pCL->getLastContainer()==NULL)
 		{
 			if(pCL->getSectionLayout()->getType() != FL_SECTION_HDRFTR && pCL->getPrev() != NULL)
@@ -730,7 +730,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			pCL = pCell->append(sdh,pcr->getIndexAP(),FL_CONTAINER_TABLE);
 		}
 		pushContainerLayout(pCL);
-		*psfh = (PL_StruxFmtHandle)pCL;
+		*psfh = (fl_ContainerLayout*)pCL;
 //
 // Don't layout until a endTable strux
 //
@@ -752,7 +752,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			{
 				fl_ContainerLayout * pCL = pCon->append(sdh,pcr->getIndexAP(),FL_CONTAINER_FRAME);
 				m_pCurrentSL = static_cast<fl_SectionLayout *>(pCL);
-				*psfh = (PL_StruxFmtHandle)pCL;
+				*psfh = (fl_ContainerLayout*)pCL;
 				break;
 			}
 #ifdef DEBUG
@@ -772,7 +772,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			return false;
 		}
 		m_pCurrentSL = static_cast<fl_SectionLayout *>(pCL2);
-		*psfh = (PL_StruxFmtHandle)pCL2;
+		*psfh = (fl_ContainerLayout*)pCL2;
 	}
 	break;
 	case PTX_EndFrame:
@@ -784,7 +784,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 		fl_ContainerLayout*	pCL = NULL;
 		UT_DEBUGMSG(("!!!!Appending EndFrame \n"));
 		pCL = m_pCurrentSL;
-		*psfh = (PL_StruxFmtHandle)pCL;
+		*psfh = (fl_ContainerLayout*)pCL;
 		m_pCurrentSL = static_cast<fl_SectionLayout *>(pCL->myContainingLayout());
 		if(m_pCurrentSL->getContainerType() == FL_CONTAINER_CELL)
 		{
@@ -797,7 +797,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 	case PTX_SectionCell:
 	{
 		UT_ASSERT(m_pCurrentSL);
-		UT_DEBUGMSG(("!!!! Append Section Cell \n"));
+		xxx_UT_DEBUGMSG(("!!!! Append Section Cell \n"));
 		
 		// Append a new CallLayout to the Current TableLayout
 		fl_ContainerLayout * pCon = getTopContainerLayout();
@@ -824,7 +824,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			return false;
 		}
 		pushContainerLayout(pCL);
-		*psfh = (PL_StruxFmtHandle)pCL;
+		*psfh = (fl_ContainerLayout*)pCL;
 	}
 	break;
 	case PTX_EndTable:
@@ -840,7 +840,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 			return false;
 		}
-		*psfh = (PL_StruxFmtHandle)pCon;
+		*psfh = (fl_ContainerLayout*)pCon;
 		fl_TableLayout * pTL = static_cast<fl_TableLayout *>(pCon);
 		UT_DEBUGMSG(("SEVIOR: End table in doclistener \n"));
 		pTL->setDirty();
@@ -862,7 +862,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 	case PTX_EndCell:
 	{
 		UT_ASSERT(m_pCurrentSL);
-		UT_DEBUGMSG(("!!!! Append End Cell \n"));
+		xxx_UT_DEBUGMSG(("!!!! Append End Cell \n"));
 		fl_ContainerLayout *  pCon = popContainerLayout();
 		UT_ASSERT(pCon);
 		if(pCon == NULL)
@@ -881,7 +881,7 @@ bool fl_DocListener::populateStrux(PL_StruxDocHandle sdh,
 			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 			return false;
 		}
-		*psfh = (PL_StruxFmtHandle) pCon;
+		*psfh = (fl_ContainerLayout*) pCon;
 	}
 	break;
 			
@@ -931,7 +931,7 @@ fl_ContainerLayout * fl_DocListener::popContainerLayout(void)
 /*!
  * Change a strux or span.
  */
-bool fl_DocListener::change(PL_StruxFmtHandle sfh,
+bool fl_DocListener::change(fl_ContainerLayout* sfh,
 							const PX_ChangeRecord * pcr)
 {
 	UT_return_val_if_fail( sfh, false );
@@ -1272,7 +1272,7 @@ bool fl_DocListener::change(PL_StruxFmtHandle sfh,
 				UT_WARNINGMSG(("getAttrProp() failed in %s:%d",
 							   __FILE__, __LINE__));
 			}
-			PL_StruxDocHandle sdh = pL2->getStruxDocHandle();
+			pf_Frag_Strux* sdh = pL2->getStruxDocHandle();
 	
 			const gchar* pszSectionType = NULL;
 			pAP->getAttribute("type", pszSectionType);
@@ -1789,13 +1789,13 @@ void fl_DocListener::processDeferredNotifications(void)
 
 /*!
  */
-bool fl_DocListener::insertStrux(PL_StruxFmtHandle sfh,
+bool fl_DocListener::insertStrux(fl_ContainerLayout* sfh,
 								 const PX_ChangeRecord * pcr,
-								 PL_StruxDocHandle sdh,
+								 pf_Frag_Strux* sdh,
 								 PL_ListenerId lid,
-								 void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+								 void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 														 PL_ListenerId lid,
-														 PL_StruxFmtHandle sfhNew))
+														 fl_ContainerLayout* sfhNew))
 {
 	UT_DEBUGMSG(("fl_DocListener::insertStrux at pos %d \n",pcr->getPosition()));
 	UT_return_val_if_fail( sdh && pcr, false );
