@@ -83,6 +83,7 @@ class fp_HdrFtrContainer;
 class FG_Graphic;
 class PD_Document;
 class PP_AttrProp;
+class pf_Frag_Strux;
 class PX_ChangeRecord_FmtMark;
 class PX_ChangeRecord_FmtMarkChange;
 class PX_ChangeRecord_Object;
@@ -101,13 +102,13 @@ class ABI_EXPORT fl_SectionLayout : public fl_ContainerLayout
 	friend class fl_DocListener;
 
 public:
-	fl_SectionLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh, PT_AttrPropIndex ap, SectionType iType, fl_ContainerType iCType, PTStruxType ptType, fl_ContainerLayout * pMyContainerLayout);
+	fl_SectionLayout(FL_DocLayout* pLayout, pf_Frag_Strux* sdh, PT_AttrPropIndex ap, SectionType iType, fl_ContainerType iCType, PTStruxType ptType, fl_ContainerLayout * pMyContainerLayout);
 	virtual ~fl_SectionLayout();
 
 	SectionType     	getType(void) const { return m_iType; }
 
 	virtual bool		recalculateFields(UT_uint32 iUpdateCount);
-	fl_BlockLayout *        getFirstBlock(void) const; 
+	fl_BlockLayout *        getFirstBlock(void) const;
 	virtual fp_Container*		getNewContainer(fp_Container * pFirstContainer = NULL) = 0;
 	virtual FL_DocLayout*		getDocLayout(void) const;
 	virtual void                markAllRunsDirty(void) =0;
@@ -134,42 +135,42 @@ public:
 	virtual bool bl_doclistener_deleteStrux(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx);
 	virtual bool bl_doclistener_changeStrux(fl_ContainerLayout*, const PX_ChangeRecord_StruxChange * pcrxc);
 	virtual bool bl_doclistener_insertBlock(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx,
-											PL_StruxDocHandle sdh,
+											pf_Frag_Strux* sdh,
 											PL_ListenerId lid,
-											void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	PL_ListenerId lid,
-																	PL_StruxFmtHandle sfhNew));
+																	fl_ContainerLayout* sfhNew));
 	virtual bool bl_doclistener_insertSection(fl_ContainerLayout*,
 											  SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 	virtual fl_SectionLayout * bl_doclistener_insertTable(fl_ContainerLayout*,
 											  SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 	virtual fl_SectionLayout * bl_doclistener_insertTable(SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 	virtual fl_SectionLayout * bl_doclistener_insertFrame(fl_ContainerLayout*,
 											  SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 
 	virtual bool bl_doclistener_insertObject(fl_ContainerLayout*, const PX_ChangeRecord_Object * pcro);
 	virtual bool bl_doclistener_deleteObject(fl_ContainerLayout*, const PX_ChangeRecord_Object * pcro);
@@ -184,7 +185,7 @@ public:
 	virtual void         setImageHeight(UT_sint32 iHeight);
 	GR_Image *           getBackgroundImage(void)
 	  {	return m_pImageImage;}
-	
+
 #ifdef FMT_TEST
 	virtual void		__dump(FILE * fp) const;
 #endif
@@ -212,7 +213,7 @@ class ABI_EXPORT fl_DocSectionLayout : public fl_SectionLayout
 	friend class fl_DocListener;
 
 public:
-	fl_DocSectionLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh, PT_AttrPropIndex ap, SectionType iType);
+	fl_DocSectionLayout(FL_DocLayout* pLayout, pf_Frag_Strux* sdh, PT_AttrPropIndex ap, SectionType iType);
 	virtual ~fl_DocSectionLayout();
 
 	fl_DocSectionLayout* getNextDocSection(void) const;
@@ -226,7 +227,7 @@ public:
 	virtual fp_Container * getLastContainer(void) const;
 	virtual void        setFirstContainer(fp_Container * pCon);
 	virtual void        setLastContainer(fp_Container * pCon);
-	
+
 	fl_FootnoteLayout  *       getFootnoteLayout(UT_uint32 footnotePID);
 	fl_AnnotationLayout  *       getAnnotationLayout(UT_uint32 footnotePID);
 
@@ -263,31 +264,31 @@ public:
 	virtual bool 	    doclistener_changeStrux(const PX_ChangeRecord_StruxChange * pcrxc);
 	bool				doclistener_deleteStrux(const PX_ChangeRecord_Strux * pcrx);
 
-	virtual bool        bl_doclistener_insertFootnote(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx, 
-											  PL_StruxDocHandle sdh,
+	virtual bool        bl_doclistener_insertFootnote(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 
 
-	virtual bool        bl_doclistener_insertAnnotation(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx, 
-											  PL_StruxDocHandle sdh,
+	virtual bool        bl_doclistener_insertAnnotation(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 
 	void				setHdrFtr(HdrFtrType iType, fl_HdrFtrSectionLayout* pHFSL);
 
-	fl_HdrFtrSectionLayout*         getHeader(void);
-	fl_HdrFtrSectionLayout*         getFooter(void);
-	fl_HdrFtrSectionLayout*         getHeaderEven(void);
-	fl_HdrFtrSectionLayout*         getFooterEven(void);
-	fl_HdrFtrSectionLayout*         getHeaderFirst(void);
-	fl_HdrFtrSectionLayout*         getFooterFirst(void);
-	fl_HdrFtrSectionLayout*         getHeaderLast(void);
-	fl_HdrFtrSectionLayout*         getFooterLast(void);
+	fl_HdrFtrSectionLayout*         getHeader(void) const;
+	fl_HdrFtrSectionLayout*         getFooter(void) const;
+	fl_HdrFtrSectionLayout*         getHeaderEven(void) const;
+	fl_HdrFtrSectionLayout*         getFooterEven(void) const;
+	fl_HdrFtrSectionLayout*         getHeaderFirst(void) const;
+	fl_HdrFtrSectionLayout*         getFooterFirst(void) const;
+	fl_HdrFtrSectionLayout*         getHeaderLast(void) const;
+	fl_HdrFtrSectionLayout*         getFooterLast(void) const;
 
 	bool                            setHdrFtrHeightChange(bool bDoHdr, UT_sint32 newHeight);
 	static void         _HdrFtrChangeCallback(UT_Worker * pWorker);
@@ -296,6 +297,7 @@ public:
 	void                            prependOwnedHeaderPage(fp_Page * p_Page);
 	void                            prependOwnedFooterPage(fp_Page * p_Page);
 	void				deleteOwnedPage(fp_Page*, bool bReallyDeleteIT=true);
+	fp_Page *                       getFirstOwnedPage(void) const {return m_pFirstOwnedPage;}
 	void                markForRebuild(void) { m_bNeedsRebuild = true;}
 	void                clearRebuild(void) { m_bNeedsRebuild = false;}
 	bool                needsRebuild(void) const { return m_bNeedsRebuild;}
@@ -303,6 +305,7 @@ public:
     void                markForReformat(void) { m_bNeedsFormat = true;}
     bool                needsReFormat(void) const { return m_bNeedsFormat;}
 	bool                isThisPageValid(HdrFtrType hfType, fp_Page * pThisPage);
+	bool                isFirstPageValid(void) const; 
     void                getVecOfHdrFtrs(UT_GenericVector<fl_HdrFtrSectionLayout *> * vecHdrFtr);
 	void                formatAllHdrFtr(void);
 	void                doMarginChangeOnly(void);
@@ -360,8 +363,6 @@ private:
 	double              m_dMaxSectionColumnHeight;
 	UT_sint32           m_iFootnoteLineThickness;
 	UT_sint32           m_iFootnoteYoff;
-	
-	bool				m_bForceNewPage;
 
 	//! First column in the section
 	fp_Column*			m_pFirstColumn;
@@ -392,7 +393,7 @@ class ABI_EXPORT fl_HdrFtrSectionLayout : public fl_SectionLayout
 	friend class fl_DocListener;
 
 public:
-	fl_HdrFtrSectionLayout(HdrFtrType iHFType, FL_DocLayout* pLayout, fl_DocSectionLayout* pDocSL, PL_StruxDocHandle sdh, PT_AttrPropIndex ap);
+	fl_HdrFtrSectionLayout(HdrFtrType iHFType, FL_DocLayout* pLayout, fl_DocSectionLayout* pDocSL, pf_Frag_Strux* sdh, PT_AttrPropIndex ap);
 	virtual ~fl_HdrFtrSectionLayout();
 
 	inline fl_DocSectionLayout*	getDocSectionLayout(void) const { return m_pDocSL; }
@@ -429,12 +430,12 @@ public:
 	virtual void            collapse(void);
 	bool                    bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 													  const PX_ChangeRecord_Strux * pcrx,
-													  PL_StruxDocHandle sdh,
+													  pf_Frag_Strux* sdh,
 													  PL_ListenerId lid,
 													  fl_TableLayout * pTL);
 	bool                    bl_doclistener_insertEndTable(fl_ContainerLayout* pTab,
 													  const PX_ChangeRecord_Strux * pcrx,
-													  PL_StruxDocHandle sdh,
+													  pf_Frag_Strux* sdh,
 													  PL_ListenerId lid);
 	virtual bool bl_doclistener_populateSpan(fl_ContainerLayout*, const PX_ChangeRecord_Span * pcrs, PT_BlockOffset blockOffset, UT_uint32 len);
 	virtual bool bl_doclistener_populateObject(fl_ContainerLayout*, PT_BlockOffset blockOffset, const PX_ChangeRecord_Object * pcro);
@@ -448,31 +449,31 @@ public:
 	virtual fl_SectionLayout * bl_doclistener_insertTable(fl_ContainerLayout*,
 											  SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 	virtual fl_SectionLayout * bl_doclistener_insertTable(SectionType iType,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
-	bool         bl_doclistener_insertFirstBlock(fl_ContainerLayout* pCL, const PX_ChangeRecord_Strux * pcrx,PL_StruxDocHandle sdh,PL_ListenerId lid);
+																	  fl_ContainerLayout* sfhNew));
+	bool         bl_doclistener_insertFirstBlock(fl_ContainerLayout* pCL, const PX_ChangeRecord_Strux * pcrx,pf_Frag_Strux* sdh,PL_ListenerId lid);
 	virtual bool bl_doclistener_insertBlock(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx,
-											PL_StruxDocHandle sdh,
+											pf_Frag_Strux* sdh,
 											PL_ListenerId lid,
-											void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	PL_ListenerId lid,
-																	PL_StruxFmtHandle sfhNew));
+																	fl_ContainerLayout* sfhNew));
 	virtual bool bl_doclistener_insertSection(fl_ContainerLayout*, const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew));
+																	  fl_ContainerLayout* sfhNew));
 	virtual bool bl_doclistener_insertObject(fl_ContainerLayout*, const PX_ChangeRecord_Object * pcro);
 	virtual bool bl_doclistener_deleteObject(fl_ContainerLayout*, const PX_ChangeRecord_Object * pcro);
 	virtual bool bl_doclistener_changeObject(fl_ContainerLayout*, const PX_ChangeRecord_ObjectChange * pcroc);
@@ -499,7 +500,7 @@ class ABI_EXPORT fl_HdrFtrShadow : public fl_SectionLayout
 	friend class fl_DocListener;
 
 public:
-	fl_HdrFtrShadow(FL_DocLayout* pLayout, fp_Page* pPage, fl_HdrFtrSectionLayout* pDocSL, PL_StruxDocHandle sdh, PT_AttrPropIndex ap);
+	fl_HdrFtrShadow(FL_DocLayout* pLayout, fp_Page* pPage, fl_HdrFtrSectionLayout* pDocSL, pf_Frag_Strux* sdh, PT_AttrPropIndex ap);
 	virtual ~fl_HdrFtrShadow();
 
 virtual	fl_HdrFtrSectionLayout*	getHdrFtrSectionLayout(void) const { return m_pHdrFtrSL; }
@@ -508,7 +509,7 @@ virtual	fl_HdrFtrSectionLayout*	getHdrFtrSectionLayout(void) const { return m_pH
 	virtual void				format(void);
 	virtual void				updateLayout(bool bDoFull);
 	virtual void				redrawUpdate(void);
-	fp_Page *                       getPage(void) { return m_pPage;}
+	fp_Page *                       getPage(void) const { return m_pPage;}
 	virtual fp_Container*		getNewContainer(fp_Container *pFirstContainer = NULL);
 	virtual fp_Container*		getFirstContainer() const;
 	virtual fp_Container*		getLastContainer() const;
@@ -537,23 +538,23 @@ public:
 	fl_ShadowListener(fl_HdrFtrSectionLayout* pHFSL, fl_HdrFtrShadow* pShadow);
 	virtual ~fl_ShadowListener();
 
-	virtual bool				populate(PL_StruxFmtHandle sfh,
+	virtual bool				populate(fl_ContainerLayout* sfh,
 										 const PX_ChangeRecord * pcr);
 
-	virtual bool				populateStrux(PL_StruxDocHandle sdh,
+	virtual bool				populateStrux(pf_Frag_Strux* sdh,
 											  const PX_ChangeRecord * pcr,
-											  PL_StruxFmtHandle * psfh);
+											  fl_ContainerLayout* * psfh);
 
-	virtual bool				change(PL_StruxFmtHandle sfh,
+	virtual bool				change(fl_ContainerLayout* sfh,
 									   const PX_ChangeRecord * pcr);
 
-	virtual bool				insertStrux(PL_StruxFmtHandle sfh,
+	virtual bool				insertStrux(fl_ContainerLayout* sfh,
 											const PX_ChangeRecord * pcr,
-											PL_StruxDocHandle sdh,
+											pf_Frag_Strux* sdh,
 											PL_ListenerId lid,
-											void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	PL_ListenerId lid,
-																	PL_StruxFmtHandle sfhNew));
+																	fl_ContainerLayout* sfhNew));
 
 	virtual bool				signal(UT_uint32 iSignal);
 
