@@ -72,7 +72,7 @@ static void s_background_properties (const char * pszBgStyle, const char * pszBg
 									 const char * pszBackgroundColor,
 									 PP_PropertyMap::Background & background);
 
-fl_TableLayout::fl_TableLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh, 
+fl_TableLayout::fl_TableLayout(FL_DocLayout* pLayout, pf_Frag_Strux* sdh, 
 			       PT_AttrPropIndex indexAP, fl_ContainerLayout * pMyContainerLayout)
 	: fl_SectionLayout(pLayout, sdh, indexAP, FL_SECTION_TABLE,FL_CONTAINER_TABLE,PTX_SectionTable, pMyContainerLayout),
 	  m_bNeedsRebuild(false),
@@ -539,7 +539,7 @@ void fl_TableLayout::format(void)
 	}
 	if(!m_bIsEndTableIn)
 	{
-		UT_DEBUGMSG(("Don't format TABLE coz there is no endtable yet! \n"));
+		xxx_UT_DEBUGMSG(("Don't format TABLE coz there is no endtable yet! \n"));
 		return;
 	}
 	m_bRecursiveFormat = true;
@@ -891,11 +891,11 @@ void fl_TableLayout::updateTable(void)
 
 bool fl_TableLayout::bl_doclistener_insertBlock(fl_ContainerLayout* /*pLBlock*/,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 
 	UT_ASSERT(pcrx->getType()==PX_ChangeRecord::PXT_InsertStrux);
@@ -916,7 +916,7 @@ bool fl_TableLayout::bl_doclistener_insertBlock(fl_ContainerLayout* /*pLBlock*/,
 		// to call down into the document (like all of the view
 		// listeners).
 		
-	PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(pNewCL);
+	fl_ContainerLayout* sfhNew = pNewCL;
 	pfnBindHandles(sdh,lid,sfhNew);
 //
 // increment the insertion point in the view.
@@ -939,11 +939,11 @@ bool fl_TableLayout::bl_doclistener_insertBlock(fl_ContainerLayout* /*pLBlock*/,
 
 bool fl_TableLayout::bl_doclistener_insertTable( const PX_ChangeRecord_Strux * pcrx,
 											   SectionType iType,
-											   PL_StruxDocHandle sdh,
+											   pf_Frag_Strux* sdh,
 											   PL_ListenerId lid,
-											   void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											   void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	   PL_ListenerId lid,
-																	   PL_StruxFmtHandle sfhNew))
+																	   fl_ContainerLayout* sfhNew))
 {
 	UT_UNUSED(iType);
 	UT_ASSERT(iType == FL_SECTION_TABLE);
@@ -968,7 +968,7 @@ bool fl_TableLayout::bl_doclistener_insertTable( const PX_ChangeRecord_Strux * p
 		// to call down into the document (like all of the view
 		// listeners).
 
-	PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(pSL);
+	fl_ContainerLayout* sfhNew = pSL;
 	pfnBindHandles(sdh,lid,sfhNew);
 
 //
@@ -994,11 +994,11 @@ bool fl_TableLayout::bl_doclistener_insertTable( const PX_ChangeRecord_Strux * p
 
 bool fl_TableLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 	fl_ContainerLayout * pNewCL = NULL;
 	pNewCL = insert(sdh,pCell,pcrx->getIndexAP(), FL_CONTAINER_CELL);
@@ -1013,7 +1013,7 @@ bool fl_TableLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 		
 	if(pfnBindHandles)
 	{
-		PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(pNewCL);
+		fl_ContainerLayout* sfhNew = pNewCL;
 		pfnBindHandles(sdh,lid,sfhNew);
 	}
 
@@ -1047,18 +1047,18 @@ bool fl_TableLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 
 bool fl_TableLayout::bl_doclistener_insertEndTable(fl_ContainerLayout*,
 												   const PX_ChangeRecord_Strux * pcrx,
-												   PL_StruxDocHandle sdh,
+												   pf_Frag_Strux* sdh,
 												   PL_ListenerId lid,
-												   void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+												   void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 	// The endTable strux actually has a format handle to to the this table layout.
 	// so we bind to this layout.
 
 	if(pfnBindHandles)
 	{	
-		PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(this);
+		fl_ContainerLayout* sfhNew = this;
 		pfnBindHandles(sdh,lid,sfhNew);
 	}
 
@@ -1617,7 +1617,6 @@ void fl_TableLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 
 	s_border_properties (pszBorderColor, pszBorderStyle, pszBorderWidth, pszColor, m_lineTop);
 
-
 	/* table fill
 	 */
 	m_background.reset ();
@@ -1631,8 +1630,6 @@ void fl_TableLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	pSectionAP->getProperty ("background-color", pszBackgroundColor);
 	
 	s_background_properties (pszBgStyle, pszBgColor, pszBackgroundColor, m_background);
-
-
 }
 
 void fl_TableLayout::_lookupMarginProperties(const PP_AttrProp* pSectionAP)
@@ -1838,8 +1835,8 @@ PT_DocPosition fl_TableLayout::getPosition(bool bActualBlockPosition /* = false
  */
 UT_uint32 fl_TableLayout::getLength(void)
 {
-	PL_StruxDocHandle sdhTab = getStruxDocHandle();
-	PL_StruxDocHandle sdhEnd = m_pDoc-> getEndTableStruxFromTableSDH(sdhTab);
+	pf_Frag_Strux* sdhTab = getStruxDocHandle();
+	pf_Frag_Strux* sdhEnd = m_pDoc-> getEndTableStruxFromTableSDH(sdhTab);
 	PT_DocPosition posEnd = 0;
 	PT_DocPosition posStart = 0;
 	UT_uint32 len = 0;
@@ -1911,7 +1908,7 @@ void fl_TableLayout::_purgeLayout(void)
 
 //------------------------------------------------------------------
 
-fl_CellLayout::fl_CellLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh, PT_AttrPropIndex indexAP, fl_ContainerLayout * pMyContainerLayout)
+fl_CellLayout::fl_CellLayout(FL_DocLayout* pLayout, pf_Frag_Strux* sdh, PT_AttrPropIndex indexAP, fl_ContainerLayout * pMyContainerLayout)
 	: fl_SectionLayout(pLayout, sdh, indexAP, FL_SECTION_CELL,FL_CONTAINER_CELL,PTX_SectionCell,pMyContainerLayout),
 	  m_bNeedsRebuild(false),
 	  m_iLeftOffset(0),
@@ -2087,7 +2084,7 @@ bool fl_CellLayout::isCellSelected(void)
 	FV_View* pView = m_pLayout->getView();
 	PT_DocPosition posStartCell = 0;
 	PT_DocPosition posEndCell =0;
-	PL_StruxDocHandle sdhEnd,sdhStart;
+	pf_Frag_Strux* sdhEnd, *sdhStart;
 
 	sdhStart = getStruxDocHandle();
 	posStartCell = m_pDoc->getStruxPosition(sdhStart) +1;
@@ -2132,11 +2129,11 @@ void fl_CellLayout::checkAndAdjustCellSize(void)
 	
 bool fl_CellLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 	fl_ContainerLayout * pNewCL = NULL;
 	fl_TableLayout * pTL = static_cast<fl_TableLayout *>(myContainingLayout());
@@ -2148,7 +2145,7 @@ bool fl_CellLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 		// listeners).
 	if(	pfnBindHandles)
 	{
-		PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(pNewCL);
+		fl_ContainerLayout* sfhNew = pNewCL;
 		pfnBindHandles(sdh,lid,sfhNew);
 	}
 	fl_CellLayout * pCL = static_cast<fl_CellLayout *>(pNewCL);
@@ -2174,17 +2171,17 @@ bool fl_CellLayout::bl_doclistener_insertCell(fl_ContainerLayout* pCell,
 	
 bool fl_CellLayout::bl_doclistener_insertEndCell(fl_ContainerLayout*,
 											  const PX_ChangeRecord_Strux * pcrx,
-											  PL_StruxDocHandle sdh,
+											  pf_Frag_Strux* sdh,
 											  PL_ListenerId lid,
-											  void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+											  void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 																	  PL_ListenerId lid,
-																	  PL_StruxFmtHandle sfhNew))
+																	  fl_ContainerLayout* sfhNew))
 {
 	// The endCell strux actually needs a format handle to to this cell layout.
 	// so we bind to this layout.
 
 		
-	PL_StruxFmtHandle sfhNew = static_cast<PL_StruxFmtHandle>(this);
+	fl_ContainerLayout* sfhNew = this;
 	pfnBindHandles(sdh,lid,sfhNew);
 
 //
@@ -2295,7 +2292,13 @@ void fl_CellLayout::format(void)
 	
 	UT_sint32 iNewHeight = getFirstContainer()->getHeight();
 	fl_ContainerLayout * myL = myContainingLayout();
-	if((myL->getContainerType() != FL_CONTAINER_SHADOW) &&
+	while (myL && (myL->getContainerType() != FL_CONTAINER_SHADOW &&
+				   myL->getContainerType() != FL_CONTAINER_HDRFTR &&
+				   myL->getContainerType() != FL_CONTAINER_DOCSECTION))
+	{
+		myL = myL->myContainingLayout();
+	}
+	if(myL && (myL->getContainerType() != FL_CONTAINER_SHADOW) &&
 	   (myL->getContainerType() != FL_CONTAINER_HDRFTR))
 	{
 		if(iNewHeight != iOldHeight)
@@ -2489,7 +2492,7 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		UT_DEBUGMSG(("!!!!!!!!!!!!!!!!!!------------------!!!!!!!!!!!\n"));
 	}
 
-	UT_DEBUGMSG(("SEVIOR: indexAp in Cell Layout %d \n",m_apIndex));
+	xxx_UT_DEBUGMSG(("SEVIOR: indexAp in Cell Layout %d \n",m_apIndex));
 	/*
 	  TODO shouldn't we be using PP_evalProperty like
 	  the blockLayout does?
@@ -2800,8 +2803,8 @@ void fl_CellLayout::_localCollapse(void)
  */
 UT_uint32 fl_CellLayout::getLength(void)
 {
-	PL_StruxDocHandle sdhCell = getStruxDocHandle();
-	PL_StruxDocHandle sdhEnd = m_pDoc->getEndCellStruxFromCellSDH(sdhCell);
+	pf_Frag_Strux* sdhCell = getStruxDocHandle();
+	pf_Frag_Strux* sdhEnd = m_pDoc->getEndCellStruxFromCellSDH(sdhCell);
 	PT_DocPosition posEnd = 0;
 	PT_DocPosition posStart = 0;
 	UT_uint32 len = 0;
@@ -2918,7 +2921,9 @@ static void s_background_properties (const char * pszBgStyle, const char * pszBg
 			{
 				background.m_t_background = PP_PropertyMap::background_type (pszBgColor);
 				if (background.m_t_background == PP_PropertyMap::background_solid)
+				{
 					UT_parseColor (pszBgColor, background.m_color);
+				}
 			}
 		}
 	}
