@@ -1,3 +1,4 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  *
@@ -364,7 +365,6 @@ void fp_VerticalContainer::getOffsets(fp_ContainerObject* pContainer, UT_sint32&
 	fp_Container * pCon = static_cast<fp_Container *>(this);
 	fp_Container * pPrev = NULL;
 	fp_TableContainer * pTab = NULL;
-	fp_TOCContainer * pTOC = NULL;
 	while(pCon && !pCon->isColumnType())
 	{
 		my_xoff += pCon->getX();
@@ -458,47 +458,12 @@ void fp_VerticalContainer::getOffsets(fp_ContainerObject* pContainer, UT_sint32&
 			return;
 		}
 	}
-//
-// Correct for the offset of the column in continuous section breaks.
-//
+
 	UT_sint32 col_x =0;
 	UT_sint32 col_y =0;
-	if(pPrev && pPrev->getContainerType() == FP_CONTAINER_TABLE)
+	if(pPrev && ((pPrev->getContainerType() == FP_CONTAINER_TABLE) ||
+				 (pPrev->getContainerType() == FP_CONTAINER_TOC)))
 	{
-		pTab = static_cast<fp_TableContainer *>(pPrev);
-		fp_Container * pTopCol = NULL;
-		if(pTab->isThisBroken())
-		{
-			pTopCol = static_cast<fp_Container *>(pTab->getMasterTable()->getFirstBrokenTable()->getColumn());
-		}
-		else
-		{
-			if(pTab->getFirstBrokenTable())
-			{
-				pTopCol = static_cast<fp_Column *>(pTab->getFirstBrokenTable()->getColumn());
-			}
-			else
-			{
-				pTopCol = static_cast<fp_Column *>(pTab->getColumn());
-			}
-		}
-		if(pTopCol != NULL)
-		{
-			if(pTopCol->getContainerType() == FP_CONTAINER_COLUMN)
-			{
-				fp_Page * pPage = pTopCol->getPage();
-				if(pPage == NULL)
-				{
-					return;
-				}
-				fp_Column * pFirstLeader = pPage->getNthColumnLeader(0);
-				UT_sint32 iColOffset = pTopCol->getY() - pFirstLeader->getY();
-				if(pPage != pTab->getPage())
-				{
-					my_yoff += iColOffset;
-				}
-			}
-		}
 		if(pCon->getContainerType() == FP_CONTAINER_COLUMN)
 		{
 			UT_sint32 col_xV =0;
@@ -512,56 +477,14 @@ void fp_VerticalContainer::getOffsets(fp_ContainerObject* pContainer, UT_sint32&
 		}
 		xoff = pCon->getX() + my_xoff + pOrig->getX();
 		yoff = pCon->getY() + my_yoff + pOrig->getY();
-	}
-	if(pPrev && pPrev->getContainerType() == FP_CONTAINER_TOC)
-	{
-		pTOC = static_cast<fp_TOCContainer *>(pPrev);
-		fp_Column * pTopCol = NULL;
-		if(pTOC->isThisBroken())
-		{
-			pTopCol = static_cast<fp_Column *>(pTOC->getMasterTOC()->getFirstBrokenTOC()->getColumn());
-		}
-		else
-		{
-			if(pTOC->getFirstBrokenTOC())
-			{
-				pTopCol = static_cast<fp_Column *>(pTOC->getFirstBrokenTOC()->getColumn());
-			}
-			else
-			{
-				pTopCol = static_cast<fp_Column *>(pTOC->getColumn());
-			}
-		}
-		if(pTopCol != NULL  && (pTopCol->getContainerType() == FP_CONTAINER_COLUMN))
-		{
-			fp_Page * pPage = pTopCol->getPage();
-			fp_Column * pFirstLeader = pPage->getNthColumnLeader(0);
-			UT_sint32 iColOffset = pTopCol->getY() - pFirstLeader->getY();
-			if(pPage != pTOC->getPage())
-			{
-				my_yoff += iColOffset;
-			}
-		}
-		if(pCon->getContainerType() == FP_CONTAINER_COLUMN)
-		{
-			UT_sint32 col_xV =0;
-			UT_sint32 col_yV =0;
-			fp_Column * pCol = static_cast<fp_Column *>(pCon);
-			pCol->getPage()->getScreenOffsets(pCol, col_xV, col_yV);
-			pCol =static_cast<fp_Column *>(pCon->getColumn());
-			pCol->getPage()->getScreenOffsets(pCol, col_x, col_y);
-			UT_sint32 ydiff = col_yV - col_y;
-			my_yoff += ydiff;
-		}
-		xoff = pCon->getX() + my_xoff + pOrig->getX();
-		yoff = pCon->getY() + my_yoff + pOrig->getY();
-		if(pCon->getContainerType() != FP_CONTAINER_COLUMN_SHADOW)
+		if ((pPrev->getContainerType() == FP_CONTAINER_TOC) &&
+			(pCon->getContainerType() != FP_CONTAINER_COLUMN_SHADOW))
 		{
 			xxx_UT_DEBUGMSG(("Not in shadow final xoff %d \n",xoff));
 			return;
 		}
-		xxx_UT_DEBUGMSG(("Offsets not FP_CONTAINER_COLUMN_SHADOW x= %d \n",xoff));
 	}
+
 	if(pCon && pCon->getContainerType() == FP_CONTAINER_COLUMN_SHADOW)
 	{
 		xoff = pCon->getX() + my_xoff + pOrig->getX();
@@ -781,7 +704,13 @@ void fp_VerticalContainer::getScreenOffsets(fp_ContainerObject* pContainer,
 		}
 		pPrev = pCon;
 		pCon = pCon->getContainer();
-		UT_return_if_fail(pCon);
+		if (!pCon)
+		{
+			// Can happen during loading
+			xoff = 0;
+			yoff = 0;
+			return;
+		}
 	}
 	UT_return_if_fail(pCon);
 	UT_sint32 col_x =0;
@@ -1767,6 +1696,7 @@ void fp_VerticalContainer::bumpContainers(fp_ContainerObject* pLastContainerToKe
 	}
 }
 
+
 /*!
   Create column
   \param pSectionLayout Section layout type used for this container
@@ -1843,7 +1773,33 @@ void fp_Column::setPage(fp_Page * pPage)
 	m_pPage = pPage;
 }
 
-
+/* Return the index of the column on its page*/
+UT_sint32 fp_Column::getColumnIndex(void)
+{
+    fp_Page * pPage = getPage();
+    fl_DocSectionLayout * pSection = getDocSectionLayout();
+    fp_Column * pCol = NULL;
+    if (!pPage || !pSection)
+    {return 0;}
+    UT_sint32 kmax = static_cast<UT_sint32>(pSection->getNumColumns());
+    UT_sint32 j;
+    for(j=0;j<pPage->countColumnLeaders();j++)
+    {
+	pCol = pPage->getNthColumnLeader(j); 
+	if (pCol && (pCol->getDocSectionLayout() == pSection))
+	{
+	    UT_sint32 k = 0;
+	    while(pCol && k<kmax)
+	    {
+		if (pCol == this)
+		{return k;}
+		pCol = static_cast<fp_Column *> (pCol->getNext());
+		k++;
+	    }
+	}
+    }
+    return 0;
+}
 /*!
  Draw column outline
  \param pDA Draw arguments
@@ -1925,23 +1881,13 @@ void fp_Column::layout(void)
 	clearWrappedLines();
 	_setMaxContainerHeight(0);
 	UT_sint32 iY = 0, iPrevY2 = 0;
+	UT_sint32 iContainerMarginAfter = 0;
 	UT_GenericVector<fl_BlockLayout *> vecBlocks;
 	fp_Line * pLastLine = NULL;
 	fp_Container *pContainer = NULL;
 	fp_Container *pPrevContainer = NULL;
 	UT_sint32 i  = 0;
 	//
-	// First calculate the border widths
-	//
-	for(i=0; i< countCons();i++)
-	{
-		pContainer = static_cast<fp_Container*>(getNthCon(i));
-		if(pContainer->getContainerType() == FP_CONTAINER_LINE)
-		{
-		    static_cast<fp_Line *>(pContainer)->calcBorderThickness();
-		}
-	}
-	//
 	// RedrawHeight makes sure we redraw from whereever a line
 	// changes position.
 	//
@@ -2055,7 +2001,7 @@ void fp_Column::layout(void)
 		{
 			iContainerHeight = pTOC->getHeight();
 		}
-		UT_sint32 iContainerMarginAfter = pContainer->getMarginAfter();
+		iContainerMarginAfter = pContainer->getMarginAfter();
 		xxx_UT_DEBUGMSG(("Layout: container %d Height %d Margin %d setY %d \n",i,iContainerHeight,iContainerMarginAfter,iY));
 		//	UT_ASSERT(iContainerHeight > 0);
 		// Update height of previous line now we know the gap between
@@ -2084,14 +2030,21 @@ void fp_Column::layout(void)
 		iPrevY2 = iY;
 		iY += iContainerHeight;
 		iY += iContainerMarginAfter;
-		//iY +=  0.5;
-
+#if DEBUG
+		if (iY - iContainerMarginAfter > getMaxHeight())
+		{
+			UT_DEBUGMSG(("Problem; MaxColHeight: %d present height: %d\n",
+						 getMaxHeight(), iY - iContainerMarginAfter));
+			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		}
+#endif
 		pPrevContainer = pContainer;
 	}
 	// Correct height position of the last line
 	if (pPrevContainer)
 	{
 		UT_ASSERT((iY - iPrevY2 + getGraphics()->tlu(1)) > 0);
+		iY -= iContainerMarginAfter;
 		if(pPrevContainer->getContainerType() == FP_CONTAINER_LINE)
 		{
 			fp_Line * pLine = static_cast<fp_Line *>(pPrevContainer);
@@ -2140,49 +2093,6 @@ void fp_Column::layout(void)
 	}
 }
 
-bool fp_Column::hasEmptySpaceAtBottom(void)
-{
-        if(countCons() == 0)
-	    return false;
-        UT_sint32 iDiff = getMaxHeight() - getHeight();
-	fp_Container * pLast = static_cast<fp_Container *>(getNthCon(countCons()-1));
-	if(pLast->getContainerType() != FP_CONTAINER_LINE)
-	    return false;
-	fp_Line * pLLast = static_cast<fp_Line *>(pLast);
-	if(pLLast->getContainer()->getContainerType() == FP_CONTAINER_ENDNOTE)
-	    return false;
-	if(pLLast->containsForcedColumnBreak() || pLLast->containsForcedPageBreak())
-	    return false;
-	fp_Container * pNext = pLast->getNextContainerInSection();
-	if(pNext == NULL)
-	  return false;
-	if(pNext->getContainerType() != FP_CONTAINER_LINE)
-	  return false;
-	if(pNext->getContainerType() == FP_CONTAINER_ENDNOTE)
-	    return false;
-	if(pNext->getContainer() == NULL)
-	    return false;
-	if(pNext->getContainer()->getContainerType() == FP_CONTAINER_ENDNOTE)
-	    return false;
-	fp_Line * pNLine = static_cast<fp_Line *>(pNext);
-	if(pNLine->containsFootnoteReference())
-	{
-	  //
-	  // Just bail out for now. Later we can add up the height of the 
-	  // footnotes
-	  //
-	  return false;
-	}
-
-	UT_sint32 iHeight = pNLine->getHeight();
-	if(1.3*static_cast<float>(iHeight) < static_cast<float>(iDiff))
-	{
-	  UT_DEBUGMSG((" height %d iDiff %d pNLine %p \n",iHeight,iDiff,pNLine));
-	     return true;
-	}
-	return false;
-}
-
 UT_sint32 fp_Column::getMaxHeight(void) const
 {
 	const fp_VerticalContainer * pVC = static_cast<const fp_VerticalContainer *>(this);
