@@ -64,14 +64,14 @@ public:
 	*/
 	inline UT_sint32	getMaxHeight(void) const
  		{ return m_iMaxHeight; }
-	
+
 	/*!
 	  Get container's width
 	  \return Width
 	*/
 	virtual UT_sint32	getWidth(void) const
 		{ return m_iWidth; }
-	
+
 	virtual UT_sint32	getX(void) const;
 
 	void        _setX( UT_sint32 iX) { m_iX = iX;}
@@ -86,7 +86,7 @@ public:
 	*/
 	virtual UT_sint32	getHeight(void) const
 		{ return m_iHeight; }
-	
+
 	UT_sint32	getColumnGap(void) const;
 
 	/*!
@@ -142,7 +142,7 @@ public:
 	virtual UT_sint32   wantHBreakAt(UT_sint32) {return 0;}
 	virtual fp_ContainerObject * VBreakAt(UT_sint32) {return NULL;}
 	virtual fp_ContainerObject * HBreakAt(UT_sint32) {return NULL;}
-	void                recalcMaxWidth(bool bDontClearIfNeeded = false) 
+	void                recalcMaxWidth(bool bDontClearIfNeeded = false)
 	{
 		UT_UNUSED(bDontClearIfNeeded);
 	}
@@ -163,6 +163,12 @@ public:
 		{ m_vecWrappedLines.clear();}
 	fp_Line *           getNthWrappedLine(UT_sint32 i)
 		{ return m_vecWrappedLines.getNthItem(i);}
+	/* Virtual functions for vertical breakable containers*/
+	virtual fp_Container * getFirstBrokenContainer() const {UT_ASSERT(0);return NULL;}
+	virtual UT_sint32      getLastWantedVBreak(void) const {return 0;}
+	virtual void           setLastWantedVBreak(UT_sint32) {;}
+	virtual void           deleteBrokenAfter(bool) {;}
+
 protected:
     void                _setMaxContainerHeight(UT_sint32 iContainerHeight);
 	UT_sint32           _getMaxContainerHeight(void) const;
@@ -175,7 +181,7 @@ private:
 	  Width of the container
 	*/
 	UT_sint32 				m_iWidth;
-	
+
 	/*!
 	  Height of the container
 	*/
@@ -214,7 +220,6 @@ public:
 	~fp_Column();
 
 	fl_DocSectionLayout*	getDocSectionLayout(void) const;
-	bool                    hasEmptySpaceAtBottom(void);
 	void			setLeader(fp_Column* p) { m_pLeader = p; }
 	void			setFollower(fp_Column* p) { m_pFollower = p; }
 	fp_Column*	getLeader(void) const  { return m_pLeader; }
@@ -228,12 +233,14 @@ public:
 	void				setPage(fp_Page* pPage);
 	virtual fp_Page*	getPage(void) const
 		{ return m_pPage; }
+
+	UT_sint32               getColumnIndex(void);
 	/*!
 	  Get container's max height
 	  \return Max height
 	*/
 	UT_sint32	        getMaxHeight(void) const;
- 	
+
 	void				layout(void);
 
 	void                collapseEndnotes(void);
