@@ -35,7 +35,7 @@
 #include "gr_EmbedManager.h"
 
 fp_EmbedRun::fp_EmbedRun(fl_BlockLayout* pBL, 
-					   UT_uint32 iOffsetFirst,PT_AttrPropIndex indexAP,PL_ObjectHandle oh)	: 
+					   UT_uint32 iOffsetFirst,PT_AttrPropIndex indexAP,pf_Frag_Object* oh)	: 
 	fp_Run(pBL,  iOffsetFirst,1, FPRUN_EMBED ),
 	m_iPointHeight(0),
 	m_pSpanAP(NULL),
@@ -139,6 +139,7 @@ void fp_EmbedRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	  getEmbedManager()->loadEmbedData(m_iEmbedUID);
 	}
 	getEmbedManager()->setDefaultFontSize(m_iEmbedUID,atoi(pszSize));
+	getEmbedManager()->setFont(m_iEmbedUID,pFont);
 	if(getEmbedManager()->isDefault())
 	{
 	  iWidth = _getLayoutPropFromObject("width");
