@@ -60,7 +60,8 @@ fp_Page::fp_Page(FL_DocLayout* pLayout,
 		m_pHeader(0),
 		m_FillType(NULL,NULL,FG_FILL_TRANSPARENT),
 		m_pLastMappedTOC(NULL),
-		m_iCountWrapPasses(0)
+		m_iCountWrapPasses(0),
+		m_iFieldPageNumber(-1)
 {
 	UT_ASSERT(pLayout);
 	UT_ASSERT(pOwner);
@@ -297,17 +298,6 @@ fp_Container * fp_Page::updatePageForWrapping(fp_Column *& pNextCol)
 		}
 		while(pCol)
 		{
-			if(pCol->hasEmptySpaceAtBottom())
-			{
-				//
-				// We have can have a problem laying out lines with
-				// borders defined. This should fix that.
-				//
-				if(pCol->countCons() > 0)
-				{
-					return static_cast<fp_Container *>(pCol->getNthCon(pCol->countCons()-1));
-				}
-			}
 			if(m_iCountWrapPasses > 10)
 			{
 				nWrapped += pCol->countWrapped();
@@ -353,7 +343,7 @@ fp_Container * fp_Page::updatePageForWrapping(fp_Column *& pNextCol)
 				}
 				
 		}
-		if((nWrappedObjs == 0) &&(m_iCountWrapPasses == 0))
+		if((nWrappedObjs == 0) &&(m_iCountWrapPasses == 1))
 		{
 			return NULL;
 		}
@@ -883,12 +873,52 @@ bool fp_Page::containsPageBreak(void) const
 }
 
 /*!
- * Returns the page number
+ * Returns the physical page number (the numbering starts from 0)
  */
 UT_sint32 fp_Page::getPageNumber(void)
 {
 	return m_pLayout->findPage(this);
 }
+
+/*!
+ * Return the page number as indicated in a page number field run.
+ * This value depends on the section properties "section-restart" 
+ * and "section-restart-value".
+ */
+
+UT_sint32 fp_Page::getFieldPageNumber(void) const
+{
+	return m_iFieldPageNumber;
+}
+
+void fp_Page::setFieldPageNumber(UT_sint32 iPageNum)
+{
+	m_iFieldPageNumber = iPageNum;
+}
+
+void fp_Page::resetFieldPageNumber(void)
+{
+	fl_DocSectionLayout * pDSL = static_cast<fl_DocSectionLayout *>(getOwningSection());
+	m_iFieldPageNumber = getPageNumber();
+	if (m_iFieldPageNumber >= 0)
+	{
+		m_iFieldPageNumber++;
+		while(pDSL && !pDSL->arePageNumbersRestarted())
+		{
+			pDSL =  pDSL->getPrevDocSection();
+		}
+		if(pDSL && pDSL->arePageNumbersRestarted())
+		{
+			fp_Page * pFirstPage = pDSL->getFirstOwnedPage();
+			if(pFirstPage)
+			{
+				UT_sint32 iFirstPage = pFirstPage->getPageNumber();
+				m_iFieldPageNumber += pDSL->getRestartedPageNumber() - iFirstPage - 1;
+			}
+		}
+	}
+}
+
 /*!
  * This method returns the height available to the requested column. It 
  * subtracts the height given to previous columns on the page as well as the 
@@ -1413,6 +1443,37 @@ fp_Column* fp_Page::getNthColumnLeader(UT_sint32 n) const
 	return m_vecColumnLeaders.getNthItem(n);
 }
 
+
+fp_Container* fp_Page::getNthColumn(UT_uint32 n,fl_DocSectionLayout *pSection) const
+{
+	fp_Column *pCol = NULL;
+	UT_sint32 j = 0;
+	bool b_sectionFound = false;
+	
+	if ((!pSection) || (n > pSection->getNumColumns()))
+	{ return NULL;}
+	for (j = 0;j < countColumnLeaders();j++)
+	{
+		pCol = getNthColumnLeader(j);
+		if (pCol && (pCol->getDocSectionLayout() == pSection))
+		{
+			b_sectionFound = true;
+			break;
+		}
+	}
+	if (!b_sectionFound)
+	{ return NULL;}
+
+	UT_uint32 k = 0;
+	while(pCol && k < n)
+	{
+		pCol = static_cast <fp_Column *>(pCol->getNext());
+		k++;
+	}
+	return pCol;
+
+}
+ 
 /*!
  * This method is called following a notification of an increase in 
  * HdrFtr size
@@ -1469,7 +1530,7 @@ bool fp_Page::breakPage(void)
 	{
 		iFootnoteHeight += getNthFootnoteContainer(i)->getHeight();
 	}
-	iY =+ iFootnoteHeight;
+	iY += iFootnoteHeight;
 
 		
 	// we need the height of the annotations on this page, to deduct.
@@ -1480,7 +1541,7 @@ bool fp_Page::breakPage(void)
 			{
 					iAnnotationHeight += getNthAnnotationContainer(i)->getHeight();
 			}
-			iY =+ iAnnotationHeight;
+			iY += iAnnotationHeight;
 	}
 
 	for (i=0; i<count; i++)
@@ -1524,6 +1585,17 @@ bool fp_Page::breakPage(void)
 		UT_sint32 maxContainers= 0;
 		UT_sint32 maxContainerHeight = 0;
 		fp_Column * pCol = pPrev;
+		if (pCol && pCol->getFirstContainer() &&
+			(pCol->getFirstContainer()->getContainerType() == FP_CONTAINER_LINE))
+		{
+			fp_Line * pLine = static_cast <fp_Line*>(pCol->getFirstContainer());
+			if (pLine->getFirstRun() &&
+				(pLine->getFirstRun()->getType() == FPRUN_FORCEDPAGEBREAK))
+			{
+				return true;
+			}
+		}
+
 		while(pCol != NULL)
 		{
 			UT_sint32 countContainers = 0;
@@ -1685,7 +1757,6 @@ void fp_Page::updateColumnX()
 	if (count == 0)
 		return;
 
-	fp_Column * pLastCol = NULL;
 	UT_ASSERT(m_pOwner == getNthColumnLeader(0)->getDocSectionLayout());
 
 
@@ -1743,7 +1814,6 @@ void fp_Page::updateColumnX()
 				iX += (iColWidth + iColumnGap);
 			}
 
-			pLastCol = pTmpCol;
 			pTmpCol = pTmpCol->getFollower();
 		}
 	}
