@@ -1,3 +1,4 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2004 Martin Sevior <msevior@physics.unimelb.edu.au>
@@ -27,6 +28,7 @@
 #include "fp_Page.h"
 #include "fp_Line.h"
 #include "fp_Run.h"
+#include "fp_TableContainer.h"
 #include "fl_DocLayout.h"
 #include "fl_SectionLayout.h"
 #include "gr_DrawArgs.h"
@@ -143,8 +145,8 @@ void fp_TOCContainer::clearScreen(void)
 		getPage()->getScreenOffsets(pCol,x,y);
 		x += srcX;
 		y += srcY;
-		getFillType()->setWidthHeight(getGraphics(),iWidth,iHeight);
-		getFillType()->Fill(getGraphics(),srcX,srcY,x,y,iWidth,iHeight);
+		getFillType().setWidthHeight(getGraphics(),iWidth,iHeight);
+		getFillType().Fill(getGraphics(),srcX,srcY,x,y,iWidth,iHeight);
 		xxx_UT_DEBUGMSG(("x %d y %d width %d height %d \n",x,y,iWidth,iHeight));
 		return;
 	}
@@ -396,15 +398,7 @@ void fp_TOCContainer::setFirstBrokenTOC(fp_TOCContainer * pBroke)
 {
 	if(isThisBroken())
 	{
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-		fp_TOCContainer * pMaster = getMasterTOC();
-		pMaster->setFirstBrokenTOC(pBroke);
-		fp_TOCContainer * pNext = static_cast<fp_TOCContainer *>(pMaster);
-		while(pNext)
-		{
-			pNext->setFirstBrokenTOC( pBroke);
-			pNext = static_cast<fp_TOCContainer *>(pNext->getNext());
-		}
+		getMasterTOC()->setFirstBrokenTOC(pBroke);
 	}
 	m_pFirstBrokenTOC = pBroke;
 
@@ -414,14 +408,7 @@ void fp_TOCContainer::setLastBrokenTOC(fp_TOCContainer * pBroke)
 {
 	if(isThisBroken())
 	{
-		fp_TOCContainer * pMaster = getMasterTOC();
-		pMaster->setLastBrokenTOC(pBroke);
-		fp_TOCContainer * pNext = static_cast<fp_TOCContainer *>(pMaster);
-		while(pNext)
-		{
-			pNext->setLastBrokenTOC( pBroke);
-			pNext = static_cast<fp_TOCContainer *>(pNext->getNext());
-		}
+		getMasterTOC()->setLastBrokenTOC(pBroke);
 	}
 	m_pLastBrokenTOC = pBroke;
 }
@@ -469,10 +456,13 @@ fp_ContainerObject * fp_TOCContainer::VBreakAt(UT_sint32 vpos)
 	{
 		return getLastBrokenTOC()->VBreakAt(vpos);
 	}
-	if(getContainer() == NULL)
+	UT_sint32 iTotalHeight = getTotalTOCHeight();
+	if (vpos >= iTotalHeight)
 	{
-	    return NULL;
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		return NULL;
 	}
+
 	pBroke = new fp_TOCContainer(getSectionLayout(),getMasterTOC());
 	getMasterTOC()->setLastBrokenTOC(pBroke);
 
@@ -482,19 +472,12 @@ fp_ContainerObject * fp_TOCContainer::VBreakAt(UT_sint32 vpos)
 // vpos is relative to the container that contains this height but we need
 // to add in the height above it.
 //
-	pBroke->setYBreakHere(getYBreak()+vpos);
 	setYBottom(getYBreak() + vpos -1);
 	UT_ASSERT(getHeight() >0);
-	fp_VerticalContainer * pVCon = static_cast<fp_VerticalContainer *>(getMasterTOC());
-	if(pVCon == NULL)
-	{
-
-	}
-	pBroke->setYBottom(pVCon->getHeight());
-	xxx_UT_DEBUGMSG(("SEVIOR????????: YBreak %d YBottom  %d Height of broken TOC %d \n",pBroke->getYBreak(),pBroke->getYBottom(),pBroke->getHeight()));
-	xxx_UT_DEBUGMSG(("SEVIOR????????: Previous TOC YBreak %d YBottom  %d Height of broken TOC %d \n",getYBreak(),getYBottom(),getHeight()));
+	pBroke->setYBreakHere(getYBreak()+vpos);
+	pBroke->setYBottom(iTotalHeight);
 	UT_ASSERT(pBroke->getHeight() > 0);
-	UT_sint32 i = 0;
+	UT_sint32 i = -1;
 //
 // The structure of TOC linked list is as follows.
 // NULL <= Master <==> Next <==> Next => NULL
@@ -506,63 +489,59 @@ fp_ContainerObject * fp_TOCContainer::VBreakAt(UT_sint32 vpos)
 	fp_Container * pUpCon = NULL;
 	if(getMasterTOC()->getFirstBrokenTOC() == this)
 	{
-		i = getContainer()->findCon(getMasterTOC());
 		pUpCon = getMasterTOC()->getContainer();
-  		pBroke->setPrev(getMasterTOC());
-  		pBroke->setNext(NULL);
-  		getMasterTOC()->setNext(pBroke);
+		pBroke->setPrev(getMasterTOC());
+		pBroke->setNext(NULL);
+		getMasterTOC()->setNext(pBroke);
 		setNext(pBroke);
+		if (pUpCon)
+		{
+			i = pUpCon->findCon(getMasterTOC());
+		}
 	}
 	else
 	{
-  		pBroke->setNext(NULL);
-  		setNext(pBroke);
+		pBroke->setNext(NULL);
+		setNext(pBroke);
 		if(getYBreak() == 0 )
 		{
 			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 			pUpCon = getMasterTOC()->getContainer();
-//
-// Fallback for loads...
-//
-			if(pUpCon == NULL)
+			if(pUpCon)
 			{
-				pUpCon = getContainer();
+				i = pUpCon->findCon(getMasterTOC());
 			}
 		}
 		else
 		{
 			pUpCon = getContainer();
-		}
-		if(getYBreak() == 0)
-		{
-			i = pUpCon->findCon(getMasterTOC());
-		}
-		else
-		{
-			i = pUpCon->findCon(this);
+			if (pUpCon)
+			{
+				i = pUpCon->findCon(this);
+			}
 		}
 	}
-	if(i >=0 && i < pUpCon->countCons() -1)
+	if((i >= 0) && (i < pUpCon->countCons() -1))
 	{
 		pUpCon->insertConAt(pBroke,i+1);
 	}
-	else if( i == pUpCon->countCons() -1)
+	else if((i >= 0) && (i == pUpCon->countCons() -1))
 	{
 		pUpCon->addCon(pBroke);
 	}
 	else
 	{
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-		return NULL;
+		UT_DEBUGMSG(("Breaking a TOC that is not yet inserted\n"));
 	}
 	pBroke->setContainer(pUpCon);
 	//
 	// Now deal with issues from a container overlapping the top of the
 	// of the new broken TOC.
 	//
-// Skip this for now. Look at fp_TableContainer to see if it's needed later
-//
-	static_cast<fp_VerticalContainer *>(pBroke)->setHeight(pBroke->getHeight());	return pBroke;
+	// Skip this for now. Look at fp_TableContainer to see if it's needed later
+	//
+	static_cast<fp_VerticalContainer *>(pBroke)->setHeight(pBroke->getHeight());	
+	return pBroke;
 }
 
 
@@ -628,7 +607,8 @@ void fp_TOCContainer::setYBottom(UT_sint32 i)
 /*!
  * The caller to this method requests a break at the vertical height
  * given. It returns the actual break height, which will always be
- * less than or equal to the requested height.
+ * less than or equal to the requested height. The function returns -1
+ * if the table does not need to be broken.
  */
 UT_sint32 fp_TOCContainer::wantVBreakAt(UT_sint32 vpos)
 {
@@ -639,6 +619,16 @@ UT_sint32 fp_TOCContainer::wantVBreakAt(UT_sint32 vpos)
 	UT_sint32 count = countCons();
 	UT_sint32 i =0;
 	UT_sint32 iYBreak = vpos;
+	UT_sint32 iTotHeight = getTotalTOCHeight();
+	if (iYBreak > iTotHeight)
+	{
+		return -1;
+	}
+	else if (iYBreak > iTotHeight - FP_TABLE_MIN_BROKEN_HEIGHT)
+	{
+		iYBreak = iTotHeight - FP_TABLE_MIN_BROKEN_HEIGHT;
+	}
+
 	fp_Line * pLine;
 	for(i=0; i< count; i++)
 	{
@@ -659,7 +649,7 @@ UT_sint32 fp_TOCContainer::wantVBreakAt(UT_sint32 vpos)
  * Return the height of this Table taking into account the possibility
  * of it being broken.
  */
-UT_sint32 fp_TOCContainer::getHeight(void)
+UT_sint32 fp_TOCContainer::getHeight(void) const
 {
 	UT_sint32 iFullHeight =  fp_VerticalContainer::getHeight();
 	if(!isThisBroken())
@@ -681,6 +671,22 @@ UT_sint32 fp_TOCContainer::getHeight(void)
 	return iMyHeight;
 }
 
+
+
+/*
+  Return the height of the complete TOC as if it was not broken
+*/
+
+UT_sint32 fp_TOCContainer::getTotalTOCHeight(void) const
+{
+	if (getMasterTOC())
+	{
+		return getMasterTOC()->getTotalTOCHeight();
+	}
+
+	return fp_VerticalContainer::getHeight();
+}
+
 /*!
  * This method adjusts the m_iYBreak and m_iYBottom variables after a 
  * setY method changes the start position of the top of the table.
@@ -837,13 +843,11 @@ void fp_TOCContainer::deleteBrokenTOCs(bool bClearFirst)
 	}
 	fp_TOCContainer * pBroke = NULL;
 	fp_TOCContainer * pNext = NULL;
-	fp_TOCContainer * pLast = NULL;
 	pBroke = getFirstBrokenTOC();
 	bool bFirst = true;
 	while(pBroke )
 	{
 		pNext = static_cast<fp_TOCContainer *>(pBroke->getNext());
-		pLast = pBroke;
 		if(!bFirst)
 		{
 		        fp_Container * pConBroke =  pBroke->getContainer();
@@ -885,6 +889,57 @@ void fp_TOCContainer::deleteBrokenTOCs(bool bClearFirst)
 	}
 }
 
+
+/*
+  Delete all broken TOCs that follows this TOC. The first broken TOC
+  is kept if the function is called by the master TOC.
+*/
+
+void fp_TOCContainer::deleteBrokenAfter(bool bClearFirst)
+{
+	if (!isThisBroken())
+	{
+		if (getFirstBrokenTOC())
+		{
+			return getFirstBrokenTOC()->deleteBrokenAfter(bClearFirst);
+		}
+		return;
+	}
+
+	if (bClearFirst)
+	{
+		clearScreen();
+		getMasterTOC()->clearBrokenContainers();
+	}
+
+	fp_TOCContainer * pBroke = static_cast<fp_TOCContainer *>(getNext());
+	fp_TOCContainer * pNext = NULL;
+	while(pBroke)
+	{
+		pNext = static_cast<fp_TOCContainer *> (pBroke->getNext());
+		if (pBroke->getContainer())
+		{
+			UT_sint32 i = pBroke->getContainer()->findCon(pBroke);
+			if (i >= 0)
+			{
+				pBroke->getContainer()->deleteNthCon(i);
+				pBroke->setContainer(NULL);
+			}
+		}
+		delete pBroke;
+		pBroke = pNext;
+	}
+
+	setNext(NULL);
+	if (!getPrev())
+	{
+		getMasterTOC()->setNext(NULL);
+	}
+	getMasterTOC()->setLastBrokenTOC(this);
+	setYBottom(getTotalTOCHeight());
+}
+
+
 fp_TOCContainer * fp_TOCContainer::getFirstBrokenTOC(void) const
 {
 	if(isThisBroken())
@@ -895,6 +950,12 @@ fp_TOCContainer * fp_TOCContainer::getFirstBrokenTOC(void) const
 }
 
 
+fp_Container * fp_TOCContainer::getFirstBrokenContainer() const
+{
+	return getFirstBrokenTOC();
+}
+
+
 void fp_TOCContainer::setContainer(fp_Container * pContainer)
 {
 	xxx_UT_DEBUGMSG(("!!!!!-----!!!!TOC Container set to %x \n",pContainer));
