@@ -44,7 +44,7 @@
  * Modified by the GTK+ Team and others 1997-1999.  See the AUTHORS
  * file for a list of people on the GTK+ Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
+ * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
 #ifndef TABLECONTAINER_H
@@ -64,6 +64,8 @@
 #include "gr_Graphics.h"
 #include "fl_TableLayout.h"
 
+#define FP_TABLE_MIN_BROKEN_HEIGHT 60
+
 class fl_TableLayout;
 
 class ABI_EXPORT fp_TableRowColumn
@@ -107,11 +109,11 @@ public:
 	fp_Container *      drawSelectedCell(fp_Line * pLine);
 	bool			    isSelected(void) const
 	{ return m_bIsSelected; }
-	void                clearSelection(void) 
-	{ m_bIsSelected = false; 
+	void                clearSelection(void)
+	{ m_bIsSelected = false;
 	  m_bLinesDrawn = true;
 	}
-	bool                doesOverlapBrokenTable(fp_TableContainer * pBroke);
+	bool                doesOverlapBrokenTable(fp_TableContainer * pBroke) const;
 	void		        drawBroken(dg_DrawArgs* pDa, fp_TableContainer * pTab);
 	virtual void		clearScreen(void);
 	void		        clearScreen(bool bNoRecursive);
@@ -119,8 +121,8 @@ public:
 	void                drawLines(fp_TableContainer * pBroke,GR_Graphics * pG,bool bDoClear);
 	void                drawLinesAdjacent(void);
 	void                draw(fp_Line * pLine);
-	fp_TableContainer * getBrokenTable(fp_Container * pCon);
-	fp_VerticalContainer * getColumn(fp_Container *pCon);
+	fp_TableContainer * getBrokenTable(fp_Container * pCon); // FIXME: see if we can make it const
+	fp_VerticalContainer * getColumn(fp_Container *pCon); // FIXME: see if we can make it const
 	UT_sint32           tweakBrokenTable(fp_TableContainer * pBroke);
 	virtual void		draw(dg_DrawArgs*);
 	virtual void		draw(GR_Graphics*) {}
@@ -134,7 +136,7 @@ public:
 	virtual UT_sint32   wantHBreakAt(UT_sint32) {return 0;}
 	virtual fp_ContainerObject * VBreakAt(UT_sint32);
 	virtual fp_ContainerObject * HBreakAt(UT_sint32) {return NULL;}
-	void                recalcMaxWidth(bool bDontClearIfNeeded = false) 
+	void                recalcMaxWidth(bool bDontClearIfNeeded = false)
 	{ UT_UNUSED(bDontClearIfNeeded); }
 	virtual void        setAssignedScreenHeight(UT_sint32) {}
 	virtual fp_Container * getNextContainerInSection(void) const;
@@ -149,7 +151,7 @@ public:
 	void                extendBotLeft(PP_PropertyMap::Line & line,GR_Graphics * pG,UT_sint32 & iextLeft);
 	void                extendBotRight(PP_PropertyMap::Line & line,GR_Graphics * pG,UT_sint32 & iextRight);
 
-	UT_sint32           getCellX(fp_Line * pLine) const; 
+	UT_sint32           getCellX(fp_Line * pLine) const;
 	UT_sint32           getCellY(fp_Line * pLine) const;
 	UT_sint32           getSpannedHeight(void);
 	void                setLineMarkers(void);
@@ -192,7 +194,7 @@ public:
 		{ m_iTopPad = i;}
 	void                setBotPad(UT_sint32 i)
 		{ m_iBotPad = i;}
-		
+
 	PP_PropertyMap::Background getBackground () const;
 
 	void setBackground (const PP_PropertyMap::Background & style);
@@ -244,7 +246,7 @@ public:
 	bool                isDirty(void) const
 	    {  return m_bDirty;}
 	bool                doesIntersectClip(fp_TableContainer * pBroke, const UT_Rect * rClip);
-	bool                isInNestedTable(void);
+	bool                isInNestedTable(void) const;
 	bool                containsNestedTables(void);
 	bool                isRepeated(void) const;
 	void                setVertAlign(UT_sint32 i) { m_iVertAlign = i; }
@@ -254,16 +256,16 @@ public:
 #endif
 
 private:
-		
+
 	void                _clear(fp_TableContainer * pBroke);
 	void				_getBrokenRect(fp_TableContainer * pBroke, fp_Page* &pPage, UT_Rect &bRec, GR_Graphics * pG);
-		
+
 //
 // These variables describe where the cell is attached to the table.
 // The first cell in the Table is at (0,0)
 //
 // m_iLeftAttach is the leftmost column containing the cell.
-//  
+//
 	UT_sint32           m_iLeftAttach;
 
 // m_iRightAttach is the first column to the right of the cell.
@@ -277,11 +279,11 @@ private:
 // m_iBottomAttach is the row immediately below the cell.
 
 	UT_sint32           m_iBottomAttach;
-	
+
 // a default color to use the a cell border style is set to "off"
 
 	UT_RGBColor			m_borderColorNone;
-	
+
 //
 // Padding left,right, top and bottom
 //
@@ -326,7 +328,7 @@ private:
 
 // bool to see if the background needs to be redrawn
 	bool				m_bBgDirty;
-	
+
 // cell-background properties
 	PP_PropertyMap::Background	m_background;
 
@@ -356,7 +358,7 @@ public:
 
 	void                sizeRequest(fp_Requisition * pRequest);
 	void                sizeAllocate(fp_Allocation * pAllocate);
-    virtual void        mapXYToPosition(UT_sint32 x, UT_sint32 y, 
+    virtual void        mapXYToPosition(UT_sint32 x, UT_sint32 y,
 										PT_DocPosition& pos,
 										bool& bBOL, bool& bEOL, bool &isTOC);
 	virtual fp_Page *   getPage(void);
@@ -364,7 +366,7 @@ public:
 	fp_Line *           getLastLineInColumn(fp_Column * pCol);
 	void				layout(void);
 	virtual void        setY(UT_sint32 iY);
-	virtual UT_sint32   getHeight(void);
+	virtual UT_sint32   getHeight(void) const;
 	virtual void        setHeight(UT_sint32 iHeight);
 	virtual void        setContainer(fp_Container * pContainer);
 	virtual void		draw(dg_DrawArgs*);
@@ -413,9 +415,9 @@ fp_Column *         getBrokenColumn(void);
 	UT_sint32           getLineThickness(void)
 		{ return m_iLineThickness;}
 	void                queueResize(void);
-	UT_sint32           getYOfRow(UT_sint32 row);
-	fp_CellContainer *  getCellAtRowColumn(UT_sint32 row, UT_sint32 column);
-	fp_CellContainer *  getCellAtRowColumnLinear(UT_sint32 row, UT_sint32 column);
+	UT_sint32           getYOfRow(UT_sint32 row) const;
+	fp_CellContainer *  getCellAtRowColumn(UT_sint32 row, UT_sint32 column) const;
+	fp_CellContainer *  getCellAtRowColumnLinear(UT_sint32 row, UT_sint32 column) const;
 	virtual fp_Container * getNextContainerInSection(void) const;
 	virtual fp_Container * getPrevContainerInSection(void) const;
 	fp_TableContainer * getMasterTable(void) const
@@ -423,11 +425,11 @@ fp_Column *         getBrokenColumn(void);
 	bool                isThisBroken(void) const;
 	void                setYBreakHere(UT_sint32 iBreakHere);
 	void                setYBottom(UT_sint32 iBotContainer);
-	bool                isInBrokenTable(fp_CellContainer * pCell, 
-										fp_Container * pCon);
+	bool                isInBrokenTable(const fp_CellContainer * pCell,
+										fp_Container * pCon) const;
 
 //
-// This is the smallest Y value of the Table allowed in this 
+// This is the smallest Y value of the Table allowed in this
 // broken Table.
 //
 	UT_sint32           getYBreak(void) const
@@ -445,36 +447,35 @@ fp_Column *         getBrokenColumn(void);
 	void                adjustBrokenTables(void);
 	UT_sint32               getBrokenTop(void);
 	UT_sint32               getBrokenBot(void);
-	void                    setBrokenTop(UT_sint32 iTop) 
+	void                    setBrokenTop(UT_sint32 iTop)
 		{ m_iBrokenTop = iTop;}
-	void                    setBrokenBot(UT_sint32 iBot) 
+	void                    setBrokenBot(UT_sint32 iBot)
 		{ m_iBrokenBottom = iBot;}
 	UT_sint32           getNumRows(void) const;
 	UT_sint32           getNumCols(void) const;
 	UT_sint32           getRowHeight(UT_sint32 iRow, UT_sint32 iMeasHeight);
+	UT_sint32           getTotalTableHeight(void) const;
 	void                setRedrawLines(void)
 		{ m_bRedrawLines = true;}
 	bool                doRedrawLines(void) const
 		{ return m_bRedrawLines;}
 	fp_TableRowColumn *     getNthCol(UT_sint32 i);
-	fp_TableRowColumn *     getNthRow(UT_sint32 i);
+	fp_TableRowColumn *     getNthRow(UT_sint32 i) const;
 	bool                    containsNestedTables(void);
 	void setRowHeightType(FL_RowHeightType iType)
 		{
 	      m_iRowHeightType = iType;
-		}		
+		}
 	void setRowHeight(UT_sint32 iHeight)
 		{
 	      m_iRowHeight = iHeight;
-		}		
-	void setLastWantedVBreak(UT_sint32 iBreakAt)
-	{
-		m_iLastWantedVBreak = iBreakAt;
-	}
-	UT_sint32 getLastWantedVBreak(void) const
-	{
-		return m_iLastWantedVBreak;
-	}
+		}
+	virtual void setLastWantedVBreak(UT_sint32 iBreakAt)
+		{m_iLastWantedVBreak = iBreakAt;}
+	virtual UT_sint32 getLastWantedVBreak(void) const
+		{return m_iLastWantedVBreak;}
+	virtual fp_Container * getFirstBrokenContainer() const;
+	virtual void deleteBrokenAfter(bool bClearFirst);
 #ifdef FMT_TEST
 	void				__dump(FILE * fp) const;
 #endif
