@@ -893,6 +893,14 @@ void fp_TextRun::findPointCoords(UT_uint32 iOffset, UT_sint32& x, UT_sint32& y,
 	//docPos = adjustCaretPosition(docPos,true);
 	//iOffset = docPos - getBlockOffset() + getBlock()->getPosition();
 	getLine()->getOffsets(this, xoff, yoff);
+	if (getLine()->getY() == INITIAL_OFFSET) 
+	{
+		UT_DEBUGMSG(("Line position requested prior to line being placed\n"));
+		if (getLine()->getPrev())
+		{
+			yoff += getLine()->getPrev()->getY() + getLine()->getHeight() - INITIAL_OFFSET;
+		}
+	}
 
 	if (m_fPosition == TEXT_POSITION_SUPERSCRIPT)
 	{
@@ -1557,6 +1565,8 @@ void fp_TextRun::_draw(dg_DrawArgs* pDA)
 // to the correct edge.
 //
 	UT_Rect * pLRec = getLine()->getScreenRect();
+	if (pLRec == NULL)
+		return;
 	if((pDA->xoff + iWidth) > (pLRec->left + pLRec->width))
 	{
 		iWidth -=  (pDA->xoff + iWidth) - (pLRec->left + pLRec->width);
@@ -2026,6 +2036,11 @@ void fp_TextRun::_getPartRect(UT_Rect* pRect,
 	if(getLine())
 	{
 		UT_Rect * pLRec = getLine()->getScreenRect();
+		if(!pLRec)
+			return;
+		if(getLine()->getContainer() && ((getLine()->getContainer()->getContainerType() == FP_CONTAINER_CELL) ||
+										 (getLine()->getContainer()->getContainerType() == FP_CONTAINER_FRAME)))
+			return;
 		if((pRect->left + pRect->width) > (pLRec->left + pLRec->width))
 		{
 			pRect->width -= (pRect->left + pRect->width) - (pLRec->left + pLRec->width);
@@ -2064,14 +2079,11 @@ bool fp_TextRun::_refreshDrawBuffer()
 	GRShapingResult eRefresh = _getRefreshDrawBuffer();
 
 	bool bRefresh = true;
-	bool bSimple  = false;
 	
 	if(m_pRenderInfo)
 	{
 		bRefresh = ((UT_uint32)eRefresh & (UT_uint32)m_pRenderInfo->m_eShapingResult) != 0;
-		bSimple = (	m_pRenderInfo->m_eShapingResult == GRSR_None);
 	}
-	
 
 	if(iLen && bRefresh)
 	{
@@ -2362,8 +2374,8 @@ void fp_TextRun::_drawSquiggle(UT_sint32 top, UT_sint32 left, UT_sint32 right, F
 	  // Do _|-|_|-|
 	  nPoints = getGraphics()->tdu((right - left + getGraphics()->tlu(3)));
 	}  
-	UT_return_if_fail(nPoints >= 1); //can be 1 for overstriking chars
-
+	if(nPoints < 1)
+		return;
 	/*
 		NB: This array gets recopied inside the polyLine implementation
 			to move the coordinates into a platform-specific point
