@@ -355,6 +355,7 @@ public:
 	PT_DocPosition saveSelectedImage (const char * toFile );
 	PT_DocPosition saveSelectedImage (const UT_ByteBuf ** outByteBuf);
 	PT_DocPosition getSelectedImage(const char **dataId) const;
+	PT_DocPosition getSelectedImage(const char **dataId,const fp_Run **pImRun) const;
 	fp_Run *getSelectedObject(void) const;
 
 	void            getTextInCurrentBlock(UT_GrowBuf & buf) const;
@@ -537,6 +538,7 @@ public:
 	void            copyFrame(bool b_keepFrame = true);
 	void            selectFrame(void);
 	bool            isFrameSelected(void) const;
+	void            activateFrame(void);
 	fl_FrameLayout * getFrameLayout(PT_DocPosition pos) const;
 	fl_FrameLayout * getFrameLayout(void) const;
 	void            setFrameFormat(const gchar ** props);
@@ -910,7 +912,7 @@ protected:
 	bool                		_drawOrClearBetweenPositions(PT_DocPosition iPos1, PT_DocPosition iPos2, bool bClear, bool bFullLineHeight);
 	bool				_ensureInsertionPointOnScreen();
 	void				_moveInsPtNextPrevPage(bool bNext);
-	void				_moveInsPtNextPrevScreen(bool bNext);
+	void				_moveInsPtNextPrevScreen(bool bNext, bool bClearSelection);
 	void				_moveInsPtNextPrevLine(bool bNext);
 	fp_Line *           _getNextLineInDoc(fp_Container * pCon) const;
 	fp_Page *			_getCurrentPage(void) const;
@@ -1159,6 +1161,7 @@ private:
 	bool                m_bAllowSmartQuoteReplacement;  // Enable/disable replacing of quote with smart quote
 														// This allows temporarily disabling smart quotes to allow inserting ANSI quote.
     int                 m_bubbleBlockerCount;
+	UT_sint32           m_iOldPageCount;
 
 public:
 	bool registerDoubleBufferingObject(FV_ViewDoubleBuffering *obj);
