@@ -26,6 +26,8 @@
 
 #include <stdio.h>
 #include <string>
+#include <vector>
+#include <map>
 
 #include "ut_types.h"
 #include "ut_vector.h"
@@ -44,6 +46,8 @@
 #include <gsf/gsf-input.h>
 #include <gsf/gsf-output.h>
 
+#include <list>
+
 class UT_ByteBuf;
 class UT_GrowBuf;
 class pt_PieceTable;
@@ -51,6 +55,7 @@ class PP_AttrProp;
 class PP_Revision;
 class PP_RevisionAttr;
 class pf_Frag_Strux;
+class pf_Frag_Object;
 class PX_ChangeRecord;
 class PD_Style;
 class PD_DocIterator;
@@ -81,7 +86,7 @@ enum
 	PD_SIGNAL_REVISION_MODE_CHANGED,
 	PD_SIGNAL_DOCNAME_CHANGED,
 	PD_SIGNAL_DOCDIRTY_CHANGED,
-	PD_SIGNAL_SAVEDOC, 
+	PD_SIGNAL_SAVEDOC,
 	PD_SIGNAL_DOCCLOSED // TODO: remove this
 };
 
@@ -208,21 +213,20 @@ class ABI_EXPORT PD_XMLIDCreator
     friend class PD_Document;
     PD_Document* m_doc;
     PD_XMLIDCreatorPrivate* m_impl;
-    
+
   protected:
 
     PD_XMLIDCreator( PD_Document* doc );
     void rebuildCache();
-    
+
   public:
-    
+
     ~PD_XMLIDCreator();
     std::string createUniqueXMLID( const std::string& desiredID, bool deepCopyRDF = false );
 };
 typedef boost::shared_ptr<PD_XMLIDCreator> PD_XMLIDCreatorHandle;
 
 
-
 /*!
  PD_Document is the representation for a document.
 */
@@ -233,7 +237,7 @@ public:
 	PD_Document();
 
 	virtual AD_DOCUMENT_TYPE getType() const {return ADDOCUMENT_ABIWORD;}
-	
+
 	virtual UT_Error		readFromFile(const char * szFilename, int ieft, const char * impProps = NULL);
 	virtual UT_Error		importFile(const char * szFilename, int ieft, bool markClean = false, bool bImportStylesFirst = true,
 									   const char * impProps = NULL);
@@ -301,8 +305,8 @@ public:
 	void					endUserAtomicGlob(void);
 	void                    setMarginChangeOnly(bool b);
 	bool                    isMarginChangeOnly(void) const;
-	bool                    changeObjectFormatNoUpdate(PTChangeFmt ptc ,PL_ObjectHandle odh,const gchar ** attributes,const gchar ** properties );	
-PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);	
+	bool                    changeObjectFormatNoUpdate(PTChangeFmt ptc ,pf_Frag_Object* odh,const gchar ** attributes,const gchar ** properties );
+PT_AttrPropIndex            getAPIFromSOH(pf_Frag_Object* odh);
 	bool					insertObject(PT_DocPosition dpos,
 										 PTObjectType pto,
 										 const gchar ** attributes,
@@ -315,6 +319,10 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool					insertSpan(PT_DocPosition dpos,
 									   const UT_UCSChar * p,
 									   UT_uint32 length,
+									   PP_AttrProp *p_AttrProp = NULL,
+									   UT_uint32 * insertedSpanLength = NULL);
+	bool					insertSpan(PT_DocPosition dpos,
+									   const std::string& s,
 									   PP_AttrProp *p_AttrProp = NULL);
 
 	bool					deleteSpan(PT_DocPosition dpos1,
@@ -346,7 +354,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 										  const gchar ** attributes,
 										  const gchar ** properties, pf_Frag_Strux ** ppfs_ret = 0);
 
-	void                    deleteHdrFtrStrux(PL_StruxDocHandle sdh);
+	void                    deleteHdrFtrStrux(pf_Frag_Strux* sdh);
 
 	bool					changeStruxFmt(PTChangeFmt ptc,
 										   PT_DocPosition dpos1,
@@ -363,11 +371,11 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 
 	bool					changeStruxFmtNoUndo(PTChangeFmt ptc,
-										   PL_StruxDocHandle sdh,
+										   pf_Frag_Strux* sdh,
 										   const gchar ** attributes,
 										   const gchar ** properties);
 
-	bool					changeStruxForLists(PL_StruxDocHandle sdh,
+	bool					changeStruxForLists(pf_Frag_Strux* sdh,
 												const char * pszParentID);
 
 	bool					insertFmtMark(PTChangeFmt ptc,
@@ -377,11 +385,11 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool                    changeLastStruxFmtNoUndo(PT_DocPosition dpos, PTStruxType pts,
 													 const gchar ** attrs, const gchar ** props,
 													 bool bSkipEmbededSections);
-	
+
 	bool                    changeLastStruxFmtNoUndo(PT_DocPosition dpos, PTStruxType pts,
 													 const gchar ** attrs, const gchar * props,
 													 bool bSkipEmbededSections);
-	
+
 	// the append- and insertBeforeFrag methods are only available while importing
 	// the document.
 
@@ -397,7 +405,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool					appendObject(PTObjectType pto, const gchar ** attributes);
 	bool					appendFmtMark(void);
 	bool					appendStyle(const gchar ** attributes);
-	bool                    changeStruxFormatNoUpdate(PTChangeFmt ptc ,PL_StruxDocHandle sdh,const gchar ** attributes);	
+	bool                    changeStruxFormatNoUpdate(PTChangeFmt ptc ,pf_Frag_Strux* sdh,const gchar ** attributes);
 	bool					insertStruxBeforeFrag(pf_Frag * pF, PTStruxType pts,
 												  const gchar ** attributes, pf_Frag_Strux ** ppfs_ret = 0);
 	bool					insertSpanBeforeFrag(pf_Frag * pF, const UT_UCSChar * p, UT_uint32 length);
@@ -407,7 +415,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool					insertFmtMarkBeforeFrag(pf_Frag * pF, const gchar ** attributes);
 
 	pf_Frag *               findFragOfType(pf_Frag::PFType iType, UT_sint32 iSubtype = -1,
-										   const pf_Frag * pfStart = NULL);
+										   pf_Frag * pfStart = NULL) const;
 	pf_Frag *               getLastFrag() const;
 	bool                    checkForSuspect(void);
 	bool                    repairDoc(void);
@@ -430,112 +438,115 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	// the first two of these functions just retrieve the AP with the given index; the latter two
 	// return AP that represents state of things with current revision settings
 	bool					getAttrProp(PT_AttrPropIndex indexAP, const PP_AttrProp ** ppAP) const;
-	bool					getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, bool bLeftSide,
+	bool					getSpanAttrProp(pf_Frag_Strux* sdh, UT_uint32 offset, bool bLeftSide,
 											const PP_AttrProp ** ppAP) const;
 
 	bool                    getAttrProp(PT_AttrPropIndex apIndx, const PP_AttrProp ** ppAP, PP_RevisionAttr ** pRevisions,
 										bool bShowRevisions, UT_uint32 iRevisionId, bool &bHiddenRevision) const;
 
-	bool                    getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, bool bLeftSide,
+	bool                    getSpanAttrProp(pf_Frag_Strux* sdh, UT_uint32 offset, bool bLeftSide,
 											const PP_AttrProp ** ppAP,
 											PP_RevisionAttr ** pRevisions,
 											bool bShowRevisions, UT_uint32 iRevisionId,
 											bool &bHiddenRevision) const;
-	
+
 	const UT_UCSChar *		getPointer(PT_BufIndex bi) const; /* see warning on this function */
-	bool					getBlockBuf(PL_StruxDocHandle sdh, UT_GrowBuf * pgb) const;
+	bool					getBlockBuf(pf_Frag_Strux* sdh, UT_GrowBuf * pgb) const;
 
 	bool					getBounds(bool bEnd, PT_DocPosition & docPos) const;
-	PTStruxType             getStruxType(PL_StruxDocHandle sdh) const;
-	PT_DocPosition			getStruxPosition(PL_StruxDocHandle sdh) const;
+	PTStruxType             getStruxType(pf_Frag_Strux* sdh) const;
+	PT_DocPosition			getStruxPosition(pf_Frag_Strux* sdh) const;
 	bool					getStruxFromPosition(PL_ListenerId listenerId,
 												 PT_DocPosition docPos,
-												 PL_StruxFmtHandle * psfh) const;
+												 fl_ContainerLayout* * psfh) const;
 	bool					getStruxOfTypeFromPosition(PL_ListenerId listenerId,
 													   PT_DocPosition docPos,
 													   PTStruxType pts,
-													   PL_StruxFmtHandle * psfh) const;
-	bool					getStruxOfTypeFromPosition(PT_DocPosition, PTStruxType pts, PL_StruxDocHandle * sdh) const;
-    PL_StruxDocHandle       getBlockFromPosition( PT_DocPosition pos ) const;
+													   fl_ContainerLayout* * psfh) const;
+	bool					getStruxOfTypeFromPosition(PT_DocPosition, PTStruxType pts, pf_Frag_Strux* * sdh) const;
+    pf_Frag_Strux*       getBlockFromPosition( PT_DocPosition pos ) const;
 
 	pf_Frag *				getFragFromPosition(PT_DocPosition docPos) const;
 
-	bool					getNextStruxOfType(PL_StruxDocHandle sdh,PTStruxType pts,
-											   PL_StruxDocHandle * nextsdh);
-	bool					getPrevStruxOfType(PL_StruxDocHandle sdh,PTStruxType pts,
-											   PL_StruxDocHandle * prevsdh);
-	bool                    getNextStrux(PL_StruxDocHandle sdh, PL_StruxDocHandle *nextSDH);
+	bool					getNextStruxOfType(pf_Frag_Strux* sdh,PTStruxType pts,
+											   pf_Frag_Strux* * nextsdh);
+	bool					getPrevStruxOfType(pf_Frag_Strux* sdh,PTStruxType pts,
+											   pf_Frag_Strux* * prevsdh);
+	bool                    getNextStrux(pf_Frag_Strux* sdh, pf_Frag_Strux* *nextSDH);
 
 	// data items
 
-	virtual bool			createDataItem(const char * szName, bool bBase64, 
+	virtual bool			createDataItem(const char * szName, bool bBase64,
                                            const UT_ByteBuf * pByteBuf,
-										   const std::string & mime_type, 
-                                           void ** ppHandle);
+										   const std::string & mime_type,
+                                           PD_DataItemHandle* ppHandle);
 	virtual bool            replaceDataItem(const char * szName, const UT_ByteBuf * pByteBuf);
 	virtual bool			getDataItemDataByName(const char * szName,
 												  const UT_ByteBuf ** ppByteBuf,
                                                   std::string* pMimeType,
-                                                  void ** ppHandle) const;
-	bool					setDataItemToken(void* pHandle, void* pToken);
-	bool					getDataItemData(void * pHandle,
-											const char ** pszName, const UT_ByteBuf ** ppByteBuf, const void** ppToken) const;
+                                                  PD_DataItemHandle* ppHandle) const;
+	bool					setDataItemToken(PD_DataItemHandle pHandle, void* pToken) const;
+	bool					getDataItemData(PD_DataItemHandle pHandle,
+											const char ** pszName, const UT_ByteBuf ** ppByteBuf,
+											const void** ppToken) const;
 	bool					getDataItemFileExtension(const char *szDataID, std::string &sExt, bool bDot = true) const;
 	bool					enumDataItems(UT_uint32 k,
-										  void ** ppHandle, const char ** pszName, const UT_ByteBuf ** ppByteBuf, std::string * pMimeType) const;
+										  PD_DataItemHandle* ppHandle, const char ** pszName,
+										  const UT_ByteBuf ** ppByteBuf, std::string * pMimeType) const;
 
-    PL_StruxDocHandle       findHdrFtrStrux(const gchar * pszHdtFtr,
+    pf_Frag_Strux*       findHdrFtrStrux(const gchar * pszHdtFtr,
 											const gchar * pszHdrFtrID);
 	bool                    verifySectionID(const gchar * pszId);
-	PL_StruxDocHandle       getLastSectionSDH(void);
-	PL_StruxDocHandle       getLastStruxOfType(PTStruxType pts);
+	const pf_Frag_Strux*       getLastSectionSDH(void) const;
+	pf_Frag_Strux*       getLastSectionMutableSDH(void);
+	pf_Frag_Strux*       getLastStruxOfType(PTStruxType pts);
 
-	bool                    changeStruxAttsNoUpdate(PL_StruxDocHandle sdh, const char * attr, const char * attvalue);
-	bool                    deleteStruxNoUpdate(PL_StruxDocHandle sdh);
+	bool                    changeStruxAttsNoUpdate(pf_Frag_Strux* sdh, const char * attr, const char * attvalue);
+	bool                    deleteStruxNoUpdate(pf_Frag_Strux* sdh);
 	bool                    deleteFragNoUpdate(pf_Frag * pf);
-	bool                    insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes );
-	bool                    isStruxBeforeThis(PL_StruxDocHandle sdh,  PTStruxType pts);
+	bool                    insertStruxNoUpdateBefore(pf_Frag_Strux* sdh, PTStruxType pts,const gchar ** attributes );
+	bool                    isStruxBeforeThis(pf_Frag_Strux* sdh,  PTStruxType pts);
 
 	// the function below does exactly what the name says -- returns the AP index; in revisions mode
 	// you would need the AP at that index to have revision attribute exploded -- use one of the
 	// functions below to retrieve props and attrs correctly reflecting revisions settings
-	PT_AttrPropIndex        getAPIFromSDH(PL_StruxDocHandle sdh);
-    bool                    getAttributeFromSDH(PL_StruxDocHandle sdh, bool bShowRevisions, UT_uint32 iRevisionLevel,
+	PT_AttrPropIndex        getAPIFromSDH(pf_Frag_Strux* sdh);
+    bool                    getAttributeFromSDH(pf_Frag_Strux* sdh, bool bShowRevisions, UT_uint32 iRevisionLevel,
 												const char * szAttribute, const char ** pszValue);
-	
-    bool                    getPropertyFromSDH(PL_StruxDocHandle sdh, bool bShowRevisions, UT_uint32 iRevisionLevel,
-											   const char * szProperty, const char ** pszValue);
+
+    bool                    getPropertyFromSDH(const pf_Frag_Strux* sdh, bool bShowRevisions, UT_uint32 iRevisionLevel,
+											   const char * szProperty, const char ** pszValue) const;
 	// styles
 	void                    getAllUsedStyles(UT_GenericVector<PD_Style*> * pVecStyles);
-	PL_StruxFmtHandle       getNthFmtHandle(PL_StruxDocHandle sdh, UT_uint32 n);
+	fl_ContainerLayout*       getNthFmtHandle(pf_Frag_Strux* sdh, UT_uint32 n);
     const char *            getDefaultStyle() const;
 	bool					getStyle(const char * szName, PD_Style ** ppStyle) const;
-	PD_Style *				getStyleFromSDH(PL_StruxDocHandle sdh);
-	PL_StruxDocHandle       getPrevNumberedHeadingStyle(PL_StruxDocHandle sdh);
+	PD_Style *				getStyleFromSDH(pf_Frag_Strux* sdh);
+	pf_Frag_Strux*       getPrevNumberedHeadingStyle(pf_Frag_Strux* sdh);
 	size_t                  getStyleCount(void);
 	bool					enumStyles(UT_uint32 k,
 									   const char ** pszName, const PD_Style ** ppStyle) const;
 	bool                    enumStyles(UT_GenericVector<PD_Style*> * & pStyles) const;
-	
+
 	bool					addStyleProperty(const gchar * szStyleName, const gchar * szPropertyName, const gchar * szPropertyValue);
 	bool					addStyleProperties(const gchar * szStyleName, const gchar ** pProperties);
 	bool	                setAllStyleAttributes(const gchar * szStyleName, const gchar ** pAttribs);
 	bool	                addStyleAttributes(const gchar * szStyleName, const gchar ** pAttribs);
 
-    PL_StruxDocHandle       findPreviousStyleStrux(const gchar * szStyle, PT_DocPosition pos);
-    PL_StruxDocHandle       findForwardStyleStrux(const gchar * szStyle, PT_DocPosition pos);
+    pf_Frag_Strux*       findPreviousStyleStrux(const gchar * szStyle, PT_DocPosition pos);
+    pf_Frag_Strux*       findForwardStyleStrux(const gchar * szStyle, PT_DocPosition pos);
 	bool					updateDocForStyleChange(const gchar * szStyleName,
 													bool isParaStyle);
-	void                    updateAllLayoutsInDoc( PL_StruxDocHandle sdh);
+	void                    updateAllLayoutsInDoc( pf_Frag_Strux* sdh);
 	void					clearIfAtFmtMark(PT_DocPosition dpos);
 
 	virtual UT_uint32		getLastSavedAsType() const { return m_lastSavedAsType; }
 	UT_uint32				getLastOpenedType() const { return m_lastOpenedType; }
 	bool					updateFields(void);
-	bool					getField(PL_StruxDocHandle sdh,
+	bool					getField(pf_Frag_Strux* sdh,
 									 UT_uint32 offset,
                                      fd_Field * &pField);
-	po_Bookmark * 			getBookmark(PL_StruxDocHandle sdh, UT_uint32 offset);
+	po_Bookmark * 			getBookmark(pf_Frag_Strux* sdh, UT_uint32 offset);
 	pf_Frag *               findBookmark(const char * pName, bool bEnd = false, pf_Frag * pfStart = NULL);
 	bool                    hasMath(void);
 
@@ -545,7 +556,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	// Footnote functions
 	bool                    isFootnoteAtPos(PT_DocPosition pos);
 	bool                    isEndFootnoteAtPos(PT_DocPosition pos);
-	UT_sint32               getEmbeddedOffset(PL_StruxDocHandle sdh,PT_DocPosition posOff, PL_StruxDocHandle & sdhEmbedded);
+	UT_sint32               getEmbeddedOffset(pf_Frag_Strux* sdh,PT_DocPosition posOff, pf_Frag_Strux* & sdhEmbedded);
 
 	// TOC functions
 	bool                    isTOCAtPos(PT_DocPosition pos);
@@ -562,17 +573,17 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	bool                    isTableAtPos(PT_DocPosition pos);
 	bool                    isEndTableAtPos(PT_DocPosition pos);
 	bool                    isCellAtPos(PT_DocPosition pos);
-	PL_StruxDocHandle       getEndTableStruxFromTableSDH(PL_StruxDocHandle tableSDH);
-	PL_StruxDocHandle       getEndCellStruxFromCellSDH(PL_StruxDocHandle cellSDH);
-	PL_StruxDocHandle       getEndTableStruxFromTablePos(PT_DocPosition posTable);
-	bool                    getRowsColsFromTableSDH(PL_StruxDocHandle tableSDH,
+	pf_Frag_Strux*       getEndTableStruxFromTableSDH(pf_Frag_Strux* tableSDH);
+	pf_Frag_Strux*       getEndCellStruxFromCellSDH(pf_Frag_Strux* cellSDH);
+	pf_Frag_Strux*       getEndTableStruxFromTablePos(PT_DocPosition posTable);
+	bool                    getRowsColsFromTableSDH(pf_Frag_Strux* tableSDH,
 													bool bShowRevisions, UT_uint32 iRevisionLevel,
 													UT_sint32 * numRows, UT_sint32 * numCols);
-	PL_StruxDocHandle       getCellSDHFromRowCol(PL_StruxDocHandle tableSDH,
+	pf_Frag_Strux*       getCellSDHFromRowCol(pf_Frag_Strux* tableSDH,
 												 bool bShowRevisions, UT_uint32 iRevisionLevel,
-												 UT_sint32 row, 
+												 UT_sint32 row,
 												 UT_sint32 col);
-	void                    miniDump(PL_StruxDocHandle sdh, UT_sint32 nstruxes);
+	void                    miniDump(pf_Frag_Strux* sdh, UT_sint32 nstruxes);
     bool                    dumpDoc( const char* msg, PT_DocPosition currentpos, PT_DocPosition endpos );
 
 	bool                    isInsertHyperLinkValid(PT_DocPosition pos) const;
@@ -586,9 +597,9 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	void					addList(fl_AutoNum * pAutoNum);
 	bool					appendList(const gchar ** attributes);
 	bool					fixListHierarchy(void);
-	void					removeList(fl_AutoNum * pAutoNum,PL_StruxDocHandle sdh );
-	void					listUpdate(PL_StruxDocHandle sdh);
-	void					StopList(PL_StruxDocHandle sdh);
+	void					removeList(fl_AutoNum * pAutoNum,pf_Frag_Strux* sdh );
+	void					listUpdate(pf_Frag_Strux* sdh);
+	void					StopList(pf_Frag_Strux* sdh);
 	void					disableListUpdates(void);
 	void					enableListUpdates(void);
 	void					updateDirtyLists(void);
@@ -606,13 +617,13 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	// PageSize functions
 	bool                    convertPercentToInches(const char * szPercent, UT_UTF8String & sInches);
 	bool					setPageSizeFromFile(const gchar ** attributes);
-	const	fp_PageSize	*	getPageSize(void) const	
+	const	fp_PageSize	*	getPageSize(void) const
 	{ return & m_docPageSize;}
 	fp_PageSize             m_docPageSize; // Move this to private later
 	bool					isBookmarkUnique(const gchar * pName) const;
 	bool					isBookmarkRelativeLink(const gchar * pName) const;
-	UT_sint32				getBookmarkCount()const {return m_vBookmarkNames.getItemCount();}
-	const gchar *		getNthBookmark(UT_sint32 n)const{return reinterpret_cast<const gchar *>(m_vBookmarkNames.getNthItem(n));}
+	UT_sint32				getBookmarkCount() const {return m_vBookmarkNames.size();}
+	const std::string & 	getNthBookmark(UT_sint32 n) const {return m_vBookmarkNames.at(n);}
 	void					addBookmark(const gchar * pName);
 	void					removeBookmark(const gchar * pName);
 
@@ -622,7 +633,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	virtual void            setMarkRevisions(bool bMark);
 	// primarly for use by the PieceTable
 	void                    setMarkRevisionsNoNotify(bool bMark) {AD_Document::setMarkRevisions(bMark);}
-	
+
 	virtual bool            acceptRejectRevision(bool bReject,
 												 UT_uint32 iStart,
 												 UT_uint32 iEnd,
@@ -633,7 +644,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 	const PP_AttrProp *     explodeRevisions(PP_RevisionAttr *& pRevisions, const PP_AttrProp * pAP,
 											 bool bShow, UT_uint32 iId, bool &bHiddenRevision) const;
-	
+
 	virtual void            purgeRevisionTable(bool bUnconditional = false);
 
 	void					notifyPieceTableChangeStart(void);
@@ -645,7 +656,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 		{ return m_pPieceTable; }
     PD_DocumentRDFHandle    getDocumentRDF(void) const;
     PD_XMLIDCreatorHandle   makeXMLIDCreator();
-    
+
 #ifdef PT_TEST
 	void					__dump(FILE * fp) const;
 	//! Pointer to last instatiated PD_Document. Used for debugging.
@@ -657,14 +668,17 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	inline bool areStylesLocked () const { return m_bLockedStyles; }    // See also lockStyles
 	void lockStyles(bool b);
 
-	virtual void setMetaDataProp (const UT_String & key, const UT_UTF8String & value);
-	virtual bool getMetaDataProp (const UT_String & key, UT_UTF8String & outProp) const;
+	virtual void setMetaDataProp (const std::string & key, const std::string & value);
+	virtual bool getMetaDataProp (const std::string & key, std::string & outProp) const;
 
 	// RIVERA TODO not working and may not be needed
-	virtual void setAnnotationProp (const UT_String & key, const UT_UTF8String & value);
-	virtual bool getAnnotationProp (const UT_String & key, UT_UTF8String & outProp) const;
+	virtual void setAnnotationProp (const std::string & key, const std::string & value);
+	virtual bool getAnnotationProp (const std::string & key, std::string & outProp) const;
 
-	UT_GenericStringMap<UT_UTF8String*> & getMetaData () { return m_metaDataMap ; }
+	const std::map<std::string,std::string> & getMetaData () const
+	{
+		return m_metaDataMap ;
+	}
 
 	// document-level property handling functions
 	const PP_AttrProp *     getAttrProp() const;
@@ -680,7 +694,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	/* Okay, as far as I can tell this is a non-persistent document property since it is not
 	 * written to the AbiWord file when the document is saved. In fact, it is only set if a
 	 * mail-merge source/link is given on the command line.
-	 * 
+	 *
 	 * Mail merge fields are, naturally, saved and loaded, but the Insert->Mail Merge Field...
 	 * dialog doesn't reflect the current document's fields but rather some internal set of
 	 * fields, which is confusing if you are trying to work with muliple mail merge sources.
@@ -706,7 +720,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	   The purpose of the following methods is to generate and manage
 	   document-wide unique identifiers; the indetifiers are type
 	   specific, with the types defined in UT_UniqueId class (ut_mics.h).
-	   
+
        UT_uint32 getUID(type):    Generates an id of a given type or
                                   UT_UID_INVALID if unique id cannot
                                   be generated (0 <= uid < UT_UID_INVALID).
@@ -717,7 +731,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
                                   used, the caller should call
                                   setMinUID(id+1) to ensure integrity of
                                   the UID generator.
-                                  
+
        bool setMinUID(type, uid): Allows to set a minimum value for all
                                   future identifiers; it returns true on
                                   success false on failure. The purpose is
@@ -738,14 +752,14 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 
 	bool      findFirstDifferenceInContent(PT_DocPosition &pos, UT_sint32 &iOffset2,
 										   const PD_Document &d) const;
-	
+
 	bool      findWhereSimilarityResumes(PT_DocPosition &pos, UT_sint32 &iOffset2,
 										 UT_uint32 & iKnownLength,
 										 const PD_Document &d) const;
 
 	virtual void   setAutoRevisioning(bool autorev);
 
-	virtual UT_uint32 getXID();
+	virtual UT_uint32 getXID() const;
 	virtual UT_uint32 getTopXID() const;
 	void              fixMissingXIDs();
 	UT_uint32         getFragXIDforVersion(const pf_Frag * pf, UT_uint32 iVersion) const;
@@ -770,6 +784,7 @@ PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);
 	UT_sint32               getCRNumber() const { return m_iCRCounter; }
 	void					setCRNumber(UT_sint32 iCRCounter) { m_iCRCounter = iCRCounter; }
 	UT_sint32               getNextCRNumber(void);
+    std::list<AV_View*>     getAllViews() const;
     void                    getAllViews(UT_GenericVector<AV_View *> * vecViews) const;
 	void                    ignoreSignals(void)
 	{ m_bIgnoreSignals = true;}
@@ -789,8 +804,8 @@ protected:
 	virtual UT_Error   		_saveAs(const char * szFilename, int ieft, bool cpy, const char * expProps = NULL);
 	virtual UT_Error        _saveAs(GsfOutput *output, int ieft, bool cpy, const char * expProps);
 	virtual UT_Error		_save(void);
-	
-	
+
+
 	void					_setClean(void);
 	void					_destroyDataItemData(void);
 	bool					_syncFileTypes(bool bReadSaveWriteOpen);
@@ -801,7 +816,7 @@ protected:
 												  bool & bDeleted);
 
 	virtual void            _clearUndo();
-	
+
 	UT_Error _importFile(const char * szFilename, int ieft,
 						 bool markClean, bool bImportStylesFirst,
 						 bool isImportFile, const char* impProps);
@@ -832,7 +847,8 @@ private:
 	UT_GenericVector<fl_AutoNum *> m_vecLists;
 	bool                    m_bHasListStopped;
 
-	UT_GenericStringMap<struct _dataItemPair*> m_hashDataItems;
+	typedef std::map<std::string, PD_DataItemHandle> hash_data_items_t;
+	hash_data_items_t m_hashDataItems;
 public:
 	IE_FileInfo				m_fileImpExpInfo;
 private:
@@ -842,9 +858,9 @@ private:
 	bool					m_bAllowInsertPointChange;
 	bool                    m_bRedrawHappenning;
 	bool                    m_bLoading;
-	UT_Vector				m_vBookmarkNames;
+	std::vector<std::string> m_vBookmarkNames;
 	bool                    m_bLockedStyles;
-	UT_GenericStringMap<UT_UTF8String*> m_metaDataMap;
+	std::map<std::string, std::string> m_metaDataMap;
 	PT_AttrPropIndex        m_indexAP;
 	bool                    m_bDontImmediatelyLayout;
 
@@ -879,6 +895,9 @@ private:
 	UT_GenericVector<ImagePage *> m_pPendingImagePage;
 	UT_GenericVector<TextboxPage *> m_pPendingTextboxPage;
 	UT_sint32               m_iStruxCount;
+	std::string             m_sUserName;
+public:
+	const std::string &getUserName() const { return m_sUserName; }
 };
 
 #endif /* PD_DOCUMENT_H */
