@@ -1,3 +1,4 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  *
@@ -42,7 +43,7 @@
 bool pt_PieceTable::_unlinkStrux(pf_Frag_Strux * pfs,
 									pf_Frag ** ppfEnd, UT_uint32 * pfragOffsetEnd)
 {
-#if 1
+#if DEBUG
 	if(pfs->getStruxType() == PTX_SectionTable)
 	{
 		UT_DEBUGMSG(("_unlink Strux Table %p \n",pfs));
@@ -103,7 +104,7 @@ bool pt_PieceTable::_unlinkStrux(pf_Frag_Strux * pfs,
 	{
 		UT_DEBUGMSG(("_unlink Strux EndTOC %p \n",pfs));
 	}
-//	m_pDocument->miniDump((PL_StruxDocHandle) pfs, 2);
+//	m_pDocument->miniDump(pfs, 2);
 #endif
 	switch (pfs->getStruxType())
 	{
@@ -159,6 +160,8 @@ bool pt_PieceTable::_unlinkStrux_Block(pf_Frag_Strux * pfs,
 	if(pfsPrev == NULL)
 	{
 		_unlinkFrag(pfs,ppfEnd,pfragOffsetEnd);
+		UT_DEBUGMSG(("shoudln't happen."));
+		UT_ASSERT(0);
 		return false;
 	}
 
@@ -312,6 +315,31 @@ bool pt_PieceTable::_unlinkStrux_Section(pf_Frag_Strux * pfs,
 		return false;
 	}
 
+	// delete frag from the embedded_strux list if needed
+	if ((pfs->getStruxType() == PTX_SectionFootnote) || 
+		(pfs->getStruxType() == PTX_SectionEndnote) || 
+		(pfs->getStruxType() == PTX_SectionAnnotation)) 
+	{
+		bool bNoteRemoved = false;
+		if (!m_embeddedStrux.empty())
+		{
+			std::list<embeddedStrux>::iterator it;
+			for (it = m_embeddedStrux.begin(); it != m_embeddedStrux.end(); ++it)
+			{
+				if ((*it).beginNote == pfs)
+				{
+					m_embeddedStrux.erase(it);
+					bNoteRemoved = true;
+					break;
+				}
+			}
+		}
+		if (!bNoteRemoved)
+		{
+			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		}
+	}
+
 	switch (pfsPrev->getStruxType())
 	{
 	case PTX_Block:
@@ -651,9 +679,9 @@ void pt_PieceTable::_deleteHdrFtrStruxWithNotify( pf_Frag_Strux * pfFragStruxHdr
 	const pf_Frag * pfFrag = NULL;
 	pfFrag = static_cast<pf_Frag *>(pfFragStruxHdrFtr);
 	// TODO HdrFtrPos is unused
-	PT_DocPosition HdrFtrPos = getFragPosition(pfFrag);
+	UT_DebugOnly<PT_DocPosition> HdrFtrPos = getFragPosition(pfFrag);
 	UT_Vector vecFragStrux;
-	UT_DEBUGMSG(("SEVIOR: Deleting hdrftr Strux Pos = %d \n",HdrFtrPos));
+	UT_DEBUGMSG(("SEVIOR: Deleting hdrftr Strux Pos = %d \n",(PT_DocPosition)HdrFtrPos));
 //
 // Now find the first Non-strux frag within this hdrftr
 //
