@@ -60,7 +60,7 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 	// walk document and for each fragment, send a notification
 	// to each layout.
   
-	PL_StruxFmtHandle sfh = 0;
+	fl_ContainerLayout* sfh = 0;
 	PT_DocPosition sum = 0;
 	UT_uint32 blockOffset = 0;
 	pf_Frag_Strux * pfs2 = NULL;
@@ -88,9 +88,8 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 				{
 					PT_DocPosition pos = pf->getPos();
 					getStruxOfTypeFromPosition(listenerId,pos,PTX_Block,&sfh);
-					PL_StruxDocHandle sdh = NULL;
-					getStruxOfTypeFromPosition(pos,PTX_Block,&sdh);
-					pfs2 = (pf_Frag_Strux *) sdh;
+
+					getStruxOfTypeFromPosition(pos,PTX_Block,&pfs2);
 					blockOffset = pos - pfs2->getPos() -1;
 					bStatus1 = pft->createSpecialChangeRecord(&pcr,pos,blockOffset);
 					UT_return_val_if_fail (bStatus1,false);
@@ -117,7 +116,6 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 		case pf_Frag::PFT_Strux:
 			{
 				pfs2 = static_cast<pf_Frag_Strux *> (pf);
-				PL_StruxDocHandle sdh = (PL_StruxDocHandle)pf;
 				sfh = 0;
 			        if(bListensOnly)
 				{
@@ -127,7 +125,7 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 				PX_ChangeRecord * pcr = NULL;
 				bool bStatus1 = pfs2->createSpecialChangeRecord(&pcr,sum);
 				UT_return_val_if_fail (bStatus1, false);
-				bool bStatus2 = pListener->populateStrux(sdh,pcr,&sfh);
+				bool bStatus2 = pListener->populateStrux(pfs2,pcr,&sfh);
 
 				// This can happen legally, for example when inserting a hdr/ftr strux
 				// which was marked deleted in revisions mode -- such strux has no
@@ -169,9 +167,10 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 				{
 					PT_DocPosition pos = pf->getPos();
 					getStruxOfTypeFromPosition(listenerId,pos,PTX_Block,&sfh);
-					PL_StruxDocHandle sdh = NULL;
-					getStruxOfTypeFromPosition(pos,PTX_Block,&sdh);
-					pf_Frag_Strux * pfs = (pf_Frag_Strux *) sdh;
+					pf_Frag_Strux* pfs = NULL;
+					getStruxOfTypeFromPosition(pos,PTX_Block,&pfs);
+					if(!pfs)
+					  return false;
 					blockOffset = pos - pfs->getPos() -1;
 					bStatus1 = pfo->createSpecialChangeRecord(&pcr,pos,blockOffset);
 					UT_return_val_if_fail (bStatus1, false);
@@ -216,9 +215,7 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 				{
 					PT_DocPosition pos = pf->getPos();
 					getStruxOfTypeFromPosition(listenerId,pos,PTX_Block,&sfh);
-					PL_StruxDocHandle sdh = NULL;
-					getStruxOfTypeFromPosition(pos,PTX_Block,&sdh);
-					pfs2 = (pf_Frag_Strux *) sdh;
+					getStruxOfTypeFromPosition(pos,PTX_Block,&pfs2);
 					blockOffset = pos - pfs2->getPos() -1;
 					bStatus1 = pffm->createSpecialChangeRecord(&pcr,pos,blockOffset);
 					UT_return_val_if_fail (bStatus1, false);
@@ -258,20 +255,20 @@ bool pt_PieceTable::_tellAndMaybeAddListener(PL_Listener * pListener,
 #include <boost/function.hpp>
 typedef boost::function< bool (PT_DocPosition, PT_DocPosition, PT_DocPosition, PL_Listener*)> f_WalkRangeFinished_t;
 
-static bool finishedFunctorEndOfRage( PT_DocPosition rangeStartPos,
+static bool finishedFunctorEndOfRage( PT_DocPosition /*rangeStartPos*/,
                                       PT_DocPosition rangeEndPos,
                                       PT_DocPosition curPos,
-                                      PL_Listener* pListener )
+                                      PL_Listener* /*pListener*/ )
 {
     if( curPos >= rangeEndPos )
         return true;
     return false;
 }
 
-static bool finishedFunctorFinishingListener( PT_DocPosition rangeStartPos,
-                                              PT_DocPosition rangeEndPos,
-                                              PT_DocPosition curPos,
-                                              PL_Listener* pListener,
+static bool finishedFunctorFinishingListener( PT_DocPosition /*rangeStartPos*/,
+                                              PT_DocPosition /*rangeEndPos*/,
+                                              PT_DocPosition /*curPos*/,
+                                              PL_Listener* /*pListener*/,
                                               PL_FinishingListener* fl )
 {
     if( fl->isFinished() )
@@ -305,7 +302,7 @@ static m_fragtypecol_t& _getTellListenerSubsetWalkRangeVisitAllFragments()
 static PT_DocPosition _tellListenerSubsetWalkRange(
     pt_PieceTable* pt,
     PL_Listener* pListener,
-    PD_DocumentRange* pDocRange,
+    PD_DocumentRange*  /*pDocRange*/,
     PT_DocPosition rangeStartPos,
     PT_DocPosition rangeEndPos,
     f_WalkRangeFinished_t finishedFunctor = finishedFunctorEndOfRage,
@@ -314,7 +311,7 @@ static PT_DocPosition _tellListenerSubsetWalkRange(
 {
     UT_DEBUGMSG(("_tellListenerSubsetWalkRange(top) listener %p startpos %d endpos %d\n",
                  pListener, rangeStartPos, rangeEndPos ));
-	PL_StruxFmtHandle sfh = 0;
+	fl_ContainerLayout* sfh = 0;
 	UT_uint32 blockOffset = 0;
 
 	pf_Frag * pf1 = NULL;
@@ -349,8 +346,9 @@ static PT_DocPosition _tellListenerSubsetWalkRange(
                     else
                         endOffset = pf->getLength();
                     bool bStatus1 = pft->createSpecialChangeRecord(&pcr,sum,blockOffset,fragOffset1,endOffset);
-                    if(!bStatus1)
+                    if(!bStatus1) {
                         UT_DEBUGMSG(("_tellListenerSubsetWalkRange(st1) a\n" ));
+		    }
                     UT_return_val_if_fail (bStatus1,false);
                     bool bStatus2 = pListener->populate(sfh,pcr);
                     if (pcr)
@@ -365,12 +363,13 @@ static PT_DocPosition _tellListenerSubsetWalkRange(
                 case pf_Frag::PFT_Strux:
                 {
                     pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *> (pf);
-                    PL_StruxDocHandle sdh = (PL_StruxDocHandle)pf;
+                    pf_Frag_Strux* sdh = pfs;
                     sfh = 0;
                     PX_ChangeRecord * pcr = NULL;
                     bool bStatus1 = pfs->createSpecialChangeRecord(&pcr,sum);
-                    if(!bStatus1)
+                    if(!bStatus1) {
                         UT_DEBUGMSG(("_tellListenerSubsetWalkRange(st1) b\n" ));
+		    }
                     UT_return_val_if_fail (bStatus1,false);
                     bool bStatus2 = pListener->populateStrux(sdh,pcr,&sfh);
                     if (pcr)
@@ -386,8 +385,9 @@ static PT_DocPosition _tellListenerSubsetWalkRange(
                     pf_Frag_Object * pfo = static_cast<pf_Frag_Object *> (pf);
                     PX_ChangeRecord * pcr = NULL;
                     bool bStatus1 = pfo->createSpecialChangeRecord(&pcr,sum,blockOffset);
-                    if(!bStatus1)
+                    if(!bStatus1) {
                         UT_DEBUGMSG(("_tellListenerSubsetWalkRange(st1) c\n" ));
+		    }
                     UT_return_val_if_fail (bStatus1,false);
                     bool bStatus2 = pListener->populate(sfh,pcr);
                     if (pcr)
@@ -403,8 +403,9 @@ static PT_DocPosition _tellListenerSubsetWalkRange(
                     pf_Frag_FmtMark * pffm = static_cast<pf_Frag_FmtMark *> (pf);
                     PX_ChangeRecord * pcr = NULL;
                     bool bStatus1 = pffm->createSpecialChangeRecord(&pcr,sum,blockOffset);
-                    if(!bStatus1)
+                    if(!bStatus1) {
                         UT_DEBUGMSG(("_tellListenerSubsetWalkRange(st1) d\n" ));
+		    }
                     UT_return_val_if_fail (bStatus1,false);
                     bool bStatus2 = pListener->populate(sfh,pcr);
                     DELETEP(pcr);
@@ -465,11 +466,11 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
     closerFragmentTypesToVisit.insert( pf_Frag::PFT_Strux );
     
 
-    bool rc = 0;
+    //bool rc = 0;
 
     if( closer )
     {
-        rc = _tellListenerSubsetWalkRange( this,
+        /*rc =*/ _tellListenerSubsetWalkRange( this,
                                            closer,
                                            pDocRange,
                                            pDocRange->m_pos1,
@@ -510,20 +511,20 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
 
             closer->setDelegate( pListener );
             closer->reset();
-            rc = _tellListenerSubsetWalkRange( this,
+            /*rc =*/ _tellListenerSubsetWalkRange( this,
                                                closer,
                                                pDocRange,
                                                pDocRange->m_pos1,
                                                pDocRange->m_pos2 );
             
-            rc = _tellListenerSubsetWalkRange( this, cl,
+            /*rc =*/ _tellListenerSubsetWalkRange( this, cl,
                                                pDocRange, startPos, pDocRange->m_pos1,
                                                f, closerFragmentTypesToVisit, walkForwards );
             
         }
     }
     
-    rc = _tellListenerSubsetWalkRange( this, pListener,
+    /*rc =*/ _tellListenerSubsetWalkRange( this, pListener,
                                        pDocRange, pDocRange->m_pos1, pDocRange->m_pos2 );
     
     if( closer )
@@ -534,7 +535,7 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
         if( PL_FinishingListener* cl = closer->getAfterContentListener() )
         {
             f_WalkRangeFinished_t f = boost::bind( finishedFunctorFinishingListener, _1, _2, _3, _4, cl );
-            rc = _tellListenerSubsetWalkRange( this, cl,
+            /*rc =*/ _tellListenerSubsetWalkRange( this, cl,
                                                pDocRange, pDocRange->m_pos2, 0,
                                                f, closerFragmentTypesToVisit );
         }
@@ -545,7 +546,7 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
     // move to using the above walker to allow mulitpass processing....
 #if 0    
     
-	PL_StruxFmtHandle sfh = 0;
+	fl_ContainerLayout* sfh = 0;
 	UT_uint32 blockOffset = 0;
 
 	pf_Frag * pf1 = NULL;
@@ -585,7 +586,7 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
 		case pf_Frag::PFT_Strux:
 			{
 				pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *> (pf);
-				PL_StruxDocHandle sdh = (PL_StruxDocHandle)pf;
+				pf_Frag_Strux* sdh = pf;
 				sfh = 0;
 				PX_ChangeRecord * pcr = NULL;
 				bool bStatus1 = pfs->createSpecialChangeRecord(&pcr,sum);
@@ -664,7 +665,7 @@ bool pt_PieceTable::tellListenerSubset( PL_Listener * pListener,
                 case pf_Frag::PFT_Strux:
                 {
                     pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *> (pf);
-                    PL_StruxDocHandle sdh = (PL_StruxDocHandle)pf;
+                    pf_Frag_Strux* sdh = pf;
                     sfh = 0;
                     PX_ChangeRecord * pcr = NULL;
                     bool bStatus1 = pfs->createSpecialChangeRecord(&pcr,sum);
