@@ -92,16 +92,20 @@ ST_LOCALISED_STYLES stLocalised[] =
 	{"Box List",                XAP_STRING_ID_STYLE_BOXLIST},		
 	{"Hand List",               XAP_STRING_ID_STYLE_HANDLIST},		
 	{"Heart List",              XAP_STRING_ID_STYLE_HEARTLIST},	
+	{"Arrowhead List",          XAP_STRING_ID_STYLE_ARROWHEADLIST},	
 	{"Chapter Heading",         XAP_STRING_ID_STYLE_CHAPHEADING},	
 	{"Section Heading",         XAP_STRING_ID_STYLE_SECTHEADING},	
 	{"Endnote Reference",       XAP_STRING_ID_STYLE_ENDREFERENCE},	
 	{"Endnote Text",            XAP_STRING_ID_STYLE_ENDTEXT},		
+	{"Endnote",                 XAP_STRING_ID_STYLE_ENDNOTE},		
 	{"Footnote Reference",      XAP_STRING_ID_STYLE_FOOTREFERENCE},	
 	{"Footnote Text",           XAP_STRING_ID_STYLE_FOOTTEXT},		
+	{"Footnote",                XAP_STRING_ID_STYLE_FOOTNOTE},		
 	{"Numbered Heading 1",      XAP_STRING_ID_STYLE_NUMHEAD1},		
 	{"Numbered Heading 2",      XAP_STRING_ID_STYLE_NUMHEAD2},		
 	{"Numbered Heading 3",      XAP_STRING_ID_STYLE_NUMHEAD3},		
 	{"Implies List",	       	XAP_STRING_ID_STYLE_IMPLIES_LIST},		
+	{"None",                    XAP_STRING_ID_STYLE_NONE},		
 	{NULL,	0}	
 };
 
@@ -128,8 +132,25 @@ void pt_PieceTable::s_getLocalisedStyleName(const char *szStyle, UT_UTF8String &
 	
 }
 
+/*
+	Gets the style name from its localised name
+*/
+const char *pt_PieceTable::s_getUnlocalisedStyleName (const char *szLocStyle)
+{		
+	static XAP_App *pApp = XAP_App::getApp();
+	const XAP_StringSet *pSS = pApp->getStringSet();
+
+	for (int n = 0; stLocalised[n].pStyle; n++)
+		if (strcmp(szLocStyle, pSS->getValue(stLocalised[n].nID)) == 0)
+			return stLocalised[n].pStyle;
+
+	return szLocStyle;
+}
+
 bool pt_PieceTable::_loadBuiltinStyles(void)
 {
+	static XAP_App *pApp = XAP_App::getApp();
+	const XAP_StringSet *pSS = pApp->getStringSet();
 	/* 	
 		!!! if adding or removing properties to the list_fmt, you have to make also changes to
 		pt_VarSet.cpp mergeAP()
@@ -206,39 +227,42 @@ bool pt_PieceTable::_loadBuiltinStyles(void)
 	UT_String_sprintf(stTmp, list_fmt,"Upper Roman List","1", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "NULL", ".");
 	_s("Upper Roman List",false,"P", "Numbered List", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Bullet List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Symbol", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Bullet List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily,"NULL");
 
 	_s("Bullet List",true, "P", "", "Current Settings", stTmp.c_str());
-	UT_String_sprintf(stTmp, list_fmt, "Implies List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Symbol", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Implies List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Implies List",false, "P", "", "Current Settings", stTmp.c_str());
 
 	UT_String_sprintf(stTmp, list_fmt, "Dashed List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "NULL", "NULL");
 	_s("Dashed List",true, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Square List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Square List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Square List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Triangle List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Triangle List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Triangle List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Diamond List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Diamond List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Diamond List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Star List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Star List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Star List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Tick List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Tick List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Tick List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Box List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Box List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Box List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Hand List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Hand List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Hand List",false, "P", "", "Current Settings", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, list_fmt, "Heart List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", "Dingbats", "NULL");
+	UT_String_sprintf(stTmp, list_fmt, "Heart List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
 	_s("Heart List",false, "P", "", "Current Settings", stTmp.c_str());
 
+	UT_String_sprintf(stTmp, list_fmt, "Arrowhead List","0", LIST_DEFAULT_INDENT, LIST_DEFAULT_INDENT_LABEL, "transparent", "%L", pszFamily, "NULL");
+	_s("Arrowhead List",false, "P", "", "Current Settings", stTmp.c_str());
+
 	// pszFamily is the nearest font to Arial found in the system
 	UT_String_sprintf(stTmp, "tabstops:0.3in/L0; list-style:Numbered List; "
 					  "start-value:1; margin-left:0.0in; text-indent:0.0in; "
@@ -273,18 +297,20 @@ bool pt_PieceTable::_loadBuiltinStyles(void)
 		"start-value:1; margin-left:0.0in; text-indent:0.0in; "
 		"field-color:transparent; list-delim:%s %%L.; "
 		"field-font:%s; list-decimal:";
-	UT_String_sprintf(stTmp, szFmt, "Chapter", pszFamily);
+	UT_String_sprintf(stTmp, szFmt, pSS->getValue(XAP_STRING_ID_STYLE_DELIM_CHAPTER), pszFamily);
 
     _s("Chapter Heading",true,"P","Numbered Heading 1","Normal", stTmp.c_str());
 
-	UT_String_sprintf(stTmp, szFmt, "Section", pszFamily);
+	UT_String_sprintf(stTmp, szFmt, pSS->getValue(XAP_STRING_ID_STYLE_DELIM_SECTION), pszFamily);
     _s("Section Heading",true,"P","Numbered Heading 1","Normal", stTmp.c_str());
 
 	_s("Endnote Reference",false,"C", "None", "Current Settings", "text-position:superscript; font-size:10pt");
-	_s("Endnote Text",false,"C", "Normal", "Current Settings", "text-position:normal");
+	_s("Endnote Text",false,"P", "Normal", "Current Settings", "text-position:normal");
+	_s("Endnote",false,"P", "Normal", "Current Settings", "text-position:normal;text-indent:-0.2in;margin-left:0.2in");
 
 	_s("Footnote Reference",false,"C", "None", "Current Settings", "text-position:superscript; font-size:10pt");
-	_s("Footnote Text",false,"C", "Normal", "Current Settings", "text-position:normal; font-size:10pt");
+	_s("Footnote Text",false,"P", "Normal", "Current Settings", "text-position:normal; font-size:10pt");
+	_s("Footnote",false,"P", "Normal", "Current Settings", "text-position:normal; font-size:10pt;text-indent:-0.2in;margin-left:0.2in");
 
 	return true;
 
@@ -334,7 +360,6 @@ bool pt_PieceTable::appendStyle(const gchar ** attributes)
 		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 		return true;		// silently ignore unnamed styles
 	}
-	UT_DEBUGMSG(("STYLE: Appending style %s \n",szName));
 	PD_Style * pStyle = NULL;
 	if (getStyle(szName,&pStyle) == true)
 	{
@@ -354,7 +379,6 @@ bool pt_PieceTable::appendStyle(const gchar ** attributes)
 	{
 		// this is a new name
 		pStyle = new PD_Style(this, indexAP, szName);
-		UT_DEBUGMSG(("STYLE: Creating new style %s saving in hash \n",szName));
 
 //
 // TODO: Learn how to use Dom's AbiObject instead of this hack.
