@@ -243,6 +243,12 @@ bool pt_PieceTable::_doTheDo(const PX_ChangeRecord * pcr, bool bUndo)
 				UNDO_return_val_if_fail (bFoundStrux, false);
 			}
 			_insertStrux(pf,fragOffset,pfsNew);
+			// insert frag in the embedded_strux list if needed
+			PTStruxType pts = pcrStrux->getStruxType();
+			if ((pts == PTX_EndFootnote) || (pts == PTX_EndEndnote) || (pts == PTX_EndAnnotation)) 
+			{
+			    _insertNoteInEmbeddedStruxList(pfsNew);
+			}
 			DONE();
 			m_pDocument->notifyListeners(pfsContainer,pfsNew,pcr);
 		}
@@ -589,10 +595,6 @@ bool pt_PieceTable::undoCmd(void)
 	// corresponding other end.
 	m_history.setScanningUndoGLOB(false);
 	UT_Byte flagsFirst = GETGLOBFLAGS(pcr);
-	if(m_fragments.areFragsDirty())
-	{
-		m_fragments.cleanFrags();
-	}
 	do
 	{
 		PX_ChangeRecord * pcrRev = pcr->reverse(); // we must delete this.
@@ -637,10 +639,6 @@ bool pt_PieceTable::redoCmd(void)
 	// corresponding other end.
 
 	UT_Byte flagsRevFirst = GETREVGLOBFLAGS(pcr);
-	if(m_fragments.areFragsDirty())
-	{
-		m_fragments.cleanFrags();
-	}
 
 	while (m_history.getRedo(&pcr))
 	{
