@@ -19,7 +19,7 @@
  * 02111-1307, USA.
  */
 
-
+#include <list>
 #include "ut_types.h"
 #include "ut_misc.h"
 #include "ut_assert.h"
@@ -65,6 +65,7 @@ pt_PieceTable::pt_PieceTable(PD_Document * pDocument)
 
 pt_PieceTable::~pt_PieceTable()
 {
+	m_fragments.purgeFrags();
 	m_hashStyles.purgeData();
 }
 
@@ -96,9 +97,9 @@ void pt_PieceTable::setPieceTableState(PTState pts)
  * Use this for deleting unneeded strux during doc import. Particularly useful for importing
  * RTF.
  */
-bool pt_PieceTable::deleteStruxNoUpdate(PL_StruxDocHandle sdh)
+bool pt_PieceTable::deleteStruxNoUpdate(pf_Frag_Strux* sdh)
 {
-	const pf_Frag_Strux * pfs = static_cast<const pf_Frag_Strux *>(sdh);
+	const pf_Frag_Strux * pfs = sdh;
 	UT_DEBUGMSG(("SEVIOR: deleting strux no update %p \n",sdh));
 	pf_Frag * pf = pfs->getNext();
 	if(pf != NULL && pf->getType() == pf_Frag::PFT_FmtMark)
@@ -106,7 +107,7 @@ bool pt_PieceTable::deleteStruxNoUpdate(PL_StruxDocHandle sdh)
 		getFragments().unlinkFrag(pf);
 		delete pf;
 	}
-	getFragments().unlinkFrag(const_cast<pf_Frag *>(static_cast<const pf_Frag *>(pfs)));
+	getFragments().unlinkFrag(const_cast<pf_Frag_Strux*>(pfs));
 	delete pfs;
 	return true;
 }
@@ -216,9 +217,9 @@ bool pt_PieceTable::createAndSendCR(PT_DocPosition iPos, UT_sint32 iType,bool bS
 /*!
  * Delete the single strux given in sdh and create and record a change record.
  */
-bool pt_PieceTable::deleteStruxWithNotify(PL_StruxDocHandle sdh)
+bool pt_PieceTable::deleteStruxWithNotify(pf_Frag_Strux* sdh)
 {
-	pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *>(const_cast<void *>(sdh));
+	pf_Frag_Strux * pfs = sdh;
 	PT_DocPosition dpos = pfs->getPos();
 	pf_Frag * pfEnd = NULL;
 	UT_uint32 pfragOffsetEnd = 0;
@@ -265,9 +266,9 @@ bool pt_PieceTable::deleteFmtMark(PT_DocPosition dpos)
  * a change record and should only be used under exceptional circumstances to 
  * repair the piecetable during loading. It was necessary to import RTF tables.
  */
-bool pt_PieceTable::insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes )
+bool pt_PieceTable::insertStruxNoUpdateBefore(pf_Frag_Strux* sdh, PTStruxType pts,const gchar ** attributes )
 {
-	const pf_Frag_Strux * pfs = static_cast<const pf_Frag_Strux *>(sdh);
+	const pf_Frag_Strux * pfs = sdh;
 	UT_DEBUGMSG(("SEVIOR: Inserting strux of type %d no update %p \n",pts,sdh));
 //
 // Create an indexAP
@@ -291,7 +292,13 @@ bool pt_PieceTable::insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType
 	pf_Frag * pfPrev = pfs->getPrev();
 	UT_return_val_if_fail (pfPrev,false);
 
-	m_fragments.insertFrag(pfPrev,static_cast<pf_Frag *>(pNewStrux));
+	m_fragments.insertFrag(pfPrev,pNewStrux);
+	// insert frag in the embedded_strux list if needed
+	if ((pts == PTX_EndFootnote) || (pts == PTX_EndEndnote) || (pts == PTX_EndAnnotation)) 
+	{
+		_insertNoteInEmbeddedStruxList(pNewStrux);
+	}
+
 #if 0
 	m_pDocument->miniDump(sdh,8);
 #endif
@@ -406,7 +413,7 @@ bool pt_PieceTable::_getSpanAttrPropHelper(pf_Frag * pf, const PP_AttrProp ** pp
 }
 
 
-bool pt_PieceTable::getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, bool bLeftSide,
+bool pt_PieceTable::getSpanAttrProp(pf_Frag_Strux* sdh, UT_uint32 offset, bool bLeftSide,
 									   const PP_AttrProp ** ppAP) const
 {
 	// return the AP for the text at the given offset from the given strux.
@@ -416,9 +423,9 @@ bool pt_PieceTable::getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, boo
 	UT_return_val_if_fail (sdh,false);
 	UT_return_val_if_fail (ppAP,false);
 
-	const pf_Frag * pf = static_cast<const pf_Frag *>(sdh);
+	const pf_Frag * pf = sdh;
 	UT_return_val_if_fail (pf->getType() == pf_Frag::PFT_Strux,false);
-	const pf_Frag_Strux * pfsBlock = static_cast<const pf_Frag_Strux *> (pf);
+	const pf_Frag_Strux * pfsBlock = sdh;
 	
 	// This assert is incorrect; blocks that are inserted inside a TOC use sdh of the TOC section
 	// UT_return_val_if_fail (pfsBlock->getStruxType() == PTX_Block,false);
@@ -447,14 +454,14 @@ bool pt_PieceTable::getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, boo
 
 		if (offset == cumEndOffset)		// there's a frag boundary exactly where we want. pfTemp is to our left.
 		{
-			if (!bLeftSide)
-				continue;				// return the next one on the next loop iteration
-
 			// FmtMarks have length zero, so we advance to put it to our left and then decide what to do
-			if (pfTemp->getNext() && (pfTemp->getNext()->getType()==pf_Frag::PFT_FmtMark))
-				continue;				// we'll return this one on the next loop iteration
-
-			// otherwise, we want the thing that we are at the end of (ie that is to the left)
+			if (!bLeftSide || (pfTemp->getNext() && (pfTemp->getNext()->getType()==pf_Frag::PFT_FmtMark)))
+				continue;				// return the next one on the next iteration
+			// If we are just after a footnote or an endnote, we move to the right fragment
+			if (isEndFootnote(pfTemp) && pfTemp->getNext())
+			{
+				pfTemp = pfTemp->getNext();
+			}
 			return _getSpanAttrPropHelper(pfTemp,ppAP);
 		}
 
@@ -471,7 +478,7 @@ bool pt_PieceTable::getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, boo
 #if 0
 // I will leave the code here for now to aid in debugging any problems
 // with the new iterator (should there be any, that is) Tomas, Nov 15, 2003
-bool pt_PieceTable::getSpanPtr(PL_StruxDocHandle sdh, UT_uint32 offset,
+bool pt_PieceTable::getSpanPtr(pf_Frag_Strux* sdh, UT_uint32 offset,
 								  const UT_UCSChar ** ppSpan, UT_uint32 * pLength) const
 {
 	// note: offset zero refers to the strux.  the first character is at
@@ -480,9 +487,9 @@ bool pt_PieceTable::getSpanPtr(PL_StruxDocHandle sdh, UT_uint32 offset,
 	*ppSpan = NULL;
 	*pLength = 0;
 
-	const pf_Frag * pf = static_cast<const pf_Frag *>(sdh);
+	const pf_Frag * pf = sdh;
 	UT_return_val_if_fail (pf->getType() == pf_Frag::PFT_Strux,false);
-	const pf_Frag_Strux * pfsBlock = static_cast<const pf_Frag_Strux *> (pf);
+	const pf_Frag_Strux * pfsBlock = sdh;
 	UT_return_val_if_fail (pfsBlock->getStruxType() == PTX_Block,false);
 	xxx_UT_DEBUGMSG(("getSpanPtr: Requested offset %d \n",offset));
 	
@@ -552,14 +559,14 @@ PD_Document * pt_PieceTable::getDocument(void)
   Copy the contents (unicode character data) of the paragraph (block)
   into the growbuf given.  We append the content onto the growbuf.
 */
-bool pt_PieceTable::getBlockBuf(PL_StruxDocHandle sdh,
+bool pt_PieceTable::getBlockBuf(pf_Frag_Strux* sdh,
                                    UT_GrowBuf * pgb) const
 {
     UT_return_val_if_fail (pgb,false);
 
-    const pf_Frag * pf = static_cast<const pf_Frag *>(sdh);
+    const pf_Frag * pf = sdh;
     UT_return_val_if_fail(pf->getType() == pf_Frag::PFT_Strux, false);
-    const pf_Frag_Strux * pfsBlock = static_cast<const pf_Frag_Strux *> (pf);
+    const pf_Frag_Strux * pfsBlock = sdh;
     UT_return_val_if_fail(pfsBlock->getStruxType() == PTX_Block, false);
 
     UT_uint32 bufferOffset = pgb->getLength();
@@ -723,11 +730,11 @@ bool pt_PieceTable::getBounds(bool bEnd, PT_DocPosition & docPos) const
 	return res;
 }
 
-PT_DocPosition pt_PieceTable::getStruxPosition(PL_StruxDocHandle sdh) const
+PT_DocPosition pt_PieceTable::getStruxPosition(pf_Frag_Strux* sdh) const
 {
 	// return absolute document position of the given handle.
 
-	const pf_Frag * pfToFind = static_cast<const pf_Frag *>(sdh);
+	const pf_Frag * pfToFind = sdh;
 
 	return getFragPosition(pfToFind);
 }
@@ -738,8 +745,7 @@ void pt_PieceTable::deleteHdrFtrStrux(pf_Frag_Strux * pfs)
 	
 	if(m_pDocument->isMarkRevisions())
 	{
-		const pf_Frag * pfFrag = NULL;
-		pfFrag = static_cast<const pf_Frag *>(pfs);
+		const pf_Frag * pfFrag = pfs;
 		PT_DocPosition dpos1 = getFragPosition(pfFrag);
 
 		pfFrag = pfFrag->getNext();
@@ -917,7 +923,7 @@ bool pt_PieceTable::getFragsFromPositions(PT_DocPosition dPos1, PT_DocPosition d
 
 bool pt_PieceTable::getStruxFromPosition(PL_ListenerId listenerId,
 											PT_DocPosition docPos,
-											PL_StruxFmtHandle * psfh) const
+											fl_ContainerLayout* * psfh) const
 {
 	// return the SFH of the last strux immediately prior to
 	// the given absolute document position.
@@ -933,7 +939,7 @@ bool pt_PieceTable::getStruxFromPosition(PL_ListenerId listenerId,
 bool pt_PieceTable::getStruxOfTypeFromPosition(PL_ListenerId listenerId,
 												  PT_DocPosition docPos,
 												  PTStruxType pts,
-												  PL_StruxFmtHandle * psfh) const
+												  fl_ContainerLayout* * psfh) const
 {
 	// return the SFH of the last strux of the given type
 	// immediately prior to the given absolute document position.
@@ -951,14 +957,9 @@ bool pt_PieceTable::getStruxOfTypeFromPosition(PL_ListenerId listenerId,
 ///
 bool pt_PieceTable::getStruxOfTypeFromPosition( PT_DocPosition docPos,
 						   PTStruxType pts,
-						   PL_StruxDocHandle * sdh) const
+						   pf_Frag_Strux* * sdh) const
 {
-
-	pf_Frag_Strux * pfs = NULL;
-	if (!_getStruxOfTypeFromPosition(docPos,pts,&pfs))
-			return false;
-	*sdh = static_cast<PL_StruxDocHandle >(pfs);
-	return true;
+	return _getStruxOfTypeFromPosition(docPos,pts,sdh);
 }
 
 bool pt_PieceTable::isEndFootnote(pf_Frag * pf) const
@@ -988,6 +989,37 @@ bool pt_PieceTable::isFootnote(pf_Frag * pf) const
 	return false;
 }
 
+
+bool pt_PieceTable::isInsideFootnote(PT_DocPosition dpos, pf_Frag ** pfBegin) const
+{
+	// return true if pos is inside a footnote, an endnote or an annotation.
+	// the address of the footnote (endnote or annotation) pfs_strux is 
+	// returned in pfBegin if pfBegin is not NULL
+	if(m_embeddedStrux.empty())
+	{
+		return false;
+	}
+
+	std::list<embeddedStrux>::const_iterator it;
+	it = m_embeddedStrux.begin();
+	for (it = m_embeddedStrux.begin(); it != m_embeddedStrux.end(); ++it)
+	{
+		if ((*it).endNote->getPos() > dpos)
+		{
+			if ((*it).beginNote->getPos() < dpos)
+			{
+				if (pfBegin)
+				{
+					*pfBegin = (*it).beginNote;
+				}
+				return true;
+			}
+			break;
+		}
+	}
+	return false;
+}
+
 bool pt_PieceTable::_getStruxFromPosition(PT_DocPosition docPos,
 											 pf_Frag_Strux ** ppfs,
                                               bool bSkipFootnotes) const
@@ -1036,11 +1068,10 @@ bool pt_PieceTable::_getStruxFromPosition(PT_DocPosition docPos,
 }
 
 
-PL_StruxDocHandle pt_PieceTable::getBlockFromPosition(PT_DocPosition pos) const
+pf_Frag_Strux* pt_PieceTable::getBlockFromPosition(PT_DocPosition pos) const
 {
 	pf_Frag_Strux* pfs = _getBlockFromPosition(pos);
-	PL_StruxDocHandle ret = static_cast<PL_StruxDocHandle>(pfs);
-    return ret;
+    return pfs;
 }
 
 
@@ -1435,5 +1466,56 @@ UT_uint32 pt_PieceTable::getXID()
 }
 
 
+/* Return true if neither dpos1 nor dpos2 is within a note and the whole document is not selected*/
+bool pt_PieceTable::_checkSkipFootnote(PT_DocPosition dpos1, PT_DocPosition dpos2, pf_Frag * pf_End) const
+{
+	if(m_embeddedStrux.empty())
+	{
+		return true;
+	}
 
+	if (!pf_End)
+	{
+		PT_BlockOffset offset;
+		getFragFromPosition(dpos2,&pf_End,&offset);
+	}
+	if ((dpos1 == 1) && ((pf_End->getType() == pf_Frag::PFT_EndOfDoc) ||
+						 ((pf_End->getType() == pf_Frag::PFT_Strux) && 
+						  (static_cast<pf_Frag_Strux*>(pf_End)->getStruxType() == PTX_SectionHdrFtr))))
+	{
+		return false;
+	}
 
+	bool bSkipNote = true;
+	std::list<embeddedStrux>::const_reverse_iterator it;
+	for (it = m_embeddedStrux.rbegin(); it != m_embeddedStrux.rend(); ++it)
+	{
+		if ((*it).beginNote->getPos() < dpos2)
+		{
+			if ((*it).endNote->getPos() > dpos2)
+			{
+				bSkipNote = false;
+			}
+			break;
+		}
+	}
+	if (bSkipNote)
+	{
+		if (it != m_embeddedStrux.rbegin())
+		{
+			it--;
+		}
+		for (; it != m_embeddedStrux.rend(); ++it)
+		{
+			if ((*it).beginNote->getPos() < dpos1)
+			{
+				if ((*it).endNote->getPos() > dpos1)
+				{
+					bSkipNote = false;
+				}
+				break;
+			}
+		}
+	}
+	return bSkipNote;
+}
