@@ -23,6 +23,7 @@
 #define PT_PIECETABLE_H
 
 #include <stdio.h>
+#include <list>
 #include "ut_types.h"
 #include "ut_growbuf.h"
 #include "ut_hash.h"
@@ -43,6 +44,7 @@ class pf_Frag_Strux_Section;
 class PX_ChangeRecord_Span;
 class PD_Style;
 class PL_ListenerCoupleCloser;
+class fl_ContainerLayout;
 
 #ifdef PT_TEST
 #include "ut_test.h"
@@ -81,8 +83,9 @@ public:
 	bool					getRedo(PX_ChangeRecord ** ppcr) const
 								{ return m_history.getRedo(ppcr); }
 	void                    clearUndo() {m_history.clearHistory();}
-	
+
 	static void		s_getLocalisedStyleName(const char *szStyle, UT_UTF8String &utf8);
+	static const char *s_getUnlocalisedStyleName(const char *szLocStyle);
 
 protected:
 	bool					_realInsertObject(PT_DocPosition dpos,
@@ -141,14 +144,14 @@ protected:
 												PTStruxType pts,
 												bool bRevisionDelete);
 
-	bool                    _realChangeStruxForLists(PL_StruxDocHandle sdh,
+	bool                    _realChangeStruxForLists(pf_Frag_Strux* sdh,
 													 const char * pszParentID,
 													 bool bRevisionDelete);
-	
+
     bool                    _realChangeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
 
 
-    
+
 	/******************************************************************
 	    these are the new revisions aware methods
 	*/
@@ -177,7 +180,7 @@ public:
     //                                      std::string v );
     // bool deleteSpanChangeTrackingMaybeMarkParagraphEndDeletion( PT_DocPosition currentpos,
     //                                                             PT_DocPosition endpos );
-    
+
 	bool					deleteSpan(PT_DocPosition dpos1,
 									   PT_DocPosition dpos2,
 									   PP_AttrProp *p_AttrProp_Before,
@@ -191,7 +194,7 @@ public:
 									   UT_uint32 &iRealDeleteCount,
 									   bool bDeleteTableStruxes,
 									   bool bDontGlob);
-	bool                    createAndSendCR(PT_DocPosition  dpos, 
+	bool                    createAndSendCR(PT_DocPosition  dpos,
 											UT_sint32 iType,bool bSave, UT_Byte iGlob);
 
 	bool                    createAndSendDocPropCR( const gchar ** pAtts, const gchar ** pProps);
@@ -240,17 +243,17 @@ public:
 
 	bool                    changeObjectFormatNoUpdate(PTChangeFmt ptc, pf_Frag_Object * pfo,const gchar ** attributes,const gchar ** properties);
 
-	bool                    changeStruxForLists(PL_StruxDocHandle sdh,
+	bool                    changeStruxForLists(pf_Frag_Strux* sdh,
 												const char * pszParentID);
     bool                    changeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
-	bool                    deleteStruxNoUpdate(PL_StruxDocHandle sdh);
+	bool                    deleteStruxNoUpdate(pf_Frag_Strux* sdh);
 	bool                    deleteFragNoUpdate(pf_Frag * pf);
-	bool                    deleteStruxWithNotify(PL_StruxDocHandle sdh);
-	bool                    insertStruxNoUpdateBefore(PL_StruxDocHandle sdh, PTStruxType pts,const gchar ** attributes );
+	bool                    deleteStruxWithNotify(pf_Frag_Strux* sdh);
+	bool                    insertStruxNoUpdateBefore(pf_Frag_Strux* sdh, PTStruxType pts,const gchar ** attributes );
 	bool                    changeLastStruxFmtNoUndo(PT_DocPosition dpos, PTStruxType pts,
 													 const gchar ** attrs, const gchar ** props,
 													 bool bSkipEmbededSections);
-	
+
 	bool                    changeLastStruxFmtNoUndo(PT_DocPosition dpos, PTStruxType pts,
 													 const gchar ** attrs, const gchar * props,
 													 bool bSkipEmbededSections);
@@ -275,7 +278,7 @@ public:
 											   bool bSkipEmbededSections);
 	bool                    appendLastStruxFmt(PTStruxType pts, const gchar ** attrs, const gchar * props,
 											   bool bSkipEmbededSections);
-	
+
 	bool					appendFmt(const gchar ** attributes);
 	bool					appendFmt(const UT_GenericVector<const gchar*> * pVecAttributes);
 	bool					appendSpan(const UT_UCSChar * p, UT_uint32 length);
@@ -290,7 +293,7 @@ public:
 												   const gchar ** attributes);
 	bool					insertFmtMarkBeforeFrag(pf_Frag * pF);
 	bool					insertFmtMarkBeforeFrag(pf_Frag * pF, const gchar ** attributes);
-	
+
 	bool					removeStyle(const gchar * name);
 	size_t					getStyleCount(void) const;
 
@@ -304,7 +307,7 @@ public:
 
 	bool					getAttrProp(PT_AttrPropIndex indexAP,
 										const PP_AttrProp ** ppAP) const;
-	bool					getSpanAttrProp(PL_StruxDocHandle sdh, UT_uint32 offset, bool bLeftSide,
+	bool					getSpanAttrProp(pf_Frag_Strux* sdh, UT_uint32 offset, bool bLeftSide,
 											const PP_AttrProp ** ppAP) const;
 
 	inline const UT_UCSChar *getPointer(PT_BufIndex bi) const
@@ -316,15 +319,15 @@ public:
 			return m_varset.getPointer(bi);
 		}
 
-	bool					getBlockBuf(PL_StruxDocHandle sdh, UT_GrowBuf * pgb) const;
+	bool					getBlockBuf(pf_Frag_Strux* sdh, UT_GrowBuf * pgb) const;
 
     PT_DocPosition          getPosEnd();
 	bool					getBounds(bool bEnd, PT_DocPosition & docPos) const;
-	PT_DocPosition			getStruxPosition(PL_StruxDocHandle sdh) const;
+	PT_DocPosition			getStruxPosition(pf_Frag_Strux* sdh) const;
 	PT_DocPosition			getFragPosition(const pf_Frag * pfToFind) const;
 
     bool dumpDoc( const char* msg, PT_DocPosition currentpos, PT_DocPosition endpos );
-    
+
 	bool					getFragFromPosition(PT_DocPosition docPos,
 												pf_Frag ** ppf,
 												PT_BlockOffset * pOffset) const;
@@ -332,17 +335,17 @@ public:
 	bool					getStruxOfTypeFromPosition(PL_ListenerId listenerId,
 													   PT_DocPosition docPos,
 													   PTStruxType pts,
-													   PL_StruxFmtHandle * psfh) const;
+													   fl_ContainerLayout* * psfh) const;
 
-    PL_StruxDocHandle       getBlockFromPosition(PT_DocPosition pos) const;
+    pf_Frag_Strux*       getBlockFromPosition(PT_DocPosition pos) const;
 
 	bool					getStruxOfTypeFromPosition(PT_DocPosition docPos,
 													   PTStruxType pts,
-													   PL_StruxDocHandle * sdh) const;
+													   pf_Frag_Strux* * sdh) const;
 
 	bool					getStruxFromPosition(PL_ListenerId listenerId,
 												 PT_DocPosition docPos,
-												 PL_StruxFmtHandle * psfh) const;
+												 fl_ContainerLayout* * psfh) const;
 
 	bool					getFragsFromPositions(PT_DocPosition dPos1, PT_DocPosition dPos2,
 												  pf_Frag ** ppf1, PT_BlockOffset * pOffset1,
@@ -354,11 +357,12 @@ public:
 									   const char ** pszName, const PD_Style ** ppStyle) const;
 
 	bool                    enumStyles(UT_GenericVector<PD_Style*> * & pStyles) const;
-	
+
 	const UT_GenericStringMap<PD_Style *> & getAllStyles()const {return m_hashStyles;}
 	bool                    isEndFootnote(pf_Frag * pf) const;
 	bool                    isFootnote(pf_Frag * pf) const;
-	
+	bool                    isInsideFootnote(PT_DocPosition dpos, pf_Frag ** pfBegin = NULL) const;
+
 	void					clearIfAtFmtMark(PT_DocPosition dpos);
     pt_VarSet &             getVarSet(void) {return m_varset;};
     pf_Fragments &          getFragments(void) {return m_fragments;};
@@ -517,7 +521,7 @@ protected:
 	void                    _deleteHdrFtrStruxWithNotify( pf_Frag_Strux * pfFragStruxHdrFtr);
 
 	bool                    _fixHdrFtrReferences(const gchar * pType, const gchar * pId, bool bNotional = false);
-	
+
 	bool					_fmtChangeStrux(pf_Frag_Strux * pfs,
 											PT_AttrPropIndex indexNewAP);
 
@@ -526,7 +530,7 @@ protected:
 													  const gchar ** attributes,
 													  const gchar ** properties,
 													  bool bRevisionDelete);
-	
+
 	bool					_fmtChangeStruxWithNotify(PTChangeFmt ptc,
 													  pf_Frag_Strux * pfs,
 													  const gchar ** attributes,
@@ -548,7 +552,7 @@ protected:
 													 pf_Frag ** ppfNewEnd,
 													 UT_uint32 * pfragOffsetNewEnd,
 													 bool bRevisionDelete);
-	
+
 	bool					_fmtChangeObject(pf_Frag_Object * pfo,
 											 PT_AttrPropIndex indexNewAP,
 											 pf_Frag ** ppfNewEnd,
@@ -610,7 +614,9 @@ protected:
 	bool					_lastUndoIsThisFmtMark(PT_DocPosition dpos);
 
 	bool					_changePointWithNotify(PT_DocPosition dpos);
-
+	bool                    _checkSkipFootnote(PT_DocPosition dpos1, PT_DocPosition dpos2, pf_Frag * pf_End = NULL) const;
+	bool                    _generateExtraPropList(pf_Frag * pf, const gchar * cStylePara,
+												   const gchar ** & sProps, std::vector <std::string> & vPropNames);
 	// helper methods for the appned and insert*BeforeFrag methods
 	bool					_makeStrux(PTStruxType pts, const gchar ** attributes,
 									   pf_Frag_Strux * &pfs);
@@ -627,7 +633,7 @@ protected:
 														const gchar ** & ppRevProps,
 														const gchar **   ppAttrib,
 														const gchar **   ppProps);
-	
+	bool                    _insertNoteInEmbeddedStruxList(pf_Frag_Strux * pfsNew);
 
 	PTState					m_pts;		/* are we loading or editing */
 	pt_VarSet				m_varset;
@@ -647,6 +653,12 @@ protected:
 
 	UT_uint32               m_iXID;
 	UT_sint32               m_iCurCRNumber;
+	struct embeddedStrux {
+		pf_Frag_Strux * beginNote;
+		pf_Frag_Strux * endNote;
+	};
+
+	std::list <embeddedStrux> m_embeddedStrux;
 };
 
 #endif /* PT_PIECETABLE_H */
