@@ -121,6 +121,9 @@
 #include "ap_Preview_Abi.h"
 #include "xap_UnixDialogHelper.h"
 #include "gr_UnixCairoGraphics.h"
+#if !GTK_CHECK_VERSION(3,0,0)
+#include "gr_UnixPangoPixmapGraphics.h"
+#endif
 #include "ie_exp_DocRangeListener.h"
 
 #ifdef GTK_WIN_POS_CENTER_ALWAYS
@@ -764,10 +767,12 @@ void AP_UnixApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool bUseClipb
 		{
 			UT_uint32 iread,iwritten = 0;
 			const char * szutf8= static_cast<const char *>(UT_convert(reinterpret_cast<const char *>(pData),iLen,szRes,"UTF-8",&iread,&iwritten));
-			IE_Imp_XHTML * pImpHTML = new IE_Imp_XHTML(pDocRange->m_pDoc);
-			bSuccess = pImpHTML->pasteFromBuffer(pDocRange,reinterpret_cast<const unsigned char *>(szutf8),iwritten,"UTF-8");
-			g_free(const_cast<char *>(szutf8));
-			DELETEP(pImpHTML);
+			if (szutf8) { 
+				IE_Imp_XHTML * pImpHTML = new IE_Imp_XHTML(pDocRange->m_pDoc);
+				bSuccess = pImpHTML->pasteFromBuffer(pDocRange,reinterpret_cast<const unsigned char *>(szutf8),iwritten,"UTF-8");
+				g_free(const_cast<char *>(szutf8));
+				DELETEP(pImpHTML);
+			}
 		}
 		else
 		{
@@ -1180,7 +1185,8 @@ bool AP_UnixApp::getCurrentSelection(const char** formatList,
     return true;
 }
 
-bool AP_UnixApp:: makePngPreview(const char * pszInFile, const char * pszPNGFile, UT_sint32 iWidth, UT_sint32 iHeight)
+#if GTK_CHECK_VERSION(3,0,0)
+bool AP_UnixApp::makePngPreview(const char * pszInFile, const char * pszPNGFile, UT_sint32 iWidth, UT_sint32 iHeight)
 {
 	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24, iWidth, iHeight);
 	cairo_t *cr = cairo_create (surface);
@@ -1215,6 +1221,44 @@ bool AP_UnixApp:: makePngPreview(const char * pszInFile, const char * pszPNGFile
 	DELETEP(pPrevAbi); // This deletes pNewDoc
 	return true;
 }
+#else
+bool AP_UnixApp::makePngPreview(const char * pszInFile, const char * pszPNGFile, UT_sint32 iWidth, UT_sint32 iHeight)
+{
+	GdkPixmap*  pPixmap = gdk_pixmap_new(NULL,iWidth,iHeight,24);
+
+	GR_UnixPixmapAllocInfo ai(pPixmap);
+
+	GR_UnixPangoPixmapGraphics * pG = (GR_UnixPangoPixmapGraphics*) GR_UnixPangoPixmapGraphics::graphicsAllocator(ai);
+
+	UT_Error error = UT_OK;
+	PD_Document * pNewDoc = new PD_Document();
+	error = pNewDoc->readFromFile(pszInFile,IEFT_Unknown, NULL);
+
+	if (error != UT_OK) 
+	{
+		return false;
+	}
+	AP_Preview_Abi * pPrevAbi = new AP_Preview_Abi(pG,iWidth,iHeight,NULL, PREVIEW_ZOOMED,pNewDoc);
+	dg_DrawArgs da;
+	memset(&da, 0, sizeof(da));
+	da.pG = pG;
+	GR_Painter * pPaint = new GR_Painter(pG);
+	pPaint->clearArea(0,0,pG->tlu(iWidth),pG->tlu(iHeight));
+	pPrevAbi->getView()->draw(0, &da);
+	UT_Rect r;
+	r.left = 0;
+	r.top = 0;
+	r.width = pG->tlu(iWidth);
+	r.height = pG->tlu(iHeight);
+	GR_Image * pImage = pPaint->genImageFromRectangle(r);
+	DELETEP(pPaint);
+	static_cast<GR_UnixImage *>(pImage)->saveToPNG( pszPNGFile);
+	DELETEP(pImage);
+	DELETEP(pG);
+	DELETEP(pPrevAbi); // This deletes pNewDoc
+	return true;
+}
+#endif
 
 /*****************************************************************/
 /*****************************************************************/
@@ -1233,6 +1277,10 @@ GR_Graphics * AP_UnixApp::newDefaultScreenGraphics() const
 	return XAP_App::getApp()->newGraphics(ai);
 }
 
+#ifdef WITH_CHAMPLAIN
+#include <champlain-gtk/champlain-gtk.h>
+#include <clutter-gtk/clutter-gtk.h>
+#endif
 
 /*****************************************************************/
 
@@ -1246,7 +1294,11 @@ int AP_UnixApp::main(const char * szAppName, int argc, char ** argv)
     // initialize our application.
 	int exit_status = 0;
 	AP_UnixApp * pMyUnixApp = new AP_UnixApp(szAppName);
-	
+
+#ifdef WITH_CHAMPLAIN
+    gtk_clutter_init (&argc, &argv);
+#endif
+    
 	/* this brace is here to ensure that our local variables on the stack
 	 * do not outlive the application object by giving them a lower scope
 	 */
@@ -1477,7 +1529,7 @@ void AP_UnixApp::catchSignals(int /*sig_num*/)
 		fflush(stdout);
 		abort();
     }
-    
+
     UT_DEBUGMSG(("Oh no - we just crashed!\n"));
 //
 // fixme: Enable this to help debug the bonobo component. After a crash the
@@ -1498,16 +1550,16 @@ void AP_UnixApp::catchSignals(int /*sig_num*/)
 	IEFileType abiType = IE_Imp::fileTypeForSuffix(".abw");
     for(;i<m_vecFrames.getItemCount();i++)
     {
-		AP_UnixFrame * curFrame = const_cast<AP_UnixFrame*>(static_cast<const AP_UnixFrame*>(m_vecFrames[i]));
+		XAP_Frame * curFrame = m_vecFrames[i];
 		UT_continue_if_fail(curFrame);
 		if (NULL == curFrame->getFilename())
 		  curFrame->backup(".abw.saved",abiType);
 		else
 		  curFrame->backup(".saved",abiType);
     }
-    
+
     fflush(stdout);
-    
+
     // Abort and dump core
     abort();
 }
