@@ -45,8 +45,8 @@
 const char * sBorderStyle[BORDER_SHADING_NUMOFSTYLES] = {
 														"0",	//No line
 														"1",	//Solid line
-														"2",	//Dashed line
-														"3"};	//Dotted line
+														"2",	//Dotted line
+														"3"};	//Dashed line
 
 static void s_apply_changes(GtkWidget *widget, gpointer data )
 {
@@ -270,7 +270,7 @@ void AP_UnixDialog_Border_Shading::runModeless(XAP_Frame * pFrame)
 
 	// Populate the window's data items
 	_populateWindowData();
-//	_connectSignals(); // last call runs setSensitivity which calls _connectSignals
+	_connectSignals();
 	abiSetupModelessDialog(GTK_DIALOG(m_windowMain), pFrame, this, BUTTON_CLOSE);
 	
 	// *** this is how we add the gc for Column Preview ***
@@ -286,7 +286,7 @@ void AP_UnixDialog_Border_Shading::runModeless(XAP_Frame * pFrame)
 	// Todo: we need a good widget to query with a probable
 	// Todo: non-white (i.e. gray, or a similar bgcolor as our parent widget)
 	// Todo: background. This should be fine
-	m_pPreviewWidget->init3dColors(gtk_widget_get_style_context(m_wPreviewArea));
+	m_pPreviewWidget->init3dColors(m_wPreviewArea);
 
 	// let the widget materialize
 
@@ -306,20 +306,14 @@ void AP_UnixDialog_Border_Shading::setSensitivity(bool /* bSens */)
 {
 //	UT_DEBUGMSG(("========================= Set the sensitivity \n"));
 
-	if (m_iLineLeftConnect == 0)
-		_connectSignals();// avoids some criticals
-		
-	XAP_GtkSignalBlocker b1(G_OBJECT(m_wLineLeft), m_iLineLeftConnect);
 	gtk_toggle_button_set_active((GtkToggleButton*)m_wLineLeft, getLeftToggled() ? TRUE: FALSE);
-
-	XAP_GtkSignalBlocker b2(G_OBJECT(m_wLineRight), m_iLineRightConnect);
 	gtk_toggle_button_set_active((GtkToggleButton*)m_wLineRight, getRightToggled() ? TRUE: FALSE);
-
-	XAP_GtkSignalBlocker b3(G_OBJECT(m_wLineTop), m_iLineTopConnect);
 	gtk_toggle_button_set_active((GtkToggleButton*)m_wLineTop, getTopToggled() ? TRUE: FALSE);
-
-	XAP_GtkSignalBlocker b4(G_OBJECT(m_wLineBottom), m_iLineBotConnect);
 	gtk_toggle_button_set_active((GtkToggleButton*)m_wLineBottom, getBottomToggled() ? TRUE: FALSE);
+
+	gboolean bEnable = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_wShadingEnable)); 
+	gtk_widget_set_sensitive(m_wShadingColorButton, bEnable);
+	gtk_widget_set_sensitive(m_wShadingOffset, bEnable);
 }
 
 void AP_UnixDialog_Border_Shading::event_Close(void)
@@ -429,7 +423,7 @@ void AP_UnixDialog_Border_Shading::event_BorderStyleChanged(void)
 	{
 		gint index = gtk_combo_box_get_active(GTK_COMBO_BOX(m_wBorderStyle));
 
-		if (index >= 0 && index <= BORDER_SHADING_NUMOFSTYLES)
+		if (index >= 0 && index < BORDER_SHADING_NUMOFSTYLES)
 		{
 			UT_UTF8String style_utf8 = sBorderStyle[index];
 			setBorderStyle(style_utf8);
@@ -501,38 +495,43 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 	GtkWidget * window;
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 	
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Border_Shading.xml";
-	
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	UT_DEBUGMSG(("Loading dialog from ap_UnixDialog_Border_Shading.xml \n"));
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Border_Shading.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Border_Shading-2.ui");
+#endif
 	
 	// Update our member variables with the important widgets that 
 	// might need to be queried or altered later
 	window = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_Border_Shading"));
-	xxx_UT_DEBUGMSG(("Got top level dialog from ap_UnixDialog_Border_Shading.xml %p \n",window));
+	xxx_UT_DEBUGMSG(("Got top level dialog from ap_UnixDialog_Border_Shading.ui %p \n",window));
 
 	m_wLineTop 		= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderTop"));
-	xxx_UT_DEBUGMSG(("Got LineTop from ap_UnixDialog_Border_Shading.xml %p \n",m_wLineTop));
+	xxx_UT_DEBUGMSG(("Got LineTop from ap_UnixDialog_Border_Shading.ui %p \n",m_wLineTop));
 
 	m_wLineLeft 	= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderLeft"));
 	m_wLineRight 	= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderRight"));
 	m_wLineBottom 	= GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderBottom"));
-	
+
 	// place some nice pixmaps on our border toggle buttons
 	label_button_with_abi_pixmap(m_wLineTop, "tb_LineTop_xpm");
 	label_button_with_abi_pixmap(m_wLineLeft, "tb_LineLeft_xpm");
 	label_button_with_abi_pixmap(m_wLineRight, "tb_LineRight_xpm");
 	label_button_with_abi_pixmap(m_wLineBottom, "tb_LineBottom_xpm");
 	
+	// set button states
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wLineTop), getTopToggled());  
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wLineLeft), getLeftToggled());  
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wLineRight), getRightToggled());  
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wLineBottom), getBottomToggled());  
+	
 	m_wPreviewArea 		= GTK_WIDGET(gtk_builder_get_object(builder, "daPreview"));
 	m_wShadingEnable	= GTK_WIDGET(gtk_builder_get_object(builder, "cbShadingEnable"));
 	
 	// set the dialog title
 	ConstructWindowName();
-	abiDialogSetTitle(window, m_WindowName);
+	abiDialogSetTitle(window, "%s", m_WindowName);
 	
 	// disable double buffering on our preview
 	gtk_widget_set_double_buffered(m_wPreviewArea, FALSE); 	
@@ -545,6 +544,7 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 	localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lblBorderStyle")), pSS, AP_STRING_ID_DLG_BorderShading_Border_Style);
 
 	localizeLabelMarkup(GTK_WIDGET(gtk_builder_get_object(builder, "lbShading")), pSS, AP_STRING_ID_DLG_BorderShading_Shading);
+	localizeButton(GTK_WIDGET(gtk_builder_get_object(builder, "cbShadingEnable")), pSS, AP_STRING_ID_DLG_BorderShading_Use_Shading);
 	m_wShadingColorLabel = GTK_WIDGET(gtk_builder_get_object(builder, "lbShadingColor"));
 	localizeLabel(m_wShadingColorLabel, pSS, AP_STRING_ID_DLG_BorderShading_Shading_Color);
 	m_wShadingOffsetLabel = GTK_WIDGET(gtk_builder_get_object(builder, "lblShadingOffset"));
@@ -559,41 +559,50 @@ GtkWidget * AP_UnixDialog_Border_Shading::_constructWindow(void)
 // Border Thickness Option menu
 // 
 	m_wBorderThickness = GTK_WIDGET(gtk_builder_get_object(builder, "omBorderThickness"));
-	GtkComboBoxText *combo = GTK_COMBO_BOX_TEXT(m_wBorderThickness);
-	gtk_combo_box_text_append_text(combo, "1/2 pt");
-	gtk_combo_box_text_append_text(combo, "3/4 pt");
-	gtk_combo_box_text_append_text(combo, "1 pt");
-	gtk_combo_box_text_append_text(combo, "1 1/2 pt");
-	gtk_combo_box_text_append_text(combo, "2 1/4 pt");
-	gtk_combo_box_text_append_text(combo, "3 pt");
-	gtk_combo_box_text_append_text(combo, "4 1/2 pt");
-	gtk_combo_box_text_append_text(combo, "6 pt");
+	GtkComboBox* combo = GTK_COMBO_BOX(m_wBorderThickness);
+	XAP_makeGtkComboBoxText(combo, G_TYPE_NONE);
+	XAP_appendComboBoxText(combo, "1/2 pt");
+	XAP_appendComboBoxText(combo, "3/4 pt");
+	XAP_appendComboBoxText(combo, "1 pt");
+	XAP_appendComboBoxText(combo, "1 1/2 pt");
+	XAP_appendComboBoxText(combo, "2 1/4 pt");
+	XAP_appendComboBoxText(combo, "3 pt");
+	XAP_appendComboBoxText(combo, "4 1/2 pt");
+	XAP_appendComboBoxText(combo, "6 pt");
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
 
 //
 // Border Style Option menu
 //
 	m_wBorderStyle = GTK_WIDGET(gtk_builder_get_object(builder, "cmbBorderStyle"));
-	GtkComboBoxText *combo_style = GTK_COMBO_BOX_TEXT(m_wBorderStyle);
-	gtk_combo_box_text_append_text(combo_style, "None");
-	gtk_combo_box_text_append_text(combo_style, "Solid line");
-	gtk_combo_box_text_append_text(combo_style, "Dashed line");
-	gtk_combo_box_text_append_text(combo_style, "Dotted line");
+	GtkComboBox* combo_style = GTK_COMBO_BOX(m_wBorderStyle);
+	XAP_makeGtkComboBoxText(combo_style, G_TYPE_NONE);
+	
+	UT_UTF8String s;
+	pSS->getValueUTF8(AP_STRING_ID_DLG_BorderShading_Border_Style_None, s);
+	XAP_appendComboBoxText(combo_style, s.utf8_str());
+	pSS->getValueUTF8(AP_STRING_ID_DLG_BorderShading_Border_Style_Solid, s);
+	XAP_appendComboBoxText(combo_style, s.utf8_str());
+	pSS->getValueUTF8(AP_STRING_ID_DLG_BorderShading_Border_Style_Dotted, s);
+	XAP_appendComboBoxText(combo_style, s.utf8_str());
+	pSS->getValueUTF8(AP_STRING_ID_DLG_BorderShading_Border_Style_Dashed, s);
+	XAP_appendComboBoxText(combo_style, s.utf8_str());
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo_style), 0);
 
 //
 // Shading offset Option menu
 //
 	m_wShadingOffset = GTK_WIDGET(gtk_builder_get_object(builder, "cmbShadingOffset"));
-	GtkComboBoxText *combo_offset = GTK_COMBO_BOX_TEXT(m_wShadingOffset);
-	gtk_combo_box_text_append_text(combo_offset, "1/2 pt");
-	gtk_combo_box_text_append_text(combo_offset, "3/4 pt");
-	gtk_combo_box_text_append_text(combo_offset, "1 pt");
-	gtk_combo_box_text_append_text(combo_offset, "1 1/2 pt");
-	gtk_combo_box_text_append_text(combo_offset, "2 1/4 pt");
-	gtk_combo_box_text_append_text(combo_offset, "3 pt");
-	gtk_combo_box_text_append_text(combo_offset, "4 1/2 pt");
-	gtk_combo_box_text_append_text(combo_offset, "6 pt");
+	GtkComboBox* combo_offset = GTK_COMBO_BOX(m_wShadingOffset);
+	XAP_makeGtkComboBoxText(combo_offset, G_TYPE_NONE);
+	XAP_appendComboBoxText(combo_offset, "1/2 pt");
+	XAP_appendComboBoxText(combo_offset, "3/4 pt");
+	XAP_appendComboBoxText(combo_offset, "1 pt");
+	XAP_appendComboBoxText(combo_offset, "1 1/2 pt");
+	XAP_appendComboBoxText(combo_offset, "2 1/4 pt");
+	XAP_appendComboBoxText(combo_offset, "3 pt");
+	XAP_appendComboBoxText(combo_offset, "4 1/2 pt");
+	XAP_appendComboBoxText(combo_offset, "6 pt");
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo_offset), 0);
 
 	// add the apply and ok buttons to the dialog
@@ -671,7 +680,11 @@ void AP_UnixDialog_Border_Shading::_connectSignals(void)
 							reinterpret_cast<gpointer>(this));
 						   
 	g_signal_connect(G_OBJECT(m_wPreviewArea),
+#if GTK_CHECK_VERSION(3,0,0)
 							"draw",
+#else
+							"expose_event",
+#endif
 							G_CALLBACK(s_preview_draw),
 							reinterpret_cast<gpointer>(this));
 
