@@ -57,14 +57,12 @@ AP_UnixDialog_FormatFootnotes::AP_UnixDialog_FormatFootnotes(XAP_DialogFactory *
 
 	m_wFootnotesStyleMenu = NULL;
 	m_wFootnoteNumberingMenu = NULL;
-	m_wFootnotesInitialValText = NULL;
 	m_wFootnoteSpin = NULL;
 	m_oFootnoteSpinAdj = NULL;
 
 	m_wEndnotesStyleMenu = NULL;
 	m_wEndnotesPlaceMenu= NULL;
 	m_wEndnotesRestartOnSection = NULL;
-	m_wEndnotesInitialValText = NULL;
 	m_wEndnoteSpin = NULL;
 	m_oEndnoteSpinAdj = NULL;
 
@@ -245,7 +243,7 @@ void AP_UnixDialog_FormatFootnotes::event_MenuFootnoteChange(GtkWidget * widget)
 	int idx = gtk_combo_box_get_active(GTK_COMBO_BOX(widget));
 	switch(idx) {
 	case 0:
-		setRestartFootnoteOnPage(true);
+		setRestartFootnoteOnPage(false);
 		setRestartFootnoteOnSection(false);
 		refreshVals();
 		return;
@@ -255,7 +253,7 @@ void AP_UnixDialog_FormatFootnotes::event_MenuFootnoteChange(GtkWidget * widget)
 		refreshVals();
 		return;
 	case 2:
-		setRestartFootnoteOnPage(false);
+		setRestartFootnoteOnPage(true);
 		setRestartFootnoteOnSection(false);
 		refreshVals();
 		return;
@@ -272,13 +270,13 @@ void AP_UnixDialog_FormatFootnotes::event_MenuEndnoteChange(GtkWidget * widget)
 	int idx = gtk_combo_box_get_active(GTK_COMBO_BOX(widget));
 	switch(idx) {
 	case 0:
-		setPlaceAtSecEnd(false);
 		setPlaceAtDocEnd(true);
+		setPlaceAtSecEnd(false);
 		refreshVals();
 		return;
 	case 1:
-		setPlaceAtSecEnd(true);
 		setPlaceAtDocEnd(false);
+		setPlaceAtSecEnd(true);
 		refreshVals();
 		return;
 	}
@@ -292,13 +290,8 @@ void AP_UnixDialog_FormatFootnotes::event_MenuEndnoteChange(GtkWidget * widget)
 */
 void  AP_UnixDialog_FormatFootnotes::refreshVals(void)
 {
-	UT_String sVal;
-	getFootnoteValString(sVal);
-	gtk_label_set_text(GTK_LABEL(m_wFootnotesInitialValText),sVal.c_str());
-
-	getEndnoteValString(sVal);
-	gtk_label_set_text(GTK_LABEL(m_wEndnotesInitialValText),sVal.c_str());
-
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_wFootnoteSpin), getFootnoteVal());
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_wEndnoteSpin), getEndnoteVal());
 
 	XAP_GtkSignalBlocker b1(G_OBJECT(m_wEndnotesRestartOnSection), 
 							m_EndRestartSectionID);
@@ -322,11 +315,11 @@ void  AP_UnixDialog_FormatFootnotes::refreshVals(void)
 
 	if(getPlaceAtDocEnd())
 	{
-		gtk_combo_box_set_active(GTK_COMBO_BOX(m_wEndnotesPlaceMenu),1);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(m_wEndnotesPlaceMenu),0);
 	}
 	else if(getPlaceAtSecEnd())
 	{
-		gtk_combo_box_set_active(GTK_COMBO_BOX(m_wEndnotesPlaceMenu),0);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(m_wEndnotesPlaceMenu),1);
 	}
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wEndnotesRestartOnSection), static_cast<gboolean>(getRestartEndnoteOnSection()));
@@ -365,14 +358,18 @@ GtkWidget * AP_UnixDialog_FormatFootnotes::_constructWindow(void)
 	GtkWidget * window;
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 	
-    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_FormatFootnotes.xml");
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_FormatFootnotes.ui");
+#else
+	GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_FormatFootnotes-2.ui");
+#endif
 
 	// might need to be queried or altered later
 	window = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_FormatFootnotes"));
 	// set the dialog title
-    std::string s;
+	std::string s;
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_Title,s);
-	abiDialogSetTitle(window, s.c_str());
+	abiDialogSetTitle(window, "%s", s.c_str());
 	
 	// localize the strings in our dialog, and set tags for some widgets
 	
@@ -417,27 +414,29 @@ GtkWidget * AP_UnixDialog_FormatFootnotes::_constructWindow(void)
 //
 // Footnotes number menu
 //
-	m_wFootnoteNumberingMenu = GTK_COMBO_BOX_TEXT(gtk_builder_get_object(builder, "omNumbering"));
+	m_wFootnoteNumberingMenu = GTK_COMBO_BOX(gtk_builder_get_object(builder, "omNumbering"));
 	UT_ASSERT(m_wFootnoteNumberingMenu );
+	XAP_makeGtkComboBoxText(m_wFootnoteNumberingMenu, G_TYPE_NONE);
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_FootRestartNone,s);
-	gtk_combo_box_text_append_text(m_wFootnoteNumberingMenu, s.c_str());
+	XAP_appendComboBoxText(m_wFootnoteNumberingMenu, s.c_str());
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_FootRestartSec,s);
-	gtk_combo_box_text_append_text(m_wFootnoteNumberingMenu, s.c_str());
+	XAP_appendComboBoxText(m_wFootnoteNumberingMenu, s.c_str());
 
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_FootRestartPage,s);
-	gtk_combo_box_text_append_text(m_wFootnoteNumberingMenu, s.c_str());
+	XAP_appendComboBoxText(m_wFootnoteNumberingMenu, s.c_str());
 //	m_wFootnotesRestartOnPage = gtk_menu_item_new_with_label (s.utf8_str());
 
 
 //
 // Endnotes placement menu
 //
-	m_wEndnotesPlaceMenu = GTK_COMBO_BOX_TEXT(gtk_builder_get_object(builder, "omEndnotePlacement"));
+	m_wEndnotesPlaceMenu = GTK_COMBO_BOX(gtk_builder_get_object(builder, "omEndnotePlacement"));
 	UT_ASSERT(m_wEndnotesPlaceMenu );
-	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_EndPlaceEndSec,s);
-	gtk_combo_box_text_append_text(m_wEndnotesPlaceMenu, s.c_str());
+	XAP_makeGtkComboBoxText(m_wEndnotesPlaceMenu, G_TYPE_NONE);
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_EndPlaceEndDoc,s);
-	gtk_combo_box_text_append_text(m_wEndnotesPlaceMenu, s.c_str());
+	XAP_appendComboBoxText(m_wEndnotesPlaceMenu, s.c_str());
+	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatFootnotes_EndPlaceEndSec,s);
+	XAP_appendComboBoxText(m_wEndnotesPlaceMenu, s.c_str());
 
 //
 // Now grab widgets for the remaining controls.
@@ -446,8 +445,6 @@ GtkWidget * AP_UnixDialog_FormatFootnotes::_constructWindow(void)
 	UT_ASSERT(m_wEndnotesRestartOnSection );
 // Endnote Initial Value Control
 
-	m_wEndnotesInitialValText = GTK_WIDGET(gtk_builder_get_object(builder, "endSpinValueText"));
-	UT_ASSERT(m_wEndnotesInitialValText );
 	m_wEndnoteSpin = GTK_WIDGET(gtk_builder_get_object(builder, "endnoteSpin"));
 	m_oEndnoteSpinAdj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(m_wEndnoteSpin));
 
@@ -456,8 +453,6 @@ GtkWidget * AP_UnixDialog_FormatFootnotes::_constructWindow(void)
 	m_wFootnoteSpin = GTK_WIDGET(gtk_builder_get_object(builder, "footnoteSpin"));
 	UT_ASSERT(m_wFootnoteSpin );
 	m_oFootnoteSpinAdj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(m_wFootnoteSpin));
-	m_wFootnotesInitialValText = GTK_WIDGET(gtk_builder_get_object(builder, "footSpinValueText"));
-	UT_ASSERT(m_wFootnotesInitialValText );
 	_connectSignals();
 	refreshVals();
 
