@@ -25,6 +25,7 @@
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "ut_string.h"
+#include "pt_PieceTable.h"
 #include "xap_UnixDialogHelper.h"
 #include "xap_GtkComboBoxHelpers.h"
 
@@ -157,6 +158,17 @@ static void s_response_triggered(GtkWidget * widget, gint resp, AP_UnixDialog_Fo
 	  abiDestroyWidget(widget);
 }
 
+static gboolean s_Text_changed (GtkWidget *widget, GdkEvent */*event*/, AP_UnixDialog_FormatTOC *me)
+{
+	UT_UTF8String sVal(gtk_entry_get_text(GTK_ENTRY(widget)));
+	UT_UTF8String sProp;
+	sProp = static_cast<const char *>(g_object_get_data(G_OBJECT(widget), "toc-prop"));
+	UT_String sNum = UT_String_sprintf("%d", me->getDetailsLevel());
+	sProp += sNum.c_str();
+	me->setTOCProperty(sProp, sVal);
+	return FALSE;
+}
+
 XAP_Dialog * AP_UnixDialog_FormatTOC::static_constructor(XAP_DialogFactory * pFactory,
 														  XAP_Dialog_Id id)
 {
@@ -204,19 +216,13 @@ void AP_UnixDialog_FormatTOC::setStyle(GtkWidget * wid)
 		sProp += sNum.c_str();
 	}
 	sVal = getNewStyle(sProp);
-	gtk_label_set_text(GTK_LABEL(pLabel),sVal.utf8_str());
 	setTOCProperty(sProp,sVal);
 	applyTOCPropsToDoc();
 }
 
 void AP_UnixDialog_FormatTOC::setSensitivity(bool bSensitive)
 {
-	gboolean gSensitive = TRUE;
-	if(!bSensitive)
-	{
-		gSensitive = FALSE;
-	}
-	gtk_widget_set_sensitive (m_wApply,gSensitive);
+	gtk_widget_set_sensitive (m_wApply, bSensitive ? TRUE : FALSE);
 }
 
 void AP_UnixDialog_FormatTOC::destroy(void)
@@ -333,6 +339,7 @@ void AP_UnixDialog_FormatTOC::runModeless(XAP_Frame * pFrame)
 	_connectSignals();
 	abiSetupModelessDialog(GTK_DIALOG(mainWindow),pFrame,this,GTK_RESPONSE_CLOSE);
 	startUpdater();
+	s_DetailsLevel_changed(_getWidget("wDetailsLevel"), this);
 }
 
 GtkWidget * AP_UnixDialog_FormatTOC::_getWidget(const char * szNameBase, UT_sint32 iLevel)
@@ -350,7 +357,11 @@ GtkWidget * AP_UnixDialog_FormatTOC::_getWidget(const char * szNameBase, UT_sint
 
 GtkWidget * AP_UnixDialog_FormatTOC::_constructWindow(void)
 {
-    m_pBuilder = newDialogBuilder("ap_UnixDialog_FormatTOC.xml");
+#if GTK_CHECK_VERSION(3,0,0)
+    m_pBuilder = newDialogBuilder("ap_UnixDialog_FormatTOC.ui");
+#else
+    m_pBuilder = newDialogBuilder("ap_UnixDialog_FormatTOC-2.ui");
+#endif
 	
 	const XAP_StringSet * pSS = m_pApp->getStringSet ();
 
@@ -361,7 +372,7 @@ GtkWidget * AP_UnixDialog_FormatTOC::_constructWindow(void)
 	// set the dialog title
 	UT_UTF8String s;
 	pSS->getValueUTF8(AP_STRING_ID_DLG_FormatTOC_Title,s);
-	abiDialogSetTitle(m_windowMain, s.utf8_str());
+	abiDialogSetTitle(m_windowMain, "%s", s.utf8_str());
 
 // localize notebook tabs
 	localizeLabel(_getWidget( "lbGeneral"), pSS, AP_STRING_ID_DLG_FormatTOC_General);
@@ -407,10 +418,11 @@ GtkWidget * AP_UnixDialog_FormatTOC::_constructWindow(void)
 void AP_UnixDialog_FormatTOC::setMainLevel(UT_sint32 iLevel)
 {
 	AP_Dialog_FormatTOC::setMainLevel(iLevel);
-	UT_UTF8String sVal;
+	UT_UTF8String sVal, sLoc;
 	sVal = getTOCPropVal("toc-dest-style",getMainLevel());
 	GtkWidget * pW= _getWidget("wDispStyle");
-	gtk_label_set_text(GTK_LABEL(pW),sVal.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sVal.utf8_str(), sLoc);
+	gtk_label_set_text(GTK_LABEL(pW), sLoc.utf8_str());
 
 
 	sVal = getTOCPropVal("toc-has-label",getMainLevel());
@@ -426,7 +438,8 @@ void AP_UnixDialog_FormatTOC::setMainLevel(UT_sint32 iLevel)
 
 	sVal = getTOCPropVal("toc-source-style",getMainLevel());
 	pW = _getWidget("wFillStyle");
-	gtk_label_set_text(GTK_LABEL(pW),sVal.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sVal.utf8_str(), sLoc);
+	gtk_label_set_text(GTK_LABEL(pW), sLoc.utf8_str());
 }
 
 
@@ -623,7 +636,7 @@ void  AP_UnixDialog_FormatTOC::event_Apply(void)
  */
 void  AP_UnixDialog_FormatTOC::_fillGUI(void)
 {
-	UT_UTF8String sVal;
+	UT_UTF8String sVal, sLoc;
 	sVal = getTOCPropVal("toc-has-heading");
 
 	GtkWidget * pW;
@@ -655,7 +668,8 @@ void  AP_UnixDialog_FormatTOC::_fillGUI(void)
 
 	sVal = getTOCPropVal("toc-heading-style");
 	pW = _getWidget("lbCurrentHeadingStyle");
-	gtk_label_set_text(GTK_LABEL(pW),sVal.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sVal.utf8_str(), sLoc);
+	gtk_label_set_text(GTK_LABEL(pW), sLoc.utf8_str());
 	g_object_set_data(G_OBJECT(_getWidget("lbChangeHeadingStyle")),"display-widget",(gpointer)pW);
 	g_object_set_data(G_OBJECT(pW),"toc-prop",(gpointer) "toc-heading-style");
 
@@ -664,7 +678,8 @@ void  AP_UnixDialog_FormatTOC::_fillGUI(void)
 
 	sVal = getTOCPropVal("toc-dest-style",getMainLevel());
 	pW= _getWidget("wDispStyle");
-	gtk_label_set_text(GTK_LABEL(pW),sVal.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sVal.utf8_str(), sLoc);
+	gtk_label_set_text(GTK_LABEL(pW), sLoc.utf8_str());
 	g_object_set_data(G_OBJECT(_getWidget("wChangeDisp")),"display-widget",(gpointer)pW);
 	g_object_set_data(G_OBJECT(pW),"toc-prop",(gpointer) "toc-dest-style");
 
@@ -745,7 +760,8 @@ void  AP_UnixDialog_FormatTOC::_fillGUI(void)
 
 	sVal = getTOCPropVal("toc-source-style",getMainLevel());
 	pW = _getWidget("wFillStyle");
-	gtk_label_set_text(GTK_LABEL(pW),sVal.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sVal.utf8_str(), sLoc);
+	gtk_label_set_text(GTK_LABEL(pW), sLoc.utf8_str());
 	g_object_set_data(G_OBJECT(_getWidget("wChangeFill")),"display-widget",(gpointer)pW);
 	g_object_set_data(G_OBJECT(pW),"toc-prop",(gpointer) "toc-source-style");
 
@@ -828,4 +844,12 @@ void  AP_UnixDialog_FormatTOC::_connectSignals(void)
 					 "changed",
 					 G_CALLBACK(s_TabLeader_changed),
 					 (gpointer) this);
+	g_signal_connect(G_OBJECT(_getWidget("edTextBefore")),
+					 "focus-out-event",
+					 G_CALLBACK(s_Text_changed),
+					 (gpointer) this);
+	g_signal_connect(G_OBJECT(_getWidget("edTextAfter")),
+					 "focus-out-event",
+					 G_CALLBACK(s_Text_changed),
+					 (gpointer) this);
 }
