@@ -29,6 +29,7 @@
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "xap_UnixDialogHelper.h"
+#include "xap_GtkSignalBlocker.h"
 
 #include "xap_Dialog_Id.h"
 #include "xap_UnixApp.h"
@@ -42,6 +43,22 @@
 #include "GTKCommon.h"
 
 
+static void AP_UnixDialog_Goto__onSwitchPage (GtkNotebook *notebook,
+											  gpointer Page,
+											  guint page,
+											  gpointer data)
+{
+	UT_UNUSED(notebook);
+	UT_UNUSED(Page);
+	UT_DEBUGMSG(("_onSwitchPage() '%d'\n", page));
+
+	if (page == 0)
+	{
+		AP_UnixDialog_Goto *dlg = static_cast<AP_UnixDialog_Goto *>(data);
+		dlg->updatePosition();
+	}
+}
+
 /*!
 * Event dispatcher for spinbutton "page".
 */
@@ -106,6 +123,20 @@ AP_UnixDialog_Goto__onFocusXMLIDs (GtkWidget 	   * /*widget*/,
 	/* propagate further */
 	return FALSE;
 }
+gboolean 
+AP_UnixDialog_Goto__onFocusAnno (GtkWidget 	   * /*widget*/,
+                                 GdkEventFocus    *event,
+                                 gpointer 		   data) 
+{
+	UT_DEBUGMSG (("MIQ: _onFocusAnno () '%d', '%d'\n", event->type, event->in));
+	if (event->type == GDK_FOCUS_CHANGE && event->in)
+    {
+		AP_UnixDialog_Goto *dlg = static_cast <AP_UnixDialog_Goto *>(data);
+		dlg->updateCache (AP_JUMPTARGET_ANNOTATION);
+	}
+	/* propagate further */
+	return FALSE;
+}
 
 /*!
 * Event dispatcher for spinbutton "page".
@@ -150,6 +181,15 @@ AP_UnixDialog_Goto__onXMLIDDblClicked (GtkTreeView       * /*tree*/,
 	AP_UnixDialog_Goto *dlg = static_cast <AP_UnixDialog_Goto *>(data);
 	dlg->onXMLIDDblClicked ();
 }
+void
+AP_UnixDialog_Goto__onAnnoDblClicked (GtkTreeView       * /*tree*/,
+                                      GtkTreePath       * /*path*/,
+                                      GtkTreeViewColumn * /*col*/,
+                                      gpointer		    data)
+{
+	AP_UnixDialog_Goto *dlg = static_cast <AP_UnixDialog_Goto *>(data);
+	dlg->onAnnoDblClicked ();
+}
 
 /*!
 * Event dispatcher for button "jump".
@@ -233,9 +273,12 @@ AP_UnixDialog_Goto::AP_UnixDialog_Goto(XAP_DialogFactory *pDlgFactory,
 									   XAP_Dialog_Id 	 id)
 	: AP_Dialog_Goto   (pDlgFactory, id), 
 	  m_wDialog 	   (NULL),
+	  m_nbNotebook	   (NULL),
 	  m_lbPage		   (NULL),
 	  m_lbLine		   (NULL),
 	  m_lbBookmarks    (NULL),
+	  m_lbXMLids	   (NULL),
+	  m_lbAnnotations  (NULL),
 	  m_sbPage		   (NULL),
 	  m_sbLine		   (NULL),
 	  m_lvBookmarks	   (NULL),
@@ -243,7 +286,10 @@ AP_UnixDialog_Goto::AP_UnixDialog_Goto(XAP_DialogFactory *pDlgFactory,
 	  m_btPrev		   (NULL),
 	  m_btNext		   (NULL),
       m_lvXMLIDs       (0),
+      m_lvAnno         (0),
 	  m_btClose 	   (NULL), 
+	  m_iPageConnect (0),
+	  m_iLineConnect (0),
 	  m_JumpTarget	   (AP_JUMPTARGET_BOOKMARK)
 {
 }
@@ -285,6 +331,9 @@ AP_UnixDialog_Goto::onLineChanged ()
 	if (line > m_DocCount.line) {
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbLine), 1);
 	}
+	if (line == 0) {
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbLine), m_DocCount.line);
+	}
 	onJumpClicked();
 }
 
@@ -303,6 +352,12 @@ AP_UnixDialog_Goto::onXMLIDDblClicked ()
 	m_JumpTarget = AP_JUMPTARGET_XMLID;
 	onJumpClicked();
 }
+void
+AP_UnixDialog_Goto::onAnnoDblClicked ()
+{
+	m_JumpTarget = AP_JUMPTARGET_ANNOTATION;
+	onJumpClicked();
+}
 
 /*!
 * Event handler for button "jump".
@@ -310,14 +365,17 @@ AP_UnixDialog_Goto::onXMLIDDblClicked ()
 void 
 AP_UnixDialog_Goto::onJumpClicked () 
 {
-    std::string text = "";
+    std::string text;
+    XAP_GtkSignalBlocker b(G_OBJECT(m_sbLine), m_iLineConnect);
 
 	switch (m_JumpTarget) {
 		case AP_JUMPTARGET_PAGE:
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_sbLine), 0);
 			text = tostr(GTK_ENTRY (m_sbPage));
 			break;
 		case AP_JUMPTARGET_LINE:
 			text = tostr(GTK_ENTRY (m_sbLine));
+			if (text == "0") return;
 			break;
 		case AP_JUMPTARGET_BOOKMARK:
 			text = _getSelectedBookmarkLabel ();
@@ -325,6 +383,9 @@ AP_UnixDialog_Goto::onJumpClicked ()
 		case AP_JUMPTARGET_XMLID:
 			text = _getSelectedXMLIDLabel();
 			break;
+		case AP_JUMPTARGET_ANNOTATION:
+			text = _getSelectedAnnotationLabel();
+			break;
 		default:
 			UT_DEBUGMSG (("AP_UnixDialog_Goto::onJumpClicked () no jump target\n"));
 			return;
@@ -369,6 +430,9 @@ AP_UnixDialog_Goto::onPrevClicked ()
 		case AP_JUMPTARGET_XMLID:
             selectPrev(GTK_TREE_VIEW (m_lvXMLIDs));
 			break;
+		case AP_JUMPTARGET_ANNOTATION:
+            selectPrev(GTK_TREE_VIEW (m_lvAnno));
+			break;
 		default:
 			UT_DEBUGMSG (("ROB: AP_UnixDialog_Goto::onPrevClicked () no jump target\n"));
 			return;
@@ -404,6 +468,9 @@ AP_UnixDialog_Goto::onNextClicked ()
 		case AP_JUMPTARGET_XMLID:
             selectNext(GTK_TREE_VIEW (m_lvXMLIDs));
 			break;
+		case AP_JUMPTARGET_ANNOTATION:
+            selectNext(GTK_TREE_VIEW (m_lvAnno));
+			break;
 		default:
 			UT_DEBUGMSG (("ROB: AP_UnixDialog_Goto::onNextClicked () no jump target\n"));
 			return;
@@ -434,6 +501,19 @@ AP_UnixDialog_Goto::updateDocCount ()
 	UT_DEBUGMSG (("ROB: updateCache () page='%d' line='%d'\n", m_DocCount.page, m_DocCount.line));
 }
 
+void AP_UnixDialog_Goto::updatePosition (void)
+{
+	// pages, page increment of 10 is pretty arbitrary (set in the GtkBuilder UI file)
+	UT_uint32 currentPage = getView()->getCurrentPageNumForStatusBar ();
+	XAP_GtkSignalBlocker b1(G_OBJECT(m_sbPage), m_iPageConnect);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbPage), currentPage);
+
+	// lines, line increment of 10 is pretty arbitrary (set in the GtkBuilder UI file)
+	UT_uint32 currentLine = 0; /* FIXME get current line */
+	XAP_GtkSignalBlocker b2(G_OBJECT(m_sbLine), m_iLineConnect);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbLine), currentLine);
+}
+
 void
 AP_UnixDialog_Goto::setupXMLIDList( GtkWidget* w )
 {
@@ -459,26 +539,81 @@ AP_UnixDialog_Goto::setupXMLIDList( GtkWidget* w )
 }
 
 
+void
+AP_UnixDialog_Goto::setupAnnotationList( GtkWidget* w )
+{
+	GtkTreeViewColumn *column = NULL;
+	GtkCellRenderer *renderer = NULL;
+	// Liststore and -view
+	GtkListStore *store = gtk_list_store_new ( NUM_ANNO_COLUMNS,
+                                               G_TYPE_INT,
+                                               G_TYPE_STRING, G_TYPE_STRING );
+	gtk_tree_view_set_model (GTK_TREE_VIEW (w), GTK_TREE_MODEL (store));
+	g_object_unref (G_OBJECT (store));
+
+	// localization
+	const XAP_StringSet * pSS = m_pApp->getStringSet ();
+	std::string id, title, author;
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Column_ID, id);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Column_Title, title);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Column_Author, author);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (w),
+												-1, id.c_str(), renderer,
+												"text", COLUMN_ANNO_ID,
+												NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (w), COLUMN_ANNO_ID );
+	gtk_tree_view_column_set_sort_column_id (column, COLUMN_ANNO_ID );
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (w),
+												-1, title.c_str(), renderer,
+												"text", COLUMN_ANNO_TITLE,
+												NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (w), COLUMN_ANNO_TITLE );
+	gtk_tree_view_column_set_sort_column_id (column, COLUMN_ANNO_TITLE );
+
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (w),
+												-1, author.c_str(), renderer,
+												"text", COLUMN_ANNO_AUTHOR,
+												NULL);
+	column = gtk_tree_view_get_column (GTK_TREE_VIEW (w), COLUMN_ANNO_AUTHOR );
+	gtk_tree_view_column_set_sort_column_id (column, COLUMN_ANNO_AUTHOR );
+    
+
+    
+	g_signal_connect (GTK_TREE_VIEW (w), "focus-in-event", 
+					  G_CALLBACK (AP_UnixDialog_Goto__onFocusAnno), static_cast <gpointer>(this)); 
+	g_signal_connect (GTK_TREE_VIEW (w), "row-activated", 
+					  G_CALLBACK (AP_UnixDialog_Goto__onAnnoDblClicked), static_cast <gpointer>(this));
+}
+
+
 /*!
 * Build dialog.
 */
 void 
-AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/) 
+AP_UnixDialog_Goto::_constructWindow (XAP_Frame * /*pFrame*/) 
 {
-	UT_DEBUGMSG (("ROB: constuctWindow ()\n"));		
-
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Goto.xml";
+	UT_DEBUGMSG (("ROB: _constructWindow ()\n"));		
 
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Goto.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Goto-2.ui");
+#endif
 
 	m_wDialog = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_Goto"));
+	m_nbNotebook = GTK_WIDGET(gtk_builder_get_object(builder, "nbNotebook"));
 	m_lbPage = GTK_WIDGET(gtk_builder_get_object(builder, "lbPage"));
 	m_lbLine = GTK_WIDGET(gtk_builder_get_object(builder, "lbLine"));
-	m_lbPage = GTK_WIDGET(gtk_builder_get_object(builder, "lbPage"));
 	m_lbBookmarks = GTK_WIDGET(gtk_builder_get_object(builder, "lbBookmarks"));
+	m_lbXMLids = GTK_WIDGET(gtk_builder_get_object(builder, "lbXMLids"));
+	m_lbAnnotations = GTK_WIDGET(gtk_builder_get_object(builder, "lbAnnotations"));
 	m_sbPage = GTK_WIDGET(gtk_builder_get_object(builder, "sbPage"));
 	m_sbLine = GTK_WIDGET(gtk_builder_get_object(builder, "sbLine"));
 	m_lvBookmarks = GTK_WIDGET(gtk_builder_get_object(builder, "lvBookmarks"));
@@ -486,11 +621,13 @@ AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/)
 	m_btPrev = GTK_WIDGET(gtk_builder_get_object(builder, "btPrev"));
 	m_btNext = GTK_WIDGET(gtk_builder_get_object(builder, "btNext"));
 	m_lvXMLIDs = GTK_WIDGET(gtk_builder_get_object(builder, "lvXMLIDs"));
+	m_lvAnno   = GTK_WIDGET(gtk_builder_get_object(builder, "lvAnno"));
 	m_btClose = GTK_WIDGET(gtk_builder_get_object(builder, "btClose"));
 
 
 	// localise	
-	// const XAP_StringSet * pSS = m_pApp->getStringSet ();
+	const XAP_StringSet * pSS = m_pApp->getStringSet();
+	localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lbPosition")), pSS, AP_STRING_ID_DLG_Goto_Label_Position);
 	/* FIXME jump targets localised in xp land, make sure they work for non ascii characters */
 	const gchar **targets = getJumpTargets ();
 	const gchar *text = NULL;
@@ -500,9 +637,14 @@ AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/)
 		gtk_label_set_text (GTK_LABEL (m_lbLine), text);
 	if ((text = targets[AP_JUMPTARGET_BOOKMARK]) != NULL)
 		gtk_label_set_text (GTK_LABEL (m_lbBookmarks), text);
+	if ((text = targets[AP_JUMPTARGET_XMLID]) != NULL)
+		gtk_label_set_text (GTK_LABEL (m_lbXMLids), text);
+	if ((text = targets[AP_JUMPTARGET_ANNOTATION]) != NULL)
+		gtk_label_set_text (GTK_LABEL (m_lbAnnotations), text);
 
 
     setupXMLIDList( m_lvXMLIDs );
+    setupAnnotationList( m_lvAnno );
     
 	// Liststore and -view
 	GtkListStore *store = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING);
@@ -520,14 +662,16 @@ AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/)
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_NAME);
 
 	// Signals
+	g_signal_connect (GTK_NOTEBOOK (m_nbNotebook), "switch-page", 
+					  G_CALLBACK (AP_UnixDialog_Goto__onSwitchPage), static_cast <gpointer>(this)); 
 	g_signal_connect (GTK_SPIN_BUTTON (m_sbPage), "focus-in-event", 
 					  G_CALLBACK (AP_UnixDialog_Goto__onFocusPage), static_cast <gpointer>(this)); 
-	g_signal_connect (GTK_SPIN_BUTTON (m_sbPage), "value-changed", 
+	m_iPageConnect = g_signal_connect (GTK_SPIN_BUTTON (m_sbPage), "value-changed",
 					  G_CALLBACK (AP_UnixDialog_Goto__onPageChanged), static_cast <gpointer>(this)); 
 
 	g_signal_connect (GTK_SPIN_BUTTON (m_sbLine), "focus-in-event", 
 					  G_CALLBACK (AP_UnixDialog_Goto__onFocusLine), static_cast <gpointer>(this)); 
-	g_signal_connect (GTK_SPIN_BUTTON (m_sbLine), "value-changed", 
+	m_iLineConnect = g_signal_connect (GTK_SPIN_BUTTON (m_sbLine), "value-changed",
 					  G_CALLBACK (AP_UnixDialog_Goto__onLineChanged), static_cast <gpointer>(this)); 
 
 	g_signal_connect (GTK_TREE_VIEW (m_lvBookmarks), "focus-in-event", 
@@ -554,21 +698,16 @@ AP_UnixDialog_Goto::constuctWindow (XAP_Frame * /*pFrame*/)
 * Update dialog's data.
 */
 void 
-AP_UnixDialog_Goto::updateWindow ()
+AP_UnixDialog_Goto::_updateWindow ()
 {
-	UT_DEBUGMSG (("ROB: updateWindow () #bookmarks='%d', mapped='%d'\n", getExistingBookmarksCount(), gtk_widget_get_mapped(m_wDialog)));
+	UT_DEBUGMSG (("ROB: _updateWindow () #bookmarks='%d', mapped='%d'\n", getExistingBookmarksCount(), gtk_widget_get_mapped(m_wDialog)));
 
 	ConstructWindowName ();
 	gtk_window_set_title (GTK_WINDOW (m_wDialog), m_WindowName);
 
-	// pages, page increment of 10 is pretty arbitrary (set in the GtkBuilder UI file)
-	UT_uint32 currentPage = getView()->getCurrentPageNumForStatusBar ();
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbPage), currentPage);
+	// position: pages and lines
+	updatePosition();
 
-	// lines, line increment of 10 is pretty arbitrary (set in the GtkBuilder UI file)
-	UT_uint32 currentLine = 1; /* FIXME get current line */
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (m_sbLine), currentLine);
-	
 	// bookmarks, detaching model for faster updates
 	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (m_lvBookmarks));
 	g_object_ref (G_OBJECT (model));
@@ -580,10 +719,10 @@ AP_UnixDialog_Goto::updateWindow ()
 	for (UT_uint32 i = 0; i < numBookmarks; i++) {
 
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		const gchar *name = getNthExistingBookmark(i);
-		UT_DEBUGMSG (("    ROB: '%s'\n", name));
+		const std::string & name = getNthExistingBookmark(i);
+		UT_DEBUGMSG (("    ROB: '%s'\n", name.c_str()));
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
-							COLUMN_NAME, name, /* 
+							COLUMN_NAME, name.c_str(), /* 
 							COLUMN_PAGE, "0", 
 							COLUMN_NUMBER, 0, */
 							-1);
@@ -592,6 +731,7 @@ AP_UnixDialog_Goto::updateWindow ()
 	g_object_unref (G_OBJECT (model));
 
     updateXMLIDList( m_lvXMLIDs );
+    updateAnnotationList( m_lvAnno );
 	updateDocCount ();
 }
 
@@ -610,7 +750,7 @@ AP_UnixDialog_Goto::updateXMLIDList( GtkWidget* w )
         GtkTreeIter iter;
         std::set< std::string > xmlids;
         rdf->getAllIDs( xmlids );
-        UT_DEBUGMSG (("MIQ: xmlids.sz:%d\n", xmlids.size() ));
+        UT_DEBUGMSG (("MIQ: xmlids.sz:%lu\n", (long unsigned)xmlids.size() ));
 
         for( std::set< std::string >::iterator xiter = xmlids.begin();
              xiter != xmlids.end(); ++xiter )
@@ -629,14 +769,47 @@ AP_UnixDialog_Goto::updateXMLIDList( GtkWidget* w )
 }
 
 
+void
+AP_UnixDialog_Goto::updateAnnotationList( GtkWidget* w )
+{
+	// detaching model for faster updates
+	GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (w));
+	g_object_ref (G_OBJECT (model));
+	gtk_tree_view_set_model (GTK_TREE_VIEW (w), NULL);
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+
+    GtkTreeIter iter;
+    FV_View* pView = getView();
+	UT_uint32 max = pView->countAnnotations();
+    for( UT_uint32 i=0; i<max; ++i )
+    {
+        gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+        std::string name   = tostr(i);
+        std::string title  = pView->getAnnotationTitle(i);
+        std::string author = pView->getAnnotationAuthor(i);
+        
+        UT_DEBUGMSG (("    MIQ: '%s'\n", name.c_str()));
+        gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
+                            COLUMN_ANNO_ID,     i,
+                            COLUMN_ANNO_TITLE,  title.c_str(),
+                            COLUMN_ANNO_AUTHOR, author.c_str(),
+                            -1);
+    }
+    
+	gtk_tree_view_set_model (GTK_TREE_VIEW (w), model);
+	g_object_unref (G_OBJECT (model));
+    
+}
+
+
 
 void 
 AP_UnixDialog_Goto::runModeless (XAP_Frame * pFrame)
 {
 	UT_DEBUGMSG (("ROB: runModeless ()\n"));
-	constuctWindow (pFrame);
+	_constructWindow (pFrame);
 	UT_ASSERT (m_wDialog);
-	updateWindow ();
+	_updateWindow ();
 	abiSetupModelessDialog (GTK_DIALOG (m_wDialog), pFrame, this, GTK_RESPONSE_CLOSE);
 	gtk_widget_show_all (m_wDialog);
 	gtk_window_present (GTK_WINDOW (m_wDialog));
@@ -648,7 +821,7 @@ AP_UnixDialog_Goto::notifyActiveFrame (XAP_Frame * /*pFrame*/)
 	UT_DEBUGMSG (("ROB: notifyActiveFrame ()\n"));
 	UT_ASSERT (m_wDialog);
 
-	updateWindow ();
+	_updateWindow ();
 	/* default to page */
 	m_JumpTarget = AP_JUMPTARGET_PAGE;
 }
@@ -658,7 +831,7 @@ AP_UnixDialog_Goto::activate (void)
 {
 	UT_ASSERT (m_wDialog);
 	UT_DEBUGMSG (("ROB: AP_UnixDialog_Goto::activate ()\n"));
-	updateWindow ();
+	_updateWindow ();
 	gtk_window_present (GTK_WINDOW (m_wDialog));
 }
 
@@ -717,3 +890,11 @@ AP_UnixDialog_Goto::_getSelectedXMLIDLabel()
 	return ret;
 }
 
+std::string
+AP_UnixDialog_Goto::_getSelectedAnnotationLabel()
+{
+	UT_DEBUGMSG (("MIQ: AP_UnixDialog_Goto::_getSelectedAnnotationLabel ()\n"));
+    std::string ret = tostr(getSelectedUInt( GTK_TREE_VIEW (m_lvAnno), COLUMN_ANNO_ID ));
+	return ret;
+}
+
