@@ -31,6 +31,7 @@
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_App.h"
 #include "xap_UnixApp.h"
@@ -186,6 +187,9 @@ GtkWidget*  AP_UnixDialog_InsertBookmark::_constructWindow(void)
   pSS->getValueUTF8(AP_STRING_ID_DLG_InsertBookmark_Title,s);
   
   m_windowMain = abiDialogNew("insert bookmark dialog", TRUE, s.utf8_str());
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_dialog_set_has_separator(GTK_DIALOG(m_windowMain), FALSE);
+#endif
 
   
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -199,6 +203,8 @@ GtkWidget*  AP_UnixDialog_InsertBookmark::_constructWindow(void)
   abiAddStockButton(GTK_DIALOG(m_windowMain), GTK_STOCK_DELETE, BUTTON_DELETE);
   m_buttonInsert = abiAddButton(GTK_DIALOG(m_windowMain), "", BUTTON_INSERT);
   localizeButtonUnderline (m_buttonInsert, pSS, AP_STRING_ID_DLG_InsertButton);
+  GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_OK, GTK_ICON_SIZE_BUTTON);
+  gtk_button_set_image(GTK_BUTTON(m_buttonInsert), img);      
 
   gtk_widget_grab_focus (m_comboBookmark);
 
