@@ -28,6 +28,7 @@
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_App.h"
 #include "xap_UnixApp.h"
@@ -54,14 +55,12 @@ AP_UnixDialog_InsertHyperlink::AP_UnixDialog_InsertHyperlink(XAP_DialogFactory *
 	m_windowMain = 0;
 	//m_comboEntry = 0;
 	m_clist = 0;
-	m_pBookmarks = 0;
 	m_iRow = -1;
 	m_entry = 0;
 }
 
 AP_UnixDialog_InsertHyperlink::~AP_UnixDialog_InsertHyperlink(void)
 {
-  DELETEPV(m_pBookmarks);
 }
 
 /*****************************************************************/
@@ -77,7 +76,7 @@ static void s_blist_clicked(GtkTreeSelection * select,
 		if(rows) {
 			me->setRow(*rows);
 			gtk_entry_set_text(GTK_ENTRY(me->m_entry), 
-							   me->m_pBookmarks[*rows]);
+					   me->m_pBookmarks[*rows].c_str());
 		}
 	}
 }
@@ -137,7 +136,7 @@ void AP_UnixDialog_InsertHyperlink::_constructWindowContents ( GtkWidget * vbox2
   pSS->getValueUTF8(AP_STRING_ID_DLG_InsertHyperlink_Msg,s);
   label1 = gtk_label_new (s.utf8_str());
   gtk_widget_show (label1);
-  gtk_box_pack_start (GTK_BOX (vbox2), label1, TRUE, FALSE, 3);
+  gtk_box_pack_start (GTK_BOX (vbox2), label1, FALSE, FALSE, 3);
 
   m_entry = gtk_entry_new();
   gtk_box_pack_start (GTK_BOX (vbox2), m_entry, FALSE, FALSE, 0);
@@ -161,7 +160,7 @@ void AP_UnixDialog_InsertHyperlink::_constructWindowContents ( GtkWidget * vbox2
   m_swindow  = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (m_swindow),GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_widget_show(m_swindow);
-  gtk_box_pack_start (GTK_BOX (vbox2), m_swindow, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox2), m_swindow, TRUE, TRUE, 0);
    
   GtkListStore * store = gtk_list_store_new(1, G_TYPE_STRING);
 
@@ -179,21 +178,18 @@ void AP_UnixDialog_InsertHyperlink::_constructWindowContents ( GtkWidget * vbox2
   gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
   //gtk_box_pack_start (GTK_BOX (vbox2), m_blist, FALSE, FALSE, 0);
 
-  DELETEPV(m_pBookmarks);
-  m_pBookmarks = new const gchar *[getExistingBookmarksCount()];
+  m_pBookmarks.clear();
 	
-  for (int i = 0; i < static_cast<int>(getExistingBookmarksCount()); i++)
-  	  m_pBookmarks[i] = getNthExistingBookmark(i);
+  for (int i = 0; i < static_cast<int>(getExistingBookmarksCount()); i++) {
+    m_pBookmarks.push_back(getNthExistingBookmark(i));
+  }
 
-  int (*my_cmp)(const void *, const void *) =
-  	  (int (*)(const void*, const void*)) strcmp;
-    	
-  qsort(m_pBookmarks, getExistingBookmarksCount(),sizeof(gchar*),my_cmp);
+  std::sort(m_pBookmarks.begin(), m_pBookmarks.end());
 
   for (int i = 0; i < static_cast<int>(getExistingBookmarksCount()); i++) {
 		  GtkTreeIter iter;
 		  gtk_list_store_append(store, &iter);
-		  gtk_list_store_set(store, &iter, 0, m_pBookmarks[i], -1);
+		  gtk_list_store_set(store, &iter, 0, m_pBookmarks[i].c_str(), -1);
   }
 
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(m_swindow),m_clist);
@@ -209,10 +205,13 @@ GtkWidget*  AP_UnixDialog_InsertHyperlink::_constructWindow(void)
   UT_UTF8String s;
   pSS->getValueUTF8(AP_STRING_ID_DLG_InsertHyperlink_Title,s);
   m_windowMain = abiDialogNew("insert table dialog", TRUE, s.utf8_str());
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_dialog_set_has_separator(GTK_DIALOG(m_windowMain), FALSE);
+#endif
 
   frame1 = gtk_frame_new (NULL);
   gtk_widget_show (frame1);
-  gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(m_windowMain))), frame1);
+  gtk_box_pack_start(GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG(m_windowMain))), frame1,true,true,0);
   gtk_container_set_border_width (GTK_CONTAINER (frame1), 4);
   gtk_frame_set_shadow_type(GTK_FRAME(frame1), GTK_SHADOW_NONE);
 
