@@ -27,6 +27,7 @@
 #include "ut_debugmsg.h"
 #include "xap_UnixDialogHelper.h"
 #include "xap_GtkSignalBlocker.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_Dialog_Id.h"
 #include "xap_UnixApp.h"
@@ -80,12 +81,14 @@ static void s_customChanged (GtkWidget * /*widget*/, AP_UnixDialog_Lists * me)
 
 static void s_FoldCheck_changed(GtkWidget * widget, AP_UnixDialog_Lists * me)
 {
-	UT_DEBUGMSG(("Doing s_FoldCheck_changed \n"));
-	UT_UTF8String sLevel = static_cast<char *> (g_object_get_data(G_OBJECT(widget),"level"));
-	UT_sint32 iLevel = atoi(sLevel.utf8_str());
-	gboolean iVal =  gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
-	bool bSet = (iVal == TRUE);
-	me->setFoldLevel(iLevel,bSet);
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
+	{
+		UT_DEBUGMSG(("Doing s_FoldCheck_changed \n"));
+		UT_UTF8String sLevel = static_cast<char *> 
+			(g_object_get_data(G_OBJECT(widget),"level"));
+		UT_sint32 iLevel = atoi(sLevel.utf8_str());
+		me->setFoldLevel(iLevel, true);
+	}
 }
 
 static void s_styleChanged(GtkWidget * w, AP_UnixDialog_Lists * me)
@@ -153,6 +156,7 @@ static void s_closeClicked (GtkWidget * /*widget*/, AP_UnixDialog_Lists * me)
 
 static gboolean s_preview_draw(GtkWidget * widget, gpointer /* data */, AP_UnixDialog_Lists * me)
 {
+	UT_DEBUG_ONLY_ARG(widget);
 	UT_ASSERT(widget && me);
 	me->previewExposed();
 	return FALSE;
@@ -194,9 +198,6 @@ void AP_UnixDialog_Lists::runModal( XAP_Frame * pFrame)
 	savedListType = getNewListType();
 
 	// *** this is how we add the gc for Lists Preview ***
-	// attach a new graphics context to the drawing area
-	XAP_UnixApp * unixapp = static_cast<XAP_UnixApp *> (m_pApp);
-	UT_ASSERT(unixapp);
 
 	// Now Display the dialog, so m_wPreviewArea->window exists
 	gtk_widget_show(m_wMainWindow);	
@@ -247,9 +248,6 @@ void AP_UnixDialog_Lists::runModeless (XAP_Frame * pFrame)
 	gtk_widget_show(m_wMainWindow);
 
 	// *** this is how we add the gc for Lists Preview ***
-	// attach a new graphics context to the drawing area
-	XAP_UnixApp * unixapp = static_cast<XAP_UnixApp *> (m_pApp);
-	UT_ASSERT(unixapp);
 
 	UT_ASSERT(m_wPreviewArea && gtk_widget_get_window(m_wPreviewArea));
 
@@ -346,7 +344,6 @@ void AP_UnixDialog_Lists::setFoldLevelInGUI(void)
  */
 void AP_UnixDialog_Lists::setFoldLevel(UT_sint32 iLevel, bool bSet)
 {
-	UT_sint32 i = 0;
 	UT_sint32 count = m_vecFoldCheck.getItemCount();
 	if(iLevel >= count)
 	{
@@ -356,13 +353,6 @@ void AP_UnixDialog_Lists::setFoldLevel(UT_sint32 iLevel, bool bSet)
 	UT_uint32 ID =0;
 	if(!bSet)
 	{
-		for(i=0; i< count;i++)
-		{
-			wF = m_vecFoldCheck.getNthItem(i);
-			ID = m_vecFoldID.getNthItem(i);
-			XAP_GtkSignalBlocker b1(G_OBJECT(wF),ID);
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wF),FALSE);
-		}
 		wF = m_vecFoldCheck.getNthItem(0);
 		ID = m_vecFoldID.getNthItem(0);
 		XAP_GtkSignalBlocker b2(G_OBJECT(wF),ID);
@@ -371,13 +361,6 @@ void AP_UnixDialog_Lists::setFoldLevel(UT_sint32 iLevel, bool bSet)
 	}
 	else
 	{
-		for(i=0; i< count;i++)
-		{
-			wF = m_vecFoldCheck.getNthItem(i);
-			ID = m_vecFoldID.getNthItem(i);
-			XAP_GtkSignalBlocker b2(G_OBJECT(wF),ID);
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wF),FALSE);
-		}
 		wF = m_vecFoldCheck.getNthItem(iLevel);
 		ID = m_vecFoldID.getNthItem(iLevel);
 		{
@@ -446,7 +429,7 @@ void  AP_UnixDialog_Lists::styleChanged(gint type)
 								GTK_TREE_MODEL(m_wListStyleBulleted_menu.obj()));
 		gtk_combo_box_set_active(m_wListTypeBox, 1);
 		setNewListType(BULLETED_LIST);
-		gtk_widget_set_sensitive(GTK_WIDGET(m_wFontOptions), false);
+		gtk_widget_set_sensitive(GTK_WIDGET(m_wFontOptions), true);
 		gtk_widget_set_sensitive(m_wStartSpin, false);
 		gtk_widget_set_sensitive(m_wDelimEntry, false);
 		gtk_widget_set_sensitive(m_wDecimalEntry, false);		
@@ -589,6 +572,9 @@ GtkWidget * AP_UnixDialog_Lists::_constructWindow(void)
 
 	ConstructWindowName();
 	m_wMainWindow = abiDialogNew ( "list dialog", TRUE, getWindowName() );	
+#if !GTK_CHECK_VERSION(3,0,0)
+	gtk_dialog_set_has_separator(GTK_DIALOG(m_wMainWindow), FALSE);
+#endif
 	vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(m_wMainWindow));
 
 	contents = _constructWindowContents();
@@ -712,7 +698,7 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 // Container for Text Folding
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_PageFolding,s);
 		GtkWidget * lbPageFolding = gtk_label_new(s.utf8_str());
-		GtkWidget * wFoldingTable = gtk_table_new(6,3,FALSE);
+		GtkWidget * wFoldingTable = gtk_table_new(7,3,FALSE);
 		gtk_widget_show(lbPageFolding);
 		gtk_widget_show(wFoldingTable);
 		gtk_notebook_append_page(GTK_NOTEBOOK(wNoteBook),wFoldingTable,lbPageFolding);
@@ -723,7 +709,7 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 
 		GtkWidget * lbLeftSpacer = gtk_label_new("");
 		gtk_misc_set_padding(GTK_MISC(lbLeftSpacer),8,0);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),lbLeftSpacer,0,1,0,6,GTK_SHRINK,GTK_FILL,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),lbLeftSpacer,0,1,0,7,GTK_SHRINK,GTK_FILL,0,0);
 		gtk_widget_show(lbLeftSpacer);
 
 // Bold markup
@@ -731,76 +717,81 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 		gtk_label_set_use_markup(GTK_LABEL(lbFoldHeading),TRUE);
 
 		localizeLabelMarkup(lbFoldHeading,pSS,AP_STRING_ID_DLG_Lists_FoldingLevelexp);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),lbFoldHeading,1,3,0,1,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),lbFoldHeading,1,3,0,1,GTK_FILL,GTK_FILL,0,16);
 		gtk_widget_show(lbFoldHeading);
 
 // Mid Left Spacing Here
 
 		GtkWidget * lbMidLeftSpacer = gtk_label_new("");
 		gtk_misc_set_padding(GTK_MISC(lbMidLeftSpacer),8,0);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),lbMidLeftSpacer,1,2,1,6,GTK_SHRINK,GTK_FILL,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),lbMidLeftSpacer,1,2,1,7,GTK_SHRINK,GTK_FILL,0,0);
 		gtk_widget_show(lbMidLeftSpacer);
 
 		m_vecFoldCheck.clear();
 		m_vecFoldID.clear();
 		UT_uint32 ID =0;
-// CheckButtons
+// RadioButtons
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_FoldingLevel0,s);
-		GtkWidget * wF = gtk_check_button_new_with_label(s.utf8_str());
+		
+		GtkWidget * wF = gtk_radio_button_new_with_label(NULL, s.utf8_str());
+		GSList *wG = gtk_radio_button_get_group(GTK_RADIO_BUTTON(wF));
 		g_object_set_data(G_OBJECT(wF),"level",(gpointer)"0");
 		ID = g_signal_connect(G_OBJECT(wF),
 						  "toggled",
 						 G_CALLBACK(s_FoldCheck_changed),
 						 (gpointer) this);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,1,2,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,2,3,GTK_FILL,GTK_FILL,0,6);
 		gtk_widget_show(wF);
 		m_vecFoldCheck.addItem(wF);
 		m_vecFoldID.addItem(ID);
 
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_FoldingLevel1,s);
-		wF = gtk_check_button_new_with_label(s.utf8_str());
+		wF = gtk_radio_button_new_with_label(wG, s.utf8_str());
+		wG = gtk_radio_button_get_group(GTK_RADIO_BUTTON(wF));
 		g_object_set_data(G_OBJECT(wF),"level",(gpointer)"1");
 		ID = g_signal_connect(G_OBJECT(wF),
 						  "toggled",
 						 G_CALLBACK(s_FoldCheck_changed),
 						 (gpointer) this);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,2,3,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,3,4,GTK_FILL,GTK_FILL,0,6);
 		gtk_widget_show(wF);
 		m_vecFoldCheck.addItem(wF);
 		m_vecFoldID.addItem(ID);
 
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_FoldingLevel2,s);
-		wF = gtk_check_button_new_with_label(s.utf8_str());
+		wF = gtk_radio_button_new_with_label(wG, s.utf8_str());
+		wG = gtk_radio_button_get_group(GTK_RADIO_BUTTON(wF));
 		g_object_set_data(G_OBJECT(wF),"level",(gpointer)"2");
 		ID = g_signal_connect(G_OBJECT(wF),
 						  "toggled",
 						 G_CALLBACK(s_FoldCheck_changed),
 						 (gpointer) this);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,3,4,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,4,5,GTK_FILL,GTK_FILL,0,6);
 		gtk_widget_show(wF);
 		m_vecFoldCheck.addItem(wF);
 		m_vecFoldID.addItem(ID);
 
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_FoldingLevel3,s);
-		wF = gtk_check_button_new_with_label(s.utf8_str());
+		wF = gtk_radio_button_new_with_label(wG, s.utf8_str());
+		wG = gtk_radio_button_get_group(GTK_RADIO_BUTTON(wF));
 		g_object_set_data(G_OBJECT(wF),"level",(gpointer)"3");
 		ID = g_signal_connect(G_OBJECT(wF),
 						  "toggled",
 						 G_CALLBACK(s_FoldCheck_changed),
 						 (gpointer) this);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,4,5,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,5,6,GTK_FILL,GTK_FILL,0,6);
 		gtk_widget_show(wF);
 		m_vecFoldCheck.addItem(wF);
 		m_vecFoldID.addItem(ID);
 
 		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_FoldingLevel4,s);
-		wF = gtk_check_button_new_with_label(s.utf8_str());
+		wF = gtk_radio_button_new_with_label(wG, s.utf8_str());
 		g_object_set_data(G_OBJECT(wF),"level",(gpointer)"4");
 		ID = g_signal_connect(G_OBJECT(wF),
 						  "toggled",
 						 G_CALLBACK(s_FoldCheck_changed),
 						 (gpointer) this);
-		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,5,6,GTK_FILL,GTK_EXPAND,0,0);
+		gtk_table_attach(GTK_TABLE(wFoldingTable),wF,2,3,6,7,GTK_FILL,GTK_FILL,0,6);
 		gtk_widget_show(wF);
 		m_vecFoldCheck.addItem(wF);
 		m_vecFoldID.addItem(ID);
@@ -879,6 +870,8 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_SetDefault,s);
 	customized_cb = gtk_dialog_add_button (GTK_DIALOG(m_wMainWindow), s.utf8_str(), BUTTON_RESET);
+	GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_REVERT_TO_SAVED, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image(GTK_BUTTON(customized_cb), img);      
 	gtk_widget_show (customized_cb);
 
 	/* todo
@@ -903,7 +896,7 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	font_om_menu = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
 	_fillFontMenu(font_om_menu);
 
-	font_om = GTK_COMBO_BOX(gtk_combo_box_new());
+	font_om = GTK_COMBO_BOX(gtk_combo_box_text_new());
 	gtk_combo_box_set_model(font_om, GTK_TREE_MODEL(font_om_menu));
 	gtk_widget_show (GTK_WIDGET(font_om));
 	gtk_table_attach (GTK_TABLE (table2), GTK_WIDGET(font_om), 1, 2, 1, 2,
@@ -925,14 +918,14 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_entry_set_text (GTK_ENTRY (format_en), "");
 
-	start_sb_adj = gtk_adjustment_new (1, 0, G_MAXINT32, 1, 10, 10);
+	start_sb_adj = (GtkAdjustment*)gtk_adjustment_new (1, 0, G_MAXINT32, 1, 10, 10);
 	start_sb = gtk_spin_button_new (GTK_ADJUSTMENT (start_sb_adj), 1, 0);
 	gtk_widget_show (start_sb);
 	gtk_table_attach (GTK_TABLE (table2), start_sb, 1, 2, 3, 4,
 					  (GtkAttachOptions) (GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 
-	text_align_sb_adj = gtk_adjustment_new (0.25, 0, 10, 0.01, 0.2, 1);
+	text_align_sb_adj = (GtkAdjustment*)gtk_adjustment_new (0.25, 0, 10, 0.01, 0.2, 1);
 	text_align_sb = gtk_spin_button_new (GTK_ADJUSTMENT (text_align_sb_adj), 0.05, 2);
 	gtk_widget_show (text_align_sb);
 	gtk_table_attach (GTK_TABLE (table2), text_align_sb, 1, 2, 4, 5,
@@ -941,7 +934,7 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (text_align_sb), TRUE);
 	gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (text_align_sb), TRUE);
 
-	label_align_sb_adj = gtk_adjustment_new (0, 0, 10, 0.01, 0.2, 1);
+	label_align_sb_adj = (GtkAdjustment*)gtk_adjustment_new (0, 0, 10, 0.01, 0.2, 1);
 	label_align_sb = gtk_spin_button_new (GTK_ADJUSTMENT (label_align_sb_adj), 0.05, 2);
 	gtk_widget_show (label_align_sb);
 	gtk_table_attach (GTK_TABLE (table2), label_align_sb, 1, 2, 5, 6,
@@ -1013,23 +1006,23 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	gtk_widget_show (preview_area);
 	gtk_container_add (GTK_CONTAINER (preview_frame), preview_area);
 
-	hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 16);
 	if(!isModal())
 		gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);
-	pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New,s);
-	start_list_rb = gtk_radio_button_new_with_label (action_group, s.utf8_str());
-	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (start_list_rb));
-	if(!isModal())
-		gtk_widget_show (start_list_rb);
-	gtk_box_pack_start (GTK_BOX (hbox1), start_list_rb, FALSE, FALSE, 0);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (start_list_rb), TRUE);
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Apply_Current,s);
 	apply_list_rb = gtk_radio_button_new_with_label (action_group, s.utf8_str());
 	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (apply_list_rb));
 	if(!isModal())
 		gtk_widget_show (apply_list_rb);
 	gtk_box_pack_start (GTK_BOX (hbox1), apply_list_rb, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (apply_list_rb), TRUE);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New,s);
+	start_list_rb = gtk_radio_button_new_with_label (action_group, s.utf8_str());
+	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (start_list_rb));
+	if(!isModal())
+		gtk_widget_show (start_list_rb);
+	gtk_box_pack_start (GTK_BOX (hbox1), start_list_rb, FALSE, FALSE, 0);
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Resume,s);
 	resume_list_rb = gtk_radio_button_new_with_label (action_group, s.utf8_str());
 	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (resume_list_rb));
@@ -1118,7 +1111,7 @@ void AP_UnixDialog_Lists::_getGlistFonts (std::vector<std::string> & glFonts)
 void AP_UnixDialog_Lists::_fillNoneStyleMenu( GtkListStore *listmenu)
 {
 	const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
-	addToStore(listmenu, pSS, AP_STRING_ID_DLG_Lists_Type_none,
+	addToStore(listmenu, pSS, AP_STRING_ID_DLG_Lists_Style_none,
 			   NOT_A_LIST);
 }
 
@@ -1168,6 +1161,8 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkListStore *listmenu)
 			   HAND_LIST);
 	addToStore(listmenu, pSS,AP_STRING_ID_DLG_Lists_Heart_List,
 			   HEART_LIST);
+	addToStore(listmenu, pSS,AP_STRING_ID_DLG_Lists_Arrowhead_List,
+			   ARROWHEAD_LIST);
 }
 
 void AP_UnixDialog_Lists::_setRadioButtonLabels(void)
@@ -1239,7 +1234,11 @@ void AP_UnixDialog_Lists::_connectSignals(void)
 					    this);
 	// the expose event of the preview
 	g_signal_connect(G_OBJECT(m_wPreviewArea),
+#if GTK_CHECK_VERSION(3,0,0)
 					   "draw",
+#else
+					   "expose_event",
+#endif
 					   G_CALLBACK(s_preview_draw),
 					   static_cast<gpointer>(this));
 	g_signal_connect(G_OBJECT(m_wMainWindow),
