@@ -27,6 +27,7 @@
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_App.h"
 #include "xap_UnixApp.h"
@@ -96,7 +97,9 @@ GtkWidget * AP_UnixDialog_MarkRevisions::constructWindow ()
   UT_UTF8String s;
   pSS->getValueUTF8(AP_STRING_ID_DLG_MarkRevisions_Title,s);
   dialog1 = abiDialogNew ( "mark revisions", TRUE, s.utf8_str());
-  gtk_window_set_default_size ( GTK_WINDOW(dialog1), 250, 150 ) ;
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_dialog_set_has_separator(GTK_DIALOG(dialog1), FALSE);
+#endif
 
   dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG (dialog1));
   gtk_widget_show (dialog_vbox1);
@@ -140,7 +143,7 @@ void AP_UnixDialog_MarkRevisions::constructWindowContents ( GtkWidget * containe
 			 vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton1));
 			 gtk_widget_show (radiobutton1);
 			 gtk_box_pack_start (GTK_BOX (vbox1), radiobutton1, FALSE, FALSE, 0);
-			 lbl1 = gtk_label_new(getComment1());
+			 lbl1 = gtk_label_new(getComment1(true));
 			 gtk_widget_show (lbl1);
 			 gtk_box_pack_start (GTK_BOX (vbox1), lbl1, FALSE, FALSE, 0);
 		 }
@@ -150,7 +153,7 @@ void AP_UnixDialog_MarkRevisions::constructWindowContents ( GtkWidget * containe
 		 if (isRev ())
 			 gtk_widget_show (radiobutton2);
 		 
-		 gtk_box_pack_start (GTK_BOX (vbox1), radiobutton2, FALSE, FALSE, 0);
+		 gtk_box_pack_start (GTK_BOX (vbox1), radiobutton2, FALSE, FALSE, 6);
 		 
 		 g_signal_connect ( G_OBJECT(radiobutton2), "toggled",
 							G_CALLBACK(focus_toggled_callback), this ) ;
@@ -165,7 +168,7 @@ void AP_UnixDialog_MarkRevisions::constructWindowContents ( GtkWidget * containe
    
    entry1 = gtk_entry_new();
    gtk_widget_show (entry1);
-   gtk_box_pack_start (GTK_BOX (vbox1), entry1, FALSE, FALSE, 0);
+   gtk_box_pack_start (GTK_BOX (vbox1), entry1, FALSE, FALSE, 8);
    
    mEntryLbl = lbl2 ;
    mComment = entry1 ;
