@@ -535,12 +535,12 @@ void Markup(GtkWidget * widget, const XAP_StringSet * /*pSS*/, char *string)
 
 GtkWidget * AP_UnixDialog_PageSetup::_constructWindow (void)
 {  
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_PageSetup.xml";
-
 	// load the dialog from the UI file
-	m_pBuilder = gtk_builder_new();
-	gtk_builder_add_from_file(m_pBuilder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	m_pBuilder = newDialogBuilder("ap_UnixDialog_PageSetup.ui");
+#else
+	m_pBuilder = newDialogBuilder("ap_UnixDialog_PageSetup-2.ui");
+#endif
 
 	const XAP_StringSet * pSS = m_pApp->getStringSet ();
 	GList *glist;
@@ -569,6 +569,7 @@ GtkWidget * AP_UnixDialog_PageSetup::_constructWindow (void)
 	m_PageHbox = _getWidget("hbox16");
 
 	/* required for translations */
+	abiDialogSetTitle(m_window, "%s", _(AP, DLG_PageSetup_Title));
 	gtk_label_set_text (GTK_LABEL (_getWidget("lbPage")), _(AP, DLG_PageSetup_Page));
 	gtk_label_set_text (GTK_LABEL (_getWidget("lbMargin")), _(AP, DLG_PageSetup_Margin));
 	Markup (_getWidget("lbPaper"), pSS, _(AP, DLG_PageSetup_Paper));
@@ -625,7 +626,7 @@ GtkWidget * AP_UnixDialog_PageSetup::_constructWindow (void)
 	{
 		gtk_list_store_append(pagesize_store, &pagesize_iter);
 		gtk_list_store_set(pagesize_store, &pagesize_iter,
-					0, fp_PageSize::PredefinedToName ((fp_PageSize::Predefined)i),
+					0, pSS->getValue(fp_PageSize::PredefinedToLocalName((fp_PageSize::Predefined) i)),
 					1, this,
 					-1);
 	}
