@@ -36,6 +36,7 @@
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
 #include "xap_GtkComboBoxHelpers.h"
+#include "xap_Gtk2Compat.h"
 
 #include "xap_App.h"
 #include "xap_UnixApp.h"
@@ -115,12 +116,34 @@ static void s_check_toggled(GtkWidget * widget, AP_UnixDialog_Paragraph * dlg)
 }
 
 #if !defined(EMBEDDED_TARGET) || EMBEDDED_TARGET != EMBEDDED_TARGET_HILDON
+
+#if !GTK_CHECK_VERSION(3,0,0)
+static gboolean do_update(gpointer p)
+{
+//
+// FIXME!!! Could get nasty crash if the dlg is destroyed while 
+// a redraw is pending....
+//
+	AP_UnixDialog_Paragraph * dlg = (AP_UnixDialog_Paragraph *) p;
+	dlg->event_PreviewAreaExposed();
+	return FALSE;
+}
+#endif
+
 static gint s_preview_draw(GtkWidget * /* widget */,
-							  cairo_t * /* cr */,
-							  AP_UnixDialog_Paragraph * dlg)
+#if GTK_CHECK_VERSION(3,0,0)
+			   cairo_t * /* cr */,
+#else
+			   GdkEventExpose * /* pExposeEvent */,
+#endif
+			   AP_UnixDialog_Paragraph * dlg)
 {
 	UT_ASSERT(dlg);
+#if GTK_CHECK_VERSION(3,0,0)
 	dlg->event_PreviewAreaExposed();
+#else
+	g_idle_add((GSourceFunc) do_update,(gpointer) dlg);
+#endif
 	return TRUE;
 }
 #endif
@@ -240,11 +263,13 @@ void AP_UnixDialog_Paragraph::event_ComboBoxChanged(GtkWidget * widget)
 
 void AP_UnixDialog_Paragraph::event_SpinIncrement(GtkWidget * widget)
 {
+	UT_DEBUG_ONLY_ARG(widget);
 	UT_ASSERT(widget);
 }
 
 void AP_UnixDialog_Paragraph::event_SpinDecrement(GtkWidget * widget)
 {
+	UT_DEBUG_ONLY_ARG(widget);
 	UT_ASSERT(widget);
 }
 
@@ -324,6 +349,10 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindow(void)
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ParaTitle,s);
 	UT_XML_cloneNoAmpersands(unixstr, s.utf8_str());
 	windowParagraph = abiDialogNew("paragraph dialog", TRUE, unixstr);
+	gtk_window_set_position(GTK_WINDOW(windowParagraph), GTK_WIN_POS_CENTER_ON_PARENT);
+#if !GTK_CHECK_VERSION(3,0,0)
+	gtk_dialog_set_has_separator(GTK_DIALOG(windowParagraph), FALSE);
+#endif
 	FREEP(unixstr);
 
 	vboxMain = gtk_dialog_get_content_area(GTK_DIALOG(windowParagraph));
@@ -335,6 +364,8 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindow(void)
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ButtonTabs,s);
 	UT_XML_cloneNoAmpersands(unixstr, s.utf8_str());
 	buttonTabs = abiAddButton (GTK_DIALOG(windowParagraph), unixstr, BUTTON_TABS);
+	GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_GOTO_LAST, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image(GTK_BUTTON(buttonTabs), img);      
 	FREEP(unixstr);
 	buttonOK = abiAddStockButton(GTK_DIALOG(windowParagraph), GTK_STOCK_OK, BUTTON_OK);
 
@@ -446,7 +477,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	gtk_box_pack_start (GTK_BOX (hboxAlignment), GTK_WIDGET(listAlignment), FALSE, FALSE, 0);
 	gtk_table_attach ( GTK_TABLE(boxSpacing), hboxAlignment, 1,2, 0,1,
                     (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
-                    (GtkAttachOptions) (GTK_FILL), 0, 0);
+                    (GtkAttachOptions) (GTK_FILL), 0, 3);
 
 	XAP_appendComboBoxTextAndInt(listAlignment, " ", 0); // add an empty menu option to fix bug 594
 	
@@ -481,6 +512,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	gtk_box_pack_start (GTK_BOX (hboxIndentation), labelIndentation, FALSE, FALSE, 0);
 	gtk_label_set_justify (GTK_LABEL (labelIndentation), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (labelIndentation), 0, 0.5);
+	gtk_misc_set_padding (GTK_MISC (labelIndentation), 0, 3);
 
 	hseparator3 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator3);
@@ -615,6 +647,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	gtk_box_pack_start (GTK_BOX (hboxSpacing), labelSpacing, FALSE, FALSE, 0);
 	gtk_label_set_justify (GTK_LABEL (labelSpacing), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (labelSpacing), 0, 0.5);
+	gtk_misc_set_padding (GTK_MISC (labelSpacing), 0, 3);
 
 	hseparator1 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (hboxSpacing), hseparator1, TRUE, TRUE, 0);
@@ -749,6 +782,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	FREEP(unixstr);
 	gtk_widget_show (labelPagination);
 	gtk_box_pack_start (GTK_BOX (hboxPagination), labelPagination, FALSE, FALSE, 0);
+	gtk_misc_set_padding (GTK_MISC (labelPagination), 0, 3);
 
 	hseparator5 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator5);
@@ -805,7 +839,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	gtk_widget_show (hseparator6);
 	gtk_table_attach ( GTK_TABLE(boxBreaks), hseparator6, 0,2, 3,4,
                     (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (GTK_FILL), 0, 0 );
+                    (GtkAttachOptions) (GTK_FILL), 0, 4 );                    
 
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PushSuppressLineNumbers,s);
 	UT_XML_cloneNoAmpersands(unixstr, s.utf8_str());
@@ -848,6 +882,7 @@ GtkWidget * AP_UnixDialog_Paragraph::_constructWindowContents(GtkWidget *windowM
 	gtk_box_pack_start (GTK_BOX (hboxPreview), labelPreview, FALSE, TRUE, 0);
 	gtk_label_set_justify (GTK_LABEL (labelPreview), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_alignment (GTK_MISC (labelPreview), 0, 0.5);
+	gtk_misc_set_padding (GTK_MISC (labelPreview), 0, 8);
 
 	hseparator4 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator4);
@@ -970,9 +1005,13 @@ void AP_UnixDialog_Paragraph::_connectCallbackSignals(void)
 #if !defined(EMBEDDED_TARGET) || EMBEDDED_TARGET != EMBEDDED_TARGET_HILDON
 	// the expose event off the preview
 	g_signal_connect(G_OBJECT(m_drawingareaPreview),
-					   "draw",
-					   G_CALLBACK(s_preview_draw),
-					   (gpointer) this);
+#if GTK_CHECK_VERSION(3,0,0)
+			 "draw",
+#else
+			 "expose_event",
+#endif
+			 G_CALLBACK(s_preview_draw),
+			 (gpointer) this);
 #endif
 }
 
