@@ -25,6 +25,10 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "GTKCommon.h"
 #include "ut_string.h"
 #include "ut_assert.h"
@@ -44,9 +48,6 @@
 #include "xap_GtkComboBoxHelpers.h"
 
 #include <sstream>
-#include <iostream>
-using std::cerr;
-using std::endl;
 
 const char* GOBJ_COL_NUM = "GOBJ_COL_NUM";
 
@@ -96,7 +97,7 @@ AP_UnixDialog_RDFEditor__onActionDelete( GtkAction*, gpointer data )
 void
 AP_UnixDialog_RDFEditor__onActionImportRDFXML( GtkAction*, gpointer data )
 {
-    cerr << "_onActionImportRDFXML()" << endl;
+    xxx_UT_DEBUGMSG(("_onActionImportRDFXML()\n"))
 	AP_UnixDialog_RDFEditor *dlg = static_cast <AP_UnixDialog_RDFEditor*>(data);
     dlg->onImportRDFXML();
 }
@@ -181,7 +182,6 @@ AP_UnixDialog_RDFEditor::AP_UnixDialog_RDFEditor( XAP_DialogFactory *pDlgFactory
     , m_wDialog 	   (0)
     , m_btClose 	   (0)
     , m_btShowAll      (0)
-    , m_query          (0)
     , m_resultsView    (0)
 	, m_resultsModel   (0)
     , m_status         (0)
@@ -290,7 +290,12 @@ void
 AP_UnixDialog_RDFEditor::hideRestrictionXMLID( bool v )
 {
     AP_Dialog_RDFEditor::hideRestrictionXMLID( v );
-    
+
+	// check that the UI is actually loaded.
+	if(!m_wDialog) {
+		return;
+	}
+
     if( v )
     {
         UT_DEBUGMSG(("AP_UnixDialog_RDFEditor, no restriction HIDING! w:%p\n", m_restrictxmlidhidew ));
@@ -300,9 +305,9 @@ AP_UnixDialog_RDFEditor::hideRestrictionXMLID( bool v )
     else
     {
         PD_RDFModelHandle model;
-        std::list< std::string > xmlids;
+        std::set< std::string > xmlids;
         getRDF()->addRelevantIDsForPosition( xmlids, getView()->getPoint() );
-        UT_DEBUGMSG(("AP_UnixDialog_RDFEditor, have restricted xmlids size:%d\n", xmlids.size() ));
+        UT_DEBUGMSG(("AP_UnixDialog_RDFEditor, have restricted xmlids size:%lu\n", (long unsigned)xmlids.size() ));
         
 		/// FIXME...
 		setRestrictedModel( model );
@@ -354,7 +359,7 @@ AP_UnixDialog_RDFEditor::onDelClicked()
     for( std::list< PD_RDFStatement >::iterator iter = l.begin(); iter != l.end(); ++iter )
     {
         const PD_RDFStatement& st = *iter;
-        cerr << "onDelClicked() removing statement:" << st.toString() << endl;
+        xxx_UT_DEBUGMSG(("onDelClicked() removing statement: %s\n", st.toString().utf8_str()));
         m->remove( st );
         removeStatement( st );
         m_count--;
@@ -374,12 +379,12 @@ AP_UnixDialog_RDFEditor::onDelClicked()
 
 
 void
-AP_UnixDialog_RDFEditor::onCellEdited( GtkCellRendererText *cell,
+AP_UnixDialog_RDFEditor::onCellEdited( GtkCellRendererText * /*cell*/,
                                        gchar *path_string,
                                        gchar *new_text,
                                        int cidx )
 {
-    cerr << "onCellEdited() nt:" << new_text << endl;
+    xxx_UT_DEBUGMSG(("onCellEdited() nt: %s\n", new_text));
 
     GtkTreeIter giter;
     GtkTreeModel* model = GTK_TREE_MODEL( m_resultsModel );
@@ -429,25 +434,26 @@ static std::string tostr( GsfInput* gsf )
 void
 AP_UnixDialog_RDFEditor::onImportRDFXML()
 {
-    cerr << "onImportRDFXML()" << endl;
+    xxx_UT_DEBUGMSG(("onImportRDFXML()\n"));
 
     UT_runDialog_AskForPathname afp( XAP_DIALOG_ID_FILE_IMPORT );
     afp.appendFiletype( "RDF/XML Triple File", "rdf" );
 
     if( afp.run( getActiveFrame() ) )
     {
-        cerr << "onImportRDFXML() path:" << afp.getPath() << endl;
+        xxx_UT_DEBUGMSG(("onImportRDFXML() path: %s", afp.getPath().utf8_str()));
         GError* err = 0;
         GsfInput* gsf = UT_go_file_open( afp.getPath().c_str(), &err );
         std::string rdfxml = tostr( gsf );
         g_object_unref (G_OBJECT (gsf));
 
-        cerr << "rdfxml:" << rdfxml << endl;
+        xxx_UT_DEBUGMSG(("rdfxml: %s\n", rdfxml.c_str()));
         PD_DocumentRDFMutationHandle m = getModel()->createMutation();
-        UT_Error e = loadRDFXML( m, rdfxml );
+		// FIXME check the error code
+        /* UT_Error e =*/ loadRDFXML( m, rdfxml );
         m->commit();
 
-        cerr << "count of triples:" << getModel()->size() << endl;
+        xxx_UT_DEBUGMSG(("count of triples: %ld\n", getModel()->size()));
         showAllRDF();
     }
     gtk_window_present( GTK_WINDOW( m_wDialog ));
@@ -456,7 +462,7 @@ AP_UnixDialog_RDFEditor::onImportRDFXML()
 void
 AP_UnixDialog_RDFEditor::onExportRDFXML()
 {
-    cerr << "onExportRDFXML()" << endl;
+    xxx_UT_DEBUGMSG(("onExportRDFXML()\n"));
 
     UT_runDialog_AskForPathname afp( XAP_DIALOG_ID_FILE_EXPORT );
     afp.appendFiletype( "RDF/XML Triple File", "rdf" );
@@ -464,7 +470,7 @@ AP_UnixDialog_RDFEditor::onExportRDFXML()
 
     if( afp.run( getActiveFrame() ) )
     {
-        cerr << "onExportRDFXML() path:" << afp.getPath() << endl;
+        xxx_UT_DEBUGMSG(("onExportRDFXML() path: %s\n", afp.getPath().utf8_str()));
         std::string rdfxml = toRDFXML( getModel() );
         GError* err = 0;
         GsfOutput* gsf = UT_go_file_create( afp.getPath().c_str(), &err );
@@ -488,33 +494,48 @@ AP_UnixDialog_RDFEditor::setStatus( const std::string& msg )
 * Build dialog.
 */
 void 
-AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/) 
+AP_UnixDialog_RDFEditor::_constructWindow (XAP_Frame * /*pFrame*/) 
 {
-	UT_DEBUGMSG (("MIQ: constuctWindow ()\n"));		
+	UT_DEBUGMSG (("MIQ: _constructWindow ()\n"));		
 
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_RDFEditor.xml";
+	const XAP_StringSet *pSS = m_pApp->getStringSet();
+	std::string text;
 
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_RDFEditor.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_RDFEditor-2.ui");
+#endif
+
 
 	m_wDialog = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_RDFEditor"));
 	m_btClose = GTK_WIDGET(gtk_builder_get_object(builder, "btClose"));
     m_btShowAll = GTK_WIDGET(gtk_builder_get_object(builder, "btShowAll"));
-    m_query     = GTK_WIDGET(gtk_builder_get_object(builder, "query"));
 	m_resultsView   = GTK_TREE_VIEW(gtk_builder_get_object(builder, "resultsView"));
-//	m_resultsModel  = GTK_LIST_STORE(gtk_builder_get_object(builder, "resultsModel"));
     m_status        = GTK_WIDGET(gtk_builder_get_object(builder, "status"));
-    m_anewtriple    = GTK_WIDGET(gtk_builder_get_object(builder, "anewtriple"));
-    m_acopytriple   = GTK_WIDGET(gtk_builder_get_object(builder, "acopytriple"));
-    m_adeletetriple = GTK_WIDGET(gtk_builder_get_object(builder, "adeletetriple"));
-    m_aimportrdfxml = GTK_WIDGET(gtk_builder_get_object(builder, "aimportrdfxml"));
-    m_aexportrdfxml = GTK_WIDGET(gtk_builder_get_object(builder, "aexportrdfxml"));
+    m_anewtriple    = GTK_ACTION(gtk_builder_get_object(builder, "anewtriple"));
+    m_acopytriple   = GTK_ACTION(gtk_builder_get_object(builder, "acopytriple"));
+    m_adeletetriple = GTK_ACTION(gtk_builder_get_object(builder, "adeletetriple"));
+    m_aimportrdfxml = GTK_ACTION(gtk_builder_get_object(builder, "aimportrdfxml"));
+    m_aexportrdfxml = GTK_ACTION(gtk_builder_get_object(builder, "aexportrdfxml"));
     m_selectedxmlid = GTK_COMBO_BOX(gtk_builder_get_object(builder, "selectedxmlid"));
     m_restrictxmlidhidew = GTK_WIDGET(gtk_builder_get_object(builder, "restrictxmlidhidew"));
 
-    
+    // localization
+    localizeMenuItem(GTK_WIDGET(gtk_builder_get_object(builder, "filemenuitem")), pSS, AP_STRING_ID_DLG_RDF_Editor_Menu_File);
+    localizeMenuItem(GTK_WIDGET(gtk_builder_get_object(builder, "editmenuitem")), pSS, AP_STRING_ID_DLG_RDF_Editor_Menu_Triple);
+    localizeButton(m_btShowAll, pSS, AP_STRING_ID_DLG_RDF_Editor_ShowAll);
+    localizeLabel(GTK_WIDGET(gtk_builder_get_object(builder, "lbRestrict")), pSS, AP_STRING_ID_DLG_RDF_Editor_Restrict);
+
+    // add three dots to menu items raising a dialog
+    text = gtk_action_get_label(m_aimportrdfxml);
+    text += "...";
+    gtk_action_set_label(m_aimportrdfxml, text.c_str());
+    text = gtk_action_get_label(m_aexportrdfxml);
+    text += "...";
+    gtk_action_set_label(m_aexportrdfxml, text.c_str());
+
     GObject *selection;
     selection = G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (m_resultsView)));
     gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection), GTK_SELECTION_MULTIPLE);
@@ -529,36 +550,39 @@ AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/)
 
     colid = C_SUBJ_COLUMN;
     ren = gtk_cell_renderer_text_new ();
-    g_object_set(ren, "editable", 1, 0 );
-    g_object_set_data( G_OBJECT(ren), GOBJ_COL_NUM,  GINT_TO_POINTER(colid) );
+    g_object_set(ren, "editable", 1, 0, NULL);
+    g_object_set_data( G_OBJECT(ren), GOBJ_COL_NUM,  GINT_TO_POINTER(colid));
     g_signal_connect_data( G_OBJECT( ren ), "edited",
                            G_CALLBACK (cell_edited_cb),
                            (gpointer)this, 0, GConnectFlags(0));
-    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( "Subject", ren, "text", colid, NULL);
+    pSS->getValueUTF8(AP_STRING_ID_DLG_RDF_Query_Column_Subject, text);
+    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( text.c_str(), ren, "text", colid, NULL);
     gtk_tree_view_append_column( GTK_TREE_VIEW( m_resultsView ), w_cols[ colid ] );
     gtk_tree_view_column_set_sort_column_id( w_cols[ colid ], colid );
     gtk_tree_view_column_set_resizable ( w_cols[ colid ], true );
     
     colid = C_PRED_COLUMN;
     ren = gtk_cell_renderer_text_new ();
-    g_object_set(ren, "editable", 1, 0 );
+    g_object_set(ren, "editable", 1, 0, NULL );
     g_object_set_data( G_OBJECT(ren), GOBJ_COL_NUM, GINT_TO_POINTER(colid) );
     g_signal_connect_data( G_OBJECT( ren ), "edited",
                            G_CALLBACK (cell_edited_cb),
                            (gpointer)this, 0, GConnectFlags(0));
-    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( "Predicate", ren, "text", colid, NULL);
+    pSS->getValueUTF8(AP_STRING_ID_DLG_RDF_Query_Column_Predicate, text);
+    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( text.c_str(), ren, "text", colid, NULL);
     gtk_tree_view_append_column( GTK_TREE_VIEW( m_resultsView ), w_cols[ colid ] );
     gtk_tree_view_column_set_sort_column_id( w_cols[ colid ], colid );
     gtk_tree_view_column_set_resizable ( w_cols[ colid ], true );
 
     colid = C_OBJ_COLUMN;
     ren = gtk_cell_renderer_text_new ();
-    g_object_set(ren, "editable", 1, 0 );
+    g_object_set(ren, "editable", 1, 0, NULL );
     g_object_set_data( G_OBJECT(ren), GOBJ_COL_NUM, GINT_TO_POINTER(colid) );
     g_signal_connect_data( G_OBJECT( ren ), "edited",
                            G_CALLBACK (cell_edited_cb),
                            (gpointer)this, 0, GConnectFlags(0));
-    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( "Object", ren, "text", colid, NULL);
+    pSS->getValueUTF8(AP_STRING_ID_DLG_RDF_Query_Column_Object, text);
+    w_cols[ colid ] = gtk_tree_view_column_new_with_attributes( text.c_str(), ren, "text", colid, NULL);
     gtk_tree_view_append_column( GTK_TREE_VIEW( m_resultsView ), w_cols[ colid ] );
     gtk_tree_view_column_set_sort_column_id( w_cols[ colid ], colid );
     gtk_tree_view_column_set_resizable ( w_cols[ colid ], true );
@@ -582,41 +606,50 @@ AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/)
         PT_DocPosition point = getView()->getPoint();
         if( PD_DocumentRDFHandle rdf = getRDF() )
         {
-            std::list< std::string > xmlids;
+            std::set< std::string > xmlids;
             rdf->addRelevantIDsForPosition( xmlids, point );
 
+            bool combined = false; 
             std::stringstream combinedxmlidss;
-            for( std::list< std::string >::const_iterator iter = xmlids.begin();
+            for( std::set< std::string >::const_iterator iter = xmlids.begin();
                  iter != xmlids.end(); ++iter )
             {
                 if( iter != xmlids.begin() )
+                {
                     combinedxmlidss << ",";
+                    combined = true;
+                }
                 combinedxmlidss << *iter;
             }
             XAP_appendComboBoxTextAndInt( m_selectedxmlid, combinedxmlidss.str().c_str(), 0 );
             setRestrictedXMLID( combinedxmlidss.str() );
             
-            int idx = 1;
-            for( std::list< std::string >::const_iterator iter = xmlids.begin();
-                 iter != xmlids.end(); ++iter, ++idx )
+            if (combined)
             {
-                XAP_appendComboBoxTextAndInt( m_selectedxmlid, iter->c_str(), idx );
+                int idx = 1;
+                for( std::set< std::string >::const_iterator iter = xmlids.begin();
+                     iter != xmlids.end(); ++iter, ++idx )
+                {
+                    XAP_appendComboBoxTextAndInt( m_selectedxmlid, iter->c_str(), idx );
+                }
+
+                gtk_combo_box_set_active( m_selectedxmlid, 0 );
+        
+                // std::list< std::string > xmlids;
+                // getRDF()->addRelevantIDsForPosition( xmlids, getView()->getPoint() );
+                // UT_DEBUGMSG(("AP_UnixDialog_RDFEditor, have restricted xmlids size:%d\n", xmlids.size() ));
+                // if( !xmlids.empty() )
+                // {
+                //     setRestrictedXMLID( xmlids.front() );
+                // }
+                
+                g_signal_connect(G_OBJECT(m_selectedxmlid),
+                                 "changed",
+                                 G_CALLBACK(s_OnXMLIDChanged),
+                                 (gpointer) this);
             }
+            else gtk_container_remove(GTK_CONTAINER(gtk_builder_get_object(builder, "topvbox")),  m_restrictxmlidhidew);
         }
-        gtk_combo_box_set_active( m_selectedxmlid, 0 );
-        
-        // std::list< std::string > xmlids;
-        // getRDF()->addRelevantIDsForPosition( xmlids, getView()->getPoint() );
-        // UT_DEBUGMSG(("AP_UnixDialog_RDFEditor, have restricted xmlids size:%d\n", xmlids.size() ));
-        // if( !xmlids.empty() )
-        // {
-        //     setRestrictedXMLID( xmlids.front() );
-        // }
-        
-        g_signal_connect(G_OBJECT(m_selectedxmlid),
-                         "changed",
-                         G_CALLBACK(s_OnXMLIDChanged),
-                         (gpointer) this);
     }
     
     
@@ -625,15 +658,15 @@ AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/)
     ///
 	g_signal_connect (GTK_BUTTON (m_btShowAll), "clicked", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onShowAllClicked), static_cast <gpointer>(this));
-	g_signal_connect (GTK_BUTTON (m_anewtriple), "activate", 
+	g_signal_connect (m_anewtriple, "activate", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onActionNew), static_cast <gpointer>(this));
-	g_signal_connect (GTK_BUTTON (m_acopytriple), "activate", 
+	g_signal_connect (m_acopytriple, "activate", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onActionCopy), static_cast <gpointer>(this));
-	g_signal_connect (GTK_BUTTON (m_adeletetriple), "activate", 
+	g_signal_connect (m_adeletetriple, "activate", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onActionDelete), static_cast <gpointer>(this));
-	g_signal_connect (GTK_BUTTON (m_aimportrdfxml), "activate", 
+	g_signal_connect (m_aimportrdfxml, "activate", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onActionImportRDFXML), static_cast <gpointer>(this));
-	g_signal_connect (GTK_BUTTON (m_aexportrdfxml), "activate", 
+	g_signal_connect (m_aexportrdfxml, "activate", 
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onActionExportRDFXML), static_cast <gpointer>(this));
     g_signal_connect (GTK_DIALOG (m_wDialog), "response",
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onDialogResponse), static_cast <gpointer>(this));
@@ -642,6 +675,11 @@ AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/)
 	g_signal_connect (m_resultsView, "cursor-changed",
 					  G_CALLBACK (AP_UnixDialog_RDFEditor__onCursorChanged), static_cast <gpointer>(this));
 
+#ifndef WITH_REDLAND
+	gtk_action_set_sensitive(m_aimportrdfxml, FALSE);  
+	gtk_action_set_sensitive(m_aexportrdfxml, FALSE);  
+#endif
+
 	g_object_unref(G_OBJECT(builder));
 }
 
@@ -649,9 +687,9 @@ AP_UnixDialog_RDFEditor::constuctWindow (XAP_Frame * /*pFrame*/)
 * Update dialog's data.
 */
 void 
-AP_UnixDialog_RDFEditor::updateWindow ()
+AP_UnixDialog_RDFEditor::_updateWindow ()
 {
-    UT_DEBUGMSG(("RDFEditor::updateWindow()\n"));
+    UT_DEBUGMSG(("RDFEditor::_updateWindow()\n"));
 	ConstructWindowName ();
 	gtk_window_set_title (GTK_WINDOW (m_wDialog), m_WindowName.c_str() );
 }
@@ -660,9 +698,9 @@ void
 AP_UnixDialog_RDFEditor::runModeless (XAP_Frame * pFrame)
 {
 	UT_DEBUGMSG (("MIQ: runModeless ()\n"));
-	constuctWindow (pFrame);
+	_constructWindow (pFrame);
 	UT_ASSERT (m_wDialog);
-	updateWindow ();
+	_updateWindow ();
 	abiSetupModelessDialog (GTK_DIALOG (m_wDialog), pFrame, this, GTK_RESPONSE_CLOSE);
     showAllRDF();
 	gtk_widget_show_all (m_wDialog);
@@ -674,7 +712,7 @@ AP_UnixDialog_RDFEditor::notifyActiveFrame (XAP_Frame * /*pFrame*/)
 {
 	UT_DEBUGMSG (("MIQ: notifyActiveFrame ()\n"));
 	UT_ASSERT (m_wDialog);
-	updateWindow ();
+	_updateWindow ();
 }
 
 void 
@@ -682,7 +720,7 @@ AP_UnixDialog_RDFEditor::activate (void)
 {
 	UT_ASSERT (m_wDialog);
 	UT_DEBUGMSG (("MIQ: AP_UnixDialog_RDFEditor::activate ()\n"));
-	updateWindow ();
+	_updateWindow ();
 	gtk_window_present (GTK_WINDOW (m_wDialog));
 }
 
@@ -709,7 +747,6 @@ AP_UnixDialog_RDFEditor::getSelection()
 {
     std::list< PD_RDFStatement > ret;
     GtkTreeModel* model = GTK_TREE_MODEL(m_resultsModel);
-    GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (m_resultsView));
     list_gtktreeiter_t l = getIterList( GTK_WIDGET(m_resultsView), true );
     for( list_gtktreeiter_t::iterator iter = l.begin(); iter != l.end(); ++iter )
     {
@@ -726,7 +763,7 @@ AP_UnixDialog_RDFEditor::getSelection()
 
         PD_RDFStatement st( getModel(), PD_URI(s), PD_URI(p), PD_Object(o) );
         ret.push_back( st );
-        cerr << "getSelection() st:" << st.toString() << endl;
+        xxx_UT_DEBUGMSG(("getSelection() st: %s\n", st.toString().utf8_str()));
     }
     
     return ret;
@@ -735,7 +772,7 @@ AP_UnixDialog_RDFEditor::getSelection()
 void
 AP_UnixDialog_RDFEditor::onCursorChanged()
 {
-    cerr << "onCursorChanged()" << endl;
+    xxx_UT_DEBUGMSG(("onCursorChanged()\n"));
     PD_URI pkg_idref("http://docs.oasis-open.org/opendocument/meta/package/common#idref");
     PD_DocumentRDFHandle rdf = getRDF();
     PD_RDFModelHandle  model = getModel();
@@ -746,15 +783,15 @@ AP_UnixDialog_RDFEditor::onCursorChanged()
         for( std::list< PD_RDFStatement >::iterator siter = sl.begin();
              siter != sl.end(); ++siter )
         {
-            cerr << " subj:" << siter->getSubject().toString() << endl;
+            xxx_UT_DEBUGMSG((" subj: %s\n", siter->getSubject().toString().utf8_string()));
             PD_ObjectList ul = model->getObjects( siter->getSubject(), pkg_idref );
             for( PD_ObjectList::iterator uiter = ul.begin(); uiter != ul.end(); ++uiter )
             {
                 std::string xmlid = uiter->toString();
                 
-                cerr << " xmlid:" << xmlid << endl;
+                xxx_UT_DEBUGMSG((" xmlid: %s\n", xmlid.c_str()));
                 std::pair< PT_DocPosition, PT_DocPosition > range = rdf->getIDRange( xmlid );
-                cerr << " start:" << range.first << " end:" << range.second << endl;
+                xxx_UT_DEBUGMSG((" start: %d end: %d\n", range.first, range.second));
                 getView()->cmdSelect( range );
                 
             }
