@@ -37,14 +37,16 @@
 #include "fv_View.h"
 #include "pd_Style.h"
 #include "ut_string_class.h"
+#include "pt_PieceTable.h"
 
 #include "gr_UnixCairoGraphics.h"
+#include "xap_Gtk2Compat.h"
 
 // define to 0 to popup dialogs on top of each other, 1 to hide them
 #define HIDE_MAIN_DIALOG 0
 
 XAP_Dialog * AP_UnixDialog_Styles::static_constructor(XAP_DialogFactory * pFactory,
-													   XAP_Dialog_Id id)
+						      XAP_Dialog_Id id)
 {
 	AP_UnixDialog_Styles * p = new AP_UnixDialog_Styles(pFactory,id);
 	return p;
@@ -317,14 +319,22 @@ void AP_UnixDialog_Styles::runModal(XAP_Frame * pFrame)
 
 	// the expose event of the preview
 	g_signal_connect(G_OBJECT(m_wParaPreviewArea),
-					   "draw",
-					   G_CALLBACK(s_paraPreview_draw),
-					   reinterpret_cast<gpointer>(this));
+#if GTK_CHECK_VERSION(3,0,0)
+			 "draw",
+#else
+			 "expose_event",
+#endif
+			 G_CALLBACK(s_paraPreview_draw),
+			 reinterpret_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(m_wCharPreviewArea),
-					   "draw",
-					   G_CALLBACK(s_charPreview_draw),
-					   reinterpret_cast<gpointer>(this));
+#if GTK_CHECK_VERSION(3,0,0)
+			 "draw",
+#else
+			 "expose_event",
+#endif
+			 G_CALLBACK(s_charPreview_draw),
+			 reinterpret_cast<gpointer>(this));
 	
 	// connect the select_row signal to the clist
 	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection(GTK_TREE_VIEW(m_tvStyles))), "changed",
@@ -396,7 +406,7 @@ void AP_UnixDialog_Styles::event_DeleteClicked(void)
 		GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(m_tvStyles));
 		GtkTreeIter iter;
 		gtk_tree_model_get_iter(model, &iter, m_selectedStyle);
-		gtk_tree_model_get(model, &iter, 0, &style, -1);
+		gtk_tree_model_get(model, &iter, 1, &style, -1);
 
 		if (!style)
 			return; // ok, nothing's selected. that's fine
@@ -476,12 +486,12 @@ GtkWidget * AP_UnixDialog_Styles::_constructWindow(void)
 {
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Styles.xml";
-	
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Styles.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Styles-2.ui");
+#endif
 
 	GtkWidget *window = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_Styles"));
 	UT_UTF8String s;
@@ -594,13 +604,13 @@ void AP_UnixDialog_Styles::_connectSignals(void) const
 void AP_UnixDialog_Styles::_populateCList(void)
 {
 	const PD_Style * pStyle;
-	const gchar * name = NULL;
+	const gchar *org_name, *loc_name;
 
 	size_t nStyles = getDoc()->getStyleCount();
 	xxx_UT_DEBUGMSG(("DOM: we have %d styles\n", nStyles));
 	
 	if (m_listStyles == NULL) {
-		m_listStyles = gtk_list_store_new (1, G_TYPE_STRING);
+		m_listStyles = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 		GtkTreeModel *sort = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (m_listStyles));
 		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sort), 0, GTK_SORT_ASCENDING);
 		gtk_tree_view_set_model (GTK_TREE_VIEW(m_tvStyles), sort);
@@ -617,35 +627,49 @@ void AP_UnixDialog_Styles::_populateCList(void)
 		gtk_tree_view_append_column(GTK_TREE_VIEW(m_tvStyles), column);
 	}
 
-	GtkTreeIter iter;
-	GtkTreeIter *pHighlightIter = NULL;
+	GtkTreeIter iter, pHighlightIter;
+	bool highlight = false;
+	UT_GenericVector<PD_Style*> *pStyles = NULL;
+	getDoc()->enumStyles(pStyles);
 	for (UT_uint32 i = 0; i < nStyles; i++)
 	{
-		getDoc()->enumStyles(static_cast<UT_uint32>(i), &name, &pStyle);
+		pStyle = pStyles->getNthItem(i);
 
 		// style has been deleted probably
 		if (!pStyle)
 			continue;
 
+		org_name = pStyle->getName();
+		
+		UT_UTF8String sLoc;
+		pt_PieceTable::s_getLocalisedStyleName(org_name, sLoc);
+		loc_name = sLoc.utf8_str();
+
 		if ((m_whichType == ALL_STYLES) || 
 			(m_whichType == USED_STYLES && pStyle->isUsed()) ||
 			(m_whichType == USER_STYLES && pStyle->isUserDefined()) ||
-			(!strcmp(m_sNewStyleName.utf8_str(), pStyle->getName()))) /* show newly created style anyways */
+			(!strcmp(m_sNewStyleName.utf8_str(), loc_name))) /* show newly created style anyways */
 		{
 			gtk_list_store_append(m_listStyles, &iter);
-			gtk_list_store_set(m_listStyles, &iter, 0, name, -1);
+			gtk_list_store_set(m_listStyles, &iter, 0, loc_name, 1, org_name, -1);
 			
-			if (!strcmp(m_sNewStyleName.utf8_str(), pStyle->getName())) {
-				pHighlightIter = gtk_tree_iter_copy(&iter);
+			if (!strcmp(m_sNewStyleName.utf8_str(), loc_name)) {
+				pHighlightIter = iter;
+				highlight = true;
 			}
 		}
 	}
+	DELETEP(pStyles);
 
 	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(m_tvStyles));
-	if (pHighlightIter) {
+	if (highlight) {
 		// select new/modified
-		gtk_tree_selection_select_iter(selection, pHighlightIter);
-		gtk_tree_iter_free(pHighlightIter);
+		GtkTreeModel *sort = gtk_tree_view_get_model(GTK_TREE_VIEW(m_tvStyles));
+		gtk_tree_model_sort_convert_child_iter_to_iter(GTK_TREE_MODEL_SORT(sort), &iter, &pHighlightIter);
+		gtk_tree_selection_select_iter(selection, &iter);
+		GtkTreePath *path = gtk_tree_model_get_path(sort, &iter); 
+		gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(m_tvStyles), path, NULL, FALSE, 0, 0);
+		gtk_tree_path_free(path);
 	}
 	else {
 		// select first
@@ -684,7 +708,7 @@ const char * AP_UnixDialog_Styles::getCurrentStyle (void) const
 	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(m_tvStyles));
 	GtkTreeIter iter;
 	gtk_tree_model_get_iter(model, &iter, m_selectedStyle);
-	gtk_tree_model_get(model, &iter, 0, &style, -1);
+	gtk_tree_model_get(model, &iter, 1, &style, -1);
 	
 	if (!style)
 		return NULL;
@@ -709,6 +733,10 @@ GtkWidget *  AP_UnixDialog_Styles::_constructModifyDialog(void)
 
 	modifyDialog = abiDialogNew("modify style dialog", TRUE, title.utf8_str());
 	gtk_container_set_border_width (GTK_CONTAINER (modifyDialog), 5);
+	gtk_window_set_resizable(GTK_WINDOW(modifyDialog), FALSE);
+#if !GTK_CHECK_VERSION(3,0,0)
+	gtk_dialog_set_has_separator(GTK_DIALOG(modifyDialog), FALSE);
+#endif	  	
 
 	_constructModifyDialogContents(gtk_dialog_get_content_area(GTK_DIALOG (modifyDialog)));
 
@@ -765,11 +793,10 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 	gtk_box_pack_start (GTK_BOX (dialog_vbox1), OverallVbox, TRUE, TRUE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (OverallVbox), 5);
 
-	comboTable = gtk_table_new (4,2, TRUE);
+	comboTable = gtk_table_new (6,2, FALSE);
 	gtk_widget_show (comboTable);
-	gtk_box_pack_start (GTK_BOX (OverallVbox), comboTable, TRUE, TRUE, 2);
+	gtk_box_pack_start (GTK_BOX (OverallVbox), comboTable, FALSE, FALSE, 2);
 	gtk_container_set_border_width (GTK_CONTAINER (comboTable), 2);
-	gtk_table_set_row_spacings (GTK_TABLE (comboTable), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (comboTable), 2);
 
 	UT_UTF8String s;
@@ -792,11 +819,20 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 	gtk_misc_set_alignment (GTK_MISC (styleTypeLabel), 0, 0.5);
 	gtk_label_set_justify (GTK_LABEL (styleTypeLabel), GTK_JUSTIFY_LEFT);
 	gtk_misc_set_padding (GTK_MISC (styleTypeLabel), 2, 2);
+	
+	GtkWidget *spacer = gtk_label_new(" ");
+	gtk_widget_show(spacer);
+	gtk_table_attach (GTK_TABLE (comboTable), spacer, 0, 2, 2, 3,
+					  (GtkAttachOptions) (GTK_FILL),
+					  (GtkAttachOptions) (0), 0, 0);
+	gtk_table_attach (GTK_TABLE (comboTable), spacer, 0, 2, 5, 6,
+					  (GtkAttachOptions) (GTK_FILL),
+					  (GtkAttachOptions) (0), 0, 0);
 
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyBasedOn,s);
 	basedOnLabel = gtk_label_new (s.utf8_str() );
 	gtk_widget_show (basedOnLabel);
-	gtk_table_attach (GTK_TABLE (comboTable), basedOnLabel, 0, 1, 2, 3,
+	gtk_table_attach (GTK_TABLE (comboTable), basedOnLabel, 0, 1, 3, 4,
 					  (GtkAttachOptions) (GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (basedOnLabel), 0, 0.5);
@@ -806,24 +842,24 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyFollowing,s);
 	followingLabel = gtk_label_new (s.utf8_str());
 	gtk_widget_show (followingLabel);
-	gtk_table_attach (GTK_TABLE (comboTable), followingLabel, 1, 2, 2, 3,
+	gtk_table_attach (GTK_TABLE (comboTable), followingLabel, 1, 2, 3, 4,
 					  (GtkAttachOptions) (GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (followingLabel), 0, 0.5);
-	gtk_misc_set_padding (GTK_MISC (followingLabel), 2, 3);
+	gtk_misc_set_padding (GTK_MISC (followingLabel), 2, 2);
 
 	styleNameEntry = gtk_entry_new ();
 	gtk_widget_show (styleNameEntry);
 	gtk_table_attach (GTK_TABLE (comboTable), styleNameEntry, 0, 1, 1, 2,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-					  (GtkAttachOptions) (0), 0, 0);
+					  (GtkAttachOptions) (0), 0, 4);
 	gtk_widget_set_size_request (styleNameEntry, 158, -1);
 
 	basedOnCombo = gtk_combo_box_text_new_with_entry ();
 	gtk_widget_show (basedOnCombo);
-	gtk_table_attach (GTK_TABLE (comboTable), basedOnCombo, 0, 1, 3, 4,
+	gtk_table_attach (GTK_TABLE (comboTable), basedOnCombo, 0, 1, 4, 5,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-					  (GtkAttachOptions) (0), 0, 0);
+					  (GtkAttachOptions) (0), 0, 4);
 		
 	basedOnEntry = gtk_bin_get_child(GTK_BIN(basedOnCombo));
 	gtk_widget_show (basedOnEntry);
@@ -831,9 +867,9 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 
 	followingCombo = gtk_combo_box_text_new_with_entry ();
 	gtk_widget_show (followingCombo);
-	gtk_table_attach (GTK_TABLE (comboTable), followingCombo, 1, 2, 3, 4,
+	gtk_table_attach (GTK_TABLE (comboTable), followingCombo, 1, 2, 4, 5,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-					  (GtkAttachOptions) (0), 0, 0);
+					  (GtkAttachOptions) (0), 0, 4);
 
 	followingEntry = gtk_bin_get_child(GTK_BIN(followingCombo));
 	gtk_widget_show (followingEntry);
@@ -847,7 +883,7 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 		gtk_widget_show (styleTypeCombo);
 		gtk_table_attach (GTK_TABLE (comboTable), styleTypeCombo, 1, 2, 1, 2,
 						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+						  (GtkAttachOptions) (0), 0, 4);
 
 		styleTypeEntry = gtk_bin_get_child(GTK_BIN(styleTypeCombo));
 		gtk_widget_show (styleTypeEntry);
@@ -859,35 +895,51 @@ void  AP_UnixDialog_Styles::_constructModifyDialogContents(GtkWidget * container
 		gtk_widget_show (styleTypeEntry);
 		gtk_table_attach (GTK_TABLE (comboTable), styleTypeEntry, 1, 2, 1, 2,
 						  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-						  (GtkAttachOptions) (0), 0, 0);
+						  (GtkAttachOptions) (0), 0, 4);
 		gtk_widget_set_size_request (styleTypeEntry, 158, -1);
 	}
 
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyPreview,s);
-	previewFrame = gtk_frame_new (s.utf8_str());
+	s = "<b>" + s + "</b>";
+	GtkWidget *lbPrevFrame = gtk_label_new(NULL);
+	gtk_label_set_markup(GTK_LABEL(lbPrevFrame), s.utf8_str());
+	gtk_widget_show(lbPrevFrame);
+	previewFrame = gtk_frame_new(NULL);
+	gtk_frame_set_label_widget(GTK_FRAME(previewFrame), lbPrevFrame);
 	gtk_frame_set_shadow_type(GTK_FRAME(previewFrame), GTK_SHADOW_NONE);
 	gtk_widget_show (previewFrame);
-	gtk_box_pack_start (GTK_BOX (OverallVbox), previewFrame, TRUE, TRUE, 2);
-	gtk_container_set_border_width (GTK_CONTAINER (previewFrame), 5);
+	gtk_box_pack_start (GTK_BOX (OverallVbox), previewFrame, TRUE, TRUE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (previewFrame), 3);
+
+	GtkWidget *wDrawFrame = gtk_frame_new(NULL);
+	gtk_frame_set_shadow_type(GTK_FRAME(wDrawFrame), GTK_SHADOW_NONE);
+	gtk_widget_show(wDrawFrame);
+	gtk_container_add(GTK_CONTAINER(previewFrame), wDrawFrame);
+	gtk_container_set_border_width(GTK_CONTAINER(wDrawFrame), 6);
 
 	modifyDrawingArea = createDrawingArea();
+	gtk_widget_set_size_request (modifyDrawingArea, -1, 85);
+	gtk_container_add (GTK_CONTAINER (wDrawFrame), modifyDrawingArea);
 	gtk_widget_show (modifyDrawingArea);
-	gtk_container_add (GTK_CONTAINER (previewFrame), modifyDrawingArea);
-	gtk_widget_set_size_request (modifyDrawingArea, -1, 120);
 
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_ModifyDescription,s);
-	GtkWidget * descriptionFrame = gtk_frame_new (s.utf8_str());
+	s = "<b>" + s + "</b>";
+	GtkWidget *lbDescrFrame = gtk_label_new(NULL);
+	gtk_label_set_markup(GTK_LABEL(lbDescrFrame), s.utf8_str());
+	gtk_widget_show(lbDescrFrame);
+	GtkWidget *descriptionFrame = gtk_frame_new(NULL);
+	gtk_frame_set_label_widget(GTK_FRAME(descriptionFrame), lbDescrFrame);
 	gtk_frame_set_shadow_type(GTK_FRAME(descriptionFrame), GTK_SHADOW_NONE);
 	gtk_widget_show (descriptionFrame);
 	gtk_box_pack_start (GTK_BOX (OverallVbox), descriptionFrame, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (descriptionFrame), 5);
 
 	DescriptionText = gtk_label_new (NULL);
+	gtk_misc_set_padding(GTK_MISC(DescriptionText), 0, 6);
 	gtk_widget_show (DescriptionText);
 	gtk_container_add (GTK_CONTAINER (descriptionFrame), DescriptionText);
-	gtk_misc_set_alignment (GTK_MISC (DescriptionText), 0, 0.5);
-	gtk_label_set_justify (GTK_LABEL (DescriptionText), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (DescriptionText), TRUE);
+	gtk_widget_set_size_request(DescriptionText, 438, -1);
 //
 // Code to choose properties to be removed from the current style.
 //
@@ -1013,9 +1065,13 @@ void AP_UnixDialog_Styles::_connectModifySignals(void)
 					   reinterpret_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(m_wModifyDrawingArea),
-					   "draw",
-					   G_CALLBACK(s_modifyPreview_draw),
-					   reinterpret_cast<gpointer>(this));
+#if GTK_CHECK_VERSION(3,0,0)
+			 "draw",
+#else
+			 "expose_event",
+#endif
+			 G_CALLBACK(s_modifyPreview_draw),
+			 reinterpret_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(m_wDeletePropButton),
 					   "clicked",
@@ -1140,7 +1196,12 @@ void AP_UnixDialog_Styles::rebuildDeleteProps(void)
  */
 void AP_UnixDialog_Styles::event_basedOn(void)
 {
+	const XAP_StringSet *pSS = m_pApp->getStringSet();
 	const gchar * psz = gtk_entry_get_text( GTK_ENTRY( m_wBasedOnEntry));
+	if (strcmp(psz, pSS->getValue(AP_STRING_ID_DLG_Styles_DefNone)) == 0)
+		psz = "None";    
+	else
+		psz = pt_PieceTable::s_getUnlocalisedStyleName(psz);	
 	g_snprintf(static_cast<gchar *>(m_basedonName),40,"%s",psz);
 	addOrReplaceVecAttribs("basedon",getBasedonName());
 	updateCurrentStyle();
@@ -1152,7 +1213,12 @@ void AP_UnixDialog_Styles::event_basedOn(void)
  */
 void AP_UnixDialog_Styles::event_followedBy(void)
 {
+	const XAP_StringSet *pSS = m_pApp->getStringSet();
 	const gchar * psz = gtk_entry_get_text( GTK_ENTRY(m_wFollowingEntry));
+	if (strcmp(psz, pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent)) == 0)
+		psz = "Current Settings";    
+	else
+		psz = pt_PieceTable::s_getUnlocalisedStyleName(psz);	
 	g_snprintf(static_cast<gchar *>(m_followedbyName),40,"%s",psz);
 	addOrReplaceVecAttribs("followedby",getFollowedbyName());
 }
@@ -1375,7 +1441,9 @@ bool  AP_UnixDialog_Styles::_populateModify(void)
 			m_answer = AP_Dialog_Styles::a_CANCEL;
 			return false;
 		}
-		gtk_entry_set_text (GTK_ENTRY(m_wStyleNameEntry), getCurrentStyle());
+		UT_UTF8String sLoc;
+		pt_PieceTable::s_getLocalisedStyleName(getCurrentStyle(), sLoc);
+		gtk_entry_set_text(GTK_ENTRY(m_wStyleNameEntry), sLoc.utf8_str());
 		gtk_editable_set_editable(GTK_EDITABLE(m_wStyleNameEntry),FALSE );
 	}
 	else
@@ -1412,13 +1480,15 @@ bool  AP_UnixDialog_Styles::_populateModify(void)
 //
 // Next make a glists of all styles and attach them to the BasedOn and FollowedBy
 //
-	size_t nStyles = getDoc()->getStyleCount();
-	const char * name = NULL;
-	const PD_Style * pcStyle = NULL;
-	for (UT_uint32 i = 0; i < nStyles; i++)
+	UT_GenericVector<PD_Style*> * pStyles = NULL;
+	getDoc()->enumStyles(pStyles);
+	UT_sint32 nStyles = pStyles->getItemCount();
+	for (UT_sint32 i = 0; i < nStyles; i++)
 	{
-	    getDoc()->enumStyles(i, &name, &pcStyle);
-
+		const PD_Style * pcStyle = pStyles->getNthItem(i);
+		const char * name = pcStyle->getName();
+		UT_UTF8String sLoc;
+		pt_PieceTable::s_getLocalisedStyleName(name, sLoc);
 		if(pBasedOnStyle && pcStyle == pBasedOnStyle)
 		{
 			szBasedOn = name;
@@ -1426,12 +1496,13 @@ bool  AP_UnixDialog_Styles::_populateModify(void)
 		if(pFollowedByStyle && pcStyle == pFollowedByStyle)
 			szFollowedBy = name;
 		if(szCurrentStyle && strcmp(name,szCurrentStyle) != 0)
-			m_gbasedOnStyles.push_back(name);
+			m_gbasedOnStyles.push_back(sLoc.utf8_str());
 		else if(szCurrentStyle == NULL)
-			m_gbasedOnStyles.push_back(name);
+			m_gbasedOnStyles.push_back(sLoc.utf8_str());
 
-		m_gfollowedByStyles.push_back(name);
+		m_gfollowedByStyles.push_back(sLoc.utf8_str());
 	}
+	DELETEP(pStyles);
 
 	m_gfollowedByStyles.sort();
 	m_gfollowedByStyles.push_back(pSS->getValue(AP_STRING_ID_DLG_Styles_DefCurrent));
@@ -1454,8 +1525,13 @@ bool  AP_UnixDialog_Styles::_populateModify(void)
 //
 	if(!isNew())
 	{
+		UT_UTF8String sLoc;
+		
 		if(pBasedOnStyle != NULL)
-			gtk_entry_set_text (GTK_ENTRY(m_wBasedOnEntry),szBasedOn);
+		{
+			pt_PieceTable::s_getLocalisedStyleName(szBasedOn, sLoc);
+			gtk_entry_set_text(GTK_ENTRY(m_wBasedOnEntry), sLoc.utf8_str());
+		}
 		else
 		{
 			pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefNone,s);
@@ -1463,7 +1539,10 @@ bool  AP_UnixDialog_Styles::_populateModify(void)
 		}
 		
 		if(pFollowedByStyle != NULL)
-			gtk_entry_set_text (GTK_ENTRY(m_wFollowingEntry),szFollowedBy);
+		{
+			pt_PieceTable::s_getLocalisedStyleName(szFollowedBy, sLoc);
+			gtk_entry_set_text(GTK_ENTRY(m_wFollowingEntry), sLoc.utf8_str());
+		}
 		else
 		{
 			pSS->getValueUTF8(AP_STRING_ID_DLG_Styles_DefCurrent,s);
