@@ -24,6 +24,7 @@
 #include "ut_string.h"
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
+#include "pt_PieceTable.h"
 
 #include "xap_UnixDialogHelper.h"
 
@@ -35,6 +36,38 @@
 #include "ap_Dialog_Id.h"
 #include "ap_UnixDialog_Stylist.h"
 
+static gint s_compare (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer /*userdata*/)
+{
+	GtkTreePath *path;
+	gint depth, row1, row2, res;
+	gchar *style1, *style2;
+
+	path = gtk_tree_model_get_path(model, a);	
+	depth = gtk_tree_path_get_depth(path);
+	
+	if (depth == 1)
+	{
+		gtk_tree_model_get(model, a, 1, &row1, -1);
+		gtk_tree_model_get(model, b, 1, &row2, -1);
+		
+		res = row1 - row2;
+	}
+	else
+	{
+		gtk_tree_model_get(model, a, 0, &style1, -1);
+		gtk_tree_model_get(model, b, 0, &style2, -1);
+	
+		res = g_utf8_collate(style1, style2);
+	
+		g_free(style1);
+		g_free(style2);
+	}
+	
+	gtk_tree_path_free(path);
+	
+	return res;
+}
+
 static void s_types_clicked(GtkTreeView *treeview,
                             AP_UnixDialog_Stylist * dlg)
 {
@@ -112,9 +145,6 @@ AP_UnixDialog_Stylist::AP_UnixDialog_Stylist(XAP_DialogFactory * pDlgFactory,
 	: AP_Dialog_Stylist(pDlgFactory,id), 
 	  m_windowMain(NULL),
 	  m_wStyleList(NULL),
-	  m_wApply(NULL),
-	  m_wClose(NULL),
-	  m_wOK(NULL),
 	  m_wRenderer(NULL),
 	  m_wModel(NULL),
 	  m_wStyleListContainer(NULL)
@@ -133,8 +163,10 @@ void AP_UnixDialog_Stylist::event_Close(void)
 
 void AP_UnixDialog_Stylist::setStyleInGUI(void)
 {
-	UT_sint32 row,col;
-	UT_UTF8String sCurStyle = *getCurStyle();
+	GtkTreeIter child, parent;
+	gboolean itering;
+	gchar *entry;
+	UT_UTF8String sLocCurStyle, sCurStyle = *getCurStyle();
 
 	if((getStyleTree() == NULL) || (sCurStyle.size() == 0))
 		updateDialog();
@@ -145,13 +177,36 @@ void AP_UnixDialog_Stylist::setStyleInGUI(void)
 	if(isStyleTreeChanged())
 		_fillTree();
 
-	getStyleTree()->findStyle(sCurStyle,row,col);
-	UT_DEBUGMSG(("After findStyle row %d col %d col \n",row,col));
-	UT_UTF8String sPathFull = UT_UTF8String_sprintf("%d:%d",row,col);
-	UT_UTF8String sPathRow = UT_UTF8String_sprintf("%d",row);
-	UT_DEBUGMSG(("Full Path string is %s \n",sPathFull.utf8_str()));
-	GtkTreePath * gPathRow = gtk_tree_path_new_from_string (sPathRow.utf8_str());
-	GtkTreePath * gPathFull = gtk_tree_path_new_from_string (sPathFull.utf8_str());
+	pt_PieceTable::s_getLocalisedStyleName(sCurStyle.utf8_str(), sLocCurStyle);
+
+	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(m_wStyleList)); 
+	itering = gtk_tree_model_get_iter_first(model, &parent);
+
+	while (itering)
+	{
+		if (gtk_tree_model_iter_children(model, &child, &parent))
+		{
+			do
+			{
+				gtk_tree_model_get(model, &child, 0, &entry, -1);
+		
+				if (strcmp(sLocCurStyle.utf8_str(), entry) == 0)
+				{
+					itering = FALSE;
+					break;
+				}
+			
+				g_free(entry);
+			
+			}
+			while (gtk_tree_model_iter_next(model, &child));
+		}
+		
+		if (itering) itering = gtk_tree_model_iter_next(model, &parent);
+	}
+
+	GtkTreePath *gPathFull = gtk_tree_model_get_path(model, &child); 
+	GtkTreePath *gPathRow = gtk_tree_model_get_path(model, &parent); 
 	gtk_tree_view_expand_row( GTK_TREE_VIEW(m_wStyleList),gPathRow,TRUE);
 	gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(m_wStyleList),gPathFull,NULL,TRUE,0.5,0.5);
 	gtk_tree_view_set_cursor(GTK_TREE_VIEW(m_wStyleList),gPathFull,NULL,TRUE);
@@ -242,39 +297,31 @@ void AP_UnixDialog_Stylist::runModal(XAP_Frame * pFrame)
 
 GtkWidget * AP_UnixDialog_Stylist::_constructWindow(void)
 {
-	// get the path where our UI file is located
-	std::string ui_path;
-	if(m_bIsModal)
-	{
-		ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Stylist_modal.xml";
-	}
-	else
-	{
-		ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Stylist.xml";
-	}
-
 	// load the dialog from the UI file
-	GtkBuilder* builder = gtk_builder_new();
-	gtk_builder_add_from_file(builder, ui_path.c_str(), NULL);
-	
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Stylist.ui");
+#else
+	GtkBuilder* builder = newDialogBuilder("ap_UnixDialog_Stylist-2.ui");
+#endif
+
 	const XAP_StringSet * pSS = m_pApp->getStringSet ();
 
 	m_windowMain   = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_Stylist"));
 	m_wStyleListContainer  = GTK_WIDGET(gtk_builder_get_object(builder, "TreeViewContainer"));
+
 	if(m_bIsModal)
 	{
-		m_wApply = GTK_WIDGET(gtk_builder_get_object(builder, "btApply"));
+		/*button =*/ gtk_dialog_add_button(GTK_DIALOG(m_windowMain), "gtk-ok", GTK_RESPONSE_OK);
 	}
 	else
 	{
-		m_wOK = GTK_WIDGET(gtk_builder_get_object(builder, "btOK"));
+		/*button =*/ gtk_dialog_add_button(GTK_DIALOG(m_windowMain), "gtk-apply", GTK_RESPONSE_APPLY);
 	}
-	m_wClose = GTK_WIDGET(gtk_builder_get_object(builder, "btClose"));
 
 	// set the dialog title
 	UT_UTF8String s;
 	pSS->getValueUTF8(AP_STRING_ID_DLG_Stylist_Title,s);
-	abiDialogSetTitle(m_windowMain, s.utf8_str());
+	abiDialogSetTitle(m_windowMain, "%s", s.utf8_str());
 
 	g_object_unref(G_OBJECT(builder));
 	
@@ -317,7 +364,7 @@ void  AP_UnixDialog_Stylist::_fillTree(void)
 	m_wModel = gtk_tree_store_new (3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
 
 	page = 0;
-	UT_UTF8String sTmp(""); 
+	UT_UTF8String sTmp(""), sLoc; 
 	for(row= 0; row < pStyleTree->getNumRows();row++)
 	{
 		gtk_tree_store_append (m_wModel, &iter, NULL);
@@ -339,21 +386,26 @@ void  AP_UnixDialog_Stylist::_fillTree(void)
 					UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 					break;
 				}
-				gtk_tree_store_set (m_wModel, &child_iter, 0, sTmp.utf8_str(), 1, row,2,col+1, -1);
-				xxx_UT_DEBUGMSG(("Adding style %s at row %d col %d \n",sTmp.utf8_str(),row,col+1));
+				pt_PieceTable::s_getLocalisedStyleName(sTmp.utf8_str(), sLoc);
+				xxx_UT_DEBUGMSG(("Adding style %s at row %d col %d \n", sLoc.utf8_str(), row, col + 1));
+				gtk_tree_store_set(m_wModel, &child_iter, 0, sLoc.utf8_str(), 1, row, 2, col + 1, -1);
 				page++;
 			}
 		}
 		else
 		{
-			xxx_UT_DEBUGMSG(("Adding style %s at row %d \n",sTmp.utf8_str(),row));
-			gtk_tree_store_set (m_wModel, &iter, 0, sTmp.utf8_str(), 1,row,2,0,-1);
+			pt_PieceTable::s_getLocalisedStyleName(sTmp.utf8_str(), sLoc);
+			xxx_UT_DEBUGMSG(("Adding style %s at row %d \n", sLoc.utf8_str(), row));
+			gtk_tree_store_set(m_wModel, &iter, 0, sLoc.utf8_str(), 1, row, 2, 0, -1);
 			page++;
 		}
 	}
 
 	// create a new treeview
-	m_wStyleList = gtk_tree_view_new_with_model (GTK_TREE_MODEL (m_wModel));
+	GtkTreeSortable *sort = GTK_TREE_SORTABLE(m_wModel);
+	gtk_tree_sortable_set_sort_func(sort, 0, s_compare, NULL, NULL);
+	gtk_tree_sortable_set_sort_column_id(sort, 0, GTK_SORT_ASCENDING);     
+	m_wStyleList = gtk_tree_view_new_with_model (GTK_TREE_MODEL (sort));
 	g_object_unref (G_OBJECT (m_wModel));
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (m_wStyleList), true);
 
