@@ -45,6 +45,7 @@
 #include "ap_Strings.h"
 
 #include "ap_UnixDialog_Tab.h"
+#include "xap_Gtk2Compat.h"
 
 //! Column indices for list-store
 enum {
@@ -233,12 +234,12 @@ void AP_UnixDialog_Tab::runModal (XAP_Frame *pFrame)
 GtkWidget * 
 AP_UnixDialog_Tab::_constructWindow ()
 {
-	// get the path where our UI file is located
-	std::string ui_path = static_cast<XAP_UnixApp*>(XAP_App::getApp())->getAbiSuiteAppUIDir() + "/ap_UnixDialog_Tab.xml";
-
 	// load the dialog from the UI file
-	m_pBuilder = gtk_builder_new();
-	gtk_builder_add_from_file(m_pBuilder, ui_path.c_str(), NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+	m_pBuilder = newDialogBuilder("ap_UnixDialog_Tab.ui");
+#else
+	m_pBuilder = newDialogBuilder("ap_UnixDialog_Tab-2.ui");
+#endif
 	GtkWidget *wDialog = GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "ap_UnixDialog_Tab"));
 	m_exUserTabs = GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "exUserTabs"));
 
@@ -248,11 +249,11 @@ AP_UnixDialog_Tab::_constructWindow ()
 	pSS->getValueUTF8 (AP_STRING_ID_DLG_Tab_TabTitle, s);
 	gtk_window_set_title (GTK_WINDOW (wDialog), s.utf8_str());	
 	
-	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbDefaultTab")), pSS, AP_STRING_ID_DLG_Tab_Label_DefaultTS);
+	localizeLabel (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbDefaultTab")), pSS, AP_STRING_ID_DLG_Tab_Label_DefaultTS);
 	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbUserTabs")), pSS, AP_STRING_ID_DLG_Tab_Label_Existing);
-	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbPosition")), pSS, AP_STRING_ID_DLG_Tab_Label_Position);
-	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbAlignment")), pSS, AP_STRING_ID_DLG_Tab_Label_Alignment);
-	localizeLabelMarkup (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbLeader")), pSS, AP_STRING_ID_DLG_Tab_Label_Leader);
+	localizeLabel (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbPosition")), pSS, AP_STRING_ID_DLG_Tab_Label_Position);
+	localizeLabel (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbAlignment")), pSS, AP_STRING_ID_DLG_Tab_Label_Alignment);
+	localizeLabel (GTK_WIDGET(gtk_builder_get_object(m_pBuilder, "lbLeader")), pSS, AP_STRING_ID_DLG_Tab_Label_Leader);
 
 
 	// initialise
