@@ -85,14 +85,14 @@ void AP_UnixFrame::setXScrollRange(void)
 	gtk_widget_get_allocation(GTK_WIDGET(pFrameImpl->m_dArea),&allocation);
 	if(pFrameImpl->m_dArea) //this isn't guaranteed in AbiCommand
 		windowWidth = static_cast<int>(pGr->tluD (allocation.width));
-	
+
 	int newvalue = ((m_pView) ? m_pView->getXScrollOffset() : 0);
 	int newmax = width - windowWidth; /* upper - page_size */
 	if (newmax <= 0)
 		newvalue = 0;
 	else if (newvalue > newmax)
 		newvalue = newmax;
-	
+
 	bool bDifferentPosition = false;
 	bool bDifferentLimits = false;
 	if(pFrameImpl->m_pHadj) //this isn't guaranteed in AbiCommand
@@ -101,14 +101,16 @@ void AP_UnixFrame::setXScrollRange(void)
 		bDifferentLimits = ((width-windowWidth) != gtk_adjustment_get_upper(pFrameImpl->m_pHadj)-
 						                        gtk_adjustment_get_page_size(pFrameImpl->m_pHadj));
 	}
-		
-	pFrameImpl->_setScrollRange(apufi_scrollX, newvalue, static_cast<gfloat>(width), static_cast<gfloat>(windowWidth));
-	
+
+
 	if (m_pView && (bDifferentPosition || bDifferentLimits))
+	{
+		pFrameImpl->_setScrollRange(apufi_scrollX, newvalue, static_cast<gfloat>(width), static_cast<gfloat>(windowWidth));
 		m_pView->sendHorizontalScrollEvent(newvalue, 
 										   static_cast<UT_sint32>
 												(gtk_adjustment_get_upper(pFrameImpl->m_pHadj)-
 												 gtk_adjustment_get_page_size(pFrameImpl->m_pHadj)));
+	}
 }
 
 void AP_UnixFrame::setYScrollRange(void)
@@ -318,7 +320,7 @@ void AP_UnixFrame::_scrollFuncX(void * pData, UT_sint32 xoff, UT_sint32 /*xrange
 	// (with clamping).  then cause the view to scroll.
 
 	gfloat xoffNew = xoff;
-	gfloat xoffMax = gtk_adjustment_get_upper(pFrameImpl->m_pVadj) - 
+	gfloat xoffMax = gtk_adjustment_get_upper(pFrameImpl->m_pHadj) - 
 		gtk_adjustment_get_page_size(pFrameImpl->m_pHadj);
 	if (xoffMax <= 0)
 		xoffNew = 0;
@@ -397,9 +399,17 @@ void AP_UnixFrame::toggleTopRuler(bool bRulerOn)
 		pFrameData->m_pTopRuler = pUnixTopRuler;		
 		pFrameImpl->m_topRuler = pUnixTopRuler->createWidget();
 
-		// attach everything	
+		// attach everything
+#if GTK_CHECK_VERSION(3,0,0)
 		gtk_grid_attach(GTK_GRID(pFrameImpl->m_innergrid), 
 				 pFrameImpl->m_topRuler, 0, 0, 2, 1);
+#else
+		gtk_table_attach(GTK_TABLE(pFrameImpl->m_innergrid), 
+						 pFrameImpl->m_topRuler, 0, 2, 0, 1, 
+						 (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+						 (GtkAttachOptions)(GTK_FILL),
+						 0, 0);
+#endif
 
 		static_cast<AP_TopRuler *>(pUnixTopRuler)->setView(m_pView,iZoom);
 
@@ -452,8 +462,16 @@ void AP_UnixFrame::toggleLeftRuler(bool bRulerOn)
 		pFrameData->m_pLeftRuler = pUnixLeftRuler;		
 		pFrameImpl->m_leftRuler = pUnixLeftRuler->createWidget();
 
+#if GTK_CHECK_VERSION(3,0,0)
 		gtk_grid_attach(GTK_GRID(pFrameImpl->m_innergrid), 
 				 pFrameImpl->m_leftRuler, 0, 1, 1, 1);
+#else
+		gtk_table_attach(GTK_TABLE(pFrameImpl->m_innergrid), 
+						 pFrameImpl->m_leftRuler, 0, 1, 1, 2,
+						 (GtkAttachOptions)(GTK_FILL),
+						 (GtkAttachOptions)(GTK_EXPAND | GTK_FILL),
+						 0,0);
+#endif
 		static_cast<AP_LeftRuler *>(pUnixLeftRuler)->setView(m_pView,iZoom);
 		setYScrollRange();
 	}
@@ -517,7 +535,13 @@ bool AP_UnixFrame::_createViewGraphics(GR_Graphics *& pG, UT_uint32 iZoom)
 
 	GtkWidget *widget = GTK_WIDGET(static_cast<AP_UnixFrameImpl *>(getFrameImpl())->m_dArea);
 	GR_UnixCairoGraphics *pUnixGraphics = static_cast<GR_UnixCairoGraphics *>(pG);
-	pUnixGraphics->init3dColors(gtk_widget_get_style_context(widget));
+#if GTK_CHECK_VERSION(3,0,0)
+	GtkWidget * w = gtk_entry_new();
+	pUnixGraphics->init3dColors(w);
+	gtk_widget_destroy(w);
+#else
+	pUnixGraphics->init3dColors(widget);
+#endif
 	pUnixGraphics->initWidget(widget);
 
 	ENSUREP_RF(pG);
