@@ -17,11 +17,13 @@
  * 02111-1307, USA.
  */
 
+#include <stdio.h>
 #include <windows.h>
 
 #include "ut_string.h"
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
+#include "ut_Win32LocaleString.h"
 
 #include "xap_App.h"
 #include "xap_Win32App.h"
@@ -31,7 +33,6 @@
 #include "ap_Dialog_Id.h"
 #include "ap_Dialog_WordCount.h"
 #include "ap_Win32Dialog_WordCount.h"
-#include "xap_Win32DialogHelper.h"
 #include "ap_Win32Resources.rc2"
 #include "ap_Win32App.h"
 
@@ -60,50 +61,20 @@ AP_Win32Dialog_WordCount::~AP_Win32Dialog_WordCount(void)
 
 void AP_Win32Dialog_WordCount::runModal(XAP_Frame * pFrame)
 {
-	// raise the dialog
-	XAP_Win32App * pWin32App = static_cast<XAP_Win32App *>(m_pApp);
-
-	LPCTSTR lpTemplate = NULL;
-
+	// raise the dialog	
 	UT_return_if_fail (m_id == AP_DIALOG_ID_WORDCOUNT);
-
-	lpTemplate = MAKEINTRESOURCE(AP_RID_DIALOG_WORDCOUNT);
-
-	int result = DialogBoxParam(pWin32App->getInstance(),lpTemplate,
-						static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow(),
-						(DLGPROC)s_dlgProc,(LPARAM)this);
-	UT_ASSERT_HARMLESS((result != -1));
+    createModal (pFrame, MAKEINTRESOURCEW(AP_RID_DIALOG_WORDCOUNT));	
 }
 
 void AP_Win32Dialog_WordCount::runModeless(XAP_Frame * pFrame)
 {
-	// raise the dialog
-	int iResult;
-	XAP_Win32App * pWin32App = static_cast<XAP_Win32App *>(m_pApp);
-
-	LPCTSTR lpTemplate = NULL;
-
-	UT_return_if_fail (m_id == AP_DIALOG_ID_WORDCOUNT);
-
-	lpTemplate = MAKEINTRESOURCE(AP_RID_DIALOG_WORDCOUNT);
-
-	HWND hResult = CreateDialogParam(pWin32App->getInstance(),lpTemplate,
-							static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow(),
-							(DLGPROC)s_dlgProc,(LPARAM)this);
-
-	UT_ASSERT_HARMLESS((hResult != NULL));
-
-	m_hWnd = hResult;
+	// raise the dialog	
+	UT_return_if_fail (m_id == AP_DIALOG_ID_WORDCOUNT);	
+	createModeless (pFrame, MAKEINTRESOURCEW(AP_RID_DIALOG_WORDCOUNT));
 
 	// Save dialog the ID number and pointer to the widget
-	UT_sint32 sid =(UT_sint32)  getDialogId();
-	m_pApp->rememberModelessId( sid, (XAP_Dialog_Modeless *) m_pDialog);
-
-	iResult = ShowWindow( m_hWnd, SW_SHOW );
-
-	iResult = BringWindowToTop( m_hWnd );
-
-	UT_ASSERT_HARMLESS((iResult != 0));
+    UT_sint32 sid =(UT_sint32) getDialogId();
+	m_pApp->rememberModelessId (sid, (XAP_Dialog_Modeless *) m_pDialog);
 }
 
 void    AP_Win32Dialog_WordCount::setUpdateCounter( UT_uint32 iRate )
@@ -156,135 +127,93 @@ void AP_Win32Dialog_WordCount::destroy(void)
 
 	m_pAutoUpdateWC->stop();
 
-	int iResult = DestroyWindow( m_hWnd );
-
-	UT_ASSERT_HARMLESS((iResult != 0));
+    destroyWindow ();
 
 	modeless_cleanup();
 }
 
 void AP_Win32Dialog_WordCount::activate(void)
 {
-	int iResult;
-
 	// Update the caption
 	ConstructWindowName();
-	SetWindowText(m_hWnd, (AP_Win32App::s_fromUTF8ToWinLocale(m_WindowName)).c_str());
-
-	iResult = ShowWindow( m_hWnd, SW_SHOW );
-
-	iResult = BringWindowToTop( m_hWnd );
-
-	UT_ASSERT_HARMLESS((iResult != 0));
+    setDialogTitle(m_WindowName);
+	showWindow(SW_SHOW);
+	bringWindowToTop();
 }
 
 void AP_Win32Dialog_WordCount::notifyActiveFrame(XAP_Frame *pFrame)
 {
-	if((HWND)GetWindowLong(m_hWnd, GWL_HWNDPARENT) != static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow())
+	if((HWND)GetWindowLongPtrW(m_hDlg, GWLP_HWNDPARENT) != static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow())
 	{
 		// Update the caption
 		ConstructWindowName();
-		SetWindowText(m_hWnd, (AP_Win32App::s_fromUTF8ToWinLocale(m_WindowName)).c_str());
+		setDialogTitle (m_WindowName);
 
-		SetWindowLong(m_hWnd, GWL_HWNDPARENT, (long)static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow());
-		SetWindowPos(m_hWnd, NULL, 0, 0, 0, 0,
+		SetWindowLongPtrW(m_hDlg, GWLP_HWNDPARENT, (LONG_PTR)static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow());
+		SetWindowPos(m_hDlg, NULL, 0, 0, 0, 0,
 						SWP_NOMOVE | SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE | SWP_FRAMECHANGED);
 		
 		event_Update();
 	}
 }
 
-void AP_Win32Dialog_WordCount::notifyCloseFrame(XAP_Frame *pFrame)
+BOOL AP_Win32Dialog_WordCount::_onDlgMessage(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
 {
-	if((HWND)GetWindowLong(m_hWnd, GWL_HWNDPARENT) == static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow())
-	{
-		SetWindowLong(m_hWnd, GWL_HWNDPARENT, NULL);
-		SetWindowPos(m_hWnd, NULL, 0, 0, 0, 0,
-						SWP_NOMOVE | SWP_NOSIZE | SWP_NOZORDER | SWP_NOACTIVATE | SWP_FRAMECHANGED);
-	}
+	if (msg != WM_VSCROLL)
+		return FALSE;
+	setUpdateCounter( (UT_uint32)HIWORD(wParam) );
+	event_Update();		
+	return TRUE;
 }
 
-BOOL CALLBACK AP_Win32Dialog_WordCount::s_dlgProc(HWND hWnd,UINT msg,WPARAM wParam,LPARAM lParam)
-{
-	// This is a static function.
-
-	AP_Win32Dialog_WordCount * pThis;
-	
-	switch (msg)
-	{
-	case WM_INITDIALOG:
-		pThis = (AP_Win32Dialog_WordCount *)lParam;
-		SetWindowLong(hWnd,DWL_USER,lParam);
-		return pThis->_onInitDialog(hWnd,wParam,lParam);
-		
-	case WM_COMMAND:
-		pThis = (AP_Win32Dialog_WordCount *)GetWindowLong(hWnd,DWL_USER);
-		if (pThis)
-			return pThis->_onCommand(hWnd,wParam,lParam);
-		else
-			return 0;
-		
-	case WM_VSCROLL:
-		pThis = (AP_Win32Dialog_WordCount *)GetWindowLong(hWnd,DWL_USER);
-		pThis->setUpdateCounter( (UT_uint32)HIWORD(wParam) );
-		pThis->event_Update();
-		return 1;
-
-	default:
-		return 0;
-	}
-}
-
-static NUMBERFMT numberfmt;
-static char gszDecSep[16];
-static char gszThSep[16];		
+static NUMBERFMTW numberfmt;
+static wchar_t gszDecSep[16];
+static wchar_t gszThSep[16];		
 
 void AP_Win32Dialog_WordCount::_setDlgItemInt(UINT nCtrl, int nValue)
-{
-	
-	char szFormatted[128], szUnFormatted[128];
-	sprintf(szUnFormatted, "%d", nValue);
+{	
+	wchar_t szFormatted[64], szUnFormatted[64];
+	swprintf(szUnFormatted, L"%d", nValue);
 
 	if (numberfmt.lpThousandSep==NULL)	// We only do this the first time
 	{
-		char szBuffer[16];
+		wchar_t szBuffer[16];
 		
-		GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, gszDecSep, sizeof(gszDecSep));
-		GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_STHOUSAND, gszThSep, sizeof(gszThSep));
+		GetLocaleInfoW(LOCALE_USER_DEFAULT, LOCALE_SDECIMAL, gszDecSep, sizeof(gszDecSep));
+		GetLocaleInfoW(LOCALE_USER_DEFAULT, LOCALE_STHOUSAND, gszThSep, sizeof(gszThSep));
 				
 		numberfmt.NumDigits = 0;		
-		GetLocaleInfo(LOCALE_USER_DEFAULT, LOCALE_ILZERO, szBuffer, sizeof(szBuffer));
-		numberfmt.LeadingZero = atoi(szBuffer);
+		GetLocaleInfoW(LOCALE_USER_DEFAULT, LOCALE_ILZERO, szBuffer, sizeof(szBuffer));
+		numberfmt.LeadingZero = _wtoi(szBuffer);
 
-		GetLocaleInfo( LOCALE_USER_DEFAULT, LOCALE_SGROUPING, szBuffer, sizeof(szBuffer));
-		numberfmt.Grouping = atoi(szBuffer);
+		GetLocaleInfoW( LOCALE_USER_DEFAULT, LOCALE_SGROUPING, szBuffer, sizeof(szBuffer));
+		numberfmt.Grouping = _wtoi(szBuffer);
 		numberfmt.lpDecimalSep = gszDecSep;
 		numberfmt.lpThousandSep = gszThSep;
 
-		GetLocaleInfo( LOCALE_USER_DEFAULT, LOCALE_INEGNUMBER, szBuffer, sizeof(szBuffer));
-		numberfmt.NegativeOrder = atoi(szBuffer);
+		GetLocaleInfoW( LOCALE_USER_DEFAULT, LOCALE_INEGNUMBER, szBuffer, sizeof(szBuffer));
+		numberfmt.NegativeOrder = _wtoi(szBuffer);
 	}
 	
 	/* Convert the number string into the proper locale defn */
-	GetNumberFormat(LOCALE_USER_DEFAULT, 0, szUnFormatted,
+	GetNumberFormatW(LOCALE_USER_DEFAULT, 0, szUnFormatted,
 		&numberfmt, szFormatted, sizeof(szFormatted));
 
-	SetDlgItemText(m_hWnd, nCtrl, szFormatted);		
+	SetDlgItemTextW(m_hDlg, nCtrl, szFormatted);		
 }						
 					
 					
-#define _DS(c,s)	SetDlgItemText(hWnd,AP_RID_DIALOG_##c,pSS->getValue(AP_STRING_ID_##s))
-#define _DSX(c,s)	SetDlgItemText(hWnd,AP_RID_DIALOG_##c,pSS->getValue(XAP_STRING_ID_##s))
+#define _DS(c,s)	setDlgItemText(AP_RID_DIALOG_##c,pSS->getValue(AP_STRING_ID_##s))
+#define _DSX(c,s)	setDlgItemText(AP_RID_DIALOG_##c,pSS->getValue(XAP_STRING_ID_##s))
 
 
 BOOL AP_Win32Dialog_WordCount::_onInitDialog(HWND hWnd, WPARAM /*wParam*/, LPARAM /*lParam*/)
 {
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
-	m_hWnd = hWnd;
 	
 	// Update the caption
 	ConstructWindowName();
-	SetWindowText(hWnd, (AP_Win32App::s_fromUTF8ToWinLocale(m_WindowName)).c_str());	
+	setDialogTitle (m_WindowName);
 			
 	m_pAutoUpdateWC = UT_Timer::static_constructor(autoupdateWC,this);
 	setUpdateCounter( 1 );
@@ -302,15 +231,13 @@ BOOL AP_Win32Dialog_WordCount::_onInitDialog(HWND hWnd, WPARAM /*wParam*/, LPARA
 	_DS(WORDCOUNT_TEXT_WORDSONLY,	DLG_WordCount_Words_No_Notes);
 	
 	_updateWindowData ();
-	XAP_Win32DialogHelper::s_centerDialog(hWnd);	
+	centerDialog();
 
 	return 1;							// 1 == we did not call SetFocus()
 }
 
 void AP_Win32Dialog_WordCount::_updateWindowData(void)
 {
-	HWND hWnd = m_hWnd;
-
 	_setDlgItemInt(AP_RID_DIALOG_WORDCOUNT_VAL_PAGE,		m_count.page);
 	_setDlgItemInt(AP_RID_DIALOG_WORDCOUNT_VAL_WORD,		m_count.word);
 	_setDlgItemInt(AP_RID_DIALOG_WORDCOUNT_VAL_CH,			m_count.ch_no);
@@ -321,7 +248,7 @@ void AP_Win32Dialog_WordCount::_updateWindowData(void)
 
 	// Update the caption in case the name of the document has changed
 	ConstructWindowName();
-	SetWindowText(hWnd, (AP_Win32App::s_fromUTF8ToWinLocale(m_WindowName)).c_str());
+	setDialogTitle (m_WindowName);
 }
 
 BOOL AP_Win32Dialog_WordCount::_onCommand(HWND /*hWnd*/, WPARAM wParam, LPARAM /*lParam*/)
