@@ -17,8 +17,8 @@
  * 02111-1307, USA.
  */
 
-#include <windows.h>
 #include <stdio.h>
+#include <windows.h>
 #include "ut_types.h"
 #include "ut_misc.h"
 #include "ut_assert.h"
@@ -28,17 +28,18 @@
 #include "gr_Win32Graphics.h"
 #include "xap_Win32App.h"
 #include "ap_Win32FrameImpl.h"
+#include "ut_Win32LocaleString.h"
 
 #include "fv_View.h"
 
 /*****************************************************************/
 
-#define GWL(hwnd)		(AP_Win32TopRuler*)GetWindowLong((hwnd), GWL_USERDATA)
-#define SWL(hwnd, f)	(AP_Win32TopRuler*)SetWindowLong((hwnd), GWL_USERDATA,(LONG)(f))
+#define GWL(hwnd)		(AP_Win32TopRuler*)GetWindowLongPtrW((hwnd), GWLP_USERDATA)
+#define SWL(hwnd, f)	(AP_Win32TopRuler*)SetWindowLongPtrW((hwnd), GWLP_USERDATA,(LONG_PTR)(f))
 
 #define ENSUREP(p)		do { UT_ASSERT_HARMLESS(p); if (!p) goto Cleanup; } while (0)
 
-static char s_TopRulerWndClassName[256];
+static wchar_t s_TopRulerWndClassName[256];
 
 /*****************************************************************/
 
@@ -74,17 +75,20 @@ void AP_Win32TopRuler::setView(AV_View * pView)
 	pG->init3dColors();
 
 	if (IsWindow(m_hwndTopRuler))
-		SendMessage(m_hwndTopRuler, WM_ERASEBKGND, (WPARAM)GetDC(m_hwndTopRuler), 0);
+		SendMessageW(m_hwndTopRuler, WM_ERASEBKGND, (WPARAM)GetDC(m_hwndTopRuler), 0);
 }
 
 /*****************************************************************/
 
-bool AP_Win32TopRuler::RegisterClass(XAP_Win32App * app)
+bool AP_Win32TopRuler::registerClass(XAP_Win32App * app)
 {
 	ATOM a;
+
+    UT_Win32LocaleString str;	
+	str.fromASCII (app->getApplicationName());
 	
 	// register class for the top ruler
-	sprintf(s_TopRulerWndClassName, "%sTopRuler", app->getApplicationName());
+	swprintf(s_TopRulerWndClassName, L"%sTopRuler",str.c_str());
 
 	a = UT_RegisterClassEx(CS_OWNDC, AP_Win32TopRuler::_TopRulerWndProc, app->getInstance(),
 						   NULL, LoadCursor(NULL, IDC_ARROW), GetSysColorBrush(COLOR_BTNFACE), NULL,
@@ -220,10 +224,10 @@ LRESULT CALLBACK AP_Win32TopRuler::_TopRulerWndProc(HWND hwnd, UINT iMsg, WPARAM
 			HDC hdc = BeginPaint(hwnd, &ps);
 			UT_return_val_if_fail(hdc, 0);
 
-			UT_Rect r(pG->tlu(ps.rcPaint.left),
-					  pG->tlu(ps.rcPaint.top),
-					  pG->tlu(ps.rcPaint.right-ps.rcPaint.left+1),
-					  pG->tlu(ps.rcPaint.bottom-ps.rcPaint.top+1));
+			UT_Rect r(ps.rcPaint.left,
+					  ps.rcPaint.top,
+					  ps.rcPaint.right-ps.rcPaint.left+1,
+					  ps.rcPaint.bottom-ps.rcPaint.top+1);
 
 			pRuler->draw(&r);
 			EndPaint(hwnd,&ps);
