@@ -271,8 +271,8 @@ void AP_Dialog_Lists::Apply(void)
 		PT_DocPosition posHigh = 0;
 		if(getView()->isSelectionEmpty() && pAuto)
 		{
-		      PL_StruxDocHandle sdhLow = pAuto->getFirstItem();
-		      PL_StruxDocHandle sdhHigh = pAuto->getLastItemInHeiracy();
+		      pf_Frag_Strux* sdhLow = pAuto->getFirstItem();
+		      pf_Frag_Strux* sdhHigh = pAuto->getLastItemInHeiracy();
 		      posLow = getView()->getDocument()->getStruxPosition(sdhLow)+1;
 		      posHigh = getView()->getDocument()->getStruxPosition(sdhHigh)+1;
 		}
@@ -291,20 +291,6 @@ void AP_Dialog_Lists::Apply(void)
 		return;
 	}
 
-/*!
- *
- * OK this is failsafe code incase the user has changed the font but wants a
- * bullet list anyway. We don't let then!
- */
-	if(m_NewListType == BULLETED_LIST || m_NewListType == IMPLIES_LIST)
-	{
-		m_pszFont = "Symbol";
-	}
-	else if(m_NewListType > DASHED_LIST && m_NewListType < OTHER_NUMBERED_LISTS)
-	{
-		m_pszFont = _getDingbatsFontName();
-	}
-
 /*!
  * Just to make things even more confusing this method is also used in a Modal
  * mannor by the styles dialog. This method is called when the users clicks "OK"
@@ -625,18 +611,10 @@ void  AP_Dialog_Lists::fillUncustomizedValues(void)
 		m_pszDecimal = ".";
 		m_iStartValue = 0;
 	}
-	if(m_NewListType == BULLETED_LIST || m_NewListType == IMPLIES_LIST)
-	{
-		m_pszFont = "Symbol";
-	}
-	else if (m_NewListType == NOT_A_LIST)
+	if (m_NewListType == NOT_A_LIST)
 	{
 		m_pszFont = "NULL";
 	}
-	else if(m_NewListType > DASHED_LIST && m_NewListType < OTHER_NUMBERED_LISTS)
-	{
-		m_pszFont = _getDingbatsFontName();
-	}
 
 	if(props_in)
 		g_free(props_in);
@@ -673,28 +651,13 @@ void  AP_Dialog_Lists::fillFakeLabels(void)
 			m_NewListType = m_DocListType;
 		m_bguiChanged = false;
 	}
-/*!
- * For Bullet type lists we don't allow the user to set either the delimimiter
- * or font from their specified values. Here we override whatever was in them
- * to the values they SHOULD be given the list type.
- */
-	if(  m_NewListType == BULLETED_LIST ||
-		 m_NewListType == IMPLIES_LIST  ||
-		 m_NewListType == DASHED_LIST )
-	{
-		m_pszFont = "Symbol";
-		m_pszDelim = "%L";
-	}
-	else if (m_NewListType == NOT_A_LIST)
+
+	if (m_NewListType == NOT_A_LIST)
 	{
 		m_pszFont = "NULL";
 		m_pszDelim = "%L";
 	}
-	else if(m_NewListType > DASHED_LIST && m_NewListType < OTHER_NUMBERED_LISTS)
-	{
-		m_pszFont = _getDingbatsFontName();
-		m_pszDelim = "%L";
-	}
+
 /*!
  * OK fill the preview variables with what they need and load them into
  * the preview class.
@@ -715,15 +678,15 @@ void  AP_Dialog_Lists::generateFakeLabels(void)
 {
 	UT_uint32 i;
 	//
-	// Start by generating 4 fake (PL_StruxDocHandle and fl_Layout pointers
+	// Start by generating 4 fake (pf_Frag_Strux* and fl_Layout pointers
 	//
 	// Jeeze gotta generate a fake void * pointer!! Try this hack.
 	//
 	for(i=0; i<4; i++)
 	{
 		DELETEP(m_pFakeLayout[i]);
-		m_pFakeSdh[i] = static_cast<PL_StruxDocHandle>(new pf_Frag_Strux_Block(NULL,0));
-		m_pFakeLayout[i] = new fl_Layout((PTStruxType) 0 , (PL_StruxDocHandle) m_pFakeSdh[i] );
+		m_pFakeSdh[i] = new pf_Frag_Strux_Block(NULL,0);
+		m_pFakeLayout[i] = new fl_Layout((PTStruxType) 0 , m_pFakeSdh[i] );
 	}
 	//
 	// Now generate the AutoNum
@@ -1114,10 +1077,6 @@ AV_View * AP_Dialog_Lists::getAvView(void)
 	return pFrame->getCurrentView();
 }
 
-const gchar* AP_Dialog_Lists::_getDingbatsFontName() const
-{
-	return "Dingbats";
-}
 
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
