@@ -858,6 +858,8 @@ UT_sint32 AP_LeftRuler::setTableLineDrag(PT_DocPosition pos, UT_sint32 & iFixed,
 
 void AP_LeftRuler::mouseMotion(EV_EditModifierState ems, UT_sint32 x, UT_sint32 y)
 {
+	UT_DEBUG_ONLY_ARG(ems);
+
 	// The X and Y that are passed to this function are x and y on the application, not on the ruler.
 	xxx_UT_DEBUGMSG(("In Left mouseMotion \n"));
 	FV_View * pView1 = static_cast<FV_View *>(m_pView);
@@ -1225,6 +1227,7 @@ static bool s_IsOnDifferentPage(const AP_LeftRulerInfo * p1, const AP_LeftRulerI
 bool AP_LeftRuler::notify(AV_View * pView, const AV_ChangeMask mask)
 {
 	// Handle AV_Listener events on the view.
+	UT_DEBUG_ONLY_ARG(pView);
 
 	UT_ASSERT(pView==m_pView);
 	FV_View * pVView = static_cast<FV_View *>(m_pView);
@@ -1506,7 +1509,7 @@ void AP_LeftRuler::_getCellMarkerRects(const AP_LeftRulerInfo * pInfo, UT_sint32
 		rCell.set(0,0,0,0);
 		return;
 	}
-	
+	/*
 	UT_sint32 bottomSpacing;
 	UT_sint32 topSpacing;
 	
@@ -1536,7 +1539,7 @@ void AP_LeftRuler::_getCellMarkerRects(const AP_LeftRulerInfo * pInfo, UT_sint32
 	{
 		topSpacing = 0;
 	}
-	
+	*/
 	UT_uint32 xLeft = pG->tlu(s_iFixedHeight) / 4;
 //	rCell.set(xLeft, pos - bottomSpacing, xLeft * 2, bottomSpacing + topSpacing); //left/top/width/height
 	UT_sint32 mywidth = xLeft *2;
@@ -1690,6 +1693,7 @@ void AP_LeftRuler::drawLU(const UT_Rect *clip)
 	pView->getLeftRulerInfo(lfi);
 
 	GR_Painter painter(m_pG);
+	painter.beginDoubleBuffering();
 
 	UT_ASSERT(lfi->m_yTopMargin >= 0);
 
