@@ -118,51 +118,52 @@ dcl(DLG_FR_FinishedFind, "AbiWord has finished searching the document.")
 dcl(DLG_FR_FinishedReplace, "AbiWord has finished its search of the document and has made %d replacements.")
 
 /* Break dialog */
-dcl(DLG_Break_BreakTitle,		"Insert break")
-dcl(DLG_Break_BreakTitle_Capital,	"Insert Break")
+dcl(DLG_Break_BreakTitle,		"Insert Break")
 dcl(DLG_Break_Insert,			"Insert")
-dcl(DLG_Break_SectionBreaks,	"Section breaks")
-dcl(DLG_Break_SectionBreaks_Capital,	"Section Breaks")
+dcl(DLG_Break_SectionBreaks,	"Section Breaks")
 dcl(DLG_Break_PageBreak,		"&Page break")
 dcl(DLG_Break_ColumnBreak,		"&Column break")
 dcl(DLG_Break_NextPage, 		"&Next page")
 dcl(DLG_Break_Continuous,		"Con&tinuous")
 dcl(DLG_Break_EvenPage, 		"&Even page")
 dcl(DLG_Break_OddPage,			"&Odd page")
+dcl(BREAK_Column,				"Column Break")
+dcl(BREAK_Page,					"Page Break")
 
 /* Insert Table dialog */
 dcl(DLG_InsertTable_TableTitle,		"Insert Table")
-dcl(DLG_InsertTable_TableSize,		"Table size")
-dcl(DLG_InsertTable_TableSize_Capital,	"Table Size")
+dcl(DLG_InsertTable_TableSize,		"Table Size")
 dcl(DLG_InsertTable_NumCols,		"Number of columns:")
 dcl(DLG_InsertTable_NumRows,		"Number of rows:")
-dcl(DLG_InsertTable_AutoFit,		"AutoFit behavior")
-dcl(DLG_InsertTable_AutoFit_Capital,	"AutoFit Behavior")
+dcl(DLG_InsertTable_AutoFit,		"AutoFit Behavior")
 dcl(DLG_InsertTable_AutoColSize, 	"Automatic column size")
 dcl(DLG_InsertTable_FixedColSize,	"Fixed column size:")
 
 /* Format FootNotes dialog */
 dcl(DLG_FormatFootnotes_Title,             "Format Footnotes and Endnotes")
-dcl(DLG_FormatFootnotes_Footnotes,         "Format Footnotes")
-dcl(DLG_FormatFootnotes_Endnotes,          "Format Endnotes")
-dcl(DLG_FormatFootnotes_FootStyle,         "Footnote style")
+dcl(DLG_FormatFootnotes_Footnotes,         "Footnotes")
+dcl(DLG_FormatFootnotes_Endnotes,          "Endnotes")
+dcl(DLG_FormatFootnotes_FootStyle,         "Footnote style:")
 dcl(DLG_FormatFootnotes_FootRestartSec,    "Restart on each section")
 dcl(DLG_FormatFootnotes_FootRestartPage,   "Restart on each page")
 dcl(DLG_FormatFootnotes_FootRestartNone,   "Don't restart")
-dcl(DLG_FormatFootnotes_FootInitialVal,    "Initial Footnote value")
-dcl(DLG_FormatFootnotes_EndStyle,          "Endnote style")
+dcl(DLG_FormatFootnotes_FootInitialVal,    "Initial Footnote value:")
+dcl(DLG_FormatFootnotes_EndStyle,          "Endnote style:")
 dcl(DLG_FormatFootnotes_EndRestartSec,     "Restart on each section")
-dcl(DLG_FormatFootnotes_EndInitialVal,     "Initial Endnote value")
+dcl(DLG_FormatFootnotes_EndInitialVal,     "Initial Endnote value:")
 dcl(DLG_FormatFootnotes_EndPlaceEndDoc,    "Place at end of document")
 dcl(DLG_FormatFootnotes_EndPlaceEndSec,    "Place at end of section")
-dcl(DLG_FormatFootnotes_EndPlacement,      "Placement")
-dcl(DLG_FormatFootnotes_FootnoteRestart,   "Numbering")
+dcl(DLG_FormatFootnotes_EndPlacement,      "Placement:")
+dcl(DLG_FormatFootnotes_FootnoteRestart,   "Numbering:")
 
 /* Format TOC dialog */
 dcl(DLG_FormatTOC_Title,                  "Format Table of Contents")
 dcl(DLG_FormatTOC_General,                "General")
-dcl(DLG_FormatTOC_LayoutDetails,          "Layout Details")
-dcl(DLG_FormatTOC_None,                   "None")
+dcl(DLG_FormatTOC_LayoutDetails,          "Details")
+dcl(DLG_FormatTOC_None,                   "None")		//xgettext:msgctxt
+dcl(DLG_FormatTOC_Dot,                    "Dots")
+dcl(DLG_FormatTOC_Dash,                   "Dashes")
+dcl(DLG_FormatTOC_Underline,              "Underlines")
 dcl(DLG_FormatTOC_HasHeading,             "&Has Heading")
 dcl(DLG_FormatTOC_HeadingText,            "H&eading text:")
 dcl(DLG_FormatTOC_HeadingStyle,           "Heading style:")
@@ -188,7 +189,7 @@ dcl(DLG_FormatTOC_Level4,                 "Level 4")
 
 /* Latex dialog */
 dcl(DLG_Latex_LatexTitle,	"LaTeX Equation")
-dcl(DLG_Latex_LatexEquation,	"LaTeX Equation")
+dcl(DLG_Latex_LatexEquation,	"LaTeX Equation:")
 dcl(DLG_Latex_Example,		"Example:")
 
 /*Equation Menus */
@@ -225,12 +226,12 @@ dcl(DLG_Spell_Suggestions,		"Sugg&estions:")
 dcl(DLG_Spell_NoSuggestions,	"(no spelling suggestions)")
 
 /* Style Dialog */
-dcl(DLG_Styles_StylesTitle, 	"Styles")
-dcl(DLG_Styles_Available,		"Available Styles")
-dcl(DLG_Styles_List,			"List")
+dcl(DLG_Styles_StylesTitle, 	"Create and Modify Styles")
+dcl(DLG_Styles_Available,		"Available Styles:")
+dcl(DLG_Styles_List,			"Type")
 dcl(DLG_Styles_ParaPrev,		"Paragraph Preview")
 dcl(DLG_Styles_CharPrev,		"Character Preview")
-dcl(DLG_Styles_Description, 	"Description")
+dcl(DLG_Styles_Description, 	"Definition")
 dcl(DLG_Styles_New, 			"New...")
 dcl(DLG_Styles_Modify,			"Modify...")
 dcl(DLG_Styles_Delete,			"Delete")
@@ -238,12 +239,12 @@ dcl(DLG_Styles_LBL_InUse,		"In Use")
 dcl(DLG_Styles_LBL_All, 		"All")
 dcl(DLG_Styles_LBL_UserDefined, "User-defined styles")
 dcl(DLG_Styles_LBL_TxtMsg,		"What Hath God Wrought")
-dcl(DLG_Styles_ModifyTitle, 	"Modify Styles")
+dcl(DLG_Styles_ModifyTitle, 	"Modify Style")
 dcl(DLG_Styles_ModifyName,		"Style Name:")
 dcl(DLG_Styles_ModifyBasedOn,	"Based On:")
-dcl(DLG_Styles_ModifyFollowing, "Style for following paragraph")
+dcl(DLG_Styles_ModifyFollowing, "Style for following paragraph:")
 dcl(DLG_Styles_ModifyPreview,	"Preview")
-dcl(DLG_Styles_ModifyDescription,	"Description")
+dcl(DLG_Styles_ModifyDescription,	"Definition")
 dcl(DLG_Styles_ModifyTemplate,	"Add to template")
 dcl(DLG_Styles_ModifyAutomatic, "Automatically update")
 dcl(DLG_Styles_ModifyShortCut,	"Shortcut Key")
@@ -254,11 +255,11 @@ dcl(DLG_Styles_ModifyTabs,		"Tabs")
 dcl(DLG_Styles_ModifyNumbering, "Numbering")
 dcl(DLG_Styles_ModifyLanguage,	"Language")
 dcl(DLG_Styles_ModifyCharacter,  "Character")
-dcl(DLG_Styles_ModifyType,		 "Style Type")
-dcl(DLG_Styles_DefNone, 		 "None")
+dcl(DLG_Styles_ModifyType,		 "Style Type:")
+dcl(DLG_Styles_DefNone, 		 "None")		//xgettext:msgctxt
 dcl(DLG_Styles_DefCurrent,		 "Current Settings")
 dcl(DLG_Styles_NewTitle,		 "New Style")
-dcl(DLG_Styles_RemoveLab,		 "Remove Property from Style")
+dcl(DLG_Styles_RemoveLab,		 "Remove Property from Style:")
 dcl(DLG_Styles_RemoveButton,	 "Remove")
 dcl(DLG_Styles_ErrNotTitle1,	 "Style Name - ")
 dcl(DLG_Styles_ErrNotTitle2,	 " - Reserved. \n You cannot use this name. Choose Another \n")
@@ -335,9 +336,9 @@ dcl(DLG_Column_One, 			"One")
 dcl(DLG_Column_Two, 			"Two")
 dcl(DLG_Column_Three,			"Three")
 dcl(DLG_Column_Line_Between,	"Line between")
-dcl(DLG_Column_Number_Cols, 	"Number of Columns")
-dcl(DLG_Column_Space_After, 	"Space after Column")
-dcl(DLG_Column_Size,			"Max Column size")
+dcl(DLG_Column_Number_Cols, 	"Number of Columns:")
+dcl(DLG_Column_Space_After, 	"Space after Column:")
+dcl(DLG_Column_Size,			"Max Column size:")
 
 dcl(DLG_Column_RtlOrder,		"Use RTL Order")
 
@@ -376,8 +377,8 @@ dcl(DLG_Options_Label_GrammarCheck, "Check &grammar as you type")
 
 dcl(DLG_Options_Label_SmartQuotes, "Enable smart (curly) quotes")
 dcl(DLG_Options_Label_CustomSmartQuotes, "Use custom smart quote style")
-dcl(DLG_Options_Label_OuterQuoteStyle, "Outer (double) quote style")
-dcl(DLG_Options_Label_InnerQuoteStyle, "Inner (single) quote style")
+dcl(DLG_Options_Label_OuterQuoteStyle, "Outer (double) quote style:")
+dcl(DLG_Options_Label_InnerQuoteStyle, "Inner (single) quote style:")
 										      // should be merged one day
 dcl(DLG_Options_Label_SpellSuggest, 	"A&lways suggest corrections")
 dcl(DLG_Options_Label_SpellMainOnly,	"Suggest from &main dictionary only")
@@ -392,11 +393,10 @@ dcl(DLG_Options_Btn_IgnoreEdit, 		"&Edit")
 dcl(DLG_Options_Label_SpellAutoReplace, "Auto replace misspelled words")
 dcl(DLG_Options_Label_SpellDictionaries,	"Dictionaries")
 
-dcl(DLG_Options_Label_SmartQuotesEnable,"&Enable smart quotes")
 dcl(DLG_Options_Label_DefaultPageSize, "Default page size")
 
 dcl(DLG_Options_Label_DirectionRtl, "Default to right-to-left direction of text")
-dcl(DLG_Options_Label_BiDiOptions, "Bi-Directional Options")
+dcl(DLG_Options_Label_BiDiOptions, "Text Directionality")
 dcl(DLG_Options_Label_HebrewContextGlyphs, "Use glyph shaping for Hebrew")
 
 dcl(DLG_Options_Label_UI,			"User Interface")
@@ -469,9 +469,9 @@ dcl(DLG_Tab_Label_TabPosition,			"Tab stop position:")
 dcl(DLG_Tab_Label_TabToClear,			"Tab stops to be cleared:")
 dcl(DLG_Tab_Label_DefaultTS,			"Default tab stops:")
 
-dcl(DLG_Tab_Label_Position,				"Position")
+dcl(DLG_Tab_Label_Position,				"Position:")
 
-dcl(DLG_Tab_Label_Alignment,			"Alignment")
+dcl(DLG_Tab_Label_Alignment,			"Alignment:")
 dcl(DLG_Tab_Radio_NoAlign, 				"None")
 dcl(DLG_Tab_Radio_Left, 				"Left")
 dcl(DLG_Tab_Radio_Center,				"Center")
@@ -479,19 +479,18 @@ dcl(DLG_Tab_Radio_Right,				"Right")
 dcl(DLG_Tab_Radio_Decimal,				"Decimal")
 dcl(DLG_Tab_Radio_Bar,					"Bar")
 
-dcl(DLG_Tab_Label_Leader,				"Leader")
-dcl(DLG_Tab_Radio_None, 				"&1 None")
-dcl(DLG_Tab_Radio_Dot,					"&2 ..........")
-dcl(DLG_Tab_Radio_Dash, 				"&3 ----------")
-dcl(DLG_Tab_Radio_Underline,			"&4 __________")
+dcl(DLG_Tab_Label_Leader,				"Leader:")
+dcl(DLG_Tab_Radio_None, 				"None")		//xgettext:msgctxt
+dcl(DLG_Tab_Radio_Dot,					"Dots")
+dcl(DLG_Tab_Radio_Dash, 				"Dashes")
+dcl(DLG_Tab_Radio_Underline,			"Underlines")
 
 dcl(DLG_Tab_Button_Set, 				"Set")
 dcl(DLG_Tab_Button_Clear,				"Clear")
 dcl(DLG_Tab_Button_ClearAll,			"Clear &All")
 
 dcl(DLG_DateTime_DateTimeTitle, 		"Insert Date and Time")
-dcl(DLG_DateTime_AvailableFormats,		"&Available formats:")
-dcl(DLG_DateTime_AvailableFormats_Capital,	"Available Formats")
+dcl(DLG_DateTime_AvailableFormats,		"Available Formats:")
 
 dcl(DLG_MergeCellsTitle,	    	     "Merge Cells")
 dcl(DLG_MergeCells_Frame,	    	     "Merge Cells")
@@ -527,7 +526,7 @@ dcl(DLG_FormatFrame_SetTextWrapping,     "Set Text Wrapping")
 dcl(DLG_FormatFrame_SetToParagraph,      "Position to Paragraph")
 dcl(DLG_FormatFrame_SetToColumn,         "Position to Column")
 dcl(DLG_FormatFrame_SetToPage,           "Position to Page")
-dcl(DLG_FormatFrame_PositionTo,          "Position Text Box")
+dcl(DLG_FormatFrame_PositionTo,          "Text Box Position")
 
 dcl(DLG_FormatTableTitle,	    	     "Format Table")
 dcl(DLG_FormatTable_Borders,	   	     "Borders")
@@ -556,22 +555,23 @@ dcl(DLG_BorderShading_Shading_Color,		"Shading color:")
 dcl(DLG_BorderShading_Color,		        "Color:")
 dcl(DLG_BorderShading_Thickness,	        "Thickness:")
 dcl(DLG_BorderShading_Border_Style,	        "Style:")
+dcl(DLG_BorderShading_Border_Style_None,	"None")
+dcl(DLG_BorderShading_Border_Style_Solid,	"Solid line")
+dcl(DLG_BorderShading_Border_Style_Dashed,	"Dashed line")
+dcl(DLG_BorderShading_Border_Style_Dotted,	"Dotted line")
 dcl(DLG_BorderShading_Offset,				"Offset:")
 dcl(DLG_BorderShading_Preview,	   			"Preview")
 
-dcl(DLG_Field_FieldTitle,				"Insert field")
-dcl(DLG_Field_FieldTitle_Capital,			"Insert Field")
+dcl(DLG_Field_FieldTitle,				"Insert Field")
 dcl(DLG_Field_Types,					"&Types:")
 dcl(DLG_Field_Types_No_Colon,				"&Types")
 dcl(DLG_Field_Fields,					"&Fields:")
 dcl(DLG_Field_Fields_No_Colon,				"&Fields")
-dcl(DLG_Field_Parameters,				"Extra parameters:")
-dcl(DLG_Field_Parameters_Capital,			"Extra Parameters")
+dcl(DLG_Field_Parameters,				"Extra Parameters:")
 
 dcl(DLG_MailMerge_MailMergeTitle, "Insert Mail Merge Field")
-dcl(DLG_MailMerge_AvailableFields, "Available Fields")
+dcl(DLG_MailMerge_AvailableFields, "Available Fields:")
 dcl(DLG_MailMerge_Insert, "Field Name:")
-dcl(DLG_MailMerge_Insert_No_Colon, "Field Name")
 dcl(DLG_MailMerge_OpenFile, "&Open File")
 
 dcl(FIELD_Error,				"Error calculating value!")
@@ -582,7 +582,7 @@ dcl(FIELD_Datetime_CurrentTime, 	"Current Time")
 dcl(FIELD_Numbers_PageNumber,		"Page Number")
 dcl(FIELD_Numbers_TOCPageNumber,		"Table of Contents Page")
 dcl(FIELD_Numbers_TOCListLabel,		"Table of Contents List Label")
-dcl(FIELD_Numbers_PageReference,	"Page Reference")
+dcl(FIELD_Numbers_PageReference,	"Page Reference to Bookmark")
 dcl(FIELD_Numbers_PagesCount,		"Number of Pages")
 dcl(FIELD_Numbers_ListLabel,		"List Label")
 dcl(FIELD_Numbers_TableSumCols,		"Sum a Table Row")
@@ -598,14 +598,14 @@ dcl(FIELD_Numbers_FootnoteReference, "Footnote reference")
 dcl(FIELD_Numbers_FootnoteAnchor,	"Footnote anchor")
 dcl(FIELD_PieceTable_Test,		"Kevins Test")
 dcl(FIELD_PieceTable_MartinTest,	"Martins Test")
-dcl(FIELD_Datetime_CurrentDate, 		"Current Date")
+dcl(FIELD_Datetime_CurrentDate, 		"Weekday Month Day, Year")
 
 dcl(FIELD_DateTime_MMDDYY, "mm/dd/yy")
 dcl(FIELD_DateTime_DDMMYY, "dd/mm/yy")
 dcl(FIELD_DateTime_MonthDayYear, "Month Day, Year")
 dcl(FIELD_DateTime_MthDayYear, "Mth. Day, Year")
 dcl(FIELD_DateTime_DefaultDate, "Default date representation")
-dcl(FIELD_DateTime_DefaultDateNoTime, "Default date (w/o time)")
+dcl(FIELD_DateTime_DefaultDateNoTime, "Current Date")
 dcl(FIELD_DateTime_Wkday, "The weekday")
 dcl(FIELD_DateTime_DOY, "Day # in the year")
 
@@ -627,19 +627,19 @@ dcl(FIELD_Application_MailMerge, "Mail Merge")
 
 dcl(FIELD_Type_Document, "Document")
 dcl(FIELD_Document_Title, "Title")
-dcl(FIELD_Document_Creator, "Creator")
-dcl(FIELD_Document_Subject, "Subject")
+dcl(FIELD_Document_Creator, "Author")
+dcl(FIELD_Document_Subject, "Subject")		//xgettext:msgctxt
 dcl(FIELD_Document_Publisher, "Publisher")
-dcl(FIELD_Document_Contributor, "Contributor")
+dcl(FIELD_Document_Contributor, "Contributor(s)")
 dcl(FIELD_Document_Date, "Date")
-dcl(FIELD_Document_Type, "Type")
-dcl(FIELD_Document_Language, "Language")
+dcl(FIELD_Document_Type, "Category")
+dcl(FIELD_Document_Language, "Language(s)")
 dcl(FIELD_Document_Coverage, "Coverage")
 dcl(FIELD_Document_Rights, "Rights")
 dcl(FIELD_Document_Keywords, "Keywords")
 dcl(FIELD_Document_Description, "Description")
 
-dcl(DLG_Goto_Title, 					"Go to...")
+dcl(DLG_Goto_Title, 					"Go to")
 dcl(DLG_Goto_Label_Help,			"Choose your target in the left side.\nIf you want to use the \"Go To\" button, just fill the Number Entry with the desired number.  You can use + and - to perform relative movement.	I.e., if you write \"+2\" and you select \"Line\", the \"Go To\" will go 2 lines below your current position.")
 dcl(DLG_Goto_Btn_Prev,					"<< Prev")
 dcl(DLG_Goto_Btn_Next,					"Next >>")
@@ -647,15 +647,46 @@ dcl(DLG_Goto_Label_What,				"Go To &What:")
 dcl(DLG_Goto_Label_Number,				"&Number:")
 dcl(DLG_Goto_Label_Name,				"&Name:")
 dcl(DLG_Goto_Btn_Goto,					"Go To")
-dcl(DLG_Goto_Target_Page,				"Page")
-dcl(DLG_Goto_Target_Line,				"Line")
+dcl(DLG_Goto_Label_Position,				"Position")
+dcl(DLG_Goto_Target_Page,				"Page:")
+dcl(DLG_Goto_Target_Line,				"Line:")
 dcl(DLG_Goto_Target_Picture,			"Picture")
 dcl(DLG_Goto_Target_Bookmark,			"Bookmark")
+dcl(DLG_Goto_Target_XMLid,			"RDF Link")
+dcl(DLG_Goto_Target_Annotation,		"Annotation")
+dcl(DLG_Goto_Column_ID,			"ID")
+dcl(DLG_Goto_Column_Title,			"Title")
+dcl(DLG_Goto_Column_Author,			"Author")
+
+dcl(DLG_RDF_Query_Title, 					"Execute SPARQL on document RDF")
+dcl(DLG_RDF_Query_ShowAll,          		"Show All RDF")
+dcl(DLG_RDF_Query_Execute,          		"Execute Query")
+dcl(DLG_RDF_Query_Column_Subject,   		"Subject")		//xgettext:msgctxt
+dcl(DLG_RDF_Query_Column_Predicate, 		"Predicate")
+dcl(DLG_RDF_Query_Column_Object,    		"Object")
+dcl(DLG_RDF_Query_Comment,					"# Insert your SPARQL query here\n# Results are shown below.")
+dcl(DLG_RDF_Query_Status,					"Query RDF: %d of total: %ld")
+dcl(DLG_RDF_Editor_Title, 					"Edit document RDF")
+dcl(DLG_RDF_Editor_Menu_File,				"&File")
+dcl(DLG_RDF_Editor_Menu_Triple,				"&Triple")
+dcl(DLG_RDF_Editor_ShowAll,					"Update")
+dcl(DLG_RDF_Editor_Status,					"Total RDF: %d")
+dcl(DLG_RDF_Editor_Restrict,				"Restrict to RDF Link:")
+dcl(DLG_RDF_Insert_NewContact,				"New Contact")
+dcl(DLG_RDF_SemanticItemInsert_Title,		"Insert Reference to Semantic Item")
+dcl(DLG_RDF_SemanticItemInsert_Ok,			"Insert Reference")
+dcl(DLG_RDF_SemanticItemInsert_Column_Refdlg,"Contacts")
+dcl(DLG_RDF_SemanticStylesheets_Title,		"RDF Stylesheet")
+dcl(DLG_RDF_SemanticStylesheets_Explanation,"Set the current stylesheet for Semantic Items in this document. New RDF objects will use this stylesheet automatically. The buttons allow you to set the stylesheet for all existing Semantic Items to the new stylesheet as well.")
+dcl(DLG_RDF_SemanticStylesheets_Contacts,	"Contacts:")
+dcl(DLG_RDF_SemanticStylesheets_Events,		"Events:")
+dcl(DLG_RDF_SemanticStylesheets_Locations,	"Locations:")
+dcl(DLG_RDF_SemanticStylesheets_Set,		"Set For All Existing")
 
 
 // Lists Dialog
 
-dcl(DLG_Lists_Title,					 "Lists for ")
+dcl(DLG_Lists_Title,					 "Bullets and Numbering")
 dcl(DLG_Lists_Start_New_List,			  "Start New List")
 dcl(DLG_Lists_Stop_Current_List,			 "Stop Current List")
 dcl(DLG_Lists_Resume_Previous_List, 			"Resume Previous List")
@@ -678,13 +709,15 @@ dcl(DLG_Lists_Tick_List,				 "Tick List")
 dcl(DLG_Lists_Box_List, 				 "Box List")
 dcl(DLG_Lists_Hand_List,				 "Hand List")
 dcl(DLG_Lists_Heart_List,				 "Heart List")
+dcl(DLG_Lists_Arrowhead_List,			 "Arrowhead List")
 dcl(DLG_Lists_Starting_Value,			 "New Starting \nValue")
 dcl(DLG_Lists_New_List_Label,			 "New List Label")
 dcl(DLG_Lists_Current_List_Type,		 "Current List Type")
 dcl(DLG_Lists_Current_List_Label,		 "Current List Label")
 dcl(DLG_Lists_Cur_Change_Start, 		 "Change Current \nList")
 dcl(DLG_Lists_Type, 					 "Type:")
-dcl(DLG_Lists_Type_none,				 "None")
+dcl(DLG_Lists_Type_none,				 "None")		//xgettext:msgctxt
+dcl(DLG_Lists_Style_none,				 "None")		//xgettext:msgctxt
 dcl(DLG_Lists_Type_bullet,				 "Bullet")
 dcl(DLG_Lists_Type_numbered,			 "Numbered")
 dcl(DLG_Lists_Style,					 "Style:")
@@ -728,17 +761,17 @@ dcl(DLG_PageNumbers_Position_No_Colon,	 "Position")
 
 	 /* page setup dialog */
 dcl(DLG_PageSetup_Title,  "Page Setup")
-dcl(DLG_PageSetup_Paper,  "Paper...")
+dcl(DLG_PageSetup_Paper,  "Paper")
 dcl(DLG_PageSetup_Width,  "&Width:")
 dcl(DLG_PageSetup_Height, "&Height:")
 dcl(DLG_PageSetup_Paper_Size, "Paper Si&ze:")
 dcl(DLG_PageSetup_Units, "&Units:")
-dcl(DLG_PageSetup_Orient, "Orientation...")
+dcl(DLG_PageSetup_Orient, "Orientation")
 dcl(DLG_PageSetup_Landscape, "&Landscape")
 dcl(DLG_PageSetup_Portrait, "&Portrait")
-dcl(DLG_PageSetup_Scale, "Scale...")
+dcl(DLG_PageSetup_Scale, "Scale")
 dcl(DLG_PageSetup_Adjust, "&Adjust to:")
-dcl(DLG_PageSetup_Percent, "% of normal size")
+dcl(DLG_PageSetup_Percent, "% of normal size")		//xgettext:no-c-format
 dcl(DLG_PageSetup_Page, "Page")
 dcl(DLG_PageSetup_Top, "&Top:")
 dcl(DLG_PageSetup_Header, "&Header:")
@@ -749,12 +782,61 @@ dcl(DLG_PageSetup_Right, "&Right:")
 dcl(DLG_PageSetup_Margin, "Margin")
 dcl(DLG_PageSetup_ErrBigMargins, "The margins selected are too large to fit on the page.")
 
+	 /* page formats */
+dcl(DLG_PageFormat_A0,				"A0")
+dcl(DLG_PageFormat_A1,				"A1")
+dcl(DLG_PageFormat_A2,				"A2")
+dcl(DLG_PageFormat_A3,				"A3")
+dcl(DLG_PageFormat_A4,				"A4")
+dcl(DLG_PageFormat_A5,				"A5")
+dcl(DLG_PageFormat_A6,				"A6")
+dcl(DLG_PageFormat_A7,				"A7")
+dcl(DLG_PageFormat_A8,				"A8")
+dcl(DLG_PageFormat_A9,				"A9")
+dcl(DLG_PageFormat_A10,				"A10")
+dcl(DLG_PageFormat_B0,				"B0")
+dcl(DLG_PageFormat_B1,				"B1")
+dcl(DLG_PageFormat_B2,				"B2")
+dcl(DLG_PageFormat_B3,				"B3")
+dcl(DLG_PageFormat_B4,				"B4")
+dcl(DLG_PageFormat_B5,				"B5")
+dcl(DLG_PageFormat_B6,				"B6")
+dcl(DLG_PageFormat_B7,				"B7")
+dcl(DLG_PageFormat_B8,				"B8")
+dcl(DLG_PageFormat_B9,				"B9")
+dcl(DLG_PageFormat_B10,				"B10")
+dcl(DLG_PageFormat_C0,				"C0")
+dcl(DLG_PageFormat_C1,				"C1")
+dcl(DLG_PageFormat_C2,				"C2")
+dcl(DLG_PageFormat_C3,				"C3")
+dcl(DLG_PageFormat_C4,				"C4")
+dcl(DLG_PageFormat_C5,				"C5")
+dcl(DLG_PageFormat_C6,				"C6")
+dcl(DLG_PageFormat_C7,				"C7")
+dcl(DLG_PageFormat_C8,				"C8")
+dcl(DLG_PageFormat_C9,				"C9")
+dcl(DLG_PageFormat_C10,				"C10")
+dcl(DLG_PageFormat_Legal,			"Legal")
+dcl(DLG_PageFormat_Folio,			"Folio")
+dcl(DLG_PageFormat_Letter,			"Letter")
+dcl(DLG_PageFormat_1_3_A4,			"1/3 A4")
+dcl(DLG_PageFormat_1_4_A4,			"1/4 A4")
+dcl(DLG_PageFormat_1_8_A4,			"1/8 A4")
+dcl(DLG_PageFormat_1_4_A3,			"1/4 A3")
+dcl(DLG_PageFormat_1_3_A5,			"1/3 A5")
+dcl(DLG_PageFormat_DLEnvelope,		"DL Envelope")
+dcl(DLG_PageFormat_C6C5Envelope,	"C6/C5 Envelope")
+dcl(DLG_PageFormat_EnvelopeNo10,	"Envelope No10")
+dcl(DLG_PageFormat_Envelope6x9,		"Envelope 6x9")                 
+dcl(DLG_PageFormat_Custom,			"Custom")
+
 dcl(MSG_AutoMerge, "Automerge")
 dcl(MSG_DirectionModeChg,	"You have changed the direction mode.")
 dcl(MSG_DefaultDirectionChg,"You have changed the default direction.")
 dcl(MSG_AfterRestartNew, "This change will only take effect when you restart AbiWord or create a new document.")
 dcl(MSG_BookmarkNotFound, "Bookmark \"%s\" was not found in this document.")
 dcl(MSG_BookmarkAlreadyExists, "This bookmark already exists. Would you like to replace the existing bookmark with this new one?")
+dcl(MSG_XMLIDAlreadyExists, "This RDF link already exists. Would you like to replace the existing RDF link with this new one?")
 dcl(MSG_HyperlinkNoSelection, "You must select a portion of the document before inserting a hyperlink.")
 dcl(MSG_HyperlinkNoBookmark, "Warning: the bookmark you provided [%s] does not exist.")
 dcl(MSG_HyperlinkCrossesBoundaries, "The text to which the hyperlink is to be attached must be within a single paragraph.")
@@ -808,10 +890,12 @@ dcl(DLG_MetaData_TAB_General,"General")
 dcl(MSG_EmptySelection, "Current Selection is Empty")
 
 dcl(DLG_InsertBookmark_Title, "Insert Bookmark")
-dcl(DLG_InsertBookmark_Msg, "Type a name for the bookmark, or select an existing from the list.")
+dcl(DLG_InsertBookmark_Msg,   "Type a name for the bookmark, or select an existing from the list:")
+dcl(DLG_InsertXMLID_Title,    "Insert RDF Link")
+dcl(DLG_InsertXMLID_Msg,      "Type a name for the RDF link:")
 
 dcl(DLG_InsertHyperlink_Title, "Insert Hyperlink")
-dcl(DLG_InsertHyperlink_Msg, "Select a target bookmark from the list.")
+dcl(DLG_InsertHyperlink_Msg, "Select a target bookmark from the list:")
 
 	/* Mark revisions dialog */
 dcl(DLG_MarkRevisions_Title, "Mark Revisions")
@@ -951,6 +1035,7 @@ dcl(MENU_LABEL_INSERT_TABLEOFCONTENTS,"Table of Contents")
 dcl(MENU_LABEL_INSERT_CLIPART,"&Clip Art")
 dcl(MENU_LABEL_INSERT_GRAPHIC,"&Picture")
 dcl(MENU_LABEL_INSERT_BOOKMARK,"Boo&kmark")
+dcl(MENU_LABEL_INSERT_XMLID,"RDF Link")
 dcl(MENU_LABEL_INSERT_HYPERLINK,"&Hyperlink")
 dcl(MENU_LABEL_INSERT_GOTO_HYPERLINK,"&Jump to hyperlink")
 dcl(MENU_LABEL_INSERT_EDIT_HYPERLINK,"&Edit hyperlink")
@@ -965,7 +1050,7 @@ dcl(MENU_LABEL_FMT_LANGUAGE,"Set &Language")
 dcl(MENU_LABEL_FMT_FONT,"&Font")
 dcl(MENU_LABEL_FMT_PARAGRAPH,"&Paragraph")
 dcl(MENU_LABEL_FMT_BULLETS,"Bullets and &Numbering")
-dcl(MENU_LABEL_TABLE_FORMAT, "&Table")
+dcl(MENU_LABEL_FMT_TABLE, "&Table")
 dcl(MENU_LABEL_FMT_DOCUMENT,"&Document")
 dcl(MENU_LABEL_FMT_BORDERS,"&Borders and Shading")
 dcl(MENU_LABEL_FMT_HDRFTR,"&Header/Footers")
@@ -1037,6 +1122,13 @@ dcl(MENU_LABEL_TOOLS_ANNOTATIONS_TOGGLE_DISPLAY,"&Show annotations")
 dcl(MENU_LABEL_GOTO_ANNOTATION,"&Jump to annotation")
 dcl(MENU_LABEL_EDIT_ANNOTATION,"&Edit annotation")
 dcl(MENU_LABEL_DELETE_ANNOTATION,"&Delete annotation")
+dcl(MENU_LABEL_RDFANCHOR_EDIT_TRIPLES,"&Edit RDF")
+dcl(MENU_LABEL_RDFANCHOR_QUERY,"&Query RDF")
+dcl(MENU_LABEL_RDFANCHOR_EDITSEMITEM,"E&dit Semantic Items")
+dcl(MENU_LABEL_RDFANCHOR_EXPORTSEMITEM,"Export Semantic Items")
+dcl(MENU_LABEL_RDFANCHOR_SELECTTHISREFTOSEMITEM,"Select this reference to Semantic Item")
+dcl(MENU_LABEL_RDFANCHOR_SELECTNEXTREFTOSEMITEM,"Select next references to Semantic Item")
+dcl(MENU_LABEL_RDFANCHOR_SELECTPREVREFTOSEMITEM,"Select previous reference to Semantic Item")
 dcl(MENU_LABEL_TABLE, "T&able")
 dcl(MENU_LABEL_TABLE_INSERT, "&Insert")
 dcl(MENU_LABEL_TABLE_INSERT_TABLE, "&Table")
@@ -1058,6 +1150,7 @@ dcl(MENU_LABEL_TABLE_DELETECOLUMN, "Delete Co&lumn")
 dcl(MENU_LABEL_TABLE_DELETE_ROWS, "&Row")
 dcl(MENU_LABEL_TABLE_DELETEROW, "Delete Ro&w")
 dcl(MENU_LABEL_TABLE_DELETE_CELLS, "&Cells")
+dcl(MENU_LABEL_TABLE_FORMAT, "&Format")
 dcl(MENU_LABEL_TABLE_SELECT, "&Select")
 dcl(MENU_LABEL_TABLE_SELECT_TABLE, "&Table")
 dcl(MENU_LABEL_TABLE_SELECT_COLUMN, "Co&lumn")
@@ -1089,6 +1182,7 @@ dcl(MENU_LABEL_TABLE_SORTCOLSDESCEND, "Sort Columns in Descending Order")
 #define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_ACCEPT_REVISION AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_ACCEPT_REVISION
 #define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_FIND_NEXT AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_FIND_NEXT
 #define AP_STRING_ID_MENU_LABEL_CONTEXT_REVISIONS_FIND_PREV AP_STRING_ID_MENU_LABEL_TOOLS_REVISIONS_FIND_PREV
+#define AP_STRING_ID_MENU_LABEL_CONTEXT_IMAGE AP_STRING_ID_MENU_LABEL_FMT_IMAGE
 dcl(MENU_LABEL_ALIGN,"&Align")
 dcl(MENU_LABEL_ALIGN_LEFT,"&Left")
 dcl(MENU_LABEL_ALIGN_CENTER,"&Center")
@@ -1203,7 +1297,7 @@ dcl(MENU_STATUSLINE_VIEW_DEFAULT_TB_LAYOUT,"Reset the current toolbar layout to
 dcl(MENU_STATUSLINE_VIEW_RULER,"Show or hide the rulers")
 dcl(MENU_STATUSLINE_VIEW_STATUSBAR,"Show or hide the status bar")
 dcl(MENU_STATUSLINE_VIEW_SHOWPARA,"Display non-printing characters")
-dcl(MENU_STATUSLINE_VIEW_LOCKSTYLES,"Allow formatting using styles only")
+dcl(MENU_STATUSLINE_VIEW_LOCKSTYLES,"Allow formatting not using styles only")
 dcl(MENU_STATUSLINE_VIEW_HEADFOOT,"Edit text at the top or bottom of every page")
 dcl(MENU_STATUSLINE_VIEW_FULLSCREEN,"View the document in full screen mode")
 dcl(MENU_STATUSLINE_VIEW_ZOOM_MENU,"Reduce or enlarge the document display")
@@ -1231,6 +1325,7 @@ dcl(MENU_STATUSLINE_INSERT_HEADER,"Insert a Header")
 dcl(MENU_STATUSLINE_INSERT_FOOTER,"Insert a Footer")
 dcl(MENU_STATUSLINE_INSERT_GRAPHIC,"Insert an existing picture from another file")
 dcl(MENU_STATUSLINE_INSERT_BOOKMARK,"Insert bookmark")
+dcl(MENU_STATUSLINE_INSERT_XMLID,"Insert RDF link...")
 dcl(MENU_STATUSLINE_INSERT_HYPERLINK,"Insert hyperlink")
 dcl(MENU_STATUSLINE_INSERT_GOTO_HYPERLINK,"Jump to hyperlink")
 dcl(MENU_STATUSLINE_INSERT_EDIT_HYPERLINK,"Edit hyperlink")
@@ -1246,6 +1341,7 @@ dcl(MENU_STATUSLINE_FMT_LANGUAGE,"Change the language of the selected text")
 dcl(MENU_STATUSLINE_FMT_FONT,"Change the font of the selected text")
 dcl(MENU_STATUSLINE_FMT_PARAGRAPH,"Change the format of the selected paragraph")
 dcl(MENU_STATUSLINE_FMT_BULLETS,"Add or modify bullets and numbering for selected paragraphs")
+dcl(MENU_STATUSLINE_FMT_TABLE,"Change the format of the table")
 dcl(MENU_STATUSLINE_FMT_DOCUMENT,"Setup your document's page properties such as page size and margins")
 dcl(MENU_STATUSLINE_FMT_BORDERS,"Add borders and shading to the selection")
 dcl(MENU_STATUSLINE_FMT_HDRFTR,"Set the types of Headers and Footers")
@@ -1291,7 +1387,7 @@ dcl(MENU_STATUSLINE_TOOLS_SCRIPTS,"Execute helper scripts")
 dcl(MENU_STATUSLINE_TOOLS_HISTORY,"See history of the current document")
 dcl(MENU_STATUSLINE_TOOLS_HISTORY_SHOW,"View document history")
 dcl(MENU_STATUSLINE_TOOLS_HISTORY_PURGE,"Remove full document history from the document")
-dcl(MENU_STATUSLINE_TOOLS_REVISIONS,"")
+dcl(MENU_STATUSLINE_TOOLS_REVISIONS," ")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SET_VIEW_LEVEL,"Choose which revision you wish to view")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_MARK,"Mark changes as you type")
 dcl(MENU_STATUSLINE_TOOLS_REVISIONS_SHOW,"Show revisions that are present in document")
@@ -1315,6 +1411,13 @@ dcl(MENU_STATUSLINE_TOOLS_ANNOTATIONS_TOGGLE_DISPLAY,"Show/hide annotations")
 dcl(MENU_STATUSLINE_GOTO_ANNOTATION,"Jump to annotation")
 dcl(MENU_STATUSLINE_EDIT_ANNOTATION,"Edit annotation")
 dcl(MENU_STATUSLINE_DELETE_ANNOTATION,"Delete annotation")
+dcl(MENU_STATUSLINE_RDFANCHOR_EDIT_TRIPLES,"Edit RDF Triples associated with location")
+dcl(MENU_STATUSLINE_RDFANCHOR_QUERY,"Query RDF associated with location")
+dcl(MENU_STATUSLINE_RDFANCHOR_EDITSEMITEM,"Edit Semantic Items for location")
+dcl(MENU_STATUSLINE_RDFANCHOR_EXPORTSEMITEM,"Export Semantic Items for location")
+dcl(MENU_STATUSLINE_RDFANCHOR_SELECTTHISREFTOSEMITEM,"Select this reference to Semantic Item")
+dcl(MENU_STATUSLINE_RDFANCHOR_SELECTNEXTREFTOSEMITEM,"Select next reference to Semantic Item")
+dcl(MENU_STATUSLINE_RDFANCHOR_SELECTPREVREFTOSEMITEM,"Select previous reference to Semantic Item")
 dcl(MENU_STATUSLINE_TABLE, "Table")
 dcl(MENU_STATUSLINE_TABLE_INSERT, "Insert")
 dcl(MENU_STATUSLINE_TABLE_INSERT_TABLE, "Insert Table")
@@ -1365,6 +1468,7 @@ dcl(MENU_STATUSLINE_TABLE_INSERT_SUMROWS, "Insert the Sum of a Table Column")
 #define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_REJECT_REVISION AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_REJECT_REVISION
 #define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_FIND_NEXT AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_FIND_NEXT
 #define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_REVISIONS_FIND_PREV AP_STRING_ID_MENU_STATUSLINE_TOOLS_REVISIONS_FIND_PREV
+#define AP_STRING_ID_MENU_STATUSLINE_CONTEXT_IMAGE AP_STRING_ID_MENU_STATUSLINE_FMT_IMAGE
 dcl(MENU_STATUSLINE_ALIGN," ")
 dcl(MENU_STATUSLINE_ALIGN_LEFT,"Left-align the paragraph")
 dcl(MENU_STATUSLINE_ALIGN_CENTER,"Center-align the paragraph")
@@ -1408,6 +1512,94 @@ dcl(MENU_STATUSLINE_FMT_IMAGE, "Resize this image")
 dcl(MENU_STATUSLINE_FMT_POSIMAGE, "Format this image")
 dcl(MENU_STATUSLINE_FMT_SETPOSIMAGE, "Set this image to be positioned")
 
+dcl(MENU_LABEL_RDF,        "&RDF")
+dcl(MENU_LABEL_RDF_HIGHLIGHT,       "Highlight RDF")
+dcl(MENU_LABEL_RDF_QUERY,           "SPARQL Query")
+dcl(MENU_LABEL_RDF_EDITOR,          "Edit RDF Triples")
+dcl(MENU_LABEL_RDF_QUERY_XMLIDS,    "Query RDF for cursor position")
+dcl(MENU_LABEL_RDF_SEMITEM,         "Semantic Item")
+dcl(MENU_LABEL_RDF_SEMITEM_CREATE,  "Create Semantic Item")
+dcl(MENU_LABEL_RDF_SEMITEM_CREATEREF,   "Create Reference")
+dcl(MENU_LABEL_RDF_SEMITEM_NEW,         "Create New")
+dcl(MENU_LABEL_RDF_SEMITEM_NEW_CONTACT,     "Contact")
+dcl(MENU_LABEL_RDF_SEMITEM_NEW_CONTACT_FROM_FILE,     "Contact from File")
+dcl(MENU_LABEL_RDF_SEMITEM_RELATION,                    "Relation")
+dcl(MENU_LABEL_RDF_SEMITEM_SET_AS_SOURCE,               "Set as Source Semantic Item")
+dcl(MENU_LABEL_RDF_SEMITEM_RELATED_TO_SOURCE,           "Related To Source Semantic Item")
+dcl(MENU_LABEL_RDF_SEMITEM_RELATED_TO_SOURCE_FOAFKNOWS, "Both People Know Each Other")
+dcl(MENU_LABEL_RDF_SEMITEM_FIND_RELATED,                "Find by Relation")
+dcl(MENU_LABEL_RDF_SEMITEM_FIND_RELATED_FOAFKNOWS,      "Both People Know Each Other")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET,     "Stylesheet")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_APPLY,                       "Apply Current")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_DISASSOCIATE,                "Disassociate")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_SETTINGS,                    "Settings")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT,                     "Apply Contact")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT_NAME,                "Name")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT_NICK,                "Nick")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT_NAME_PHONE,          "Name, Phone")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT_NICK_PHONE,          "Nick, Phone")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_CONTACT_NAME_HOMEPAGE_PHONE, "Name, (Homepage), Phone")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT,                       "Apply Event")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT_NAME,                  "Name")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY,               "Summary")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_LOCATION,      "Summary, Location")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_LOCATION_TIMES,"Summary, Location, Start and End Times")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_TIMES,         "Summary, Start and End Times")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_LOCATION,                    "Apply Location")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_LOCATION_NAME,               "Name")
+dcl(MENU_LABEL_RDF_SEMITEM_STYLESHEET_LOCATION_NAME_LATLONG,       "Name, Latitude and Longitude")
+dcl(MENU_LABEL_RDF_ADV,             "Advanced")
+dcl(MENU_LABEL_RDF_ADV_TEST,            "Test RDF subsystem")
+dcl(MENU_LABEL_RDF_ADV_DUMP_OBJECTS,    "Dump RDF Objects")
+dcl(MENU_LABEL_RDF_ADV_DUMP_FOR_POINT,  "Dump RDF related to Cursor Position")
+dcl(MENU_LABEL_RDF_ADV_PLAY,            "Playing with RDF during development")
+
+
+
+dcl(MENU_STATUSLINE_RDF,             "Interact with RDF")
+dcl(MENU_STATUSLINE_RDF_HIGHLIGHT,       "Highlight areas of the document with RDF associated")
+dcl(MENU_STATUSLINE_RDF_QUERY,           "Execute a SPARQL Query on all document RDF...")
+dcl(MENU_STATUSLINE_RDF_EDITOR,          "Directly edit the RDF for the entire document...")
+dcl(MENU_STATUSLINE_RDF_QUERY_XMLIDS,    "Query the RDF associated with the cursor position...")
+dcl(MENU_STATUSLINE_RDF_SEMITEM,         "Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_CREATE,  "Create Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_CREATEREF, "Create new Reference to existing Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_NEW,       "Create new Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_NEW_CONTACT, "Create new Contact Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_NEW_CONTACT_FROM_FILE, "Create new Contact Semantic Item by importing a vcard")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_RELATION,                    "Relation")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_SET_AS_SOURCE,               "Set as Source Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_RELATED_TO_SOURCE,           "Related To Source Semantic Item")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_RELATED_TO_SOURCE_FOAFKNOWS, "Both People Know Each Other")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_FIND_RELATED,                "Find by Relation")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_FIND_RELATED_FOAFKNOWS,      "Both People Know Each Other")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET,     "Stylesheet")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_APPLY,                       "Apply Current")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_DISASSOCIATE,                "Disassociate and apply default stylesheet")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_SETTINGS,                    "Settings")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT,                     "Apply Contact")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT_NAME,                "Name")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT_NICK,                "Nick")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT_NAME_PHONE,          "Name, Phone")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT_NICK_PHONE,          "Nick, Phone")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_CONTACT_NAME_HOMEPAGE_PHONE, "Name, (Homepage), Phone")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT,                       "Apply Event")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT_NAME,                  "Name")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY,               "Summary")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_LOCATION,      "Summary, Location")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_LOCATION_TIMES,"Summary, Location, Start and End Times")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_EVENT_SUMMARY_TIMES,         "Summary, Start and End Times")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_LOCATION,                    "Apply Location")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_LOCATION_NAME,               "Name")
+dcl(MENU_STATUSLINE_RDF_SEMITEM_STYLESHEET_LOCATION_NAME_LATLONG,       "Name, Latitude and Longitude")
+dcl(MENU_STATUSLINE_RDF_ADV,             "Advanced RDF")
+dcl(MENU_STATUSLINE_RDF_ADV_TEST,            "Run some RDF tests and show results on console")
+dcl(MENU_STATUSLINE_RDF_ADV_DUMP_OBJECTS,    "Dump out information about RDF Objects")
+dcl(MENU_STATUSLINE_RDF_ADV_DUMP_FOR_POINT,  "Dump the raw RDF associated with the cursor position")
+dcl(MENU_STATUSLINE_RDF_ADV_PLAY,            "Run some RDF tests that change during development")
+
+
+
 /* Toolbar labels */
 dcl(TB_Extra,"Extra")
 dcl(TB_Format,"Format")
@@ -1488,6 +1680,16 @@ dcl(TOOLBAR_LABEL_MERGERIGHT, "Merge right")
 dcl(TOOLBAR_LABEL_MERGEABOVE, "Merge above")
 dcl(TOOLBAR_LABEL_MERGEBELOW, "Merge below")
 dcl(TOOLBAR_LABEL_MENU, "Menu")
+dcl(TOOLBAR_LABEL_REVISIONS_NEW,"New Revision")
+dcl(TOOLBAR_LABEL_REVISIONS_SELECT,"Select Revision")
+dcl(TOOLBAR_LABEL_REVISIONS_SHOW_FINAL,"Show document at final version without revision highlighting")
+dcl(TOOLBAR_LABEL_REVISIONS_FIND_PREV,"Select the parts of the document contained in the previous revision")
+dcl(TOOLBAR_LABEL_REVISIONS_FIND_NEXT,"Select the parts of the document contained in the next revision")
+dcl(TOOLBAR_LABEL_SEMITEM_THIS,"Select this reference to this Semantic Item")
+dcl(TOOLBAR_LABEL_SEMITEM_NEXT,"Select next reference to this Semantic Item")
+dcl(TOOLBAR_LABEL_SEMITEM_PREV,"Select previous reference to this Semantic Item")
+dcl(TOOLBAR_LABEL_SEMITEM_EDIT,"Edit this Semantic Item")
+dcl(TOOLBAR_LABEL_SEMITEM_STYLESHEET_APPLY,"Apply stylesheet to this Semantic Item")
 
 dcl(TOOLBAR_STATUSLINE_FILE_NEW,"Create a new document")
 dcl(TOOLBAR_STATUSLINE_FILE_OPEN,"Open an existing document")
@@ -1561,6 +1763,16 @@ dcl(TOOLBAR_STATUSLINE_MERGERIGHT, "Merge with right cell")
 dcl(TOOLBAR_STATUSLINE_MERGEABOVE, "Merge with cell above")
 dcl(TOOLBAR_STATUSLINE_MERGEBELOW, "Merge with cell below")
 dcl(TOOLBAR_STATUSLINE_MENU, "Menu")
+dcl(TOOLBAR_STATUSLINE_REVISIONS_NEW, "Revisions new...")
+dcl(TOOLBAR_STATUSLINE_REVISIONS_SELECT, "Revisions select...")
+dcl(TOOLBAR_STATUSLINE_REVISIONS_SHOW_FINAL, "Show final document...")
+dcl(TOOLBAR_STATUSLINE_REVISIONS_FIND_PREV, "Select the parts of the document belonging to the previous version...")
+dcl(TOOLBAR_STATUSLINE_REVISIONS_FIND_NEXT, "Select the parts of the document belonging to the next version...")
+dcl(TOOLBAR_STATUSLINE_SEMITEM_THIS, "Select this reference to this Semantic Item...")
+dcl(TOOLBAR_STATUSLINE_SEMITEM_NEXT, "Select next reference to this Semantic Item...")
+dcl(TOOLBAR_STATUSLINE_SEMITEM_PREV, "Select previous reference to this Semantic Item...")
+dcl(TOOLBAR_STATUSLINE_SEMITEM_EDIT,"Edit this Semantic Item")
+dcl(TOOLBAR_STATUSLINE_SEMITEM_STYLESHEET_APPLY,"Apply stylesheet to this Semantic Item")
 
 dcl(TOOLBAR_TOOLTIP_FILE_NEW,"Create a new document")
 dcl(TOOLBAR_TOOLTIP_FILE_OPEN,"Open an existing document")
@@ -1634,5 +1846,16 @@ dcl(TOOLBAR_TOOLTIP_MERGERIGHT, "Merge with right cell")
 dcl(TOOLBAR_TOOLTIP_MERGEABOVE, "Merge with cell above")
 dcl(TOOLBAR_TOOLTIP_MERGEBELOW, "Merge with cell below")
 dcl(TOOLBAR_TOOLTIP_MENU, "Menu")
+dcl(TOOLBAR_TOOLTIP_REVISIONS_NEW, "Create a new Revision")
+dcl(TOOLBAR_TOOLTIP_REVISIONS_SELECT, "Choose which revision of the document to see and edit")
+dcl(TOOLBAR_TOOLTIP_REVISIONS_SHOW_FINAL, "Show final document")
+dcl(TOOLBAR_TOOLTIP_REVISIONS_FIND_PREV, "Select the parts of the document contained in the previous revision")
+dcl(TOOLBAR_TOOLTIP_REVISIONS_FIND_NEXT, "Select the parts of the document contained in the next revision")
+
+dcl(TOOLBAR_TOOLTIP_SEMITEM_THIS, "Select this reference to Semantic Item")
+dcl(TOOLBAR_TOOLTIP_SEMITEM_NEXT, "Select next reference to Semantic Item")
+dcl(TOOLBAR_TOOLTIP_SEMITEM_PREV, "Select previous reference to Semantic Item")
+dcl(TOOLBAR_TOOLTIP_SEMITEM_EDIT,"Edit this Semantic Item")
+dcl(TOOLBAR_TOOLTIP_SEMITEM_STYLESHEET_APPLY,"Apply stylesheet to this Semantic Item")
 
 dcl(COMMAND_LINE_PRINTING_DEPRECATED, "The '--print' option has been removed as of AbiWord 2.8. You can achieve the desired behavior using AbiWord's command-line conversion tools and then piping the output to a print spooler. Eg: 'abiword --to=ps --to-name=fd://1 myfile.txt | lpr'")
