@@ -24,6 +24,7 @@
 
 #include "ut_locale.h"
 #include "ut_string.h"
+#include "ut_std_string.h"
 #include "ut_types.h"
 #include "ut_bytebuf.h"
 #include "ut_base64.h"
@@ -187,23 +188,23 @@ public:
 						IE_Exp_AbiWord_1 * pie, bool isTemplate);
 	virtual ~s_AbiWord_1_Listener();
 
-	virtual bool		populate(PL_StruxFmtHandle sfh,
+	virtual bool		populate(fl_ContainerLayout* sfh,
 								 const PX_ChangeRecord * pcr);
 
-	virtual bool		populateStrux(PL_StruxDocHandle sdh,
+	virtual bool		populateStrux(pf_Frag_Strux* sdh,
 									  const PX_ChangeRecord * pcr,
-									  PL_StruxFmtHandle * psfh);
+									  fl_ContainerLayout* * psfh);
 
-	virtual bool		change(PL_StruxFmtHandle sfh,
+	virtual bool		change(fl_ContainerLayout* sfh,
 							   const PX_ChangeRecord * pcr);
 
-	virtual bool		insertStrux(PL_StruxFmtHandle sfh,
+	virtual bool		insertStrux(fl_ContainerLayout* sfh,
 									const PX_ChangeRecord * pcr,
-									PL_StruxDocHandle sdh,
+									pf_Frag_Strux* sdh,
 									PL_ListenerId lid,
-									void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+									void (* pfnBindHandles)(pf_Frag_Strux* sdhNew,
 															PL_ListenerId lid,
-															PL_StruxFmtHandle sfhNew));
+															fl_ContainerLayout* sfhNew));
 
 	virtual bool		signal(UT_uint32 iSignal);
 
@@ -232,6 +233,10 @@ protected:
 								 bool bIgnoreProperties = false);
 	void				_outputData(const UT_UCSChar * p, UT_uint32 length);
 	void				_outputXMLChar(const gchar * data, UT_uint32 length);
+	void                _outputXMLChar(const std::string & s)
+	{
+		_outputXMLChar(s.c_str(), s.size());
+	}
 	void				_outputXMLAttribute(const gchar * key, const gchar * value, UT_uint32 length);
 	void				_outputXMLAttribute(const gchar * key, const std::string& value );
 	void				_handleStyles(void);
@@ -885,7 +890,7 @@ s_AbiWord_1_Listener::getObjectKey(const PT_AttrPropIndex& api, const gchar* key
 }
 
 
-bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
+bool s_AbiWord_1_Listener::populate(fl_ContainerLayout* /*sfh*/,
 									  const PX_ChangeRecord * pcr)
 {
 	switch (pcr->getType())
@@ -990,6 +995,7 @@ bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
    				{
    					_closeSpan();
    					_closeField();
+					_closeHyperlink();
 					const PP_AttrProp * pAP = NULL;
 					m_pDocument->getAttrProp(api,&pAP);
 					const gchar * pName;
@@ -1003,27 +1009,22 @@ bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 						if(bFound)
 							break;
 					}
-
+					
 					if(bFound)
 					{
 						//this is the start of the hyperlink
    						_openTag("a", "",false, api,pcr->getXID(),true);
    						m_bInHyperlink = true;
    					}
-   					else
-   					{
-   						_closeHyperlink();
-   					}
-
 
    					return true;
-
    				}
 
    			case PTO_Annotation:
    				{
    					_closeSpan();
    					_closeField();
+					_closeAnnotation();
 					const PP_AttrProp * pAP = NULL;
 					m_pDocument->getAttrProp(api,&pAP);
 					const gchar * pName;
@@ -1043,15 +1044,8 @@ bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 						UT_DEBUGMSG(("Doing open annotation object \n"));
    						m_bInAnnotation = true;
    					}
-   					else
-   					{
-						UT_DEBUGMSG(("Doing close annotation object \n"));
-   						_closeAnnotation();
-   					}
-
 					
    					return true;
-
    				}
 
    			case PTO_RDFAnchor:
@@ -1097,9 +1091,9 @@ bool s_AbiWord_1_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 	}
 }
 
-bool s_AbiWord_1_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
+bool s_AbiWord_1_Listener::populateStrux(pf_Frag_Strux* /*sdh*/,
 										   const PX_ChangeRecord * pcr,
-										   PL_StruxFmtHandle * psfh)
+										   fl_ContainerLayout* * psfh)
 {
 	UT_return_val_if_fail(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux, false);
 	const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
@@ -1311,20 +1305,20 @@ bool s_AbiWord_1_Listener::populateStrux(PL_StruxDocHandle /*sdh*/,
 	}
 }
 
-bool s_AbiWord_1_Listener::change(PL_StruxFmtHandle /*sfh*/,
+bool s_AbiWord_1_Listener::change(fl_ContainerLayout* /*sfh*/,
 									const PX_ChangeRecord * /*pcr*/)
 {
   UT_ASSERT_NOT_REACHED();
 	return false;
 }
 
-bool s_AbiWord_1_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool s_AbiWord_1_Listener::insertStrux(fl_ContainerLayout* /*sfh*/,
 										  const PX_ChangeRecord * /*pcr*/,
-										  PL_StruxDocHandle /*sdh*/,
+										  pf_Frag_Strux* /*sdh*/,
 										  PL_ListenerId /* lid */,
-										  void (* /*pfnBindHandles*/)(PL_StruxDocHandle /* sdhNew */,
+										  void (* /*pfnBindHandles*/)(pf_Frag_Strux* /* sdhNew */,
 																	  PL_ListenerId /* lid */,
-																	  PL_StruxFmtHandle /* sfhNew */))
+																	  fl_ContainerLayout* /* sfhNew */))
 {
 	UT_ASSERT_NOT_REACHED();						// this function is not used.
 	return false;
@@ -1393,34 +1387,35 @@ UT_Error IE_Exp_AbiWord_1::_writeDocument(void)
 
 	m_pListener = new s_AbiWord_1_Listener(getDoc(),this, m_bIsTemplate);
 	if (!m_pListener)
-		{
-			close_gsf_handle(m_output);
-			return UT_IE_NOMEMORY;
-		}
+	{
+		close_gsf_handle(m_output);
+		return UT_IE_NOMEMORY;
+	}
 
+	bool bStatusTellListener = true;
 	if (getDocRange())
 	{
-		if(!getDoc()->tellListenerSubset(static_cast<PL_Listener *>(m_pListener),getDocRange()))
-			{
-				close_gsf_handle(m_output);
-				return UT_ERROR;
-			}
+		bStatusTellListener = getDoc()->tellListenerSubset(static_cast<PL_Listener *>(m_pListener),getDocRange());
 	}
 	else
 	{
-		if (!getDoc()->tellListener(static_cast<PL_Listener *>(m_pListener)))
-			{
-				close_gsf_handle(m_output);
-				return UT_ERROR;
-			}
+		bStatusTellListener = getDoc()->tellListener(static_cast<PL_Listener *>(m_pListener));
 	}
 	
 	delete m_pListener;
 	m_pListener = NULL;
-
 	close_gsf_handle(m_output);
 
-	return ((m_error) ? UT_IE_COULDNOTWRITE : UT_OK);
+	if (!bStatusTellListener)
+	{
+		return UT_ERROR;
+	}
+	else if (m_error)
+	{
+		return UT_IE_COULDNOTWRITE;
+	}
+
+	return UT_OK;
 }
 
 /*****************************************************************/
@@ -1546,8 +1541,8 @@ void s_AbiWord_1_Listener::_handleMetaData(void)
 
   // set all of the important meta-data props
 
-  m_pDocument->setMetaDataProp ( PD_META_KEY_GENERATOR, UT_UTF8String("AbiWord") ) ;
-  m_pDocument->setMetaDataProp ( PD_META_KEY_FORMAT,    UT_UTF8String(IE_MIMETYPE_AbiWord) ) ;
+  m_pDocument->setMetaDataProp ( PD_META_KEY_GENERATOR, "AbiWord" ) ;
+  m_pDocument->setMetaDataProp ( PD_META_KEY_FORMAT,    IE_MIMETYPE_AbiWord ) ;
 
 #if 0
   // get the saved time, remove trailing newline
@@ -1559,33 +1554,25 @@ void s_AbiWord_1_Listener::_handleMetaData(void)
 
   // TODO: set dc.date and abiword.date_created if document is new (i.e. first save)
 
-  UT_GenericStringMap<UT_UTF8String*> & ref = m_pDocument->getMetaData() ;
+  const std::map<std::string, std::string> & ref = m_pDocument->getMetaData() ;
 
   // don't print out a thing
-  if ( ref.size () == 0 )
+  if ( ref.empty() ) {
     return ;
+  }
 
   m_pie->write("<metadata>\n");
 
-  UT_GenericStringMap<UT_UTF8String*>::UT_Cursor cursor ( &ref ) ;
-
-  const UT_UTF8String * val = NULL ;
-  for ( val = cursor.first(); cursor.is_valid(); val = cursor.next () )
-    {
-      if ( val )
-	{
-	  const UT_UTF8String *stringval = val;
-	  if( stringval->size () > 0 )
-	    {
+  std::map<std::string, std::string>::const_iterator iter = ref.begin();
+  for ( ; iter != ref.end(); ++iter ) {
+	  if( !iter->second.empty() ) {
 	      m_pie->write( "<m key=\"" ) ;
-	      _outputXMLChar ( cursor.key().c_str(), cursor.key().size() ) ;
+	      _outputXMLChar ( iter->first ) ;
 	      m_pie->write ( "\">" ) ;
-		  UT_UTF8String esc = *stringval;
-	      _outputXMLChar ( esc.utf8_str(), esc.byteLength() ) ;
+	      _outputXMLChar ( iter->second ) ;
 	      m_pie->write ( "</m>\n" ) ;
-	    }
-	}
-    }
+	  }
+  }
 
   m_pie->write("</metadata>\n");
 }
@@ -1785,16 +1772,15 @@ void s_AbiWord_1_Listener::_handleRevisions(void)
 	const UT_GenericVector<AD_Revision*> & vRevisions = m_pDocument->getRevisions();
 
 	UT_sint32 k = 0;
+	std::string s;
 	for (k=0; k < vRevisions.getItemCount(); k++)
 	{
 		pRev = vRevisions.getNthItem(k);
 		UT_continue_if_fail(pRev);
 		
-		UT_String s;
-		
 		if (!bWroteOpenRevisionsSection)
 		{
-			UT_String_sprintf(s, "<revisions show=\"%d\" mark=\"%d\" show-level=\"%d\" auto=\"%d\">\n",
+			s = UT_std_string_sprintf("<revisions show=\"%d\" mark=\"%d\" show-level=\"%d\" auto=\"%d\">\n",
 							  m_pDocument->isShowRevisions(),
 							  m_pDocument->isMarkRevisions(),
 							  m_pDocument->getShowRevisionId(),
@@ -1804,9 +1790,9 @@ void s_AbiWord_1_Listener::_handleRevisions(void)
 			bWroteOpenRevisionsSection = true;
 		}
 
-		UT_String_sprintf(s, "<r id=\"%d\" time-started=\"%lld\" version=\"%d\">",
+		s = UT_std_string_sprintf("<r id=\"%d\" time-started=\"%lld\" version=\"%d\">",
 						  pRev->getId(),
-						  (UT_uint64)pRev->getStartTime(),
+						  (long long)pRev->getStartTime(),
 						  pRev->getVersion());
 		
 		m_pie->write(s.c_str());
