@@ -25,6 +25,20 @@
 
 #include "ie_exp_HTML.h"
 
+#include <pd_DocumentRDF.h>
+#include "ie_exp_DocRangeListener.h"
+#include "pl_ListenerCoupleCloser.h"
+
+#include <gsf/gsf-outfile.h>
+#include <gsf/gsf-output-stdio.h>
+#include <gsf/gsf-outfile-stdio.h>
+#include <gsf/gsf-output-memory.h>
+#include <gsf/gsf-infile.h>
+#include <gsf/gsf-input.h>
+#include <gsf/gsf-input-stdio.h>
+#include <glib.h>
+#include <glib/gstdio.h>
+
 #define MYEOL "\n"
 #define MAX_LINE_LEN 200
 
@@ -57,7 +71,7 @@ bool IE_Exp_HTML_Sniffer::getDlgLabels(const gchar ** pszDesc,
                                    IEFileType * ft)
 {
     *pszDesc = "HTML/XHTML/PHTML/MHT (.html, .xhtml, .phtml, .mht)";
-    *pszSuffixList = "*.html;*.xhtml;*.phtml;*.mht";
+    *pszSuffixList = "*.html; *.xhtml; *.phtml; *.mht";
     *ft = getFileType();
     return true;
 }
@@ -87,6 +101,7 @@ IE_Exp_HTML::IE_Exp_HTML(PD_Document * pDocument)
         m_style_tree(new IE_Exp_HTML_StyleTree(pDocument)),
         m_styleListener(new IE_Exp_HTML_StyleListener(m_style_tree)),
         m_bSuppressDialog(false),
+        m_bDefaultWriterFactory(true),
         m_suffix(""),
     m_pNavigationHelper(new IE_Exp_HTML_NavigationHelper(getDoc(), getFileName())),
 	m_pWriterFactory( 
@@ -113,8 +128,104 @@ IE_Exp_HTML::IE_Exp_HTML(PD_Document * pDocument)
 
 IE_Exp_HTML::~IE_Exp_HTML()
 {
-    DELETEP(m_style_tree);
-	DELETEP(m_pWriterFactory);
+    if (m_bDefaultWriterFactory)
+        delete m_pWriterFactory;
+	delete m_pNavigationHelper;
+	delete m_styleListener;
+    delete m_style_tree;
+}
+
+
+/*
+ * Copies document contents to the clipboard. Based on ODF exporter method.
+*/
+UT_Error IE_Exp_HTML::copyToBuffer(PD_DocumentRange * pDocRange,UT_ByteBuf *  bufHTML)
+{
+    //
+    // First export selected range to a tempory document
+    //
+    PD_Document * outDoc = new PD_Document();
+    outDoc->createRawDocument();
+    IE_Exp_DocRangeListener * pRangeListener = new IE_Exp_DocRangeListener(pDocRange,outDoc);
+    UT_DEBUGMSG(("DocumentRange low %d High %d \n",pDocRange->m_pos1,pDocRange->m_pos2));
+    PL_ListenerCoupleCloser* pCloser = new PL_ListenerCoupleCloser();
+    pDocRange->m_pDoc->tellListenerSubset(pRangeListener,pDocRange,pCloser);
+    if( pCloser)
+        delete pCloser;
+    
+    //
+    // Grab the RDF triples while we are copying...
+    //
+    if( PD_DocumentRDFHandle outrdf = outDoc->getDocumentRDF() )
+    {
+
+        std::set< std::string > xmlids;
+        PD_DocumentRDFHandle inrdf = pDocRange->m_pDoc->getDocumentRDF();
+        inrdf->addRelevantIDsForRange( xmlids, pDocRange );
+
+        if( !xmlids.empty() )
+        {
+            UT_DEBUGMSG(("HTML export creating restricted RDF model xmlids.sz:%ld \n",(long)xmlids.size()));
+            PD_RDFModelHandle subm = inrdf->createRestrictedModelForXMLIDs( xmlids );
+            PD_DocumentRDFMutationHandle m = outrdf->createMutation();
+            m->add( subm );
+            m->commit();
+            subm->dumpModel("copied rdf triples subm");
+            outrdf->dumpModel("copied rdf triples result");
+        }
+        
+        // PD_DocumentRDFMutationHandle m = outrdf->createMutation();
+        // m->add( PD_URI("http://www.example.com/foo"),
+        //         PD_URI("http://www.example.com/bar"),
+        //         PD_Literal("copyToBuffer path") );
+        // m->commit();
+    }
+    outDoc->finishRawCreation();
+    //
+    // OK now we have a complete and valid document containing our selected 
+    // content. We export this to an in memory GSF buffer
+    //
+    IE_Exp_HTML * pNewExp = NULL; 
+    char *szTempFileName = NULL;
+    GError *err = NULL;
+    g_file_open_tmp ("XXXXXX", &szTempFileName, &err);
+    GsfOutput * outBuf =  gsf_output_stdio_new (szTempFileName,&err);
+    IEFileType ftHTML = IE_Exp::fileTypeForMimetype("text/html");
+    UT_Error aerr = IE_Exp::constructExporter(outDoc,outBuf,
+											  ftHTML,(IE_Exp**)&pNewExp);
+    if(pNewExp == NULL)
+    {
+         return aerr;
+    }
+
+	pNewExp->suppressDialog();
+	
+    aerr = pNewExp->writeFile(szTempFileName);
+    if(aerr != UT_OK)
+    {
+	delete pNewExp;
+	delete pRangeListener;
+	UNREFP( outDoc);
+	g_remove(szTempFileName);
+	g_free (szTempFileName);
+	return aerr;
+    }
+    //
+    // File is closed at the end of the export. Open it again.
+    //
+
+    GsfInput *  fData = gsf_input_stdio_new(szTempFileName,&err);
+    UT_DebugOnly<UT_sint32> siz = gsf_input_size(fData);
+    const UT_Byte * pData = gsf_input_read(fData,gsf_input_size(fData),NULL);
+    UT_DEBUGMSG(("Writing %d bytes to clipboard \n", (UT_sint32)siz));
+    bufHTML->append( pData, gsf_input_size(fData));
+    
+    delete pNewExp;
+    delete pRangeListener;
+    UNREFP( outDoc);
+    g_remove(szTempFileName);
+    g_free (szTempFileName);
+    return aerr;
 }
 
 void IE_Exp_HTML::_buildStyleTree()
@@ -174,32 +285,34 @@ UT_Error IE_Exp_HTML::_doOptions()
     }
     /* run the dialog
      */
+	if(!pFrame->getFilename())
+	{
+	    XAP_Dialog_Id id = XAP_DIALOG_ID_HTMLOPTIONS;
 
-    XAP_Dialog_Id id = XAP_DIALOG_ID_HTMLOPTIONS;
+	    XAP_DialogFactory * pDialogFactory
+	            = static_cast<XAP_DialogFactory *> (XAP_App::getApp()->getDialogFactory());
 
-    XAP_DialogFactory * pDialogFactory
-            = static_cast<XAP_DialogFactory *> (XAP_App::getApp()->getDialogFactory());
+	    XAP_Dialog_HTMLOptions * pDialog
+	            = static_cast<XAP_Dialog_HTMLOptions *> (pDialogFactory->requestDialog(id));
 
-    XAP_Dialog_HTMLOptions * pDialog
-            = static_cast<XAP_Dialog_HTMLOptions *> (pDialogFactory->requestDialog(id));
+	    UT_return_val_if_fail(pDialog, false);
 
-    UT_return_val_if_fail(pDialog, false);
+	    pDialog->setHTMLOptions(&m_exp_opt, XAP_App::getApp());
 
-    pDialog->setHTMLOptions(&m_exp_opt, XAP_App::getApp());
+	    pDialog->runModal(pFrame);
 
-    pDialog->runModal(pFrame);
+	    /* extract what they did
+	     */
+	    bool bSave = pDialog->shouldSave();
+	
+	    pDialogFactory->releaseDialog(pDialog);
 
-    /* extract what they did
-     */
-    bool bSave = pDialog->shouldSave();
-
-    pDialogFactory->releaseDialog(pDialog);
-
-    if (!bSave)
-    {
-        return UT_SAVE_CANCELLED;
-    }
-    return UT_OK;
+	    if (!bSave)
+	    {
+	        return UT_SAVE_CANCELLED;
+	    }
+	}
+        return UT_OK;
 }
 
 UT_Error IE_Exp_HTML::_writeDocument()
@@ -528,11 +641,16 @@ void IE_Exp_HTML::_createChapter(PD_DocumentRange* range, const UT_UTF8String &t
     if (isIndex)
     {
         output = getFp();
-        filename = UT_go_basename_from_uri(getFileName());
-    } else
+		char* s = UT_go_basename_from_uri(getFileName());
+        filename = s;
+		g_free(s);
+    } 
+	else
     {
         filename = ConvertToClean(title) + m_suffix;
-        UT_UTF8String outputUri = UT_go_dirname_from_uri(getFileName(), false);
+		char* s = UT_go_dirname_from_uri(getFileName(), false);
+		UT_UTF8String outputUri = s;
+		g_free(s);
         outputUri += G_DIR_SEPARATOR_S + filename;
         output = UT_go_file_create(outputUri.utf8_str(), NULL);
     }
@@ -648,9 +766,10 @@ void IE_Exp_HTML::_createMultipart()
 
 void IE_Exp_HTML::setWriterFactory(IE_Exp_HTML_WriterFactory* pWriterFactory)
 {
-	if (m_pWriterFactory != NULL)
+	if ((m_pWriterFactory != NULL) && (m_bDefaultWriterFactory))
 	{
 		DELETEP(m_pWriterFactory);
+        m_bDefaultWriterFactory = false;
 	}
 	
 	if (pWriterFactory == NULL)
@@ -658,6 +777,7 @@ void IE_Exp_HTML::setWriterFactory(IE_Exp_HTML_WriterFactory* pWriterFactory)
 		m_pWriterFactory = 
             new IE_Exp_HTML_DefaultWriterFactory(getDoc(),
                                                              this->m_exp_opt);
+        m_bDefaultWriterFactory = true;
 	} else
     {
         m_pWriterFactory = pWriterFactory;
@@ -675,6 +795,19 @@ bool IE_Exp_HTML::hasMathML(const UT_UTF8String& file)
     }
 }
 
+bool IE_Exp_HTML::hasMathML(const std::string& file)
+{
+	UT_UTF8String f(file);
+    if (m_mathmlFlags.find(f) != m_mathmlFlags.end())
+    {
+        return m_mathmlFlags[f];
+    } 
+	else
+    {
+        return false;
+    }
+}
+
 void IE_Exp_HTML::printStyleTree(PD_Document* pDocument, UT_ByteBuf& sink)
 {
     IE_Exp_HTML html(pDocument);
