@@ -24,13 +24,13 @@
 
 #include "ie_exp_HTML_util.h"
 
-const char * s_DTD_XHTML_AWML = "!DOCTYPE html PUBLIC \"-//ABISOURCE//DTD XHTML plus AWML 2.2//EN\" \"http://www.abisource.com/2004/xhtml-awml/xhtml-awml.mod\"";
+const char s_DTD_XHTML_AWML[] = "!DOCTYPE html PUBLIC \"-//ABISOURCE//DTD XHTML plus AWML 2.2//EN\" \"http://www.abisource.com/2004/xhtml-awml/xhtml-awml.mod\"";
 
-const char * s_DTD_XHTML = "!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\"";
+const char s_DTD_XHTML[] = "!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\"";
 
-const char * s_DTD_HTML4 = "!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\"";
+const char s_DTD_HTML4[] = "!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\"";
 
-const char * s_Delimiter =
+const char s_Delimiter[] =
     "=======================================================";
 
 const char * s_Header[2] = {
@@ -38,7 +38,7 @@ const char * s_Header[2] = {
 "For more information visit http://www.abisource.com.   "
 };
 
-const char * s_HeaderCompact = "Created by Abiword, www.abisource.com";
+const char s_HeaderCompact[] = "Created by Abiword, www.abisource.com";
 
 bool m_bSecondPass = false;
 bool m_bInAFENote = false;
@@ -327,13 +327,16 @@ UT_UTF8String getStyleSizeString(const gchar * szWidth, double widthPercentage,
 
 IE_Exp_HTML_DataExporter::IE_Exp_HTML_DataExporter(PD_Document* pDocument,
             const UT_UTF8String &baseName):
-    m_pDocument(pDocument),
-    m_fileDirectory(UT_go_basename_from_uri(baseName.utf8_str()) 
-        + UT_UTF8String(FILES_DIR_NAME)),
-    m_baseDirectory(UT_go_dirname_from_uri(baseName.utf8_str(), false))
-    
+    m_pDocument(pDocument)
 {
-    
+	char* s = UT_go_basename_from_uri(baseName.utf8_str());
+    m_fileDirectory = s;
+    m_fileDirectory += FILES_DIR_NAME;
+	g_free(s);
+
+	s = UT_go_dirname_from_uri(baseName.utf8_str(), false);
+    m_baseDirectory = s;
+	g_free(s);
 }
 
 IE_Exp_HTML_FileExporter::IE_Exp_HTML_FileExporter(PD_Document* pDocument, 
@@ -437,7 +440,7 @@ UT_UTF8String IE_Exp_HTML_MultipartExporter::saveData(const gchar *szDataId,
     
     UT_UTF8String contents;
     encodeDataBase64(szDataId, contents, false);
-    UT_DEBUGMSG(("%d", contents.length()));
+    UT_DEBUGMSG(("%lu", (long unsigned)contents.length()));
     m_buffer += contents;
     m_buffer += MYEOL;
     m_buffer += MYEOL;
@@ -633,7 +636,7 @@ void IE_Exp_HTML_TagWriter::openTag(const std::string& tagName, bool isInline, b
     }
     m_buffer += "<" + tagName;
     
-    UT_DEBUGMSG(("Opened tag: %s\n", tagName.c_str())); 
+    UT_DEBUGMSG(("Opened tag: %s Depth: %ld\n", tagName.c_str(), (long)m_tagStack.size())); 
 }
 
 void IE_Exp_HTML_TagWriter::addAttribute(const std::string& name, const std::string& value)
