@@ -20,6 +20,7 @@
  */
 
 #include <stdlib.h>
+#include <string>
 #include "ut_string.h"
 #include "ut_bytebuf.h"
 #include "ut_base64.h"
@@ -294,7 +295,7 @@ void IE_Exp_RTF::exportHdrFtr(const char * pszHdrFtr , const char * pszHdrFtrID,
 #endif
 	m_pListenerWriteDoc->_setTabEaten(false);
 
-	PL_StruxDocHandle hdrSDH = getDoc()->findHdrFtrStrux((const gchar *) pszHdrFtr,(const gchar * ) pszHdrFtrID);
+	pf_Frag_Strux* hdrSDH = getDoc()->findHdrFtrStrux((const gchar *) pszHdrFtr,(const gchar * ) pszHdrFtrID);
 
 	if(hdrSDH == NULL)
 	{
@@ -303,7 +304,7 @@ void IE_Exp_RTF::exportHdrFtr(const char * pszHdrFtr , const char * pszHdrFtrID,
 	}
 	PT_DocPosition posStart = getDoc()->getStruxPosition(hdrSDH);
 	PT_DocPosition posEnd = 0;
-	PL_StruxDocHandle nextSDH = NULL;
+	pf_Frag_Strux* nextSDH = NULL;
 	bool found = getDoc()->getNextStruxOfType(hdrSDH,PTX_SectionHdrFtr ,&nextSDH);
 
 	if(!found || (nextSDH == NULL ))
@@ -662,6 +663,15 @@ void IE_Exp_RTF::_rtf_pcdata(UT_UTF8String &sPCData, bool bSupplyUC, UT_uint32 i
 	write(sEscapedData.utf8_str());
 }
 
+/*
+ * Access functions for above
+ */
+void IE_Exp_RTF::_rtf_pcdata(const std::string & szPCData, bool bSupplyUC, UT_uint32 iAltChars)
+{
+	UT_UTF8String str(szPCData);
+	_rtf_pcdata(str, bSupplyUC, iAltChars);
+}
+
 /*
  * Access functions for above
  */
@@ -1011,7 +1021,7 @@ bool IE_Exp_RTF::_write_rtf_header(void)
 // Write out the facingp and titlepg keywords so that we can export our fancy
 // header-footers to RTF
 //
-	PL_StruxDocHandle sdh = NULL;
+	pf_Frag_Strux* sdh = NULL;
 	getDoc()->getStruxOfTypeFromPosition(2,PTX_Section,&sdh);
 	if(sdh != NULL)
 	{
@@ -1102,8 +1112,10 @@ bool IE_Exp_RTF::_write_rtf_header(void)
         if( getDocRange() )
         {
             PD_DocumentRDFHandle rdf = getDoc()->getDocumentRDF();
-            std::list< std::string > xmlids;
+            std::set< std::string > xmlids;
             rdf->addRelevantIDsForRange( xmlids, getDocRange() );
+            UT_DEBUGMSG(("MIQ: RTF export creating restricted RDF model xmlids.sz:%lu\n", 
+						 (unsigned long)xmlids.size()));
             PD_RDFModelHandle subm = rdf->createRestrictedModelForXMLIDs( xmlids );
             std::string rdfxml = toRDFXML( subm );
             _rtf_chardata( s_escapeXMLString(rdfxml) );
@@ -1328,7 +1340,7 @@ const gchar * IE_Exp_RTF::_getStyleProp(
  * does not print opening and closing braces.
  */
 void IE_Exp_RTF::_write_parafmt(const PP_AttrProp * pSpanAP, const PP_AttrProp * pBlockAP, const PP_AttrProp * pSectionAP,
-								bool & bStartedList, PL_StruxDocHandle sdh, UT_uint32 & iCurrID, bool &bIsListBlock,
+								bool & bStartedList, pf_Frag_Strux* sdh, UT_uint32 & iCurrID, bool &bIsListBlock,
 								UT_sint32 iNestLevel)
 {
 	const gchar * szTextAlign = PP_evalProperty("text-align",pSpanAP,pBlockAP,pSectionAP,getDoc(),true);
@@ -1373,7 +1385,7 @@ void IE_Exp_RTF::_write_parafmt(const PP_AttrProp * pSpanAP, const PP_AttrProp *
 
 	const gchar * szPattern = PP_evalProperty("shading-pattern",pSpanAP,pBlockAP,pSectionAP,getDoc(),true);
 	const gchar * szShadingForeCol =  PP_evalProperty("shading-foreground-color",pSpanAP,pBlockAP,pSectionAP,getDoc(),true);
-	const gchar * szShadingBackCol =  PP_evalProperty("shading-background-color",pSpanAP,pBlockAP,pSectionAP,getDoc(),true);
+	//const gchar * szShadingBackCol =  PP_evalProperty("shading-background-color",pSpanAP,pBlockAP,pSectionAP,getDoc(),true);
 
 
 	// TODO add other properties here
@@ -1705,9 +1717,12 @@ void IE_Exp_RTF::_write_parafmt(const PP_AttrProp * pSpanAP, const PP_AttrProp *
 			{
 				UT_uint32 j,len;
 				len = UT_UCS4_strlen(tmp);
-				for(j=0;j<=len;j++)
-					p[j] = (char) (unsigned char) *tmp++;
-				_rtf_chardata(p,len);
+				write(" ");
+				for(j=0;j < len;j++)
+				{
+					std::string sBullet = UT_std_string_sprintf("\\u%d",(UT_sint32)tmp[j]);
+					write(sBullet.c_str());
+				}
 			}
 			_rtf_close_brace();
 		}
@@ -2069,7 +2084,7 @@ void IE_Exp_RTF::_write_charfmt(const s_RTF_AttrPropAdapter & apa)
 }
 
 void IE_Exp_RTF::_output_revision(const s_RTF_AttrPropAdapter & apa, bool bPara,
-								  PL_StruxDocHandle sdh, UT_sint32 iNestLevel,
+								  pf_Frag_Strux* sdh, UT_sint32 iNestLevel,
 								  bool & bStartedList,  bool &bIsListBlock, UT_uint32 &iCurrID)
 {
 	const gchar *szRevisions = apa.getAttribute("revision");
@@ -2188,9 +2203,9 @@ void IE_Exp_RTF::_output_revision(const s_RTF_AttrPropAdapter & apa, bool bPara,
 			const char * pADauth = bPara ? "pnrauth" : "revauth";
 			const char * pADdttm = bPara ? "pnrdate" : "revdttm";
 			
-			const char * pDEL     = "deleted";
-			const char * pDELauth = "revauthdel";
-			const char * pDELdttm = "revdttmdel";
+			const char pDEL[]     = "deleted";
+			const char pDELauth[] = "revauthdel";
+			const char pDELdttm[] = "revdttmdel";
 
 			// it seems that block props cannot be changed in rev mode
 			const char * pCHauth = bPara ? NULL : "crauth";
@@ -2809,9 +2824,8 @@ void IE_Exp_RTF::_output_LevelText(fl_AutoNum * pAuto, UT_uint32 iLevel, UT_UCSC
 	}
 	else
 	{
-		_rtf_nonascii_hex2(1);
-		_rtf_nonascii_hex2((UT_sint32) bulletsym);
-		write(" ");
+		std::string sBullet = UT_std_string_sprintf(" \\u%d",(UT_sint32) bulletsym);
+		write(sBullet.c_str());
 		write(";");
 		_rtf_close_brace();
 		_rtf_open_brace();
@@ -2973,7 +2987,6 @@ void IE_Exp_RTF::_output_ListRTF(fl_AutoNum * pAuto, UT_uint32 iLevel)
 {
 // List Type
 	UT_sint32 Param = 0;
-	UT_String fontName;
 	UT_UCSChar bulletsym=0;
 	FL_ListType lType = NUMBERED_LIST;
 	if(pAuto != NULL)
@@ -3007,58 +3020,51 @@ void IE_Exp_RTF::_output_ListRTF(fl_AutoNum * pAuto, UT_uint32 iLevel)
 		break;
 	case BULLETED_LIST:
 		Param = 23;
-		bulletsym = 0xb7;
-		fontName = "Symbol";
+		bulletsym = 0x2022;
 		break;
 	case DASHED_LIST:
 		Param = 23;
-		bulletsym = '-';
-		fontName = "Times New Roman";
+		bulletsym = 0x002D;
 		break;
 	case SQUARE_LIST:
 		Param = 23;
-		bulletsym = 0x6E;
-		fontName = "Dingbats";
+		bulletsym = 0x25A0;
 		break;
 	case TRIANGLE_LIST:
 		Param = 23;
-		bulletsym = 0x73;
-		fontName = "Dingbats";
+		bulletsym = 0x25B2;
 		break;
 	case DIAMOND_LIST:
 		Param = 23;
-		bulletsym = 0xA9;
-		fontName = "Dingbats";
+		bulletsym = 0x2666;
 		break;
 	case STAR_LIST:
 		Param = 23;
-		bulletsym = 0x53;
-		fontName = "Dingbats";
+		bulletsym = 0x2733;
 		break;
 	case IMPLIES_LIST:
 		Param = 23;
-		bulletsym = 0xDE;
-		fontName = "Dingbats";
+		bulletsym = 0x21D2;
 		break;
 	case TICK_LIST:
 		Param = 23;
-		bulletsym = 0x33;
-		fontName = "Dingbats";
+		bulletsym = 0x2713;
 		break;
 	case BOX_LIST:
 		Param = 23;
-		bulletsym = 0x72;
-		fontName = "Dingbats";
+		bulletsym = 0x2752;
 		break;
 	case HAND_LIST:
 		Param = 23;
-		bulletsym = 0x2B;
-		fontName = "Dingbats";
+		bulletsym = 0x261E;
 		break;
 	case HEART_LIST:
 		Param = 23;
-		bulletsym = 0xAA;
-		fontName = "Dingbats";
+		bulletsym = 0x2665;
+		break;
+	case ARROWHEAD_LIST:
+		Param = 23;
+		bulletsym = 0x27A3;
 		break;
 	}
 	_rtf_keyword("levelnfc",Param);
@@ -3091,7 +3097,7 @@ void IE_Exp_RTF::_output_ListRTF(fl_AutoNum * pAuto, UT_uint32 iLevel)
 //
 	else
 	{
-		PL_StruxDocHandle sdh = pAuto->getFirstItem();
+		pf_Frag_Strux* sdh = pAuto->getFirstItem();
 		const char * szIndent = NULL;
 		const char * szAlign = NULL;
 		// TODO -- we have a problem here; props and attrs are, due to revisions, view dependent and
@@ -3116,25 +3122,6 @@ void IE_Exp_RTF::_output_ListRTF(fl_AutoNum * pAuto, UT_uint32 iLevel)
 // Leveltext and levelnumbers
 //
 	_output_LevelText(pAuto,iLevel,bulletsym);
-//
-// Export the bullet font
-//
-	if(Param == 23)
-	{
-			{
-				_rtf_font_info fi;
-
-				if (fi.init(fontName.c_str())) {
-					UT_sint32 ifont = _findFont(&fi);
-					if(ifont < 0)
-					{
-						UT_ASSERT_NOT_REACHED();
-						ifont = 0;
-					}
-					_rtf_keyword("f",ifont);
-				}
-			}
-	}
 }
 
 /*!
@@ -3327,7 +3314,7 @@ bool IE_Exp_RTF::s_escapeString( std::string& outStr, const std::string& inStr,
 std::string IE_Exp_RTF::s_escapeString( const std::string& inStr, UT_uint32 iAltChars )
 {
     UT_UTF8String sOutStr;
-    bool ret = s_escapeString( sOutStr, inStr.c_str(), inStr.length(), iAltChars );
+    /*bool ret =*/ s_escapeString( sOutStr, inStr.c_str(), inStr.length(), iAltChars );
     return (std::string)sOutStr.utf8_str();
 }
 
