@@ -127,14 +127,22 @@ bool IE_Imp::appendStruxFmt(pf_Frag_Strux * pfs, const gchar ** attributes)
 	}
 }
 
+bool IE_Imp::appendSpan ( const std::string& s )
+{
+	UT_UCS4String t( s );
+	return appendSpan( t.ucs4_str(), t.length() );
+}
+
+
 bool IE_Imp::appendSpan (const UT_UCSChar * p, UT_uint32 length)
 {
 	if (!m_isPaste)
 		return m_pDocument->appendSpan(p, length);
 	else
 		{
-			bool bRes = m_pDocument->insertSpan (m_dpos, p, length);
-			m_dpos += length;
+			UT_uint32 fragLength = 0;
+			bool bRes = m_pDocument->insertSpan (m_dpos, p, length, NULL, &fragLength);
+			m_dpos += fragLength;
 			return bRes;
 		}
 }
